#
# spec file for package kernel-xen
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%define srcversion 2.6.37
%define patchversion 2.6.37.6
%define variant %{nil}

%include %_sourcedir/kernel-spec-macros

%define build_flavor	xen
%define build_kdump	(%build_flavor == "kdump")
%define build_xen	(%build_flavor == "xen" || %build_flavor == "ec2")
%define build_vanilla	(%build_flavor == "vanilla")
%define build_ps3	(%build_flavor == "ps3")

%define build_src_dir %my_builddir/linux-%srcversion
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%define obj_install_dir %src_install_dir-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-obj

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,check-supported-list,group-source-files.pl,find-provides,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,configtool.pl,log.sh})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_KMSG_IDS CONFIG_SPLIT_PACKAGE CONFIG_ENTERPRISE_SUPPORT
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_base (%CONFIG_SPLIT_PACKAGE == "y")
%define split_extra (%CONFIG_SPLIT_PACKAGE == "y" && %CONFIG_ENTERPRISE_SUPPORT == "y")

%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif

Name:           kernel-xen
Summary:        The Xen Kernel
Version:        2.6.37.6
Release:        0.11.1
%if %using_buildservice
%else
%endif
License:        GPL v2 only
Group:          System/Kernel
Url:            http://www.kernel.org/
AutoReqProv:    on
BuildRequires:  coreutils module-init-tools sparse
BuildRequires:  fdupes
Provides:       multiversion(kernel)
Provides:       %{name}_%_target_cpu = %version-%release
Provides:       %name = %version-%source_rel
%if %split_base
Provides:       kernel-base = %version-%source_rel
# Obsolete the -base subpackage from 11.1 and 11.2 development phase
Obsoletes:      %name-base <= 2.6.31
%endif
Requires(pre):  coreutils awk
# Need a module-init-tools with /usr/lib/module-init-tools/weak-modules2
Requires(post): module-init-tools >= 3.4
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if 0%{?suse_version} >= 1130
Requires(post): mkinitrd >= 2.6.0
%else
Requires(post): mkinitrd
%endif
#!BuildIgnore:  perl-Bootloader mkinitrd

%ifarch ia64
# arch/ia64/scripts/unwcheck.py
BuildRequires:  python
%endif
%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%if %build_xen
%ifarch %ix86
%if %build_flavor != "ec2"
Provides:       kernel-xenpae = %version
Obsoletes:      kernel-xenpae <= %version
%endif
%endif
#!BuildIgnore:  xen
%endif

Provides:       %name-nongpl
Obsoletes:      %name-nongpl
%if %build_vanilla
# force bzip2 instead of lzma compression to allow install on older dist versions
%define _binary_payload w9.bzdio
%endif
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
%if ! %build_vanilla
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
%endif
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel

Source0:        http://www.kernel.org/pub/linux/kernel/v2.6/linux-%srcversion.tar.bz2
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source34:       check-supported-list
Source35:       group-source-files.pl
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       config-options.changes.txt
Source40:       source-timestamp
Source44:       find-provides
Source45:       split-modules
Source46:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-packages.conf
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source66:       configtool.pl
Source67:       log.sh
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source107:      patches.xen.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source112:      patches.trace.tar.bz2
Source113:      patches.kabi.tar.bz2
Source120:      kabi.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86 x86_64

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       107
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       112
NoSource:       113
NoSource:       120

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# sles10 / 10.3
Obsoletes:      iwlwifi-kmp-%build_flavor
Obsoletes:      ipw3945-kmp-%build_flavor
# sles10 / 11.0
Obsoletes:      uvcvideo-kmp-%build_flavor
# 11.0
Obsoletes:      atl2-kmp-%build_flavor
Obsoletes:      wlan-ng-kmp-%build_flavor
Obsoletes:      et131x-kmp-%build_flavor
Obsoletes:      ivtv-kmp-%build_flavor
Obsoletes:      at76_usb-kmp-%build_flavor
Obsoletes:      pcc-acpi-kmp-%build_flavor
Obsoletes:      btusb-kmp-%build_flavor
# sle11-ga
Obsoletes:      enic-kmp-%build_flavor
Obsoletes:      fnic-kmp-%build_flavor
Obsoletes:      brocade-bfa-kmp-%build_flavor
Obsoletes:      kvm-kmp-%build_flavor
Obsoletes:      perfmon-kmp-%build_flavor
Obsoletes:      iwlagn-2-6-27-kmp-%build_flavor
Obsoletes:      msi-wmi-kmp-%build_flavor
# sle11
Obsoletes:      ocfs2-kmp-%build_flavor
# 11.1
Obsoletes:      quickcam-kmp-%build_flavor < 0.6.7

# Provide the exported symbols as "ksym(symbol) = hash"
%define __find_provides %_sourcedir/find-provides %name

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 0

%description
The Linux kernel for Xen paravirtualization.

This kernel can be used both as the domain0 ("xen0") and as an
unprivileged ("xenU") kernel.


%source_timestamp
%prep
if ! [ -e %_sourcedir/linux-%srcversion.tar.bz2 ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 107 -a 108 -a 109 -a 110 -a 111 -a 112 -a 113 -a 120

mkdir -p %kernel_build_dir

supported_conf() {
	%_sourcedir/guards $* < %_sourcedir/supported.conf | \
	sed 's,.*/,,; s,\.ko$,,' | sort -u
}

# Generate the list of modules to be marked as supported
{   supported_conf base
    supported_conf --default=0 external | sed 's/$/ external/'
} > %kernel_build_dir/Module.supported
supported_conf --default=0 base >%kernel_build_dir/Module.base

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

if test -e ../config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	%_sourcedir/configtool.pl ../config{,.addon}/%cpu_arch_flavor >.config
else
	cp ../config/%cpu_arch_flavor .config
fi
%build_src_dir/scripts/config \
	--set-str CONFIG_LOCALVERSION %release_num-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO \
	--disable  CONFIG_DEBUG_INFO_REDUCED
%else
	--disable CONFIG_DEBUG_INFO
%endif

MAKE_ARGS="$MAKE_ARGS -C %build_src_dir O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS
else
    cp .config .config.orig
    make silentoldconfig $MAKE_ARGS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d -printf '%%P\n' > %my_builddir/obj-files

cat > .kernel-binary.spec.buildenv <<EOF
# Override the timestamp 'uname -v' reports with the build
# timestamp.
export KBUILD_BUILD_VERSION="$(grep SHA1_ID %_sourcedir/source-timestamp | awk '{ print $2 }')"
export KBUILD_BUILD_TIMESTAMP="$(head -n 1 %_sourcedir/source-timestamp)"

# The following branch/timestamp will end up in Oopses.
export OOPS_TIMESTAMP="$(
    echo -n $(sed -ne 's/^GIT Branch: \(.*\)/\1-/p' \
		  %_sourcedir/source-timestamp)
    head -n 1 %_sourcedir/source-timestamp \
	| tr -dc 0-9)"

export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
EOF

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# If the %jobs macro is defined to a number, make will spawn that many jobs.
# There are several ways how to define it:
# If you are using the build script:
#     build --jobs=N kernel-$flavor.spec
# With plain rpmbuild:
#     rpmbuild -ba --define 'jobs N' kernel-$flavor.spec
# To spawn as many jobs as there are cpu cores:
#     rpmbuild -ba --define "jobs 0$(grep -c ^processor /proc/cpuinfo)" \
#         kernel-$flavor.spec
# You can also set this permanently in ~/.rpmmacros:
#     %jobs 0%(grep -c ^processor /proc/cpuinfo)
%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../linux-%srcversion/scripts/kmsg-doc
    make %{?jobs:-j%jobs} all $MAKE_ARGS CONFIG_DEBUG_SECTION_MISMATCH=y D=2
%else
    make %{?jobs:-j%jobs} all $MAKE_ARGS CONFIG_DEBUG_SECTION_MISMATCH=y
%endif

%install

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/build will be a stale symlink until the
# kernel-devel package is installed. Don't check for stale symlinks
# in the brp-symlink check:
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor compressed=false

    if test $1 == "--compressed"; then
        compressed=true
    fi
    cp vmlinux %buildroot/$vmlinux
    >%my_builddir/vmlinux.debug.files
%if 0%{?__debug_package:1}
    if $compressed; then
        local vmlinux_debug=usr/lib/debug/$vmlinux.debug
        mkdir -p $(dirname %buildroot/$vmlinux_debug)
        /usr/lib/rpm/debugedit -b $RPM_BUILD_DIR -d /usr/src/debug \
    			   -l vmlinux.sourcefiles %buildroot/$vmlinux
        # FIXME: create and package build-id symlinks
        objcopy --only-keep-debug \
    	    %buildroot/$vmlinux \
    	    %buildroot/$vmlinux_debug || :
        objcopy --add-gnu-debuglink=%buildroot/$vmlinux_debug \
    	    --strip-debug \
    	    %buildroot/$vmlinux || :
        mkdir -p %buildroot/usr/src/debug
        LANG=C sort -z -u vmlinux.sourcefiles | grep -Ezv "<(built-in|stdin)>" \
    	| ( cd %_builddir && cpio -pd0m %buildroot/usr/src/debug )
        find %buildroot/usr/src/debug -type d -print0 | xargs -0 -r chmod 0755
        find %buildroot/usr/src/debug -type f -print0 | xargs -0 -r chmod 0644
        echo -e "%%defattr(-, root, root)\\n/$vmlinux_debug" >%my_builddir/vmlinux.debug.files
    else
        # make vmlinux executable so that find-debuginfo.sh picks it up
        # (TODO: fix find-debuginfo.sh instead)
        chmod +x %buildroot/$vmlinux
    fi
%endif
    if $compressed; then
	gzip -9 %buildroot/$vmlinux
        chmod a-x %buildroot/$vmlinux.gz
    fi
}

%if %build_kdump
    add_vmlinux
    image=vmlinux
%else

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
%if %build_xen
    image=vmlinuz
%else
    image=bzImage
%endif
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch alpha
    add_vmlinux --compressed
    cp -p arch/alpha/boot/vmlinux.gz %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64
    add_vmlinux
    image=vmlinux
%endif
%ifarch ia64
    add_vmlinux --compressed
    mv %buildroot/boot/vmlinux-%kernelrelease-%build_flavor.gz \
       %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    cp -p arch/s390/boot/image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
    if test -e arch/s390/boot/kerntypes.o; then
        cp -p arch/s390/boot/kerntypes.o %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor
    elif test -x "$(which dwarfextract 2>/dev/null)"; then
	dwarfextract vmlinux %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor || echo "dwarfextract failed ($?)"
    fi
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch sparc64
    add_vmlinux --compressed
    image=zImage
    cp -p arch/sparc/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinux
%endif

# end of build_kdump
%endif

for sub in '-base' '' '-extra'; do
    case "$sub" in
    '-base' | '') base_package=1 ;;
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
    done
done

%if %build_kdump || %build_xen || %build_vanilla || %build_ps3
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor

    gzip -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

    if ! %_sourcedir/check-supported-list \
	    %_sourcedir %buildroot/lib/modules/%kernelrelease-%build_flavor; then
%if %supported_modules_check
	exit 1
%endif
	echo "Consistency check error: please update supported.conf."
    fi

%ifarch s390 s390x
    if test -e arch/s390/boot/kerntypes.o; then
        :
    elif test -x "$(which dwarfextract 2>/dev/null)" -a \
	-f %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor; then
	find %buildroot -name "*.ko" > kofiles.list
	dwarfextract %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor -C kofiles.list || echo "dwarfextract failed ($?)"
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%_target_cpu ]; then
	ln -sf %cpu_arch %rpm_install_dir/%_target_cpu
	ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

%if %split_base
    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir/Module.base \
	-s %kernel_build_dir/Module.supported
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

%else
    (   cd %buildroot
	find lib/modules/%kernelrelease-%build_flavor -type f -name '*.ko' -printf '/%%p\n'
    ) > %my_builddir/base-modules
%endif

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	if [ ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    tar -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Replace the absolute with a relative path
    sed -i "s,%build_src_dir,../../../linux-%kernelrelease%variant,g" \
	%rpm_install_dir/%cpu_arch_flavor/Makefile
fi

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/vmlinux-*.gz %buildroot/boot/symtypes* \
				%buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f" >> %my_builddir/kernel-devel.files
done

{   cd %buildroot
    find boot \
	\( -type l -o -name 'initrd-*' \) -printf '%%%%ghost /%%p\n' -o \
	-type f -name 'vmlinux-*' -printf '%%%%attr(0644, root, root) /%%p\n' -o \
        -type f -printf '/%%p\n'

    # Add the auto-generated (by mkdumprd) kdump initrd to %ghost so that
    # the file gets removed when uninstalling the kernel.
    echo '%%ghost /boot/initrd-%kernelrelease-kdump'
    touch $RPM_BUILD_ROOT/boot/initrd-%kernelrelease-kdump

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    test -d lib/firmware/%kernelrelease-%build_flavor && \
    find lib/firmware/%kernelrelease-%build_flavor \
	-type d -o \
	-printf '/%%p\n'
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u >%my_builddir/tmp
cat %my_builddir/tmp %my_builddir/kernel-devel.files | sort | uniq -u | \
    add_dirs_to_filelist >%my_builddir/kernel-base.files
rm %my_builddir/tmp

%if %split_base
    add_dirs_to_filelist %my_builddir/{kernel-base.files,main-modules} \
	> %my_builddir/kernel-main.files
%endif
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%endif

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%if %split_base

%files -f kernel-main.files
%else

%files -f kernel-base.files
%endif
%defattr(-, root, root)

%package base
Summary:        The Xen Kernel - base modules
License:        GPL v2 only
Group:          System/Kernel
Url:            http://www.kernel.org/
AutoReqProv:    on
Provides:       multiversion(kernel)
Provides:       kernel-base = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): module-init-tools
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
The Linux kernel for Xen paravirtualization.

This kernel can be used both as the domain0 ("xen0") and as an
unprivileged ("xenU") kernel.

This package contains only the base modules, required in all installs.


%source_timestamp
%preun base -f preun-base.sh

%postun base -f postun-base.sh

%pre base -f pre-base.sh

%post base -f post-base.sh

%if %split_base

%files base -f kernel-base.files
%defattr(-, root, root)
%endif

%package extra
Summary:        The Xen Kernel - Unsupported kernel modules
License:        GPL v2 only
Group:          System/Kernel
Url:            http://www.kernel.org/
AutoReqProv:    on
Provides:       multiversion(kernel)
Provides:       %name-extra_%_target_cpu = %version-%release
Provides:       kernel-extra = %version-%source_rel
Requires:       %{name}_%_target_cpu = %version-%release
Requires(pre):  coreutils awk
Requires(post): module-init-tools
Requires(post): perl-Bootloader
Requires(post): mkinitrd
Supplements:    packageand(product(SUSE_SLED):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description extra
The Linux kernel for Xen paravirtualization.

This kernel can be used both as the domain0 ("xen0") and as an
unprivileged ("xenU") kernel.

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script.
License:        GPL v2 only
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
License:        GPL v2 only
Group:          Development/Sources
Provides:       multiversion(kernel)
Provides:       %name-devel = %version-%source_rel
Requires:       kernel-devel%variant = %version-%source_rel
Supplements:    packageand(%name:kernel-devel%variant)
AutoReqProv:    on

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp
%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%if %_target_cpu != %cpu_arch
%obj_install_dir/%_target_cpu
/usr/src/linux-obj/%_target_cpu
%endif
%endif

%package devel-debuginfo
# rpm doesn't notice that vmlinux.debug belongs to the gzipped vmlinux.gz
Summary:        Debug information for package %name-devel
License:        GPL v2 only
Group:          Development/Debug

%description devel-debuginfo
Debug information for package %name-devel


%source_timestamp
%files devel-debuginfo -f vmlinux.debug.files

%changelog
* Mon Dec 19 2011 bpoirier@suse.de
- econet: 4 byte infoleak to the network (bnc#681184
  CVE-2011-1173).
- commit d3bfb6d
* Sun Dec 18 2011 bpoirier@suse.de
- ipv6: netfilter: ip6_tables: fix infoleak to userspace
  (bnc#681185 CVE-2011-1172).
- commit 869dd96
* Tue Dec 13 2011 bpoirier@suse.de
- batman-adv: Only write requested number of byte to user buffer
  (bnc#736149 CVE-2011-4604).
- batman-adv: bat_socket_read missing checks (bnc#736149
  CVE-2011-4604).
- commit 07f855d
* Thu Dec  8 2011 bpoirier@suse.de
- ipv6: fix NULL dereference in udp6_ufo_fragment() (bnc#707288
  CVE-2011-2699).
- commit 2d6bb88
* Mon Dec  5 2011 bpoirier@suse.de
- netfilter: ip_tables: fix infoleak to userspace (bnc#681181
  CVE-2011-1171).
- commit e090058
* Mon Dec  5 2011 bpoirier@suse.de
- netfilter: arp_tables: fix infoleak to userspace (bnc#681180
  CVE-2011-1170).
- commit 8b41f28
* Fri Dec  2 2011 bpoirier@suse.de
- bridge: netfilter: fix information leak (bnc#676602
  CVE-2011-1080).
- commit 62c3d6e
* Thu Dec  1 2011 mhocko@suse.cz
- Refresh
  patches.fixes/cgroup_freezer_freeze_stopped_tasks_correctly.patch.
- commit 22bd277
* Thu Dec  1 2011 jbeulich@novell.com
- patches.xen/1124-x86-undo-limit-pages.patch: x86: undo_limit_pages()
    must reset page count.
- patches.xen/1126-netback-invalidation-index.patch: netback: use correct
    index for invalidation in netbk_tx_check_mop().
- patches.xen/xen3-patch-2.6.37: Add barrier emulation to blkback.
- Refresh other Xen patches.
- commit 36149a1
* Thu Dec  1 2011 bpoirier@suse.de
- inet_diag: fix inet_diag_bc_audit() (bnc#700879 CVE-2011-2213).
- commit 12c0a80
* Thu Nov 24 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch: Add missing git-commit.
- commit 350fcc8
* Wed Nov 23 2011 jdelvare@suse.de
- hwmon: (max1111) Fix race condition causing NULL pointer
  exception.
- hwmon: (it87) Fix label group removal.
- hwmon: (coretemp) Fix TjMax detection for older CPUs.
- hwmon: (coretemp) Relax target temperature range check.
- hwmon: (asus_atk0110) Fix memory leak.
- i2c/pca954x: Initialize the mux to disconnected state.
- commit f33e890
* Wed Nov 23 2011 jdelvare@suse.de
- Move drm-radeon-kms-fix-up-gpio-i2c-mask-bits-for-r4xx.patch to a better place
- commit 5da68df
* Tue Nov 22 2011 jdelvare@suse.de
- drm/radeon/kms: fix up gpio i2c mask bits for r4xx (bnc#691052).
- commit 1b9d079
* Tue Nov 22 2011 mhocko@suse.cz
- cgroup_freezer: fix freezing groups with stopped tasks
  (bnc#713933).
- commit fef1462
* Mon Nov 21 2011 bpoirier@suse.de
- netfilter: ipt_CLUSTERIP: fix buffer overflow (bnc#702037
  CVE-2011-2534).
- commit 6480665
* Fri Nov 18 2011 bpoirier@suse.de
- dccp: handle invalid feature options length (bnc#692498
  CVE-2011-1770).
- commit fa6032a
* Tue Nov 15 2011 bpoirier@suse.de
- ipv6: make fragment identifications less predictable (bnc#707288
  CVE-2011-2699).
- commit 9c1c64f
* Tue Nov 15 2011 jbeulich@novell.com
- re-introduce machine_to_phys_order for kABI consistency.
- commit 5dbc86b
* Tue Nov 15 2011 jbeulich@novell.com
- patches.xen/1101-x86-m2p-nr.patch: x86: replace order-based range
    checking of M2P table by linear one.
- Refresh other Xen patches.
- commit 8dd9722
* Mon Nov 14 2011 bpoirier@suse.de
- gro: Only reset frag0 when skb can be pulled (bnc#709764
  CVE-2011-2723).
- commit e289f56
* Mon Nov 14 2011 bpoirier@suse.de
- igbvf: Remove extra struct page member
  (http://article.gmane.org/gmane.linux.network/180760).
- commit 1ad2feb
* Fri Nov 11 2011 bpoirier@suse.de
- af_packet: prevent information leak (bnc#710235 CVE-2011-2898).
- commit 1e4accd
* Mon Nov  7 2011 neilb@suse.de
- sunrpc: wake up SOFTCONN tasks when a connection error happens
  (bnc#679059).
- commit 561328d
* Fri Nov  4 2011 jbohac@suse.cz
- ip: ip_options_compile() resilient to NULL skb route
  (bnc#709561, CVE-2011-4087).
- bridge: reset IPCB in br_parse_ip_options (bnc#709561,
  CVE-2011-4087).
- commit af1bd88
* Thu Nov  3 2011 mszeredi@suse.cz
- patches.fixes/hfs-fix-hfs_find_init-sb-ext_tree-null-ptr-oops.patch:
    hfs: fix hfs_find_init() sb->ext_tree NULL ptr oops
    (CVE-2011-2203 bnc#699709).
- commit 726dc6b
* Thu Nov  3 2011 jeffm@suse.com
- crypto: ghash - Avoid null pointer dereference if no key is set
  (CVE-2011-4081 bnc#726788).
- commit fc6977d
* Thu Nov  3 2011 jdelvare@suse.de
- patches.fixes/drm-radeon-kms-fix-i2c-masks.patch: Add git commit ID.
- commit 7178a7a
* Thu Nov  3 2011 mhocko@suse.cz
- oom: thaw threads if oom killed thread is frozen before
  deferring (bnc#723999).
- commit b5cde4c
* Thu Nov  3 2011 jdelvare@suse.de
- i8k: Avoid lahf in 64-bit code.
- i2c-taos-evm: Fix log messages.
- pata_it821x: Fix RAID type display.
- commit a6c42a9
* Wed Oct 19 2011 mszeredi@suse.cz
- Ecryptfs: Add mount option to check uid of device being mounted
  = expect uid (bnc#711539 CVE-2011-1833).
- commit 449d08f
* Tue Oct 18 2011 jack@suse.cz
- novfs: Unable to change password in the Novell Client for Linux
  (bnc#713229).
- novfs: last modification time not reliable (bnc#642896).
- novfs: unlink directory after unmap (bnc#649625).
- fs: novfs: Fix exit handlers on local_unlink (bnc#649625).
- novfs: "Unable to save Login Script" appears when trying to save a
  user login script (bnc#638985).
- fs: novfs: Limit check for datacopy between user and kernel
  space.
- novfs: Fix checking of login id (bnc#626119).
- novfs: Set the sticky bit for the novfs mountpoint (bnc#686412).
- commit db66ffa
* Fri Oct  7 2011 trenn@suse.de
- ACPICA: Fix issues/fault with automatic "serialized" method
  support (bnc#678097).
- commit 70b5e9f
* Thu Oct  6 2011 jdelvare@suse.de
- Include patches.fixes/drm-radeon-kms-fix-i2c-masks.patch, forgotten in previous commit.
- commit 1fc91ef
* Thu Oct  6 2011 jdelvare@suse.de
- drm/radeon/kms: Fix I2C mask definitions (bnc#712023).
- commit d5bb2d7
* Wed Oct  5 2011 jack@suse.cz
- ext4: Fix max file size and logical block counting of extent
  format file (bnc#706374).
- commit e2db9d3
* Wed Oct  5 2011 jack@suse.cz
- novfs: fix off-by-one allocation error (bnc#669378 bnc#719710).
- novfs: fix some kmalloc/kfree issues (bnc#669378 bnc#719710).
- novfs: fix some DirCache locking issues (bnc#669378 bnc#719710).
- commit b7b0bf4
* Mon Oct  3 2011 sjayaraman@suse.de
- cifs: add fallback in is_path_accessible for old servers
  (bnc#718028).
- commit df7c1aa
* Fri Sep 30 2011 mhocko@suse.cz
- memsw: remove noswapaccount kernel parameter (bnc#719450).
- commit a3f8429
* Wed Sep 28 2011 tonyj@suse.de
- perf: Fix software event overflow (bnc#712366, CVE-2011-2918).
- commit 3d0d5e6
* Fri Sep 23 2011 mszeredi@suse.cz
- patches.fixes/fuse-check-size-of-fuse_notify_inval_entry-message.patch:
    fuse: check size of FUSE_NOTIFY_INVAL_ENTRY message (bnc#716901
    CVE-2011-3353).
- commit af7133e
* Wed Sep 21 2011 mhocko@suse.cz
- Provide memory controller swap extension.
  Keep the feature disabled by default. Use swapaccount=1 kernel boot
  parameter for enabling it.
- commit 5e87389
* Wed Sep 21 2011 mhocko@suse.cz
- Config cleanups.
  CONFIG_OLPC should be enabled only for i386 non PAE
- commit 8bf194e
* Mon Sep 19 2011 mgorman@suse.de
- patches.fixes/ksm-fix-null-pointer-dereference-in-scan_get_next_rmap_item.patch
    ksm: fix NULL pointer dereference in scan_get_next_rmap_item
    (bnc#697901, CVE-2011-2183)
- commit 3ae69fc
* Sun Sep 18 2011 sjayaraman@suse.de
- Update
  patches.fixes/cifs-always-do-is_path_accessible-check-in-cifs_moun.patch
  (bnc#718028, CVE-2011-3363).
- commit c0f21d9
* Sun Sep 18 2011 sjayaraman@suse.de
- cifs: always do is_path_accessible check in cifs_mount
  (bnc#718028).
- commit d807f2a
* Thu Sep  8 2011 jdelvare@suse.de
- Add Git-commit tag to
  patches.fixes/i2c-algo-bit-call-pre-post_xfer-for-bit_test.patch.
- commit 78e929f
* Wed Aug 31 2011 jslaby@suse.cz
- Refresh patches.fixes/pty-fix-pty-counting.patch.
- commit 2ddb3ad
* Wed Aug 31 2011 jslaby@suse.cz
- TTY: pty, fix pty counting (bnc#711203).
- commit a76e300
* Mon Aug 29 2011 sjayaraman@suse.de
- cifs: fix possible memory corruption in CIFSFindNext
  (bnc#714001, CVE-2011-3191).
- commit 673f74b
* Mon Aug 22 2011 gregkh@suse.de
- USB: OHCI: fix another regression for NVIDIA controllers
  (bnc#682204).
- commit 7dccae1
* Wed Aug 17 2011 jbeulich@novell.com
- patches.xen/1098-blkfront-cdrom-ioctl-check.patch: blkfront: avoid
    NULL de-reference in CDROM ioctl handling.
- Refresh other Xen patches.
- commit bcddc83
* Fri Aug 12 2011 mszeredi@suse.cz
- patches.fixes/validate-size-of-efi-guid-partition-entries.patch:
    Validate size of EFI GUID partition entries (bnc#692784,
    CVE-2011-1776).
- commit dfa7ecf
* Mon Aug  1 2011 trenn@suse.de
- x86, mtrr: lock stop machine during MTRR rendezvous sequence
    (bnc#672008).
- Delete patches.arch/mtrr_stop_machine_quick_fix.patch.
- commit add3681
* Thu Jul 21 2011 neilb@suse.de
- nfsd4: Fix filp leak (bnc#704788).
- commit 3259ca5
* Wed Jul 20 2011 jeffm@suse.com
- proc: restrict access to /proc/PID/io (CVE-2011-2495
  bnc#703155).
- commit 88ff195
* Wed Jul 20 2011 jeffm@suse.com
- taskstats: don't allow duplicate entries in listener mode
  (CVE-2011-2484 bnc#703153).
- commit b731e93
* Tue Jul 19 2011 eich@suse.de
- Update patches.fixes/agp-fix-arbitrary-kernel-memory-write.patch
  (bnc#693043, bnc#689797, CVE-2011-2022, CVE-2011-1745).
- commit afd8b52
* Mon Jul 18 2011 eich@suse.de
- agp: fix arbitrary kernel memory writes (bnc#693043,
  CVE-2011-2022).
- commit 084cd2e
* Fri Jul 15 2011 neilb@suse.de
- nfsd4: fix oops on lock failure (bnc#704788).
- commit 9e49458
* Wed Jul 13 2011 jack@suse.cz
- ext4: init timer earlier to avoid a kernel panic in
  __save_error_info (bnc#701998).
- commit e23080a
* Mon Jul 11 2011 eich@suse.de
- Remove patches.arch/x86_agpgart-g33-stoeln-fix-2.patch.
  Since calculation of available gtt entries is done differently
  oops fixed by this patch should no longer occur.
- commit df7b5c1
* Mon Jul 11 2011 mhocko@suse.de
- Hide new tk_rebind_retry from kABI checker (bnc#702013).
- NLM: Don't hang forever on NLM unlock requests (bnc#702013
  CVE-2011-2491).
- commit c1d1975
* Mon Jul  4 2011 tiwai@suse.de
- Fix invalid color overrides in bootsplash consoles (bnc#584493).
- commit 1c226c4
* Thu Jun 30 2011 jankit@suse.de
- Blacklist Traxdata CDR4120 and IOMEGA Zip drive to avoid lock
  ups (bnc# 681840).
- commit 6134f03
* Wed Jun 29 2011 jslaby@suse.cz
- TTY: ldisc, do not close until there are readers (bnc#698247
  bnc#693374).
- commit d0e7740
* Wed Jun 29 2011 mhocko@suse.cz
- oom: use pte pages in OOM score (bnc#702579 CVE-2011-2498).
- commit fc437c7
* Tue Jun 28 2011 mhocko@suse.cz
- mm: avoid wrapping vm_pgoff in mremap() (bnc#702285,
  CVE-2011-2496).
- vm: fix vm_pgoff wrap in upward expansion (bnc#702285,
  CVE-2011-2496).
- commit 1b0815a
* Tue Jun 28 2011 mhocko@suse.cz
- vm: fix vm_pgoff wrap in stack expansion (bnc#702285,
  CVE-2011-2496).
- commit 3e5f682
* Mon Jun 27 2011 jbeulich@novell.com
- patches.xen/1080-blkfront-xenbus-gather-format.patch:
- patches.xen/1081-blkback-resize-transaction-end.patch:
- patches.xen/1089-blkback-barrier-check.patch:
- patches.xen/1090-blktap-locking.patch:
- patches.xen/1091-xenbus-dev-no-BUG.patch:
- Refresh other Xen patches (bnc#687368).
- commit ee5f632
* Thu Jun 23 2011 mhocko@suse.cz
- Fix for buffer overflow in ldm_frag_add not sufficient
  (bnc#698221, CVE-2011-1017, CVE-2011-2182).
- commit 3289cbf
* Wed Jun 22 2011 sjayaraman@suse.de
- cifs: set ra_pages in backing_dev_info (bnc#699123).
- commit dcda278
* Fri Jun 17 2011 trenn@suse.de
- x86, mtrr: lock stop machine during MTRR rendezvous sequence
  (bnc#697859).
- commit 1e07179
* Thu Jun 16 2011 jeffm@suse.com
- inotify: fix double free/corruption of stuct user (bnc#655693
    CVE-2011-1479).
- commit 05ac9a0
* Thu Jun 16 2011 tiwai@suse.de
- Fix bug numbers in previous commits
- commit 769d942
* Thu Jun 16 2011 tiwai@suse.de
- ALSA: fix hda AZX_DCAPS_NO_TCSEL quirk check in driver_caps
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda - Reorganize controller quriks with bit flags
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda - Use LPIB for ATI/AMD chipsets as default
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda - Enable snoop bit for AMD controllers
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda - Enable sync_write workaround for AMD generically
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda - ALSA HD Audio patch
  for Intel Panther Point DeviceIDs
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda: Prevent writing ICH6_PCIREG_TCSEL on AMD systems
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- ALSA: hda - Add support for VMware controller
  (bnc#700250,bnc#700251,bnc#700253,bnc#700254,bnc#700256,bnc#700257).
- commit e605dee
* Fri Jun  3 2011 trenn@suse.de
- workqueue: fix deadlock in worker_maybe_bind_and_lock()
  (bnc#672008 bnc#661979).
- commit 83e2ed5
* Tue May 31 2011 mmarek@suse.cz
- README.BRANCH: This is 11.4.
- commit 240e594
* Mon May 30 2011 jack@suse.cz
- vfs: Pass setxattr(2) flags properly (bnc#677827).
- commit 136d61a
* Mon May 30 2011 jack@suse.cz
- mm: Fix assertion mapping->nrpages == 0 in end_writeback()
    (bnc#693013 bnc#666423).
- Refresh patches.xen/tmem.
- commit 66646bf
* Tue May 24 2011 jbohac@suse.cz
- net: ip_expire() must revalidate route (bnc#694498,
  CVE-2011-1927).
- commit 17a2607
* Fri May 20 2011 jslaby@suse.cz
- proc: do proper range check on readdir offset (bnc#688432).
- next_pidmap: fix overflow condition (bnc#688432).
- commit d5ccd3f
* Mon May 16 2011 mhocko@suse.cz
- proc: fix oops on invalid /proc/<pid>/maps access (bnc#693382).
- commit 85dba47
* Sun May 15 2011 jslaby@suse.cz
- eeepc-laptop: Use ACPI handle to identify rfkill port
  (bnc#595586).
- commit 1c6d6bd
* Fri May 13 2011 mmarek@suse.cz
- Build the kotd against 11.4
- commit c41dee1
* Fri May 13 2011 mhocko@suse.cz
- memcg: allocate memory cgroup structures in local nodes
    (bnc#692502, bnc#669889).
- mm: add alloc_pages_exact_nid() (bnc#692502, bnc#669889).
- commit a803b7a
* Thu May 12 2011 sjayaraman@suse.de
- cifs: check for private_data before trying to put it
    (bnc#692497).
- commit 6fe591b
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/files-slab-rcu.patch.
- commit a8d226b
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.fixes/aggressive-zone-reclaim.patch: because
    the patch is very workload specific and can lead to unexpected
    reclaims in parallel node local workloads.
- commit 33bfbc3
* Tue May 10 2011 mhocko@suse.cz
- Delete patches.suse/mm-devzero-optimisation.patch: patch is no
    longer needed because we have zero page.
- commit 218d663
* Tue May 10 2011 jslaby@suse.cz
- deal with races in /proc/*/{syscall,stack,personality}
    (bnc#674982 CVE-2011-1020).
- auxv: require the target to be tracable (or yourself)
    (bnc#674982 CVE-2011-1020).
- close race in /proc/*/environ (bnc#674982 CVE-2011-1020).
- report errors in /proc/*/*map* sanely (bnc#674982
    CVE-2011-1020).
- pagemap: close races with suid execve (bnc#674982
    CVE-2011-1020).
- commit 1982421
* Tue May 10 2011 jslaby@suse.cz
- Update
    patches.fixes/prevent-rt_sigqueueinfo-from-spoofing-fix.patch
    (bnc#681826 CVE-2011-1182).
- commit b157cc0
* Mon May  9 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37.6.
- patches.xen/1074-xenbus_conn-type.patch:
- patches.xen/1079-hvm-kdump-reset.patch:
- Refresh other Xen patches.
- commit 1ea5fb7
* Tue May  3 2011 mszeredi@suse.cz
- fs/partitions/ldm.c: fix oops caused by corrupted partition
    table (CVE-2011-1017 bnc#674648).
- commit 1b3b736
* Thu Apr 28 2011 mfasheh@suse.com
- btrfs: return EXDEV when linking from different subvolumes
    (bnc#679545).
- commit 3a54105
* Tue Apr 26 2011 jslaby@suse.cz
- NET: cdc-phonet, fix stop-queue handling (bnc#689583).
- commit f8d7fa6
* Mon Apr 25 2011 jeffm@suse.com
- xen/i386: Add missing END for spurious_interrupt_bug.
- commit d0f6e4d
* Mon Apr 25 2011 jeffm@suse.com
- Enabled patches.kabi/sched-autogroup-fix-rt-group-sched.
- commit 3f5a598
* Mon Apr 25 2011 jeffm@suse.com
- kABI: Guard changes to struct autogroup (bnc#680510).
- commit 505e072
* Mon Apr 25 2011 jeffm@suse.com
- sched, autogroup: fix CONFIG_RT_GROUP_SCHED sched_setscheduler() failure (bnc#680510).
  The change is safe other than needing kABI guards.
- commit f417a2b
* Fri Apr 22 2011 jeffm@suse.com
- Revert "- sched, autogroup: fix CONFIG_RT_GROUP_SCHED sched_setscheduler() failure (bnc#680510)."
  This reverts commit e4e6f9738a1ac4837777f6480268c6cb56722d0c.
  This patch modified struct autogroup, which caused massive kABI changes.
- commit 401f90a
* Thu Apr 21 2011 jbohac@suse.cz
- bridge: fix 802.3ad bonding  (bnc#685469).
- commit 46ab2e4
* Thu Apr 21 2011 sjayaraman@suse.de
- Revert "net/sunrpc: Use static const char arrays" (bnc#668880).
- commit 446cab2
* Wed Apr 20 2011 jdelvare@suse.de
- i2c-algo-bit: Call pre/post_xfer for bit_test (bnc#669937,
    freedesktop#36221).
- commit 0eb4b26
* Tue Apr 19 2011 jack@suse.cz
- ext4: fix ext4_da_block_invalidatepages() to handle page range
    properly (bnc#679898).
- commit 9445b77
* Tue Apr 19 2011 jslaby@suse.cz
- mm: prevent concurrent unmap_mapping_range() on the same inode.
- Refresh
    patches.kabi/revert-mm-prevent-concurrent-unmap_mapping_range-on-.patch.
- commit f44f181
* Tue Apr 19 2011 jack@suse.cz
- ext4: mark multi-page IO complete on mapping failure
    (bnc#679898).
- commit 39ff8fe
* Tue Apr 19 2011 jeffm@suse.com
- Updated Patch-mainline for patches.fixes/libata-dvr-216d-can-t-do-setxfer-dvd-rw-dvr-216d.
- commit 3d54583
* Tue Apr 19 2011 jeffm@suse.com
- KABI: Re-export shrink_dcache_for_umount_subtree.
- commit cc0aa7f
* Mon Apr 18 2011 jslaby@suse.cz
- block: revert __invalidate_device prototype change.
- Delete
    patches.kabi/revert-Fix-over-zealous-flush_disk-when-changing-dev.patch.
- commit be37261
* Mon Apr 18 2011 jslaby@suse.cz
- block: revert __blk_run_queue prototype change.
- Delete
    patches.kabi/blk-revert-add-force_kblockd-to-__blk_run_queue.patch.
- Delete
    patches.kabi/blk-revert-blk-flush-shouldn-t-call-directly-into-.patch.
- commit 24a2e21
* Mon Apr 18 2011 jslaby@suse.cz
- Revert "Fix over-zealous flush_disk when changing device size.".
- commit 1dea4c1
* Mon Apr 18 2011 jslaby@suse.cz
- SoN: fix kABI breakage.
- Revert "block: add @force_kblockd to __blk_run_queue()".
- Revert "block: blk-flush shouldn't call directly into
    q->request_fn() __blk_run_queue()".
- Revert "mm: prevent concurrent unmap_mapping_range() on the
    same inode".
- DRM: revert drm_device num_crtcs change.
- Block: export lost functions.
- FUSE: fuse_req kABI guard.
- MD: mddev_s kABI guard.
- commit 8e97c09
* Mon Apr 18 2011 jslaby@suse.cz
- ethtool: guard against compat.h.
- commit 33844c8
* Mon Apr 18 2011 jslaby@suse.cz
- patches.kernel.org/revert-x86-Cleanup-highmap-after-brk-is-concluded.patch:
    Move to patches.arch where it belongs.
- commit a116831
* Sun Apr 17 2011 jeffm@suse.de
- Update reference module symbol versions.
- commit ed9da6e
* Fri Apr 15 2011 jeffm@suse.com
- libata: DVR-216D can't do SETXFER DVD-RW DVR-216D (bnc#679143).
- libata: DVR-212D can't do SETXFER DVD-RW DVR-212D.
- commit b7aca8a
* Thu Apr 14 2011 bphilips@suse.de
- bonding: Incorrect TX queue offset (bnc#687116, CVE-2011-1581).
- commit 9efcee8
* Thu Apr 14 2011 jeffm@suse.com
- char/tpm: Fix unitialized usage of data buffer (bnc#680040
    CVE-2011-1160).
- commit 97c1e00
* Thu Apr 14 2011 jeffm@suse.com
- fs/partitions/efi.c: corrupted GUID partition tables can cause
    kernel oops (bnc#687113 CVE-2011-1577).
- commit b350a92
* Thu Apr 14 2011 jeffm@suse.com
- drivers/leds/leds-lp5523.c: world-writable engine* sysfs files
    (bnc#673934).
- drivers/leds/leds-lp5521.c: world-writable sysfs engine* files
    (bnc#673934).
- mfd: ab8500: world-writable debugfs register-* files
    (bnc#673934).
- scsi_transport_iscsi: make priv_sess file writeable only by root
    (bnc#673934).
- mfd: ab3500: world-writable debugfs register-* files
    (bnc#673934).
- drivers/misc/ep93xx_pwm.c: world-writable sysfs files
    (bnc#673934).
- mfd: ab3100: world-writable debugfs *_priv files (bnc#673934).
- UBIFS: restrict world-writable debugfs files (bnc#673934).
- scsi: aic94xx: world-writable sysfs update_bios file.
- drivers/rtc/rtc-ds1511.c: world-writable sysfs nvram file
    (bnc#673934).
- video: sn9c102: world-wirtable sysfs files (bnc#673934).
- commit c30fedb
* Wed Apr 13 2011 jeffm@suse.com
- irda: validate peer name and attribute lengths (bnc#681497
    CVE-2011-1180).
- commit 15c6d16
* Mon Apr 11 2011 gregkh@suse.de
- Platform: add Samsung Laptop platform driver (bnc#681076).
- Delete
    patches.drivers/staging-samsung-laptop-add-support-for-lots-of-laptops.patch.
- commit fbf0cf7
* Mon Apr 11 2011 gregkh@suse.de
- staging: hv: use sync_bitops when interacting with the
    hypervisor.
- staging: hv: Fix GARP not sent after Quick Migration.
- commit 053ec3e
* Wed Apr  6 2011 jslaby@suse.cz
- Revert "x86: Cleanup highmap after brk is concluded"
    (bnc#684248).
- Delete
    patches.arch/x86-save-cr4-to-mmu_cr4_features-at-boot.patch.
- commit 2d663f6
* Wed Apr  6 2011 jbohac@suse.cz
- rose: Add length checks to CALL_REQUEST parsing (bnc#681175).
- ROSE: prevent heap corruption with bad facilities (bnc#681175).
- commit 88980a0
* Wed Apr  6 2011 jeffm@suse.de
- reiserfs: Force inode evictions before umount to avoid crash
    (bnc#610598 bnc#680073 bnc#684112).
- Delete patches.fixes/reiserfs-xattr-crash-fix.
- commit 895e529
* Tue Apr  5 2011 eich@suse.de
- drm/radeon/kms: check AA resolve registers on r300 (bnc#674693).
    CVE-2011-1016.
- commit 67cfac5
* Tue Apr  5 2011 mgalbraith@suse.de
- sched, autogroup: fix CONFIG_RT_GROUP_SCHED sched_setscheduler() failure (bnc#680510).
- commit e4e6f97
* Mon Apr  4 2011 jslaby@suse.cz
- ips: use interruptible waits in ips-monitor (bnc#680932).
- commit 3d18256
* Fri Apr  1 2011 sjayaraman@suse.de
- nfs: Create a memory reserve for nfs_page_cache (bnc#678466).
- netvm: Reduce the size of the routing reserves and be careful
    of dst_alloc() (bnc#678466).
- mm: Add mem_reserve_kmem_cache_add helper (bnc#678466).
- commit 0820508
* Wed Mar 30 2011 jslaby@suse.cz
- Relax si_code check in rt_sigqueueinfo and rt_tgsigqueueinfo
    (bnc#681826).
- commit 88f8185
* Tue Mar 29 2011 bphilips@suse.de
- gro: reset skb_iif on reuse (bnc#682965, CVE-2011-1478).
- gro: Reset dev pointer on reuse (bnc#682965, CVE-2011-1478).
- commit ebd85e0
* Mon Mar 28 2011 tiwai@suse.de
- ALSA: hda - Increase the default buffer size (682725).
- ALSA: hda - Fix pin-config of Gigabyte mobo (bnc#677256).
- commit 3ddda13
* Mon Mar 28 2011 jslaby@suse.cz
- Update to 2.6.37.6:
  - obsoletes:
  - patches.fixes/prevent-rt_sigqueueinfo-from-spoofing.patch.
- Refresh patches.xen/tmem.
- Refresh patches.xen/xen-dcdbas.
- commit ef8ab18
* Fri Mar 25 2011 mhocko@suse.cz
- page_cgroup: reduce allocation overhead for page_cgroup array
    for CONFIG_SPARSEMEM (bnc#669889).
- commit ee7dff4
* Fri Mar 25 2011 jslaby@suse.cz
- Update patches.kernel.org/patch-2.6.37.4-5 (bnc#558740).
    (Add a bug reference)
- commit 6018f94
* Thu Mar 24 2011 tiwai@suse.de
- ALSA: hda - Fix SPDIF out regression on ALC889 (bnc#679588).
- commit ada924a
* Thu Mar 24 2011 jslaby@suse.cz
- Prevent rt_sigqueueinfo and rt_tgsigqueueinfo from spoofing
    the signal code (bnc#681826 CVE-2011-1020).
- commit 6c089d5
* Thu Mar 24 2011 tiwai@suse.de
- ALSA: sound/pci/asihpi: check adapter index in hpi_ioctl
    (bnc#680816).
- sound/oss/opl3: validate voice and channel indexes (bnc#681999).
- sound/oss: remove offset from load_patch callbacks (bnc#681999).
- kabi/severities: ignore OSS kABI
- commit a1b4e73
* Thu Mar 24 2011 jack@suse.cz
- xfs: zero proper structure size for geometry calls (bnc#672505).
- commit 440bdd4
* Thu Mar 24 2011 rjw@suse.de
- PM / Hibernate: Reduce autotuned default image size (bnc#648742).
- commit 7c5671f
* Thu Mar 24 2011 jslaby@suse.cz
- Update to 2.6.37.5:
  - obsoletes:
  - patches.drivers/alsa-hda-0017-Realtek-ALC88x-Do-not-over-initialize-speakers.
- Refresh
    patches.fixes/hid-add-support-for-Skycable-0x3f07-wireless-present.patch.
- commit 88da918
* Wed Mar 23 2011 jack@suse.cz
- Fix almost-infinite slab cache growing (bnc#554081).
- commit 4f0739f
* Mon Mar 21 2011 jkosina@suse.cz
- Refresh
    patches.fixes/hid-add-support-for-Skycable-0x3f07-wireless-present.patch.
    fix build due to error in backport
- commit 4dd52bf
* Mon Mar 21 2011 jkosina@suse.cz
- HID: add support for Skycable 0x3f07 wireless presenter
    (bnc#681297).
- commit 64b16b9
* Fri Mar 18 2011 jslaby@suse.cz
- NET: cdc-phonet, handle empty phonet header (bnc#673992).
- commit 3a0111f
* Thu Mar 17 2011 neilb@suse.de
- Make selection of 'readdir-plus' adapt to usage patterns
    (bnc#678123).
- commit 05628d2
* Thu Mar 17 2011 neilb@suse.de
- Fix cookie decoding problem in NFS (bnc#678123).
- commit 0aa74e7
* Wed Mar 16 2011 sjayaraman@suse.de
- SoN: collapse: mm: Report the low watermark correctly (bnc#678497).
- commit 8e72153
* Wed Mar 16 2011 sjayaraman@suse.de
- netvm: Do not mark requests for swapfile writes as dirty or
    kswapd fails to free the page (bnc#678472).
- commit df7d9b9
* Wed Mar 16 2011 sjayaraman@suse.de
- SoN: nfs: Use page_file_offset during page writeback (bnc#677738).
- SoN: nfs: Convert nfs_mark_request_dirty() to use page_file_mapping()
    (bnc#677738).
- commit 6c7452f
* Wed Mar 16 2011 sjayaraman@suse.de
- SoN: netvm: Remove duplicated initialization in net/ipv4/route.c
    (bnc#678970).
- commit b9bc93d
* Mon Mar 14 2011 jslaby@suse.cz
- Update to 2.6.37.4:
  - obsoletes:
  - patches.fixes/ath9k-Fix-ath9k-prevents-CPU-to-enter-C3-states.patch.
  - patches.fixes/media-DiB7000M-add-pid-filtering.patch.
- commit b3091d2
* Mon Mar 14 2011 tiwai@suse.de
- ALSA: HDA: Realtek ALC88x: Do not over-initialize speakers
    and hp that are primary outputs (bnc#679016).
- ALSA: HDA: Fixup unnecessary volume control index on Realtek
    ALC88x (bnc#679016).
- ALSA: HDA: Fix volume control naming for surround speakers on
    Realtek auto-parser (bnc#679016).
- ALSA: HDA: Enable surround and subwoofer on Lenovo Ideapad Y530
    (bnc#679016).
- ALSA: hda - Add support for multiple headphone/speaker controls
    for Realtek (bnc#679016).
- ALSA: hda - 4930g add internal lfe slider (bnc#679016).
- ALSA: hda - Fix unable to record issue on ASUS N82JV
    (bnc#679016).
- ALSA: hda - switch lfe with side in mixer for 4930g
    (bnc#679016).
- ALSA: HDA: Fix automute on Thinkpad L412/L512 (bnc#679016).
- ALSA: HDA: Add SKU ignore for another Thinkpad Edge 14
    (bnc#679016).
- ALSA: hda - Apply Sony VAIO hweq fixup only once (bnc#679016).
- ALSA: hda - Fix ALC275 enable hardware EQ for SONY VAIO
    (bnc#679016).
- ALSA: hda - Fix EAPD on Lenovo NB ALC269 to low (bnc#679016).
- commit b5b352b
* Mon Mar 14 2011 tiwai@suse.de
- ALSA: hda - Add a generic fixup callback for Realtek codecs
    (bnc#679016).
- ALSA: hda - Fix missing EAPD for Acer 4930G (bnc#679016).
- commit 35da099
* Fri Mar 11 2011 jslaby@suse.cz
- DiB7000M: add pid filtering (bnc#644807).
- commit ab6796e
* Fri Mar 11 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37.3 and c/s 1072.
- apply xen specific patch to the Chelsio ethernet drivers.
- commit 7db4348
* Thu Mar 10 2011 jslaby@suse.cz
- Mantis, hopper: use MODULE_DEVICE_TABLE (bnc#607239).
- commit 33a71b9
* Tue Mar  8 2011 jslaby@suse.cz
- Update to 2.6.37.3:
  - obsoletes:
  - patches.drivers/alsa-usb-audio-fix-oops-due-to-cleanup-race-when-disconnect.
  - patches.drivers/e1000e-82579-PHY-incorrectly-identified-during-init.patch.
  - patches.arch/acpi-debugfs-fix-buffer-overflows-double-free.patch.
  - patches.fixes/loop-over-loop-hang-fix.patch.
- Refresh patches.xen/xen-x86-no-lapic.
- Refresh patches.xen/xen3-patch-2.6.19.
- commit dca38e6
* Fri Mar  4 2011 jack@suse.cz
- debugfs: Fix filesystem reference counting on debugfs_remove()
    failure (bnc#668101).
- commit 9166129
* Wed Mar  2 2011 bphilips@suse.de
- e1000e: 82579 PHY incorrectly identified during init
    (bnc#668437).
- commit 8e49073
* Tue Mar  1 2011 knikanth@suse.de
- block: kill loop_mutex (bnc#669394).
- commit e8a3617
* Mon Feb 28 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Add annotations to
    lib/rwsem_64.S.
- commit a1349cb
* Sun Feb 27 2011 jslaby@suse.cz
- iwlwifi: fix ack health for WiFi/BT combo devices (bnc#662733).
- iwlwifi: cleanup iwl_good_ack_health (bnc#662733).
- commit 655657f
* Fri Feb 25 2011 jslaby@suse.cz
- Update to 2.6.37.2 (bnc#674245):
  - obsoletes:
  - patches.arch/perf_adjust_timechart_to_new_cpuidle_events.patch.
  - patches.drivers/alsa-01-caiaq-Fix-possible-string-buffer-overflow.
  - patches.fixes/revert-tpm_tis-Use-timeouts-returned-from-TPM.patch.
- commit d1287f4
* Thu Feb 24 2011 tiwai@suse.de
- ALSA: usb-audio: fix oops due to cleanup race when disconnecting
    (bnc#674735).
- commit 74b3781
* Thu Feb 24 2011 jslaby@suse.cz
- ath9k: Fix ath9k prevents CPU to enter C3 states (bnc#667793).
- Refresh
    patches.fixes/revert-tpm_tis-Use-timeouts-returned-from-TPM.patch.
- Delete
    patches.fixes/0001-Revert-ath9k-use-per-device-struct-for-pm_qos_-opera.patch.
- Delete
    patches.fixes/0002-Revert-ath9k-Remove-pm_qos-request-after-hw-unregist.patch.
- Delete
    patches.fixes/0003-Revert-ath9k-Fix-a-DMA-latency-issue-for-Intel-Pinet.patch.
  These patches went upstream, update.
- commit be3e181
* Tue Feb 22 2011 mszeredi@suse.cz
- xfs: prevent leaking uninitialized stack memory in FSGEOMETRY_V1
    (CVE-2011-0711 bnc#672524).
- commit 547a9f9
* Mon Feb 21 2011 tiwai@suse.de
- ALSA: caiaq - Fix possible string-buffer overflow (bnc#672499,
    CVE-2011-0712).
- commit f6a72cc
* Sun Feb 20 2011 jslaby@suse.cz
- Revert "tpm_tis: Use timeouts returned from TPM" (bnc#673619).
- commit d991856
* Fri Feb 18 2011 rjw@suse.de
- ACPI / debugfs: Fix buffer overflows, double free (bnc#666095).
- commit da9d3a8
* Fri Feb 18 2011 jslaby@suse.cz
- Update to 2.6.37.1:
  - obsoletes:
  - patches.arch/x86-mtrr-avoid-MTRR-reprogramming-on-BP-during-boot-on.patch
  - patches.drivers/alsa-hda-0001-Fix-memory-leaks-in-conexant-jack-arrays
  - patches.drivers/alsa-hda-0002-Fix-missing-CA-initialization-for-HDMI-DP
  - patches.fixes/calibrate-jiffy-overflow
  - patches.fixes/fix-ata-panic-with-ata_id
  - patches.fixes/fix-prlimit64-for-suid-sgid-processes.patch
  - patches.fixes/input-introduce-notimeout-blacklist-for-Dell-Vostro-.patch
  - patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash
  - patches.fixes/staging-rt2860-Fix-incorrect-netif_stop_queue-usage.patch
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/SoN-16-netvm-reserve-inet.patch.
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Refresh patches.xen/xen3-auto-common.diff.
- Refresh patches.xen/xen3-fixup-common.
- Refresh patches.xen/xen3-patch-2.6.37.
- commit a638bb4
* Fri Feb 18 2011 sjayaraman@suse.de
- Refresh patches.suse/SoN-06-mm-kmem_estimate_pages.patch to accomodate
    an upstream change.
- commit a4e281e
* Thu Feb 17 2011 rjw@suse.de
- PNP / ACPI: Use DEVICE_ACPI_HANDLE() for device ACPI handle access (bnc#434742).
- commit a73834f
* Thu Feb 17 2011 gregkh@suse.de
- Update config files.
    disable CONFIG_DRM_VMWGFX. (bnc#606458)
- commit 409d54e
* Wed Feb 16 2011 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Re-add change lost during
    initial 2.6.37 merge.
- commit 7a5313d
* Wed Feb 16 2011 tiwai@suse.de
- ALSA: HDA: Add Lenovo vendor quirk for Conexant 205xx
    (bnc#670946).
- commit b3bc287
* Tue Feb 15 2011 jeffm@suse.com
- tty: add 'active' sysfs attribute to tty0 and console device.
- commit 7ae6e9a
* Tue Feb 15 2011 jslaby@suse.cz
- Revert "ath9k: Fix a DMA latency issue for Intel Pinetrail
    platforms." (bnc#667793).
- Revert "ath9k: Remove pm_qos request after hw
    unregister." (bnc#667793).
- Revert "ath9k: use per-device struct for pm_qos_* operations"
    (bnc#667793).
- commit b2849f6
* Tue Feb 15 2011 jack@suse.cz
- bridge: Replace mp->mglist hlist with a bool (bnc#653547).
- bridge: Fix timer typo that may render snooping less effective
    (bnc#653547).
- bridge: Fix mglist corruption that leads to memory corruption
    (bnc#653547).
- commit a70e5ca
* Mon Feb 14 2011 mmarek@suse.cz
- Move spec file templates and helper scripts to a separate branch, to
    ease synchronizing these files among master, vanilla and linux-next.
- commit 411abb8
* Mon Feb 14 2011 mmarek@suse.cz
- Delete a couple of obsolete kabi and other scripts from misc/:
- Delete misc/checkmod.
- Delete misc/collect_ksyms.
- Delete misc/diff-the-xfs-cvs.
- Delete misc/ksyms.py.
- Delete misc/mangle-ifdef.py.
- Delete misc/obsolete-module-aliases.
- Delete misc/testmodule.
- commit 3dd255b
* Mon Feb 14 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Delete misc/extract-modaliases, the code
    was merged into rpm's find-supplements script.
- Delete rpm/check-build.sh, not needed anymore.
- commit bd6fa48
* Thu Feb 10 2011 jeffm@suse.com
- flexcop: fix registering braindead stupid names (brc#575873
    bnc#661429).
- commit 2e98bfc
* Wed Feb  9 2011 gregkh@suse.de
- Staging: samsung-laptop: add support for lots of laptops
    (bnc#661682).
- commit c6d0dc9
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Set timestamp of sources to the commit
    timestamp, so that they are always older than generated files in
    /usr/src/linux-obj (bnc#669669).
- commit 31e675a
* Wed Feb  9 2011 tiwai@suse.de
- ALSA: hda - Fix missing CA initialization for HDMI/DP
    (bnc#670577).
- commit 474305e
* Wed Feb  9 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Do not run fdupes in /usr/src/linux-obj, to
    keep timestamps intact.
- commit e211a69
* Tue Feb  8 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove .gitignore files after applying patches
    (fix last change).
- commit d6a7494
* Tue Feb  8 2011 jslaby@suse.cz
- orinoco: allow IW_AUTH_MFP to pass through (bnc#661624).
- commit 442a3d7
* Tue Feb  8 2011 jbeulich@novell.com
- Fix a few issues in patches.suse/stack-unwind (bnc#661409).
- commit f82619b
* Mon Feb  7 2011 jslaby@suse.cz
- staging: rt2860: Fix incorrect netif_stop_queue usage warning
    (bnc#661657).
- commit 39b4c1e
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/{kernel-source.spec.in,mkspec}: Sync with vanilla and linux-next
- commit fecf998
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Remove dead code.
- commit b97b6f2
* Mon Feb  7 2011 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-spec-macros: Fix the definition
    of %%release_major and rename it to %%release_num to better describe
    what it does. Add some comments to explain how the versioning works.
- commit 3de2a1a
* Fri Feb  4 2011 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh: Fix sed regexp
- commit d889fe7
* Thu Feb  3 2011 rjw@suse.de
- x86, mtrr: avoid MTRR reprogramming on BP during boot on (bnc#623393).
- commit 0664ad4
* Thu Feb  3 2011 jbeulich@novell.com
- Update Xen patches to c/s 1066.
- cpuidle/x86/perf: fix power:cpu_idle double end events and
    throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
    ones (bnc#665153).
- commit e88242f
* Thu Feb  3 2011 jbeulich@novell.com
- Fix jiffy calculations in calibrate_delay_direct to handle
    overflow.
- commit 4a69163
* Wed Feb  2 2011 jeffm@suse.com
- patches.fixes/reiserfs-xattr-crash-fix: fix crash
    during failed mount (bnc#668878)
- commit de24d15
* Wed Feb  2 2011 tiwai@suse.de
- ALSA: hda - Fix memory leaks in conexant jack arrays
    (bnc#668929).
- commit 7dbcb59
* Mon Jan 31 2011 jslaby@suse.cz
- Refresh patches.rpmify/cloneconfig.diff.
  scripts/kconfig/conf accepts long parameters only for some time already
- commit 36bcdd7
* Mon Jan 31 2011 jslaby@suse.cz
- block: loop queue_lock null pointer derefence in blk_throtl_exit
    v3 (bnc#666598).
- commit cd38efd
* Mon Jan 31 2011 jslaby@suse.cz
- Fix prlimit64 for suid/sgid processes (bnc#668262).
- commit dae8217
* Sun Jan 23 2011 jeffm@suse.com
- netfilter: Implement RFC 1123 for FTP conntrack (bnc#466279).
- commit 3e2a2b2
* Sat Jan 22 2011 jeffm@suse.com
- ata: Fix panics with ata_id (bnc#660464).
- commit fa7af15
* Sat Jan 22 2011 jeffm@suse.de
- Updated some Patch-mainline headers.
- commit 9122bf0
* Fri Jan 21 2011 trenn@suse.de
- perf: Do not export power_frequency, but power_start event
    (bnc#665153).
- cpuidle/x86/perf: fix power:cpu_idle double end events and
    throw cpu_idle events from the cpuidle layer (bnc#665153).
- perf: Clean up power events by introducing new, more generic
    ones (bnc#665153).
- cpuidle: Rename X86 specific idle poll state from C0 to POLL
    (bnc#665153).
- perf timechart: Adjust perf timechart to the new power events
    (bnc#665153).
- Fix display of idle boxes (none).
- Fix huge and wronge C-state drawings due to uninitialized
    start/end timestamps (none).
- Update config files.
- doc/config-options.changes:
    CONFIG_EVENT_POWER_TRACING_DEPRECATED=y
- commit b308eff
* Wed Jan 19 2011 jbohac@suse.cz
-    revert: ipv6: don't flush routes when setting loopback down.
- commit de347ac
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Initialize the global lock spinlock as
    appropriate (bnc#637377).
- commit c4b8238
* Tue Jan 18 2011 trenn@suse.de
- ACPI / ACPICA: Fix global lock acquisition (bnc#637377).
- commit 15cd726
* Mon Jan 17 2011 jeffm@suse.com
- mISDN: Add support for group membership check (bnc#564423).
- commit 3f46938
* Fri Jan 14 2011 mmarek@suse.cz
- Revert %%kernelrelease changes originally made on the vanilla branch,
    they break on master and must be done differently.
- commit b610327
* Thu Jan 13 2011 jkosina@suse.cz
- Input: introduce 'notimeout' blacklist for Dell Vostro V13
    (bnc#641105).
- commit cb76856
* Wed Jan 12 2011 jeffm@suse.com
- In-kernel dependencies for reiser4
  - Delete patches.suse/reiser4-exports.
  - Delete patches.suse/reiser4-set_page_dirty_notag.
- commit 1b97130
* Tue Jan 11 2011 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29: Fix a regression.
- commit 6acb967
* Mon Jan 10 2011 jack@suse.cz
- novfs: NCP Fragments can be upto 64k in size (bnc#625965).
- commit afd7489
* Mon Jan 10 2011 jbeulich@novell.com
- Update Xen patches to 2.6.37-final and c/s 1062.
- commit ef70146
* Mon Jan 10 2011 jeffm@suse.com
- Enabled AGP modules as parts of the static kernel on i386 (bnc#609607)
- commit 9446eb0
* Sat Jan  8 2011 jengelh@medozas.de
- config: run oldconfig on sparc64/default
- commit aa3e940
* Sat Jan  8 2011 jengelh@medozas.de
- config: update sparc64/net and throw out unworthy options
- commit 1aca53d
* Fri Jan  7 2011 mmarek@suse.cz
- Delete patches.suse/gfs2-ro-mounts-only.patch (obsolete and unused)
- commit 38ff246
* Fri Jan  7 2011 trenn@suse.de
- Some are mainline, some are/will be implemented differently:
- Delete patches.drivers/dynamic_debug_1.patch.
- Delete patches.drivers/dynamic_debug_2.patch.
- Delete patches.drivers/dynamic_debug_3.patch.
- Delete patches.drivers/dynamic_debug_4.patch.
- Delete patches.drivers/dynamic_debug_5.patch.
- Delete patches.drivers/dynamic_debug_6.patch.
- Delete patches.drivers/dynamic_debug_7.patch.
- commit 68dc5c8
* Fri Jan  7 2011 neilb@suse.de
- Remove old patch
- commit 7fc009b
* Thu Jan  6 2011 jeffm@suse.com
- reiserfs: Fix crash during umount (bnc#610598).
- commit 88f26ac
* Thu Jan  6 2011 mmarek@suse.cz
- rpm/kernel-source.spec.in: Move the source tree if %%kernelrelease is
    different from the tarball version.
- commit 6be9ffe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.suse/export-sync_page_range (unused).
- commit d19ee6d
* Thu Jan  6 2011 jeffm@suse.com
- Delete patches.suse/supported-flag-sysfs: Merged with patches.suse/supported-flag
- commit 0f2e67b
* Thu Jan  6 2011 jeffm@suse.com
- Removed unused kdb patches.
  - Delete patches.suse/kdb-build-fixes.
  - Delete patches.suse/kdb-common.
  - Delete
    patches.suse/kdb-fix-assignment-from-incompatible-pointer-warnings.
  - Delete
    patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro.
  - Delete patches.suse/kdb-handle-nonexistance-keyboard-controller.
  - Delete patches.suse/kdb-ia64.
  - Delete patches.suse/kdb-usb-rework.
  - Delete patches.suse/kdb-vm-api-changes-for-2-6-34.
  - Delete patches.suse/kdb-x86.
  - Delete patches.suse/kdb-x86-build-fixes.
  - Delete patches.suse/kdb_dont_touch_i8042_early.patch.
  - Delete patches.suse/kdb_fix_ia64_build.patch.
  - Delete patches.xen/xen3-kdb-x86.
- commit c9e725d
* Thu Jan  6 2011 jeffm@suse.com
- rpm/kernel-source.spec.in: Remove the relocation of the source tree.
    It's expanded in-place.
- commit 8cde941
* Thu Jan  6 2011 jack@suse.cz
- Delete patches.suse/ext2-fsync-err as it is obsolete and unused.
- commit c8f4ebe
* Thu Jan  6 2011 mmarek@suse.cz
- Delete patches.fixes/kbuild-fix-generating-of-.symtypes-files.
    Fixed upstream in commit e26d6b8.
- commit 1b628e1
* Thu Jan  6 2011 mgalbraith@suse.de
- Replaced autogroup patch with what will appear in 2.6.38
- Replaced cgroup use after free fix wtih what will appear in 2.6.38
- Refresh
    patches.fixes/sched-cgroup-use-exit-hook-to-avoid-use-after-free-crash.
- Refresh patches.suse/sched-automated-per-session-task-groups.
- Delete patches.fixes/sched-fix-autogroup-proc-interface-race.
- commit 81f018b
* Thu Jan  6 2011 jeffm@suse.com
- Update to 2.6.37-final.
- commit f4cd126
* Thu Dec 30 2010 jeffm@suse.com
- taskstats: Use better ifdef for alignment (bko#24272).
- commit 2948ffa
* Wed Dec 29 2010 jeffm@suse.com
- Update to 2.6.37-rc8.
  - Eliminated 1 patch.
- commit 42518e6
* Tue Dec 28 2010 mgalbraith@suse.de
- sched: fix autogroup /proc interface race.
- commit fd7019c
* Mon Dec 27 2010 jeffm@suse.com
- scripts/wd-functions.sh: Re-added support for finding tarball in $MIRROR.
- commit c8014fb
* Mon Dec 27 2010 jeffm@suse.com
- sched, cgroup: Use exit hook to avoid use-after-free crash.
- commit 59c0581
* Mon Dec 27 2010 jeffm@suse.com
- Update to 2.6.37-rc7.
  - Eliminated 9 patches.
- commit d38591c
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "x86: allocate space within a region top-down"
    (bnc#655048).
    Backport to XEN.
- commit 92c0965
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "PCI: fix pci_bus_alloc_resource() hang, prefer positive
    decode" (bnc#655048).
- Revert "x86: allocate space within a region top-down"
    (bnc#655048).
- Revert "x86/PCI: allocate space from the end of a region,
    not the beginning" (bnc#655048).
- Revert "PCI: allocate bus resources from the top down"
    (bnc#655048).
- Revert "resources: support allocating space within a region
    from the top down" (bnc#655048).
- resources: add arch hook for preventing allocation in reserved
    areas (bnc#655048).
- x86: avoid low BIOS area when allocating address space
    (bnc#655048).
- x86: avoid E820 regions when allocating address space
    (bnc#655048).
- x86: avoid high BIOS area when allocating address space
    (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7bbbf27
* Mon Dec 20 2010 jslaby@suse.cz
- Revert "- resources: add arch hook for preventing allocation in reserved"
  This reverts commit 7e253537787f4fb057e12a166356169c5adb9665. It was unintended to be pushed as the patches are obsoleted.
- commit 6f3bdf8
* Mon Dec 20 2010 jslaby@suse.cz
- Delete
    patches.fixes/res-0010-PCI-fix-pci_bus_alloc_resource-hang-prefer-positive-.patch.
    It's unreferenced and wrong.
- commit 9e6fc50
* Thu Dec 16 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Define %%kernelrelease
- commit 1d67b13
* Thu Dec 16 2010 jeffm@suse.com
- Linux: 2.6.37-rc6.
- Update config files.
- Refresh patches.suse/SoN-23-mm-swapfile.patch.
- Refresh patches.suse/SoN-26-nfs-swapper.patch.
- Refresh patches.xen/xen3-fixup-xen.
- Refresh patches.xen/xen3-patch-2.6.24.
- commit 5650f90
* Mon Dec 13 2010 jbeulich@novell.com
- Update Xen config files (XEN_NETDEV_LOOPBACK=n).
- supported.conf: Update.
- commit d385dff
* Mon Dec 13 2010 tiwai@suse.de
- Refresh patches.suse/bootsplash-scaler: Fix crash when bootsplash animation is used (bnc#646908)
- commit c5eced1
* Fri Dec 10 2010 jslaby@suse.cz
- resources: add arch hook for preventing allocation in reserved
    areas (bnc#655048).
- x86: avoid BIOS area when allocating address space (bnc#655048).
- x86: avoid PNP resources when allocating address space
    (bnc#655048).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 7e25353
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen config files (CONFIG_XEN_COMPAT=0x040000).
- commit 5343e5f
* Fri Dec 10 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc5.
- commit bef1a0d
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix timestamp of /usr/src/linux-obj/.../.config
- rpm/kernel-binary.spec.in: Fix timestamp of /usr/src/linux-obj/.../.config
- commit 149d22b
* Thu Dec  9 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:Factory
- commit bf19860
* Wed Dec  8 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Allow to build against any version of
    kernel-source
- commit 37bdc47
* Tue Dec  7 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Remove stringification
    (needed only with very old assemblers).
- commit 987c244
* Tue Dec  7 2010 jeffm@suse.com
- scripts/sequence-patch.sh: Added -vanilla suffix to the directory name when expanding vanilla tree.
- commit 77ad87b
* Tue Dec  7 2010 jeffm@suse.com
- Update vanilla config files.
- commit f55f81b
* Tue Dec  7 2010 jeffm@suse.com
- Update to 2.6.37-rc5.
- commit ca102d9
* Tue Dec  7 2010 jbeulich@novell.com
- patches.suse/novfs-fix-ioctl-usage: Fix compiler warnings.
- commit faf2142
* Mon Dec  6 2010 mgalbraith@suse.de
- Replace buggy per tty autogroup patch with final per session patch as
    integrated into tip.
- sched: Add 'autogroup' scheduling feature: automated per session task groups (bnc#657613).
- Delete patches.suse/sched-automated-per-tty-task-groups.
- commit 0db6b6b
* Mon Dec  6 2010 jbeulich@novell.com
- patches.rpmify/rpm-kernel-config, patches.rpmify/split-package,
    patches.suse/0004-richacl-In-memory-representation-and-helper-function.patch,
    patches.suse/SoN-15-netvm-reserve.patch,
    patches.suse/SoN-27-nfs-swap_ops.patch,
    patches.suse/kconfig-automate-kernel-desktop,
    patches.suse/mm-tune-dirty-limits.patch,
    patches.suse/supported-flag-enterprise: Clean up Kconfig portions.
- commit 713650c
* Mon Dec  6 2010 jeffm@suse.com
- Fixed corrupted -rc4 patch.
- commit 9802d4e
* Mon Dec  6 2010 jeffm@suse.de
- Update to 2.6.37-rc4.
- commit d102b44
* Mon Nov 29 2010 jeffm@suse.com
- Merge 2.6.37-rc3-git6 with Xen.
- commit 7089cd5
* Mon Nov 29 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git6.
- commit 1294ef9
* Fri Nov 26 2010 jbeulich@novell.com
- Update Xen patches to 2.6.37-rc3-git1 and c/s 1055.
- xen/acpi: Add memory hotadd to pvops dom0 (bnc#651066).
- xen/acpi: Export host physical CPU information to dom0
    (bnc#651066).
- Xen: para-virtual watchdog driver.
- introduce {rd,wr}msr_safe_on_pcpu() and add/enable users.
- eliminate scalability issues from initrd handling.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit cf6d991
* Fri Nov 26 2010 trenn@suse.de
- PERF: Fix perf timechart C-state regression (none).
- commit ba2671d
* Wed Nov 24 2010 jeffm@suse.com
- Update to 2.6.37-rc3-git1.
- commit 4ad245f
* Mon Nov 22 2010 jeffm@suse.com
- Update to 2.6.37-rc3.
  - Eliminated 1 patch.
- commit 12ac0ac
* Mon Nov 22 2010 jslaby@suse.cz
- Delete patches.fixes/make-note_interrupt-fast.diff.
- Delete patches.fixes/twl6030-fix-note_interrupt-call.
  __do_IRQ from ia64 lapic code is no longer called, because they use
  genirqs properly. So these patches don't make sense anymore. If we
  need something to do, then it's adding action_ret == IRQ_NONE test
  into handle_percpu_irq before jumping into note_interrupt.
- commit facd623
* Sun Nov 21 2010 jslaby@suse.cz
- PCI: fix offset check for sysfs mmapped files (bnc#655157).
- commit 2938f56
* Wed Nov 17 2010 jeffm@suse.com
- sched: automated per tty task groups.
  - Enabled in -desktop flavors for better interactivity.
- commit 2d5d397
* Tue Nov 16 2010 jeffm@suse.de
- doc/config-options.changes: Updated changes for 2.6.37-rc1 and -rc2.
- commit 0aca8b8
* Tue Nov 16 2010 jeffm@suse.com
- Update to 2.6.37-rc2.
- commit 1453a04
* Mon Nov 15 2010 jslaby@suse.cz
- PCI: fix pci_bus_alloc_resource() hang, prefer positive decode
    (bnc#651256).
- commit 4404c19
* Mon Nov 15 2010 jeffm@suse.com
- Update vanilla config files.
- commit 60b4a47
* Mon Nov 15 2010 jeffm@suse.com
- Update to 2.6.37-rc1-git11.
  - Eliminated 2 patches.
- commit 5959a67
* Mon Nov 15 2010 jeffm@suse.com
- supported.conf: Added missing dependencies.
- commit 0537c35
* Sat Nov 13 2010 jslaby@suse.cz
- TTY: restore tty_ldisc_wait_idle (bnc#642043).
- commit 84d87bf
* Fri Nov 12 2010 jeffm@suse.de
- Update to 2.6.37-rc1.
  - Eliminated 26 patches.
  - Xen is disabled.
- commit b9044e3
* Thu Nov 11 2010 gregkh@suse.de
- Update config files. (bnc#652954) increase the number of possible and
    default uarts for users with multi-port serial cards for the i386 and
    x86-64 default configs.
- commit 85c87e3
* Thu Nov 11 2010 jslaby@suse.cz
- rt2x00: Fix max TX power settings (bnc#584028).
- rt2x00: Fix channel configuration for RF3052 (bnc#584028).
- commit 60c0452
* Thu Nov 11 2010 jslaby@suse.cz
- resources: add a default alignf to simplify find_resource()
    (bnc#651256).
- resources: factor out resource_clip() to simplify
    find_resource() (bnc#651256).
- resources: ensure callback doesn't allocate outside available
    space (bnc#651256).
- resources: handle overflow when aligning start of available area
    (bnc#651256).
- resources: support allocating space within a region from the
    top down (bnc#651256).
- PCI: allocate bus resources from the top down (bnc#651256).
- x86/PCI: allocate space from the end of a region, not the
    beginning (bnc#651256).
- x86: update iomem_resource end based on CPU physical address
    capabilities (bnc#651256).
- x86: allocate space within a region top-down (bnc#651256).
- Refresh patches.xen/xen3-patch-2.6.34.
- commit 8c68ad1
* Tue Nov  9 2010 jack@suse.cz
- novfs: Fix for the issue of kernel dumps core on restart
    (bnc#641811).
- commit 76ba833
* Fri Oct 29 2010 jslaby@suse.cz
- net: Limit socket I/O iovec total length to INT_MAX
    (bnc#650128).
- commit 2ba74bb
* Fri Oct 29 2010 trenn@suse.de
- Update config files.
    Forgot to enable ACPI_EC_DEBUGFS on i386/pae
- commit 66b605b
* Wed Oct 27 2010 jslaby@suse.cz
- aha152x: enable PCMCIA on 64bit (bnc#630652).
- Update config files.
- commit a91d17c
* Wed Oct 27 2010 jslaby@suse.cz
- hpet: unmap unused I/O space (bnc#629908 bnc#629901).
- commit dad22c3
* Tue Oct 26 2010 trenn@suse.de
- Update config files.
    Enable CONFIG_ACPI_EC_DEBUGFS=m on supported archs.
- commit 9035254
* Tue Oct 26 2010 jbeulich@novell.com
- Update Xen config files (restore options accidentally deleted
    by 1b1584fccbfdc42e6e8b35c3c207ca65feb0c7d5).
- commit f8e5000
* Mon Oct 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36 and c/s 1043.
- xen: netback: take net_schedule_list_lock when removing entry
    from net_schedule_list.
- Update Xen config files.
- commit b772cd8
* Mon Oct 25 2010 tiwai@suse.de
- ALSA: hda - Add workarounds for CT-IBG controllers (bnc#564324).
- ALSA: hda - Add some workarounds for Creative IBG (bnc#564324).
- ALSA: hda - Fix wrong SPDIF NID assignment for CA0110
    (bnc#564324).
- commit 2256eda
* Fri Oct 22 2010 jeffm@suse.de
- Update to 2.6.36-final.
- commit 1b1584f
* Fri Oct 22 2010 jbeulich@novell.com
- patches.arch/i386-unwind-annotations,
    patches.arch/x86_64-unwind-annotations: Update Patch-mainline tags.
- commit 6ee5ccb
* Thu Oct 21 2010 sjayaraman@suse.de
- SoN: fix null pointer dereference in swap_entry_free.
- SoN: fix mess up on swap with multi files from same nfs server.
- Refresh patches.xen/tmem.
- commit d068f12
* Mon Oct 18 2010 trenn@suse.de
- ACPI: Make Embedded Controller command timeout delay
    configurable (bnc#639261).
- commit 9ea38cf
* Fri Oct 15 2010 jslaby@suse.cz
- Update to 2.6.36-rc8.
- commit 0c0e67c
* Fri Oct 15 2010 jslaby@suse.cz
- Refresh patches.suse/SoN-22-netvm.patch.
  Fix lock imbalance in net core (caused errors with bridges). (bnc#637235)
- commit f7ca98f
* Tue Oct 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc7 and c/s 1042.
- Update tmem interface to v1.
- commit 03c1043
* Mon Oct 11 2010 mmarek@suse.cz
- Generate per-symbol provides again (fate#305945).
  11.4 will do incremental downloads of repository metadata
  (fate#309561), so there should be no problem with the update
  repository anymore.
- commit 4258cf2
* Mon Oct 11 2010 jbeulich@novell.com
- patches.apparmor/apparmor-compatibility-patch-for-v5-network-control:
    Remove .rej file from this patch.
- commit 8828ce5
* Fri Oct  8 2010 jeffm@suse.de
- Update to 2.6.36-rc7.
- commit 82673e4
* Tue Oct  5 2010 jbeulich@novell.com
- patches.drivers/dynamic_debug_4.patch: Fix build issues with
    !DYNAMIC_DEBUG and build warning.
- commit b08d2aa
* Tue Oct  5 2010 jeffm@suse.de
- Enable SECURITY_APPARMOR_COMPAT_24
- commit f9b83fc
* Tue Oct  5 2010 jeffm@suse.de
- AppArmor: Allow dfa backward compatibility with broken
    userspace.
- AppArmor: compatibility patch for v5 interface.
- AppArmor: compatibility patch for v5 network control.
- commit cb27981
* Mon Oct  4 2010 jeffm@suse.de
- Update to 2.6.36-rc6.
  - Eliminated 2 patches.
- commit 57ae577
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 one more time.
- commit d527087
* Fri Sep 24 2010 trenn@suse.de
- acpi: ec_sys: access user space with get_user()/put_user()
    (none).
- commit d028761
* Fri Sep 24 2010 trenn@suse.de
- kernel/module.c: Fix compiler warnings if debug is compiled in
    (none).
- PNP: Use dev_dbg instead of dev_printk(KERN_DEBUG.. if
    DYNAMIC_DEBUG is compiled in (none).
- PNP: Compile all pnp built-in stuff in one module namespace
    (none).
- Dynamic Debug: Introduce global fake module param module.ddebug
  - V4 (none).
- Dynamic Debug: Initialize dynamic debug earlier via
    arch_initcall (none).
- Dynamic Debug: Introduce ddebug_query= boot parameter (none).
- Dynamic Debug: Split out query string parsing/setup from
    proc_write (none).
- commit dcd5c68
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28 again.
- commit 2fbc89f
* Fri Sep 24 2010 jbeulich@novell.com
- Refresh patches.xen/xen3-patch-2.6.28.
- commit cba31c7
* Fri Sep 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc5 and c/s 1038.
- commit 7b86243
* Thu Sep 23 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix for kernel release strings like
    2.6.36-rc5-73-g57aebd7-vanilla.
- rpm/kernel-spec-macros: Cleanup.
- commit 0926a18
* Thu Sep 23 2010 jeffm@suse.de
- rose: Fix signedness issues wrt. digi count (CVE-2010-3310
    bnc#640721).
- commit bcdc88b
* Tue Sep 21 2010 jeffm@suse.de
- qla4xxx: add workaround for missing readq/writeq.
- commit 643f9cf
* Tue Sep 21 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: BuildRequire proper version of kernel-source
- commit beb33d1
* Tue Sep 21 2010 jeffm@suse.de
- Linux: 2.6.36-rc5.
  - Eliminated 6 patches (all security backports).
- commit d4603b4
* Mon Sep 20 2010 jeffm@suse.de
- Revert "- make SCSI and ATA drivers modules again. (bnc#564357)."
  This reverts commit 75e8e5eae2c1e8dd279370f2c7650835ee821deb.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
  This change only applies to enterprise releases and should have been
  reverted prior to the release of openSUSE 11.3.
- commit 7fc084f
* Mon Sep 20 2010 sjayaraman@suse.de
- Update patches.suse/SoN-05-reserve-slub.patch to accomodate an upstream
    change that uses kmem_cache flags instead of PageSlubDebug flag.
- commit 4ea582b
* Mon Sep 20 2010 jeffm@suse.de
- Set LSM_MMAP_MIN_ADDR=0 to allow tools like DOSemu to work properly. The
    default is still set to 64k.
- commit 0581892
* Sun Sep 19 2010 jeffm@suse.com
- Delete patches.suse/cgroup-disable-memory.patch: It is no longer needed. The performance hit that it caused has been eliminated.
- commit 1ec7da8
* Fri Sep 17 2010 jeffm@suse.de
- wext: fix potential private ioctl memory content leak
    (CVE-2010-2955 bnc#635413).
- wext: fix potential private ioctl memory content leak
    (CVE-2010-2955 bnc#635413).
- commit 6df45c9
* Thu Sep 16 2010 jeffm@suse.de
- x86-64, compat: Test %%rax for the syscall number, not %%eax
    (CVE-2010-3301 bnc#639708).
- x86-64, compat: Retruncate rax after ia32 syscall entry tracing
    (CVE-2010-3301 bnc#639708).
- commit fb77404
* Thu Sep 16 2010 jeffm@suse.de
- compat: Make compat_alloc_user_space() incorporate the
    access_ok() (CVE-2010-3081 bnc#639709).
- commit 664a0ac
* Wed Sep 15 2010 jeffm@suse.com
- Remove reference to unused patch.
- commit a3abfe2
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/usb/hso.c: prevent reading uninitialized memory
    (CVE-2010-3298 bnc#639483).
- commit 35e70c8
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/cxgb3/cxgb3_main.c: prevent reading uninitialized
    stack memory (CVE-2010-3296 bnc#639481).
- commit a0634a9
* Wed Sep 15 2010 jeffm@suse.de
- drivers/net/eql.c: prevent reading uninitialized stack memory
    (CVE-2010-3297 bnc#639482).
- commit 2a7b160
* Wed Sep 15 2010 tiwai@suse.de
- Revert "patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171"
  This reverts commit c6a176c1df9ab4c69dd54ff3076bc92806eac8fd.
  It should have been applied to SLE11-SP1 branch.
- commit 05f07f3
* Tue Sep 14 2010 jslaby@suse.cz
- Update to Linux 2.6.36-rc4.
  - Obsoletes:
  - patches.fixes/bonding-jiffies2.patch.
  - patches.fixes/irda-correctly-clean-up-self-ias_obj-on-irda_bind-failure.
  - patches.fixes/net-sched-fix-kernel-leak-in-act_police.
  - patches.rpmify/spectra-depends-on-moorestown.
- fix build on s390 as of 2.6.36-rc4.
- Refresh patches.suse/SoN-08-mm-page_alloc-emerg.patch.
- Refresh patches.suse/reiser4-set_page_dirty_notag.
- Refresh patches.xen/pci-guestdev.
- Update config files.
- commit 6915057
* Mon Sep 13 2010 oneukum@suse.de
- patches.drivers/matador_reset_quirk.diff: Fix reset with Matador btusb devices bnc#626171
- commit c6a176c
* Mon Sep 13 2010 jdelvare@suse.de
- patches.fixes/bonding-jiffies2.patch: Update patch-mainline.
- commit a1a8fdd
* Fri Sep  3 2010 jeffm@suse.de
- Always build in AGP on x86/x86_64 so KMS works on LiveCDs (bnc#609607).
- commit d9bfa1e
* Fri Sep  3 2010 jeffm@suse.com
- irda: Correctly clean up self->ias_obj on irda_bind() failure
    (CVE-2010-2954 bnc#636112).
- commit f04e61f
* Wed Sep  1 2010 jbeulich@novell.com
- Update Xen patches to 2.6.36-rc3 and c/s 1029.
- fix unwind annotations.
- config.conf: Re-enable Xen.
- Update x86 config files.
- commit 6836619
* Wed Sep  1 2010 jbeulich@novell.com
- fix unwind annotations.
- commit 5aa6daf
* Tue Aug 31 2010 jeffm@suse.com
- net sched: fix kernel leak in act_police (CVE-2010-2942
    bnc#632309).
- commit 66e1d72
* Tue Aug 31 2010 jdelvare@suse.de
- fix jiffies overflow problems in bonding (bnc#613273).
- commit 28bd2e8
* Mon Aug 30 2010 jeffm@suse.de
- Refresh vanilla configs.
- commit 26a681e
* Mon Aug 30 2010 jeffm@suse.de
- Update to Linux: 2.6.36-rc3.
  - Eliminated 7 patches.
- commit d298d2d
* Sat Aug 28 2010 jslaby@suse.cz
- Delete
    patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch.
- Delete
    patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch.
- Delete
    patches.suse/rlim-0022-FS-proc-make-limits-writable.patch.
    This was just a workaround crap. In 2.6.36 we have a nice syscall
    instead. Sorry for commiting this to the merge-36 branch first. I
    didn't notice it was already merged here.
- commit 5449fcb
* Fri Aug 27 2010 jeffm@suse.com
- Disabled ACPI table override patches again. fsnotify was introduced into
    the truncate path and causes crashes.
- commit e18fc2c
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/supported-flag-enterprise: Fixed recovery on load failure.
- commit 8a06643
* Thu Aug 26 2010 jeffm@suse.de
- Refresh patches.suse/stack-unwind: Fixed recovery on load failure.
- commit 7f15b29
* Tue Aug 24 2010 jeffm@suse.com
- patches.arch/s390-message-catalog.diff: dev_info -> _dev_info
- commit ba20988
* Tue Aug 24 2010 jeffm@suse.de
- patches.suse/stack-unwind: Fix build on !SMP
- commit abd5493
* Tue Aug 24 2010 jeffm@suse.de
- s390: Fix prototype for execve.
- commit b448268
* Tue Aug 24 2010 jeffm@suse.de
- spectra: depend on X86_MRST.
- commit 1e3fb89
* Tue Aug 24 2010 jeffm@suse.de
- Delete patches.arch/ppc-vmcoreinfo.diff.
- commit ea39e14
* Tue Aug 24 2010 jeffm@suse.de
- caif: Use asm/unaligned.h.
- commit 92c07c2
* Tue Aug 24 2010 jeffm@suse.de
- Refresh patches.suse/SoN-20-netvm-tcp-deadlock.patch: Added missing
    fixup for sk_rmem_schedule in caif.
- commit a9ff761
* Tue Aug 24 2010 mmarek@suse.cz
- makefile: not need to regenerate kernel.release file when
    make kernelrelease.
- commit 81237a8
* Tue Aug 24 2010 jeffm@suse.com
- rpm/kernel-source.spec.in, scripts/tar-up.sh: Renamed config-options.changes
    to config-options.changes.txt in the exported package to avoid triggering
    a build service rule error.
- commit ff4889e
* Tue Aug 24 2010 jeffm@suse.com
- Revert "- Renamed doc/config-options.changes to doc/config-options.changes.txt to"
  This reverts commit 124ac26de4839f8181a5badedb231eedf5770a3e.
- commit 2932c62
* Tue Aug 24 2010 jeffm@suse.com
- Renamed doc/config-options.changes to doc/config-options.changes.txt to
    avoid triggering a build service rule error.
- commit 124ac26
* Mon Aug 23 2010 jeffm@suse.de
- supported.conf: Add iscsi_boot_sysfs
- commit 80e2ea9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Fixed typo with last fix.
- commit 22210d9
* Mon Aug 23 2010 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disable CONFIG_DEBUG_INFO. It's enabled
    dynamically in the spec file and now has follow-on options.
- commit d270759
* Mon Aug 23 2010 jeffm@suse.de
- patches.rpmify/spectra-drop-locked_ioctl-support: add <linux/smp_lock.h>
    to grab the BKL
- commit 1df02ec
* Mon Aug 23 2010 jeffm@suse.de
- Update config files: Disabled DEBUG_INFO_REDUCED.
- commit 393680a
* Mon Aug 23 2010 jeffm@suse.de
- Updated to 2.6.36-rc2.
  - Eliminated 2 patches.
- commit 52d47a0
* Wed Aug 18 2010 jeffm@suse.de
- Update to 2.6.36-rc1.
  - Eliminated 71 patches.
  - spectra: Drop ->locked_ioctl support.
  - spectra: Drop ->prepare_flush_fn support.
  - spectra: Remove duplicate GLOB_VERSION.
  - novfs: Fix ioctl usage.
  - novfs: use evict_inode.
  - Xen is disabled.
- commit 63642f6
* Mon Aug 16 2010 tiwai@suse.de
- ALSA: hda - Add quirk for Dell Vostro 1220 (bnc#631066).
- commit df12c34
* Fri Aug 13 2010 jeffm@suse.com
- README.BRANCH: Updated to reflect the permenent in-progress status.
- commit a2c882e
* Thu Aug 12 2010 gregkh@suse.de
- Update to 2.6.35.1
  - security fixes
  - bug fixes
  - obsoletes:
    patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch.
- commit a009fb4
* Thu Aug 12 2010 gregkh@suse.de
- Delete patches.kernel.org/patch-2.6.35-rc1.
- Delete patches.kernel.org/patch-2.6.35-rc1-rc2.
- Delete patches.kernel.org/patch-2.6.35-rc2-rc3.
- Delete patches.kernel.org/patch-2.6.35-rc3-rc4.
- Delete patches.kernel.org/patch-2.6.35-rc4-rc5.
- Delete patches.kernel.org/patch-2.6.35-rc5-rc6.
- commit 2e67843
* Thu Aug 12 2010 gregkh@suse.de
- Refresh patches.fixes/novfs-lindent.
  Someone needs to remember to actually test out their patches before
  adding them to the repo...
- commit 6569c56
* Thu Aug 12 2010 jeffm@suse.com
- doc/README.SUSE: Updated to describe the process used to add custom patches
- commit e5f4670
* Thu Aug 12 2010 jslaby@suse.cz
- patches.fixes/vmscan-fix-stalls.patch: vmscan: raise the bar
    to PAGEOUT_IO_SYNC stalls (bnc#625339).
- commit 1efea94
* Wed Aug 11 2010 jack@suse.cz
- novfs: Lindent novfs sources.
- commit 361594a
* Wed Aug 11 2010 neilb@suse.de
- Refresh
    patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch.
- Refresh patches.fixes/sunrpc-monotonic-expiry.
- Delete patches.fixes/nfs-write.c-bug-removal.patch.
  Update some patches for 2.6.35
- commit 15d7a62
* Wed Aug 11 2010 neilb@suse.de
- NFS: allow close-to-open cache semantics to apply to root of
    NFS filesystem (bnc#584720).
- commit deea101
* Tue Aug 10 2010 tiwai@suse.de
- ALSA: hda - patch_nvhdmi.c: Add missing codec IDs, unify names
    (bnc#627212).
- ALSA: hda - Add pin-fix for HP dc5750 (bnc#624118).
- commit 4844a71
* Mon Aug  9 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35 final and c/s 1025.
- create devices in /dev/xen when they are expected to be
    used there.
- xen/netback: Allow setting of large MTU before rings have
    connected.
- xen/netback: Always pull through PKT_PROT_LEN bytes into the
    linear part of an skb.
- pass trigger mode and polarity information to Xen for all
    interrupts.
- Update Xen config files.
- supported.conf: Add pci-iomul.ko.
- commit c642c1b
* Fri Aug  6 2010 jeffm@suse.de
- patches.xen/xen3-auto-xen-arch.diff: Update struct acpi_power_register
    usage from upstream commit 718be4aa.
- commit 4ce0b48
* Fri Aug  6 2010 jeffm@suse.de
- Update to 2.6.35-final and refresh patch set.
- commit a40327f
* Mon Aug  2 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Package log.sh in the source rpm
- commit 53246ff
* Fri Jul 23 2010 jack@suse.cz
- novfs: Fix error codes for getxattr for novfs (bnc#529535).
- commit 06b3243
* Fri Jul 23 2010 jeffm@suse.de
- Update to 2.6.35-rc6.
- commit 643df99
* Fri Jul 23 2010 jack@suse.cz
- novfs: code cleanup for one case of novfs return value
    (bnc#624606).
- commit 4875860
* Wed Jul 21 2010 jack@suse.cz
- Fixed patch headers of patches.fixes/novfs-xattr-memleak
- commit 65ab01f
* Wed Jul 21 2010 jack@suse.cz
- novfs: Fix a memory leak that causes an OOM condition
    (bnc#610828).
- commit 519d8a0
* Tue Jul 20 2010 jack@suse.cz
- novfs: backing device info initialization (bnc#623472).
- commit b576dae
* Tue Jul 20 2010 mmarek@suse.cz
- scripts/tar-up.sh: Generate the rpm changelog using gitlog2changes.
- Move kernel-source.changes.old to rpm/ (not included in the pachage
    though).
- commit 8ed2389
* Tue Jul 20 2010 jblunck@suse.de
- rpm/package-descriptions: Change summary/description for trace flavor (bnc#488692).
- commit da8e17e
* Mon Jul 19 2010 mmarek@suse.cz
- Move rpm changelog to kernel-source.changes.old
- commit 93036bd
* Thu Jul 15 2010 bphilips@suse.de
- X86_MRST: Disable moorsetown since it deselects SERIO_I8042
  - See 0b28bac5aef7bd1ab213723df031e61db9ff151a, fixed in -tip but we
    still don't want X86_MRST
* Wed Jul 14 2010 trenn@suse.de
- patches.arch/acpi_fix_fadt_32_bit_zero_length.patch: Only use
  32 bit addresses if they have a valid length (bug#581644).
* Wed Jul 14 2010 bphilips@suse.de
- Update -desktop config files to enable CGROUPS for systemd
* Wed Jul 14 2010 jeffm@suse.de
- Update to 2.6.35-rc5.
  - Eliminated 5 patches.
* Tue Jul 13 2010 jack@suse.de
- patches.fixes/novfs-overflow-fixes: novfs: security: Add buffer
  overflow, integer wraparound fixes (bnc#594362).
* Wed Jul  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc4.
* Wed Jul  7 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-2.6.35-api-changes: Updated for -debug flavor.
* Wed Jul  7 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Jul  7 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Install config-option.changes
  This file documents the changes in the kernel configs.
* Wed Jul  7 2010 mmarek@suse.cz
- patches.rpmify/kbuild-setlocalversion-fix: kbuild: Fix path
  to scripts/setlocalversion.
* Tue Jul  6 2010 jeffm@suse.de
- Update to 2.6.35-rc4.
  - Eliminated 4 patches.
* Fri Jul  2 2010 jeffm@suse.de
- patches.fixes/iwlwifi-fix-tx-power-configuration-on-3945-and-4965-devices:
  iwlwifi: fix TX power configuration on 3945 and 4965 devices
  (bnc#619440 bnc#610421).
* Fri Jul  2 2010 jbeulich@novell.com
- patches.suse/stack-unwind: Fix after upstream commit
  9e565292270a2d55524be38835104c564ac8f795.
* Fri Jul  2 2010 trenn@suse.de
- patches.arch/x86_mce_intel_decode_physical_fix_dynamic_debug.patch:
  For some reason the macro used by dynamic debug breaks things
  (bnc#619416).
* Fri Jul  2 2010 trenn@suse.de
  Mainline goes another way (bug #476509).
  Also there is a problem with this patch, breaking dynamic debugging
  (bnc#619416) -> just remove it, there will show up something else
  mainline.
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  Delete.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Delete.
* Thu Jul  1 2010 jeffm@suse.de
- patches.suse/dm-raid45-api-update-remove-dm_put-after-dm_table_get_md:
  dm-raid45: API update: Remove dm_put after dm_table_get_md
  (bnc#615656).
* Thu Jul  1 2010 jdelvare@suse.de
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  Update references (bnc#610362).
* Thu Jul  1 2010 bphilips@suse.de
- patches.drivers/ixgbe-disable-tx-engine-before-disabling-tx-laser.patch:
  ixgbe: disable tx engine before disabling tx laser.
- patches.drivers/ixgbe-fix-panic-when-shutting-down-system-with-WoL-e.patch:
  ixgbe: fix panic when shutting down system with WoL enabled.
- patches.drivers/ixgbe-skip-non-IPv4-packets-in-ATR-filter.patch:
  ixgbe: skip non IPv4 packets in ATR filter.
- patches.fixes/e1000e-don-t-inadvertently-re-set-INTX_DISABLE.patch:
  e1000e: don't inadvertently re-set INTX_DISABLE.
* Wed Jun 30 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Delete.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Delete.
* Tue Jun 29 2010 nfbrown@suse.de
- patches.fixes/nfs_wb_page_deadlock.fix: NFS: Fix another
  nfs_wb_page() deadlock (bnc#612794).
* Mon Jun 28 2010 mmarek@suse.cz
- rpm/find-provides: Add base symsets to the main subpackage.
* Fri Jun 25 2010 jeffm@suse.de
- Update config files for sparc64/net to remove unnecessary options.
* Fri Jun 25 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Fri Jun 25 2010 jbeulich@novell.com
- patches.arch/kvm-split-paravirt-ops-by-functionality: Adjust
  Kconfig style to match upstream.
- patches.fixes/seccomp-disable-tsc-option: Adjust Kconfig style
  to match upstream.
- patches.suse/SoN-11-mm-reserve.patch: Fix compiler warning.
* Fri Jun 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.35-rc3.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Thu Jun 24 2010 agruen@suse.de
- Replace the nfs4acl patches by their successor patch queue,
  richacls (see http://www.suse.de/~agruen/richacl/).
- Update config files: CONFIG_EXT4_FS_RICHACL=y.
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/ext4-make-sure-the-move_ext-ioctl-can-t-overwrite-append-only-files:
  ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only
  files (bnc#612457 CVE-2010-2066).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-writing-to-non-page-aligned-gfs2_quota-structures:
  GFS2: Fix writing to non-page aligned gfs2_quota structures
  (bnc#599957 CVE-2010-1436).
* Thu Jun 24 2010 jeffm@suse.de
- patches.fixes/gfs2-fix-permissions-checking-for-setflags-ioctl:
  GFS2: Fix permissions checking for setflags ioctl() (bnc#608576
  CVE-2010-1641).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Thu Jun 24 2010 jdelvare@suse.de
- patches.drivers/hwmon-it87-fix-in7-on-IT8720F.patch: hwmon:
  (it87) Fix in7 on IT8720F (bnc#612910).
* Wed Jun 23 2010 jeffm@suse.de
- btrfs fix rollup from v2.6.35:
- patches.fixes/btrfs-handle-err_ptr-from-posix_acl_from_xattr:
  Btrfs: handle ERR_PTR from posix_acl_from_xattr().
- patches.fixes/btrfs-avoid-bug-when-dropping-root-and-reference-in-same-transaction:
  Btrfs: avoid BUG when dropping root and reference in same
  transaction.
- patches.fixes/btrfs-prohibit-a-operation-of-changing-acl-s-mask-when-noacl-mount-option-used:
  Btrfs: prohibit a operation of changing acl's mask when noacl
  mount option used.
- patches.fixes/btrfs-should-add-a-permission-check-for-setfacl:
  Btrfs: should add a permission check for setfacl.
- patches.fixes/btrfs-btrfs_lookup_dir_item-can-return-err_ptr:
  Btrfs: btrfs_lookup_dir_item() can return ERR_PTR.
- patches.fixes/btrfs-btrfs_read_fs_root_no_name-returns-err_ptrs:
  Btrfs: btrfs_read_fs_root_no_name() returns ERR_PTRs.
- patches.fixes/btrfs-unwind-after-btrfs_start_transaction-errors:
  Btrfs: unwind after btrfs_start_transaction() errors.
- patches.fixes/btrfs-btrfs_iget-returns-err_ptr: Btrfs:
  btrfs_iget() returns ERR_PTR.
- patches.fixes/btrfs-handle-kzalloc-failure-in-open_ctree:
  Btrfs: handle kzalloc() failure in open_ctree().
- patches.fixes/btrfs-handle-error-returns-from-btrfs_lookup_dir_item:
  Btrfs: handle error returns from btrfs_lookup_dir_item().
- patches.fixes/btrfs-fix-bug_on-for-fs-converted-from-extn:
  Btrfs: Fix BUG_ON for fs converted from extN.
- patches.fixes/btrfs-fix-null-dereference-in-relocation-c:
  Btrfs: Fix null dereference in relocation.c.
- patches.fixes/btrfs-fix-remap_file_pages-error: Btrfs: fix
  remap_file_pages error.
- patches.fixes/btrfs-uninitialized-data-is-check_path_shared:
  Btrfs: uninitialized data is check_path_shared().
- patches.fixes/btrfs-fix-fallocate-regression: Btrfs: fix
  fallocate regression.
- patches.fixes/btrfs-fix-loop-device-on-top-of-btrfs: Btrfs:
  fix loop device on top of btrfs.
- patches.fixes/btrfs-add-more-error-checking-to-btrfs_dirty_inode:
  Btrfs: add more error checking to btrfs_dirty_inode.
- patches.fixes/btrfs-allow-unaligned-dio: Btrfs: allow unaligned
  DIO.
- patches.fixes/btrfs-drop-verbose-enospc-printk: Btrfs: drop
  verbose enospc printk.
- patches.fixes/btrfs-fix-block-generation-verification-race:
  Btrfs: Fix block generation verification race.
- patches.fixes/btrfs-fix-preallocation-and-nodatacow-checks-in-o_direct:
  Btrfs: fix preallocation and nodatacow checks in O_DIRECT.
- patches.fixes/btrfs-avoid-enospc-errors-in-btrfs_dirty_inode:
  Btrfs: avoid ENOSPC errors in btrfs_dirty_inode.
- patches.fixes/btrfs-move-o_direct-space-reservation-to-btrfs_direct_io:
  Btrfs: move O_DIRECT space reservation to btrfs_direct_IO.
- patches.fixes/btrfs-rework-o_direct-enospc-handling: Btrfs:
  rework O_DIRECT enospc handling.
- patches.fixes/btrfs-use-async-helpers-for-dio-write-checksumming:
  Btrfs: use async helpers for DIO write checksumming.
- patches.fixes/btrfs-don-t-walk-around-with-task-state-task_running:
  Btrfs: don't walk around with task->state != TASK_RUNNING.
- patches.fixes/btrfs-do-aio_write-instead-of-write: Btrfs:
  do aio_write instead of write.
- patches.fixes/btrfs-add-basic-dio-read-write-support: Btrfs:
  add basic DIO read/write support.
- patches.fixes/direct-io-add-a-hook-for-the-fs-to-provide-its-own-submit_bio-function:
  direct-io: add a hook for the fs to provide its own submit_bio
  function.
- patches.fixes/btrfs-metadata-enospc-handling-for-balance:
  Btrfs: Metadata ENOSPC handling for balance.
- patches.fixes/btrfs-pre-allocate-space-for-data-relocation:
  Btrfs: Pre-allocate space for data relocation.
- patches.fixes/btrfs-metadata-enospc-handling-for-tree-log:
  Btrfs: Metadata ENOSPC handling for tree log.
- patches.fixes/btrfs-metadata-reservation-for-orphan-inodes:
  Btrfs: Metadata reservation for orphan inodes.
- patches.fixes/btrfs-introduce-global-metadata-reservation:
  Btrfs: Introduce global metadata reservation.
- patches.fixes/btrfs-update-metadata-reservation-for-delayed-allocation:
  Btrfs: Update metadata reservation for delayed allocation.
- patches.fixes/btrfs-integrate-metadata-reservation-with-start_transaction:
  Btrfs: Integrate metadata reservation with start_transaction.
- patches.fixes/btrfs-introduce-contexts-for-metadata-reservation:
  Btrfs: Introduce contexts for metadata reservation.
- patches.fixes/btrfs-kill-init_btrfs_i: Btrfs: Kill
  init_btrfs_i().
- patches.fixes/btrfs-shrink-delay-allocated-space-in-a-synchronized:
  Btrfs: Shrink delay allocated space in a synchronized.
- patches.fixes/btrfs-kill-allocate_wait-in-space_info: Btrfs:
  Kill allocate_wait in space_info.
- patches.fixes/btrfs-link-block-groups-of-different-raid-types:
  Btrfs: Link block groups of different raid types.
- patches.fixes/nilfs-fix-breakage-caused-by-barrier-flag-changes:
  nilfs: fix breakage caused by barrier flag changes.
- patches.fixes/blkdev-generalize-flags-for-blkdev_issue_fn-functions:
  blkdev: generalize flags for blkdev_issue_fn functions.
* Wed Jun 23 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fixed typo.
* Tue Jun 22 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-force_dma: ata_generic:
  implement ATA_GEN_* flags and force enable DMA on MBP 7,1
  (bko#15923).
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Tue Jun 22 2010 mmarek@suse.cz
- rpm/config.sh: Build against openSUSE:11.3.
* Tue Jun 22 2010 knikanth@suse.de
- patches.suse/dm-raid45-26-Nov-2009.patch: DMRAID45 module
  (bnc#615906, bnc#565962).
- patches.suse/dm-raid45_2.6.27_20081027.patch: Delete.
- Sync dm-raid45 to the later version.
* Mon Jun 21 2010 jeffm@suse.de
- Resync v2.6.35 with master.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/acpi-generic-initramfs-table-override-support:
  Refresh.
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Refresh.
* Mon Jun 21 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Require a mkinitrd that supports
  KMS (bnc#615680).
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap calls
  while loading initramfs files.
* Mon Jun 21 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: Fix missing kmap of
  pages for initramfs loading.
* Fri Jun 18 2010 jbeulich@novell.com
- patches.xen/xen3-driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
- Refresh other Xen patches.
- Update Xen config files.
* Thu Jun 17 2010 teheo@suse.de
- patches.drivers/libata-ata_generic-mcp89-mbp71:
  ahci,ata_generic: let ata_generic handle new MBP w/ MCP89
  (bko#15923).
* Wed Jun 16 2010 jeffm@suse.de
- Update to 2.6.35-rc3.
  - Eliminated 1 patch.
* Mon Jun 14 2010 jslaby@suse.de
- patches.fixes/pci-hotplug-cpqphp-fix-crash.patch: PCI:
  hotplug/cpqphp, fix NULL dereference (bnc#609338).
* Wed Jun  9 2010 jeffm@suse.de
- patches.rpmify/ceph-atomic_long-init-fix: ceph: fix atomic64_t
  initialization on ia64.
* Tue Jun  8 2010 jeffm@suse.de
- patches.trace/utrace-core: Workaround missing kref_set().
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/ppc64-xmon-dmesg-printing.patch: Refresh.
* Tue Jun  8 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: Refresh.
- patches.rpmify/wlags49-missing-strlen-include: wlags49_h2:
  build fix.
* Tue Jun  8 2010 jeffm@suse.de
- patches.arch/x86_mce_intel_decode_physical_address.patch:
  Refresh.
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  Refresh.
* Tue Jun  8 2010 jeffm@suse.com
- supported.conf: Updated dependencies for 2.6.35
* Mon Jun  7 2010 jeffm@suse.com
- patches.kernel.org/revert-tty-fix-a-little-bug-in-scrup-vt-c:
  Revert "tty: fix a little bug in scrup, vt.c".
* Mon Jun  7 2010 jeffm@suse.com
- Update to 2.6.35-rc2.
* Thu Jun  3 2010 jeffm@suse.de
- Re-enable DSDT in initramfs code.
- patches.suse/acpi-don-t-preempt-until-the-system-is-up: acpi:
  don't preempt until the system is up.
* Wed Jun  2 2010 bphilips@suse.de
- patches.drivers/e1000e-entropy-source.patch: Reintroduce IRQF_SHARED
  to fix non-MSI case (bnc#610362).
* Wed Jun  2 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: More -rt fixes.
* Tue Jun  1 2010 jeffm@suse.com
- Update to 2.6.35-rc1.
  - Eliminated 13 patches.
  - Xen is disabled.
* Tue Jun  1 2010 bphilips@suse.de
- patches.drivers/tg3-5785-and-57780-asic-revs-not-working.patch:
  tg3: 5785 and 57780 asic revs not working (bnc#580780).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-module-subpackage: Change the kmp versioning to prefix
  the kernel version with "k" to avoid false version downgrades
  (bnc#609483).
* Tue Jun  1 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: pcre-tools is not needed.
* Mon May 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix for -rt.
* Wed May 26 2010 gregkh@suse.de
- patches.drivers/driver-core-add-devname-module-aliases-to-allow-module-on-demand-auto-loading.patch:
  driver core: add devname module aliases to allow module
  on-demand auto-loading.
* Tue May 25 2010 jeffm@suse.de
- supported.conf: Added mperf, which powernow and acpi-cpufreq now
  depend on.
* Tue May 25 2010 jeffm@suse.com
- patches.arch/powernow-k8-add-core-performance-boost-support:
  powernow-k8: Add core performance boost support (bnc#602209).
- patches.arch/x86-cpu-add-amd-core-boosting-feature-flag-to-proc-cpuinfo:
  x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo.
- patches.arch/x86-cpufreq-add-aperf-mperf-support-for-amd-processors:
  x86, cpufreq: Add APERF/MPERF support for AMD processors
  (bnc#602209).
* Tue May 25 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34 final.
- Update Xen config files.
- patches.xen/xen3-acpi_processor_check_maxcpus.patch: Do not
  try to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Mon May 24 2010 jbenc@suse.cz
- patches.suse/b43-missing-firmware-info.patch: b43: Change
  firmware missing message to refer to openSUSE script.
* Sun May 23 2010 teheo@suse.de
- patches.drivers/pci-disable-msi-on-K8M800: pci: disable MSI
  on VIA K8M800 (bnc#599508).
* Sat May 22 2010 trenn@suse.de
- patches.xen/xen3-auto-common.diff: Refresh.
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
* Sat May 22 2010 trenn@suse.de
- patches.fixes/acpi_processor_check_maxcpus.patch: Do not try
  to set up acpi processor stuff on cores exceeding maxcpus=
  (bnc#601520).
- patches.fixes/acpi_wmi_debug.patch: X86 platform wmi: Introduce
  debug param to log all WMI events (bnc#598059).
- patches.fixes/hp_wmi_fix_acpi_version_integer_size.patch:
  x86 platform drivers: hp-wmi fix buffer size depending on ACPI
  version (bnc#598059).
- patches.fixes/wmi_debug_pass_guid: X86 platform wmi: Also log
  GUID string when an event happens and debug is set (bnc#598059).
- patches.fixes/wmi_dump_wdg_data.patch: X86 platfrom wmi: Add
  debug facility to dump WMI data in a readable way (bnc#598059).
* Thu May 20 2010 jeffm@suse.com
- Disabled CONFIG_RT2800PCI (bnc#606243)
  - These devices are handled by the rt2860 staging driver.
* Mon May 17 2010 jeffm@suse.com
- patches.fixes/kvm-ioapic.patch: Refresh.
* Mon May 17 2010 jeffm@suse.com
- Update to 2.6.34-final.
* Wed May 12 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix preserving of old symsets.
* Wed May 12 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc7 and c/s 1017.
* Tue May 11 2010 jeffm@suse.com
- Update config files for vanilla.
* Tue May 11 2010 jeffm@suse.com
- Updated to 2.6.34-rc7.
  - Eliminated 3 patches.
* Sun May  2 2010 jeffm@suse.com
- Update to 2.6.34-rc6.
  - Eliminated 2 patches.
* Sun May  2 2010 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-due-to-null-nameidata: Allow null nd
  (as nfs server uses) on create (bnc#593940).
* Fri Apr 30 2010 trenn@suse.de
- patches.fixes/acpi_ensure_spec_correct_address_space_length.patch:
  ACPI/x86/PCI: compute Address Space length rather than using
  _LEN (bnc#598641).
* Thu Apr 29 2010 jbeulich@novell.com
- Update -ec2 config files (X86_MSR=m again).
* Thu Apr 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc5-git8 and c/s 1016.
- Update Xen config files.
- patches.xen/xen-kzalloc: use kzalloc() in favor of
  kmalloc()+memset().
- patches.xen/xen-fix_trace_power.patch: Rename to ...
- patches.xen/xen3-x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  ... this.
* Thu Apr 29 2010 knikanth@suse.de
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Refresh.
  Fix patch to call dm_table_get directly instead of calling
  dm_get_table unnecesarily.
* Thu Apr 29 2010 jeffm@suse.com
- Update to 2.6.34-rc5-git8.
  - Eliminated 1 patch.
* Wed Apr 28 2010 trenn@suse.de
- patches.xen/xen-fix_trace_power.patch: x86 cpufreq: Make
  trace_power_frequency cpufreq driver independent (none).
* Wed Apr 28 2010 mmarek@suse.cz
- Disable CONFIG_FIRMWARE_IN_KERNEL in all configs, we start udev
  early enough in the initrd.
* Wed Apr 28 2010 trenn@suse.de
- patches.fixes/acpi-cpufreq_fix_cpu_any_notification.patch:
  acpi-cpufreq: Fix CPU_ANY CPUFREQ_{PRE,POST}CHANGE notification
  (none).
- patches.trace/x86_cpufreq_make_trace_power_frequency_cpufreq_driver_independent.patch:
  x86 cpufreq: Make trace_power_frequency cpufreq driver
  independent (none).
* Wed Apr 28 2010 trenn@suse.de
- Update config files.
  Unify X86_MSR and X86_CPUID configs:
  - CONFIG_X86_CPUID=m
  - CONFIG_X86_MSR=y
  for all i386 and x86_64 flavors.
* Mon Apr 26 2010 jeffm@suse.com
- Disabled CONFIG_TUNE_CELL on ppc64 (bnc#599045)
* Mon Apr 26 2010 jeffm@suse.com
- Enabled CONFIG_FIREWIRE (bnc#586172)
  - CONFIG_IEEE1394 is still enabled but deprecated.
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp_wmi_add_media_key.patch: x86 platform drivers:
  hp-wmi Add media key 0x20e8 (bnc#598059).
* Fri Apr 23 2010 trenn@suse.de
- patches.fixes/hp-wmi_detect_keys.patch: x86 platform drivers:
  hp-wmi Reorder event id processing (bnc#598059).
- patches.fixes/hp_wmi_catch_unkown_event_key_codes.patch: x86
  platform drivers: hp-wmi Catch and log unkown event and key
  codes correctly (bnc#598059).
- patches.fixes/hp_wmi_use_prefix_string.patch: x86 platform
  drivers: hp-wmi Use consistent prefix string for messages
  (bnc#598059).
* Thu Apr 22 2010 jeffm@suse.com
- patches.suse/s390-Kerntypes.diff: Fix slab.h vs slab_def.h
  include ordering in kerntypes.c
* Thu Apr 22 2010 mmarek@suse.cz
- rpm/kernel-*.spec.in: Provide %%name = %%version-%%source_rel in
  all spec files (bnc#598453).
* Thu Apr 22 2010 tiwai@suse.de
- Update config files: Fix remaining CONFIG_LEDS_CLASS=m
* Thu Apr 22 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  Refresh.  Fix dependency with LED class.
- Update config files.
* Wed Apr 21 2010 tiwai@suse.de
- patches.drivers/input-Add-LED-support-to-Synaptics-device:
  input: Add LED support to Synaptics device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/input-Add-support-of-Synaptics-Clickpad-device:
  input: Add support of Synaptics Clickpad device
  (bnc#547370,bnc#582529,bnc#589014).
- patches.drivers/synaptics-hp-clickpad: Delete.
* Wed Apr 21 2010 jeffm@suse.com
- Update to  2.6.34-rc5.
  - Eliminated 1 patch.
* Mon Apr 19 2010 jack@suse.de
- patches.fixes/novfs-LFS-initialization: fs: novfs: Initialize
  super-block with standard macros.
- patches.fixes/novfs-return-ENOTEMPTY-when-deleting-nonempty-dir:
  fs: novfs: Return ENOTEMPTY when tyring to delete a non-empty
  folder (bnc#583964).
* Mon Apr 19 2010 jeffm@suse.de
- patches.fixes/x86-apbt-conditionally-register-cpu-hp-notifier-for-apbt:
  x86/apbt: conditionally register cpu hp notifier for apbt
  (bko#15786).
* Thu Apr 15 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc4 and c/s 1011.
- patches.xen/xen-netfront-ethtool: netfront: ethtool -i does
  not return info about xennet driver (bnc#591179).
- patches.xen/xen-no-reboot-vector: eliminate REBOOT_VECTOR.
- patches.xen/xen-x86_64-kern_addr_valid: x86-64:
  kern_addr_valid() must not walk page tables mapping hypervisor
  space (bnc#591371).
- Update Xen config files.
- supported.conf: drivers/xen/evtchn.ko is supported.
* Thu Apr 15 2010 teheo@suse.de
- patches.fixes/block-blk_abort_request-lock-fix: libata/SCSI:
  fix locking around blk_abort_request() (bnc#585927).
* Wed Apr 14 2010 jeffm@suse.de
- Update to 2.6.34-rc4.
  - Eliminated 3 patches.
* Tue Apr 13 2010 mmarek@suse.cz
- Update vanilla config files.
* Tue Apr 13 2010 tiwai@suse.de
- patches.suse/bootsplash-console-fix: Fix rendering on linux
  console with bootsplash (bnc#595657,bnc#594209).
* Tue Apr 13 2010 agraf@suse.de
- Update config files to disable KVM on PPC also for ppc/ppc64.
* Tue Apr 13 2010 teheo@suse.de
- Update config files to disable CONFIG_DEBUG_BLOCK_EXT_DEVT which was
  enabled by 5246824c to ease testing userland handling of ext devt.
* Mon Apr 12 2010 jslaby@suse.de
- patches.fixes/hibernation-fix-s2disk.patch: PM / Hibernate:
  user.c, fix SNAPSHOT_SET_SWAP_AREA handling (bko#15728).
* Mon Apr 12 2010 jack@suse.de
- patches.fixes/novfs-dentry-cache-limit.patch: novfs: Remove
  dcache count restricting code (bnc#576026).
* Mon Apr 12 2010 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: Refresh (bnc#588458).
* Fri Apr  9 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: Fix issue on
  32-bit systems.
* Fri Apr  9 2010 knikanth@suse.de
- patches.fixes/loop-update-mtime.patch: loop: Update mtime when
  writing using aops (bnc#590738).
* Thu Apr  8 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-permissions-on-reiserfs_priv:
  reiserfs: Fix permissions on .reiserfs_priv (bnc#593906
  CVE-2010-1146).
* Thu Apr  8 2010 agraf@suse.de
- Update PPC config files to disable KVM on PPC. It's not ready yet.
  Please enable it again as soon as we hit 2.6.35.
* Wed Apr  7 2010 jengelh@medozas.de
- Add config/sparc64/net that is light on size. For netbooting,
  both the kernel and initrd must fit into 10MB.
* Wed Mar 31 2010 jeffm@suse.de
- Updated sparc64 config.
* Wed Mar 31 2010 jeffm@suse.de
- Update to 2.6.34-rc3.
* Wed Mar 31 2010 mmarek@suse.cz
- doc/README.SUSE: Update some obsolete information.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-docs.spec.in: Fix path to kernel source.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/configtool.pl, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Add support for custom config options
  in config.addon.tar.bz2. This tarball is expected to have the
  same layout as config.tar.bz2 and the config options listed there
  take precedence over config.tar.bz2.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generate the chmod +x line automatically.
* Wed Mar 31 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh:
  Generate the Source: lines from kernel-source.spec.in.
* Tue Mar 30 2010 jeffm@suse.de
- patches.fixes/reiserfs-remove-2-tb-file-size-limit: reiserfs:
  Remove 2 TB file size limit (bnc#592100).
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in, rpm/mkspec:
  Generated the NoSource and %%setup lines automatically from the
  preamble.
* Tue Mar 30 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Provide $pkg = %%version-%%source_rel
  in kernel-devel and kernel-source-vanilla.
* Mon Mar 29 2010 jeffm@suse.de
- patches.fixes/reiserfs-fix-locking-BUG-during-mount-failure:
  reiserfs: Fix locking BUG during mount failure (bnc#591807).
* Mon Mar 29 2010 jeffm@suse.de
- Disabled MAX63XX_WATCHDOG on s390.
* Mon Mar 29 2010 jeffm@suse.de
- Update to 2.6.34-rc2-git3.
  - Eliminated 1 patch.
  - Fixed ps3 config.
* Mon Mar 29 2010 jbeulich@novell.com
- Update Xen patches to 2.6.34-rc2 and c/s 1007.
- Update config files.
- config.conf: Re-enable Xen configs.
- patches.xen/xen-floppy: Xen: improve floppy behavior
  (bnc#584216).
- patches.xen/xen-vscsi-module-alias: allow pv scsi hba driver
  to be loaded automatically.
- patches.xen/xen-vusb-module-alias: allow pv usb hcd driver to
  be loaded automatically (bnc#584213).
* Fri Mar 26 2010 jkosina@suse.cz
- patches.fixes/hid-fix-gyration-oops.patch: HID: fix oops in
  gyration_event() (bnc#589329).
* Thu Mar 25 2010 jack@suse.de
- patches.fixes/novfs-fix-oops-in-scope-finding: novfs: fix an
  oops in novfs scope-finding code (bnc#588579).
* Thu Mar 25 2010 jeffm@suse.de
- patches.fixes/powerpc-fix-handling-of-strnlen-with-zero-len:
  powerpc: fix handling of strnlen with zero len (bnc#582681).
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/lpfc-add-raywire-id: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/linux-2.6.29-kms-after-sata.patch: Refresh.
* Tue Mar 23 2010 jeffm@suse.de
- patches.fixes/do_anonymous_page-race: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.drivers/libata-prefer-over-ide: Delete.
- patches.drivers/libata-ahci-aspire-3810t-noncq: Delete.
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: Delete.
- patches.suse/block-add-mangle-devt-switch: Delete.
* Tue Mar 23 2010 jeffm@suse.de
- patches.suse/apm_setup_UP.diff: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: Delete.
- patches.arch/ppc-efika-mpc52xx-ac97.patch: Delete.
- patches.arch/ppc-efika-psc-console-autodetection.patch: Delete.
- patches.suse/suse-ppc32-mol-BIT: Delete.
- patches.suse/suse-ppc32-mol-get-property: Delete.
- patches.suse/suse-ppc32-mol-handle-mm-fault: Delete.
- patches.suse/suse-ppc32-mol-ioctl: Delete.
- patches.suse/suse-ppc32-mol-kbuild.patch: Delete.
- patches.suse/suse-ppc32-mol-semaphore: Delete.
- patches.suse/suse-ppc32-mol-sheep: Delete.
- patches.suse/suse-ppc32-mol.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/dlm-enable-debug.patch: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.fixes/ds1682-build-fix: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/kvm-as-kmp: Delete.
* Mon Mar 22 2010 jeffm@suse.de
- patches.suse/xfs-dmapi-fix-incompatible-pointer-type-warning:
  xfs/dmapi: fix incompatible pointer type warning.
* Sun Mar 21 2010 jeffm@suse.de
- Updated to 2.6.34-rc2.
  - Eliminated 4 patches.
* Fri Mar 19 2010 jbohac@suse.cz
- set CONFIG_IPV6=y for all flavours (bnc#561611)
* Thu Mar 18 2010 jeffm@suse.de
- Refreshed patch series.
* Wed Mar 17 2010 jeffm@suse.de
- Updated to 2.6.34-rc1-git6.
  - Eliminated 8 patches.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Remove Obsoletes: for 10.3 KMPs.
* Tue Mar 16 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Move Obsoletes: msi-wmi-kmp to the
  sle11-ga group and make the comment more explanatory.
* Tue Mar 16 2010 trenn@suse.de
- rpm/kernel-binary.spec.in:
  bnc#587578
* Thu Mar 11 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Thu Mar 11 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  Fix unintialized variable. Refresh.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/gpio/max730x, max7301 now
  depends on it.
* Wed Mar 10 2010 jeffm@suse.de
- Enabled CONFIG_DRM_RADEON_KMS; Matching KMS-enabled X.org has
  been committed to Factory.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-kvm-build-failure-workaround: powerpc:
  kvm build failure workaround.
* Wed Mar 10 2010 jeffm@suse.de
- patches.rpmify/powerpc-mpc52xx-build-fix: powerpc: Build fix
  for mpc52xx.
* Wed Mar 10 2010 jeffm@suse.de
- supported.conf: Added kernel/drivers/i2c/i2c-smbus, i2c-parport
  now depends on it.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: the dwarfextract package has been
  dropped from Factory.
* Wed Mar 10 2010 jeffm@suse.de
- Update config files for vanilla.
* Wed Mar 10 2010 jdelvare@suse.de
- supported.conf: Add hwmon/ams back.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix symsets for non-split kernels.
* Wed Mar 10 2010 mmarek@suse.cz
- rpm/kernel-source.spec.in: Add symsets.pl to the src.rpm.
* Wed Mar 10 2010 jeffm@suse.de
- Updated to 2.6.34-rc1.
  - Eliminated 36 patches.
  - Xen is disabled
  - Added new doc/config-options.changes to document configuration
    changes.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Package symsets in the -devel package.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides: Do not generate ksym(...) provides.
* Tue Mar  9 2010 mmarek@suse.cz
- rpm/find-provides, rpm/symsets.pl: Generate symsets again
  (bnc#582907).
* Fri Mar  5 2010 knikanth@suse.de
- patches.fixes/xfs-nonblocking-inode-locking-io-completion.patch:
  xfs: Non-blocking inode locking in IO completion (bnc#568319).
* Fri Mar  5 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: split devel files and full source
  into two rpms, of which only the former is really required for
  KMP building
* Fri Mar  5 2010 jengelh@medozas.de
- add configs/sparc64/default
* Wed Mar  3 2010 tonyj@suse.de
- patches.trace/powerpc-rename-irq-tracing: should have been deleted by
  previous commit
* Wed Mar  3 2010 tonyj@suse.de
- remove perfmon2 patches
* Wed Mar  3 2010 tonyj@suse.de
- Remove lttng-instrumentation patches, they have been removed from
  SLE11SP1
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Tue Mar  2 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33 and c/s 1003.
- patches.xen/xen-clockevents: replace Xen's custom time handling
  with such using GENERIC_CLOCKEVENTS infrastructure.
- Update Xen config files.
* Tue Mar  2 2010 nfbrown@suse.de
- patches.fixes/sunrpc-monotonic-expiry: sunrpc: use monotonic
  time in expiry cache (bnc#578668).
* Thu Feb 25 2010 jeffm@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: Obsolete.
* Thu Feb 25 2010 mmarek@suse.cz
- Drop include of generated/autoconf.h in our patches, it's not
  needed since 2.6.15:
- patches.suse/novfs-client-module: Refresh.
- patches.suse/s390-Kerntypes.diff: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
* Thu Feb 25 2010 teheo@suse.de
- scripts/run_oldconfig.sh doesn't update ppc/vanilla for some reason.
  Do it manually.
* Thu Feb 25 2010 teheo@suse.de
- ppc explicitly sets CONFIG_LEDS_TRIGGER_IDE_DISK.  Run
  scripts/run_oldconfig.sh to fix configs up.
* Thu Feb 25 2010 teheo@suse.de
- Drop CONFIG_IDE from all configs.
* Thu Feb 25 2010 jeffm@suse.com
- patches.xen/xen3-patch-2.6.33-rc8-final: Build fix for the
  2.6.33-final update.
* Wed Feb 24 2010 jeffm@suse.de
- Updated to 2.6.33-final.
  - Eliminated 4 patches.
* Wed Feb 24 2010 jeffm@suse.de
- patches.rpmify/ftrace-fix-ftrace_event_call-alignment-for-use-with-gcc-4-5:
  ftrace: fix ftrace_event_call alignment for use with gcc 4.5
  (bnc#582222).
* Wed Feb 24 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc8 and c/s 997.
- patches.xen/xen-x86-time-per-cpu: fold per-CPU accounting data
  into a structure.
- patches.xen/xen-x86-xtime-lock: reduce contention on xtime_lock
  (bnc#569014, bnc#571041, bnc#571769, bnc#572146).
* Wed Feb 24 2010 jengelh@medozas.de
- rpm/kernel-source.spec.in: use macros in a few more places
* Tue Feb 23 2010 jack@suse.de
- patches.fixes/novfs-fix-inode-uid: novfs: Get proper UID when
  looking up inode (bnc#486997).
- patches.fixes/novfs-incorrect-filesize-fix: novfs: novfs
  reports incorrect file size (bnc#426536).
- patches.fixes/novfs-truncate-fix: novfs: Fixes corruption of
  OO documents on NSS Volumes (bnc#508259).
* Sat Feb 20 2010 jengelh@medozas.de
- use standard short options in tar commands
* Wed Feb 17 2010 nfbrown@suse.de
- patches.fixes/nfs-find-crash: Fix potential oops when running
  find on an NFS mount. (bnc#573107).
* Tue Feb 16 2010 jeffm@suse.com
- Set CONFIG_LSM_MMAP_MIN_ADDR=4096 to allow qemu to emulate
  other architectures properly (bnc#574654).
* Tue Feb 16 2010 jeffm@suse.com
- Update to 2.6.33-rc8.
  - Eliminated 1 patch.
* Mon Feb 15 2010 rgoldwyn@suse.de
- patches.fixes/novfs-err_ptr-fix.diff: Oops in novfs:unlink_local
  (bnc#569071).
* Fri Feb 12 2010 trenn@suse.de
- Update config files.
  Enable p4_clockmod for i386 desktop
  While this is broken by design it allows to remove clocking
  limits from the vendor on e.g. eeepc 701
* Fri Feb 12 2010 jeffm@suse.com
- patches.fixes/taskstats-alignment: delayacct: align to 8 byte
  boundary on 64-bit systems (bnc#578065).
* Fri Feb 12 2010 trenn@suse.de
- patches.fixes/acpi_fix_no_critical_tp.patch: ACPI thermal:
  Don't invalidate thermal zone if critical trip point is bad
  (bnc#531547).
- patches.fixes/acpi_pci_hot_plug_sanity_checks.patch: ACPI:
  acpi_bus_{scan,bus,add}: return -ENODEV if no device was found
  (bnc#531547).
- patches.fixes/acpi_thermal_check_trip_points.patch: ACPI
  thermal: Check for thermal zone requirement (bnc#531547).
* Fri Feb 12 2010 jdelvare@suse.de
- supported.conf: saa7111 and saa7114 are gone.
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-fix-kdb_cmds-to-include-the-arch-common-macro:
  kdb: fix kdb_cmds to include the arch common macro (bnc#578421).
* Wed Feb 10 2010 jeffm@suse.com
- patches.suse/kdb-handle-nonexistance-keyboard-controller: kdb:
  handle nonexistance keyboard controller (bnc#578051).
* Wed Feb 10 2010 gregkh@suse.de
- patches.fixes/dvb-l64781.ko-broken-with-gcc-4.5.patch: dvb:
  l64781.ko broken with gcc 4.5.
* Tue Feb  9 2010 jeffm@suse.com
- patches.apparmor/apparmor-check-for-network-in-interrupt-and-work-around:
  apparmor: check for network in interrupt and work around
  (bnc#492961, bln#350789).
* Tue Feb  9 2010 jeffm@suse.com
- Update to 2.6.33-rc7.
  - Eliminated 1 patch.
* Tue Feb  9 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-66-idt-hp-mute-led-fix-polarity:
  ALSA: hda - Fix default polarity of mute-LED GPIO on 92HD83x/88x
  codecs (bnc#578190).
* Mon Feb  8 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-63-idt-hp-mute-led-detect:
  ALSA: hda - Detect HP mute-LED GPIO setup from GPIO counts
  (bnc#577927).
- patches.drivers/alsa-sp1-hda-64-idt-hp-mute-led-cleanup: ALSA:
  hda - Merge HP mute-LED status callback on both IDT 92HD7x
  and 8x codecs (bnc#577927).
- patches.drivers/alsa-sp1-hda-65-idt-hp-mute-led-cleanup2:
  ALSA: hda - Remove static gpio_led setup via model (bnc#577927).
* Fri Feb  5 2010 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: Delete from repo and series.conf.
  Back to 32bytes lvb length for clvm (bnc#573460).
* Fri Feb  5 2010 duwe@suse.de
- Update config files: Compile IBM_BSR into kernel, not as module.
  (ppc only, bnc#572381)
* Fri Feb  5 2010 duwe@suse.de
- patches.arch/ppc-pseries-ncpus-1: powerpc: Add static fields
  to ibm,client-architecture call (bnc#570909).
- patches.arch/ppc-pseries-ncpus-2: powerpc/pseries: Pass more
  accurate number of supported cores to firmware (bnc#570909).
* Fri Feb  5 2010 coly.li@suse.de
- disable patches.suse/64bytes_lvb_len.diff in series.conf
* Thu Feb  4 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: Remove the previous
  hack and set STRIP_KEEP_SYMTAB='*/vmlinux-*' instead to avoid
  stripping symbols from the ppc vmlinux image (bnc#572148).
* Thu Feb  4 2010 knikanth@suse.de
- patches.fixes/dm-stripe-zero-stripes: dm-stripe: return -EINVAL
  if stripe count is zero (bnc#576312).
* Thu Feb  4 2010 npiggin@suse.de
- Disable patches.suse/files-slab-rcu.patch.
* Thu Feb  4 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete iwlagn-2-6-27-kmp
  (bnc#559533).
* Thu Feb  4 2010 tiwai@suse.de
- supported.conf: mark snd-wss-lib unsupported
* Thu Feb  4 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-61-add-idt92hd88x-support2:
  ALSA: hda - Adding support for another IDT 92HD83XXX codec
  (bnc#569354).
* Wed Feb  3 2010 jbohac@suse.cz
- supported.conf: marked em_cmp supported (bnc#568130)
* Wed Feb  3 2010 mmarek@suse.cz
- rpm/kernel-binary.spec.in: automatically install a matching
  - devel package if kernel-source is installed.
* Wed Feb  3 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc6 and c/s 989.
- patches.xen/xen-netback-generalize: Netback: Generalize
  static/global variables into 'struct xen_netbk'.
- patches.xen/xen-netback-kernel-threads: Use Kernel thread to
  replace the tasklet.
- patches.xen/xen-netback-multiple-tasklets: Netback:
  Multiple tasklets support.
* Tue Feb  2 2010 jkosina@suse.cz
- patches.suse/suse-ppc64-branding: the message about crashed kernel
  doesn't make sense any more with CONFIG_CRASH_DUMP enabled by
  default (bnc#575884).
* Sat Jan 30 2010 jeffm@suse.com
- Update to 2.6.33-rc6.
  - Eliminated 12 patches.
* Sat Jan 30 2010 jeffm@suse.com
- patches.rpmify/hugetlbfs-fix-section-mismatches: Removed __init
  from hugetlb_sysfs_add_hstate instead of adding it elsewhere.
* Sat Jan 30 2010 jslaby@suse.de
- patches.suse/kdb-common: Fix hid crash (bnc#570591)
* Fri Jan 29 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-60-add-idt92hd88x-support: ALSA:
  hda - Add support for IDT 92HD88 family codecs (bnc#569354).
* Fri Jan 29 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  Update patch-mainline tag.
* Fri Jan 29 2010 jbenc@suse.cz
- Update config files: fixed vanilla configs.
* Thu Jan 28 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-59-idt92hd83xxx-hp-mute-led: ALSA:
  hda - Add mute LED check for HP laptops with IDT 92HD83xxx codec
  (bnc#569354).
* Thu Jan 28 2010 jbeulich@novell.com
- patches.suse/supported-flag: Fix -ec2 build.
- patches.suse/supported-flag-enterprise: Refresh.
- patches.xen/xen3-patch-2.6.33-rc3: Fix ia64 build.
* Thu Jan 28 2010 jbeulich@novell.com
- Update Xen patches to 2.6.33-rc5 and c/s 987.
- config.conf: Re-enable Xen.
- Update config files.
* Thu Jan 28 2010 jbenc@suse.cz
- Update config files: enabled CONFIG_CFG80211_WEXT to keep backward
  user space compatibility and enabled few wireless drivers.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: Add support for an additional series file in
  patches.addon/series, this will be applied after the main series.
* Thu Jan 28 2010 mmarek@suse.cz
- rpm/apply-patches: put the patch loops from kernel-binary.spec.in
  and kernel-source.spec.in to one place.
* Wed Jan 27 2010 jeffm@suse.de
- Deleted 28 unused patches.
* Wed Jan 27 2010 jeffm@suse.com
- Update config files.
* Wed Jan 27 2010 jkosina@suse.cz
- patches.fixes/pci-fix-nested-spinlock-hang-in-aer_inject.patch:
  pci: fix nested spinlock hang in aer_inject (bnc#573578).
* Wed Jan 27 2010 mmarek@suse.cz
- Update config files: disable generic_serial users.
- patches.drivers/reenable-generic_serial: Delete.
- rpm/generic_serial-blacklist: Delete (bnc#569676).
* Wed Jan 27 2010 jengelh@medozas.de
- remove patches.suse/netfilter-ipv4options [bnc#490142]
* Wed Jan 27 2010 jeffm@suse.com
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: Refresh.
* Tue Jan 26 2010 knikanth@suse.de
- supported.conf: Fix misspelt dm-region-hash and mark it supported
  correctly (bnc#565962)
* Mon Jan 25 2010 gregkh@suse.de
- Update to 2.6.32.6
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.drivers/8250_pnp-wacom-add
  - patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch
  - patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch
  - patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch
* Mon Jan 25 2010 jeffm@suse.com
- supported.conf: Added sparse_keymap (eeepc_laptop depends on it)
* Mon Jan 25 2010 npiggin@suse.de
- patches.suse/slab-handle-memoryless-nodes-v2a.patch: slab -
  handle memoryless nodes V2a (bnc#436025, bnc#570492).
* Mon Jan 25 2010 jeffm@suse.com
- Updated to 2.6.33-rc5.
  - Eliminated 2 patches.
* Mon Jan 25 2010 trenn@suse.de
- Update config files.
- patches.arch/x86_mce_intel_decode_physical_address.patch: x86,
  mce: Xeon75xx specific interface to get corrected memory error
  information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_compile_fix.patch:
  x86, mce: Xeon75xx specific interface to get corrected memory
  error information (bnc#573380, fate#307738).
- patches.arch/x86_mce_intel_decode_physical_address_rename_fix.patch:
  x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
  (bnc#573380, fate#307738).
- patches.xen/xen3-auto-arch-x86.diff: Refresh.
* Mon Jan 25 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-57-cx5051-toshiba-quirk:
  ALSA: hda - Add support for Toshiba Satellite M300
  (bnc#492233,bnc#565904).
- patches.drivers/alsa-sp1-hda-58-cx5051-lenovo-mute-fix: ALSA:
  hda - Change headphone pin control with master volume on cx5051
  (bnc#573050).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_enable_tsc_sync_check_again.patch: x86:
  Reenable TSC sync check at boot, even with NONSTOP_TSC
  (bnc#573379).
* Mon Jan 25 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix_2nd_ver.patch:
  x86: Set hotpluggable nodes in nodes_possible_map (bnc#567216).
- patches.arch/x86_node_hotplug_parse_srat_fix.patch: Delete.
* Mon Jan 25 2010 trenn@suse.de
- supported.conf:
  Add mce-inject and hwpoison-inject so that Intel can easier test
  this. As these are debug drivers, they might get reverted from
  support.conf again if kernel-extra package gets fixed for SLES,
  only seem to exist for SLED because "NCC is not yet working for SP1".
  (bnc#572552).
* Sat Jan 23 2010 bphilips@suse.de
- patches.drivers/tg3-updates-from-f4188d-to-ba5b0bf.patch: tg3:
  updates from f4188d to ba5b0bf (bnc#573237).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-irq-check-move_in_progress-before-freeing-the-vector-mapping.patch:
  x86, irq: Check move_in_progress before freeing the vector
  mapping (bnc#558247).
* Sat Jan 23 2010 rjw@suse.de
- patches.arch/x86-apic-use-logical-flat-for-systems-with-8-or-fewer-logical-cpus.patch:
  x86, apic: use logical flat for systems with <= 8 logical cpus
  (bnc#567510).
- patches.arch/x86-revert-apic-Use-logical-flat-on-intel-with-8-or-fewer-logical-cpus.patch:
  x86: Revert "apic: Use logical flat on intel with <= 8 logical
  cpus" (bnc#567510).
* Sat Jan 23 2010 gregkh@suse.de
- Update to 2.6.32.5:
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.drivers/alsa-sp1-hda-54-alc861-capture-fix
  - patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard
  - patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
  - patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch
* Fri Jan 22 2010 tonyj@suse.de
- Update config files: drop UTRACE from default s390 configs
  as per communication from Ihno.
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/x86-msr-cpuid-register-enough-minors-for-the-msr-and-cpuid-drivers.patch:
  x86, msr/cpuid: Register enough minors for the MSR and CPUID
  drivers (bnc#572720).
* Fri Jan 22 2010 gregkh@suse.de
- patches.kernel.org/scsi-enclosure-fix-oops-while-iterating-enclosure_status-array.patch:
  SCSI: enclosure: fix oops while iterating enclosure_status array
  (bnc#572818).
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  Delete.
* Fri Jan 22 2010 duwe@suse.de
- Update config files.
- patches.arch/ppc-extended_h_cede-update-to-mainline: Incremental
  patch set to sync H_CEDE with actual mainline (bnc#550447,
  FATE#307059).
* Fri Jan 22 2010 trenn@suse.de
- Update config files.
  Add DMAR to -trace flavor -> get in sync with -default
* Fri Jan 22 2010 hare@suse.de
- patches.fixes/qla2xxx-restore-pci-state-after-eeh-recovery:
  Re-save PCI state after EEH recovery (bnc#570233).
* Fri Jan 22 2010 jjolly@suse.de
- patches.arch/s390-06-01-zfcp-introduce-bsg-timeout-callback.patch:
  zfcp: introduce BSG timeout callback (BNC#572659).
- patches.arch/s390-06-02-zfcp-set-hw-timeout-requested-by-bsg.patch:
  zfcp: set HW timeout requested by BSG request (BNC#572659).
* Fri Jan 22 2010 bphilips@suse.de
- patches.drivers/netxen-8f9b3f-to-c651a8.patch: netxen: 8f9b3f
  to c651a8 (bnc#572832).
* Fri Jan 22 2010 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh to
  newest version of patch.
* Thu Jan 21 2010 astarikovskiy@suse.de
- supported.conf: added power_meter driver (FATE #306959).
* Thu Jan 21 2010 tonyj@suse.de
- config.conf: add -trace flavor for s390* at Ihno's request
- Add more tracers to existing ppc64 trace config at IBM request
  Both related to FATE# 307051.
- patches.trace/ftrace-framepointer.diff: Delete.
* Thu Jan 21 2010 hare@suse.de
- patches.fixes/scsi-fc-class-allow-LLD-bsg-timeout:
  scsi_transport_fc: Allow LLD to reset FC BSG timeout
  (bnc#572658).
* Thu Jan 21 2010 jbeulich@novell.com
- patches.xen/xen-privcmd-mmap-batch-clear: privcmd: mmapbatch-v2
  fixes.
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/lpfc-8.3.5-update: lpfc update to 8.3.5
  (bnc#572427).
- patches.drivers/lpfc-8.3.5.3-update: lpfc driver update to
  8.3.5.3 (bnc#572427).
* Thu Jan 21 2010 hare@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Update headers for series2git.
* Wed Jan 20 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh. More updates and
  clean-up by Egbert (bnc#570082)
* Wed Jan 20 2010 jkosina@suse.cz
- patches.drivers/add-support-for-intel-cougar-point-chipset.patch:
  Intel Cougar Point PCH Support (FATE#308854 bnc#565845).
* Wed Jan 20 2010 jslaby@suse.de
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  Refresh.
  (change firmwares in makefile)
* Wed Jan 20 2010 jslaby@suse.de
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: Refresh.
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch: Refresh.
* Wed Jan 20 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.4 and c/s 984.
- Update Xen config files.
* Wed Jan 20 2010 bphilips@suse.de
- patches.drivers/bnx2i-backport-from-v2.6.32-to-45ca38e.patch:
  bnx2i: Backport from v2.6.32 to 45ca38e (bnc#564640).
- patches.drivers/bnx2x-backports-v2.6.32-to-af901ca.patch:
  bnx2x: backports v2.6.32 to af901ca (bnc#564638).
- patches.drivers/cnic-backport-from-v2.6.32-4e9c4f.patch: cnic:
  backport from v2.6.32-4e9c4f (bnc#564640).
* Wed Jan 20 2010 gregkh@suse.de
- Update config files.  2.6.32.4 changed one of them.
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fixed the text area
  calculation, and added the upscaling (bnc#570082).
* Tue Jan 19 2010 jeffm@suse.com
- Updated to 2.6.33-rc4-git7.
  - Eliminated 4 patches.
* Tue Jan 19 2010 gregkh@suse.de
- Patch refresh for fuzz due to upstream -stable additions.
* Tue Jan 19 2010 gregkh@suse.de
- Update to 2.6.32.4
  - security fixes
  - bug fixes
  - obsoletes:
  - patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y
  - patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix
  - patches.fixes/audit_untag_chunk.patch
  - patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch
  - patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1
* Tue Jan 19 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-55-alc259-hp-pin-fix: ALSA: hda -
  Fix parsing pin node 0x21 on ALC259 (bnc#571879).
- patches.drivers/alsa-sp1-hda-56-realtek-eapd-fix: ALSA: hda -
  Turn on EAPD only if available for Realtek codecs (bnc#571879).
* Tue Jan 19 2010 tiwai@suse.de
- patches.suse/bootsplash-scaler: Refresh.  Fix the hang-up with
  resolution changes (bnc#570082)
* Tue Jan 19 2010 jkosina@suse.cz
- supported.conf: added aesni-intel (bnc#566618 FATE#304209).
* Tue Jan 19 2010 jkosina@suse.cz
- Update config files: set CONFIG_CRYPTO_HMAC=y to avoid
  regression from SLE11 (bnc#571501).
* Tue Jan 19 2010 jack@suse.de
- patches.fixes/reiserfs-truncate-blocks-not-used-by-a-write.patch:
  reiserfs: truncate blocks not used by a write (bnc#483375).
* Mon Jan 18 2010 jeffm@suse.de
- patches.suse/smtnice-disable: Delete (obsolete).
* Mon Jan 18 2010 jeffm@suse.com
- Disabled custom ACPI table loading from initramfs again.
* Mon Jan 18 2010 jeffm@suse.com
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh.
* Mon Jan 18 2010 trenn@suse.de
- patches.arch/x86_node_hotplug_parse_srat_fix.patch:
  x86/mm/srat_64.c: nodes_parsed should include all nodes detected
  by ACPI (bnc#567140).
* Mon Jan 18 2010 hare@suse.de
- patches.fixes/aic79xx-null-scb-in-nonpkt-busfree: aic79xx: check
  for non-NULL scb in ahd_handle_nonpkt_busfree (bnc#542568).
* Mon Jan 18 2010 nfbrown@suse.de
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  Refresh to fix 60 second delay. (bnc#568271)
* Sat Jan 16 2010 tonyj@suse.de
- patches.fixes/audit_untag_chunk.patch: fix braindamage in
  audit_tree.c untag_chunk() (bnc#556282).
* Sat Jan 16 2010 rjw@suse.de
- patches.xen/xen-x86-rename-display_cacheinfo-to-cpu_detect_cache_sizes.patch:
  x86: Rename display_cacheinfo() to cpu_detect_cache_sizes().
* Fri Jan 15 2010 gregkh@suse.de
- Update config files.
- patches.drivers/vmw_pvscsi-scsi-driver-for-vmware-s-virtual-hba.patch:
  vmw_pvscsi: SCSI driver for VMware's virtual HBA.
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/hid-add-device-ids-for-new-model-of-apple-wireless-keyboard:
  HID: add device IDs for new model of Apple Wireless Keyboard
  (bnc#568231).
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 hare@suse.de
- patches.drivers/qla2xxx-8.03.01.01.11.1-k8-update: qla2xxx
  driver update to 8.03.01.01.11.1-k8 (bnc#560415).
- patches.drivers/qla2xxx-8.03.01.02.11.1-k8-update: qla2xxx
  driver update to 8.03.01.02.11.1-k8 (bnc#570233).
- patches.drivers/lpfc-add-raywire-id: Delete.
- patches.drivers/qla2xxx-8.03.01-k7-update: Delete.
* Fri Jan 15 2010 trenn@suse.de
- patches.suse/kdb_dont_touch_i8042_early.patch: Avoid early
  hang when i8042 controller is missing (bnc#528811).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/reiser4-sync_inodes: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.fixes/remount-no-shrink-dcache: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 jeffm@suse.com
- patches.suse/smtnice-disable: Updated to 2.6.33.
* Fri Jan 15 2010 jeffm@suse.com
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: Delete (obsolete).
* Fri Jan 15 2010 mfasheh@suse.com
- patches.fixes/Ocfs2-Let-ocfs2-support-fiemap-for-symlink-and-fast-.patch:
  Ocfs2: Let ocfs2 support fiemap for symlink and fast symlink..
- patches.fixes/Ocfs2-Should-ocfs2-support-fiemap-for-S_IFDIR-inode.patch:
  Ocfs2: Should ocfs2 support fiemap for S_IFDIR inode?.
- patches.fixes/ocfs-stop-using-do_sync_mapping_range.patch:
  ocfs: stop using do_sync_mapping_range.
- patches.fixes/ocfs2-Add-reflinked-file-s-inode-to-inode-hash-earil.patch:
  ocfs2: Add reflinked file's inode to inode hash eariler..
- patches.fixes/ocfs2-Find-proper-end-cpos-for-a-leaf-refcount-block.patch:
  ocfs2: Find proper end cpos for a leaf refcount block..
- patches.fixes/ocfs2-Set-i_nlink-properly-during-reflink.patch:
  ocfs2: Set i_nlink properly during reflink..
- patches.fixes/ocfs2-always-include-acl-support.patch: ocfs2:
  Always include ACL support.
- patches.fixes/ocfs2-cluster-Make-fence-method-configurable-v2.patch:
  ocfs2/cluster: Make fence method configurable - v2.
- patches.fixes/ocfs2-devel-remove-redundant-OCFS2_MOUNT_POSIX_ACL-c.patch:
  ocfs2-devel: remove redundant OCFS2_MOUNT_POSIX_ACL check
  in ocfs2_get_acl_nolock().
- patches.fixes/ocfs2-explicit-declare-uninitialized-var-in-user_clu.patch:
  ocfs2: explicit declare uninitialized var in
  user_cluster_connect().
- patches.fixes/ocfs2-make-acl-use-the-default.patch: ocfs2:
  Make acl use the default.
- patches.fixes/ocfs2-refcounttree.c-cleanup.patch: ocfs2:
  refcounttree.c cleanup..
- patches.fixes/ocfs2-replace-u8-by-__u8-in-ocfs2_fs.h.patch:
  ocfs2: replace u8 by __u8 in ocfs2_fs.h.
- patches.fixes/ocfs2-return-EAGAIN-instead-of-EAGAIN-in-dlm.patch:
  ocfs2: return -EAGAIN instead of EAGAIN in dlm.
- patches.fixes/ocfs2-set-MS_POSIXACL-on-remount.patch: ocfs2:
  Set MS_POSIXACL on remount.
- patches.fixes/ocfs2-trivial-Use-le16_to_cpu-for-a-disk-value-in-xa.patch:
  ocfs2/trivial: Use le16_to_cpu for a disk value in xattr.c.
- patches.fixes/ocfs2-trivial-Use-proper-mask-for-2-places-in-hearbe.patch:
  ocfs2/trivial: Use proper mask for 2 places in hearbeat.c.
- patches.suse/fiemap-Add-new-extent-flag-FIEMAP_EXTENT_SHARED.patch:
  fiemap: Add new extent flag FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-Use-FIEMAP_EXTENT_SHARED.patch: ocfs2:
  Use FIEMAP_EXTENT_SHARED.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/x86-Limit-number-of-per-cpu-TSC-sync-messages.patch:
  x86: Limit number of per cpu TSC sync messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Limit-the-number-of-processor-bootup-messages.patch:
  x86: Limit the number of processor bootup messages (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-CPU-cache-size-output-for-non-Intel-too.patch:
  x86: Remove CPU cache size output for non-Intel too (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-enabling-x2apic-message-for-every-CPU.patch:
  x86: Remove enabling x2apic message for every CPU (bnc#564618,
  FATE#306952).
- patches.arch/x86-Remove-the-CPU-cache-size-printks.patch: x86:
  Remove the CPU cache size printk's (bnc#564618, FATE#306952).
- patches.arch/x86-cpu-mv-display_cacheinfo-cpu_detect_cache_sizes.patch:
  x86, cpu: mv display_cacheinfo -> cpu_detect_cache_sizes
  (bnc#564618, FATE#306952).
- patches.arch/x86-ucode-amd-Load-ucode-patches-once-and-not-separately-of-each-CPU.patch:
  x86: ucode-amd: Load ucode-patches once and not separately of
  each CPU (bnc#564618, FATE#306952).
- patches.fixes/sched-Limit-the-number-of-scheduler-debug-messages.patch:
  sched: Limit the number of scheduler debug messages (bnc#564618,
  FATE#306952).
- patches.fixes/timers-init-Limit-the-number-of-per-cpu-calibration-bootup-messages.patch:
  timers, init: Limit the number of per cpu calibration bootup
  messages (bnc#564618, FATE#306952).
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/add-initramfs-file_read_write: Build fix.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-enterprise: Refresh.
* Thu Jan 14 2010 jeffm@suse.com
- patches.suse/supported-flag-sysfs: Properly report proprietary modules
* Thu Jan 14 2010 jeffm@suse.de
- patches.suse/add-initramfs-file_read_write: initramfs: add
  initramfs_{read,write} (bnc#568120).
- Re-enabled custom ACPI table loading from initramfs.
* Thu Jan 14 2010 trenn@suse.de
- Update config files.
  Enable CONFIG_CPU_FREQ_DEBUG as requested by HP.
  This one adds conditional printks which can be enabled via:
  cpufreq.debug=7
* Thu Jan 14 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-54-alc861-capture-fix: ALSA: hda -
  Fix missing capture mixer for ALC861/660 codecs (bnc#567340).
* Thu Jan 14 2010 mmarek@suse.de
- rpm/find-provides, rpm/kernel-binary.spec.in: really fix ppc
  symbol provides.
* Thu Jan 14 2010 rjw@suse.de
- patches.arch/UV-Expose-irq_desc-node-in-proc.patch: Expose the
  irq_desc node as /proc/irq/*/node. (bnc#566745, fate#306952).
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/dmfe-tulip-Let-dmfe-handle-DM910x-except-for-SPARC-o.patch:
  dmfe/tulip: Let dmfe handle DM910x except for SPARC on-board
  chips (bnc#537016).
* Wed Jan 13 2010 jkosina@suse.cz
- patches.fixes/crypto-testmgr-fix-complain-about-lacking-test.patch:
  crypto: testmgr - Fix complain about lack test for internal
  used algorithm (bnc#568278 FATE#306883).
* Wed Jan 13 2010 jeffm@suse.com
- Update to 2.6.33-rc4.
  - Eliminated patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io
* Wed Jan 13 2010 mmarek@suse.cz
- patches.suse/bootsplash-keep-multiple-data: Keep multiple
  splash screens for KMS (bnc#570082).
- patches.suse/bootsplash-scaler: Add bootsplash image scaler
  (bnc#570082).
* Wed Jan 13 2010 mmarek@suse.de
- rpm/kernel-binary.spec.in, rpm/find-provides: extract exported
  symbols from /boot/vmlinux before the image is stripped (affects
  ppc).
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/twl6030-fix-note_interrupt-call: Rename to patches.fixes/twl6030-fix-note_interrupt-call
* Wed Jan 13 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  Avoid atomic op by introducing discarding flag instead
* Wed Jan 13 2010 jeffm@suse.com
- patches.rpmify/autoconf-h-fix-locations: autoconf.h: Fix
  locations.
* Wed Jan 13 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: Renamed to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  Delete.
* Tue Jan 12 2010 jeffm@suse.com
- Update config files.
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: rename to patches.rpmify/ppc-crashdump-typefix
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 jeffm@suse.com
- patches.fixes/signal-fix-kernel-information-leak-with-print-fatal-signals-1:
  kernel/signal.c: fix kernel information leak with
  print-fatal-signals=1 (bnc#569902).
* Tue Jan 12 2010 rjw@suse.de
- needs_update: Remove some patches that we've got through the
  upstream.
* Tue Jan 12 2010 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-53-alc861vd-capture-fix: ALSA:
  hda - Fix ALC861-VD capture source mixer (bnc#568305).
* Tue Jan 12 2010 jeffm@suse.com
- Update to 2.6.33-rc3-git5.
* Tue Jan 12 2010 trenn@suse.de
- patches.fixes/nohz_prevent_clocksource_wrapping_during_idle.patch:
  nohz: Prevent clocksource wrapping during idle (bnc#569238).
* Tue Jan 12 2010 jack@suse.de
- patches.suse/readahead-request-tunables.patch: Update readahead
  and max_sectors tunables (bnc#548529).
* Tue Jan 12 2010 jkosina@suse.cz
- patches.drivers/watchdog-iTCO_wdt-Add-support-for-Intel-Ibex-Peak.patch:
  iTCO_wdt: Add support for Intel Ibex Peak (bnc#557081
  FATE#308591).
* Tue Jan 12 2010 tonyj@suse.de
- needs_update: remove LTT/trace patches (assigned to jbl), all had
  already been taken care of by my fwd port to 2.6.32
* Tue Jan 12 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Fixup compilation error.
* Tue Jan 12 2010 rjw@suse.de
- patches.fixes/PCI-Always-set-prefetchable-base-limit-upper32-registers.patch:
  PCI: Always set prefetchable base/limit upper32 registers
  (bnc#569003).
* Mon Jan 11 2010 jeffm@suse.com
- Merged patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu into
  patches.arch/kvm-split-paravirt-ops-by-functionality
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/kmsg-fix-parameter-limitations to
  patches.arch/kmsg-fix-parameter-limitations
* Mon Jan 11 2010 jeffm@suse.com
- patches.rpmify/x86_64-ksyms-make-the-native_load_gs_index-export-depend-on-config_paravirt_cpu:
  x86_64/ksyms: Make the native_load_gs_index export depend
  on CONFIG_PARAVIRT_CPU.
* Mon Jan 11 2010 jeffm@suse.com
- Renamed patches.rpmify/rt2870-fix-section-mismatches to
  patches.rpmify/rt2860-fix-section-mismatches
* Mon Jan 11 2010 jeffm@suse.de
- Updated to 2.6.33-rc3-git3.
  - Eliminated 392 patches.
  - Xen is disabled.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k9-5.01.00.00.11.01-k10.patch:
  Update qla4xxx driver for SLES11 SP1 (bnc#556572,FATE#307128).
* Mon Jan 11 2010 jblunck@suse.de
- needs_update: Removed some patches.
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/bfa-2.1.2.1-update: Update bfa driver to
  version 2.1.2.1 (bnc#561881).
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/fcoe-libfc-adds-enable-di: adds enable/disable
  for fcoe interface (bnc#562046).
- patches.fixes/fcoe-use-lld-s-wwpn-and-w: Use LLD's WWPN and
  WWNN for lport if LLD supports ndo_fcoe_get_wwn (bnc#562046).
- patches.fixes/libfc-reduce-hold-time-on: reduce hold time on
  SCSI host lock (bnc#562046).
- patches.fixes/libfc-remote-port-gets-st: remote port gets
  stuck in restart state without really restarting (bnc#562046).
* Mon Jan 11 2010 hare@suse.de
- patches.drivers/mpt2sas-03.100.03.00-update: LSI mptsas2 driver
  update to 03.100.03.00 (bnc#566013).
* Mon Jan 11 2010 jbeulich@novell.com
- patches.xen/xen-x86_64-nx-user-mappings: Delete (bnc#568741).
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/qla4xxx-lun-reset-fix: Delete.
* Mon Jan 11 2010 hare@suse.de
- patches.fixes/scsi-dh-rdac-add-ibm-174x: scsi_dh_rdac: Add
  two new IBM devices (bnc# 556159).
* Sat Jan  9 2010 jslaby@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Refresh.
- patches.suse/rlim-0002-resource-move-kernel-function-inside-__KERNEL__.patch:
  resource: move kernel function inside __KERNEL__ (FATE#305733).
- patches.suse/rlim-0003-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits (FATE#305733).
- patches.suse/rlim-0004-IA64-use-helpers-for-rlimits.patch:
  [IA64] use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0005-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage (FATE#305733).
- patches.suse/rlim-0006-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0007-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0008-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0009-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0010-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0011-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0012-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0013-infiniband-use-helpers-for-rlimits.patch:
  infiniband: use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0014-ipc-use-helpers-for-rlimits.patch: ipc:
  use helpers for rlimits (FATE#305733).
- patches.suse/rlim-0015-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit (FATE#305733).
- patches.suse/rlim-0016-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu (FATE#305733).
- patches.suse/rlim-0017-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows (FATE#305733).
- patches.suse/rlim-0018-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit (FATE#305733).
- patches.suse/rlim-0019-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks (FATE#305733).
- patches.suse/rlim-0020-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task (FATE#305733).
- patches.suse/rlim-0021-FS-proc-switch-limits-reading-to-fops.patch:
  FS: proc, switch limits reading to fops (FATE#305733).
- patches.suse/rlim-0022-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable (FATE#305733).
- patches.suse/rlim-0023-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Delete.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Delete.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Delete.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Delete.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Delete.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Delete.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Delete.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Delete.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Delete.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Delete.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: Delete.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Delete.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Delete.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Delete.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Delete.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Delete.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Delete.
  Sync with upstream. Drop limits syscalls altogether.
* Sat Jan  9 2010 jkosina@suse.cz
- patches.apparmor/apparmor.diff: Delete, as it is unused after
  splitup into smaller patches.
* Fri Jan  8 2010 sjayaraman@suse.de
- patches.suse/SoN-23-mm-swapfile.patch: Fix up the enum declaration
  to avoid conflict due to a upstream change.
* Fri Jan  8 2010 jkosina@suse.cz
- patches.fixes/quota-fix-reserved-space-management-for-ordinary-fs.patch:
  quota: fix reserved space management for ordinary fs.
* Fri Jan  8 2010 gregkh@suse.de
- patches.drivers/staging-hv-fix-smp-problems-in-the-hyperv-core-code.patch:
  Staging: hv: fix smp problems in the hyperv core code.
* Fri Jan  8 2010 jeffm@suse.de
- Disable set,getprlimit compat syscalls on xen.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled custom ACPI table loading from initramfs until
  the scheduling while atomic issues are worked out.
* Fri Jan  8 2010 jeffm@suse.de
- Disabled set,getprlimit syscalls until the syscall numbers
  have been officially reserved.
* Fri Jan  8 2010 jeffm@suse.com
- patches.arch/module-handle-ppc64-relocating-kcrctabs-when-config_relocatable-y:
  module: handle ppc64 relocating kcrctabs when
  CONFIG_RELOCATABLE=y (bnc#566243).
* Thu Jan  7 2010 jbeulich@novell.com
- Update Xen patches to 2.6.32.3 and c/s 974.
- Update EC2 config files.
- patches.xen/xen3-x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.xen/xen3-x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.xen/xen3-x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  Delete.
- patches.xen/xen-scsifront-block-timeout-update: Delete.
- patches.xen/xen3-x86-fix-nodac: Delete.
* Thu Jan  7 2010 bphilips@suse.de
- patches.drivers/e1000-enhance-frame-fragment-detection.patch:
  e1000: enhance frame fragment detection (bnc#567376,
  CVE-2009-4536).
- patches.drivers/e1000e-enhance-frame-fragment-detection.patch:
  e1000e: enhance frame fragment detection (bnc#567376,
  CVE-2009-4538).
* Thu Jan  7 2010 gregkh@suse.de
- Update to 2.6.32.3
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.arch/s390-04-03-dasd-diag-ro.patch
  - patches.drivers/alsa-sp1-hda-50-alc88x-missing-capsrc_nids
  - patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host
  - patches.fixes/scsi-ipr-fix-eeh-recovery
* Wed Jan  6 2010 rjw@suse.de
- patches.arch/x86-Force-irq-complete-move-during-cpu-offline.patch:
  x86: Force irq complete move during cpu offline (bnc#558247).
- patches.arch/x86-Remove-local_irq_enable-local_irq_disable-in-fixup_irqs.patch:
  x86: Remove local_irq_enable()/local_irq_disable() in
  fixup_irqs() (bnc#558247).
- patches.arch/x86-Remove-move_cleanup_count-from-irq_cfg.patch:
  x86: Remove move_cleanup_count from irq_cfg (bnc#558247).
- patches.arch/x86-Remove-unnecessary-mdelay-from-cpu_disable_common.patch:
  x86: Remove unnecessary mdelay() from cpu_disable_common()   .
- patches.arch/x86-Unify-fixup_irqs-for-32-bit-and-64-bit-kernels.patch:
  x86: Unify fixup_irqs() for 32-bit and 64-bit kernels
  (bnc#558247).
- patches.arch/x86-Use-EOI-register-in-io-apic-on-intel-platforms.patch:
  x86: Use EOI register in io-apic on intel platforms
  (bnc#558247).
- patches.arch/x86-intr-remap-Avoid-irq_chip-mask-unmask-in-fixup_irqs-for-intr-remapping.patch:
  x86, intr-remap: Avoid irq_chip mask/unmask in fixup_irqs()
  for intr-remapping (bnc#558247).
- patches.arch/x86-io-apic-Move-the-effort-of-clearing-remoteIRR-explicitly-before-migrating-the-irq.patch:
  x86, io-apic: Move the effort of clearing remoteIRR explicitly
  before migrating the irq (bnc#558247).
- patches.arch/x86-ioapic-Document-another-case-when-level-irq-is-seen-as-an-edge.patch:
  x86, ioapic: Document another case when level irq is seen as
  an edge (bnc#558247).
- patches.arch/x86-ioapic-Fix-the-EOI-register-detection-mechanism.patch:
  x86, ioapic: Fix the EOI register detection mechanism
  (bnc#558247).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/pci_aer_mce_inject_check_osc_for_aer.patch: PCI:
  AER: fix aer inject result in kernel oops (bnc#566619).
* Wed Jan  6 2010 trenn@suse.de
- patches.fixes/PCIe-AER-reject-aer-inject-if-hardware-mask-error-reporting.patch:
  PCIe AER: reject aer inject if hardware mask error reporting
  (bnc#566621).
* Wed Jan  6 2010 gregkh@suse.de
- patches.xen/xen3-patch-2.6.29: Refresh due to conflicts from i915
  changes.  Ick, the xen code sucks rocks, it shouldn't be touching
  stuff here at all.
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
- patches.drivers/drm-i915-add-i915_lp_ring_sync-helper.patch:
  drm/i915: add i915_lp_ring_sync helper (bnc#568447).
- patches.drivers/drm-i915-fix-get_core_clock_speed-for-g33-class-desktop-chips.patch:
  drm/i915: fix get_core_clock_speed for G33 class desktop chips
  (bnc#568447).
- patches.drivers/drm-i915-fully-switch-off-overlay-when-not-in-use.patch:
  drm/i915: fully switch off overlay when not in use (bnc#568447).
- patches.drivers/drm-i915-implement-drmmode-overlay-support-v4.patch:
  drm/i915: implement drmmode overlay support v4 (bnc#568447).
- patches.drivers/drm-i915-implement-fastpath-for-overlay-flip-waiting.patch:
  drm/i915: implement fastpath for overlay flip waiting
  (bnc#568447).
* Wed Jan  6 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  Refresh.
* Tue Jan  5 2010 gregkh@suse.de
- patches.drivers/drm-i915-add-acpi-opregion-support-for-ironlake.patch:
  drm/i915: Add ACPI OpRegion support for Ironlake (bnc#568436).
* Tue Jan  5 2010 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: Update to newer version
* Wed Dec 30 2009 nfbrown@suse.de
- patches.fixes/nfs-fix-NFS4ERR_FILE_OPEN-handling:
  NFS4ERR_FILE_OPEN handling in Linux/NFS (bnc#526819).
* Mon Dec 28 2009 jeffm@suse.com
- patches.fixes/dmar-fix-oops-with-no-dmar-table: dmar: Fix oops
  with no DMAR table (bnc#548108).
* Sun Dec 27 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-52-hdmi-sticky-stream-tag: ALSA:
  hda - HDMI sticky stream tag support (FATE#306783).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/xpc_first_contact_when_active.patch: X86: UV
  - xpc_make_first_contact hang due to not accepting ACTIVE
  state. (bnc#562288, fate#306952).
- patches.arch/xpc_fix_xpc_get_fifo_entry_uv.patch: x86: UV - XPC
  NULL deref when mesq becomes empty. (bnc#562288, fate#306952).
- patches.arch/xpc_introduce_xp_socket.patch: x86: UV - XPC
  needs to provide an abstraction for uv_gpa. (bnc#562288,
  fate #306952).
- patches.arch/xpc_pass_nasid_to_gru_create_message_queue.patch:
  UV - pass nasid instead of nid to gru_create_message_queue
  (bnc#562288, fate#306952).
- patches.arch/xpc_recv_msg_slots_wrap.patch: X86: UV - XPC
  receive message reuse triggers invalid BUG_ON(). (bnc#562288,
  fate#306952).
- patches.arch/xpc_uv_bios_changes.patch: x86: UV - Update XPC
  to handle updated BIOS interface. (bnc#562288, fate#306952).
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561989_gru_rollup.patch: SGI GRU Updates
  (bnc#561989, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ppc-crashdump-typefix: powerpc: use min_t in
  copy_oldmem_page.
* Wed Dec 23 2009 rjw@suse.de
- patches.arch/bug-561946_uv_irq_affinity.patch: x86: SGI UV: Fix
  irq affinity for hub based interrupts (bnc#561946, fate#306952).
- patches.arch/bug-561946_uv_move_ioapic.patch: x86, apic: Move
  SGI UV functionality out of generic IO-APIC code (bnc#561946,
  fate#306952).
- patches.arch/bug-561946_uv_use_rtc.patch: x86: UV RTC: Always
  enable RTC clocksource (bnc#561946, fate#306952).
* Wed Dec 23 2009 jeffm@suse.com
- patches.fixes/ia64-fix-sba-iommu-to-handle-allocation-failure-properly:
  fix SBA IOMMU to handle allocation failure properly
  (bnc#545367).
* Tue Dec 22 2009 jeffm@suse.com
- Enabled CONFIG_CRASH_DUMP on ppc/ppc64 (bnc#566243).
* Tue Dec 22 2009 jeffm@suse.com
- patches.fixes/scsi-ipr-fix-eeh-recovery: ipr: fix EEH recovery
  (bnc#566613).
* Sun Dec 20 2009 trenn@suse.de
- Update config files.
- patches.drivers/cpufreq_ondemand_limit_fix.patch: cpufreq:
  Fix ondemand to not request targets outside policy limits
  (fate#306746).
- patches.drivers/cpufreq_processor_clocking_control_pcc_driver.patch:
  x86,cpufreq: Processor Clocking Control (PCC) driver
  (fate#306746).
- supported.conf:
* Sun Dec 20 2009 rjw@suse.de
- patches.arch/bug-561939_uv_bios_call_hwperf_updated.patch:
  x86, uv: Add serial number parameter to uv_bios_get_sn_info()
  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: Delete.
* Sat Dec 19 2009 jeffm@suse.com
- patches.fixes/scsi_debug-scale-virtual_gb-with-sector_size-properly:
  scsi_debug: scale virtual_gb with sector_size properly
  (bnc#535939).
* Sat Dec 19 2009 gregkh@suse.de
- patches.xen/xen3-fixup-xen: Refresh.  Fix up build error from
  .32.2 import
* Sat Dec 19 2009 gregkh@suse.de
- Update to 2.6.32.2
  - lots of security fixes
  - loads of bugfixes
  - other goodness
  - obsoletes:
  - patches.arch/bug-561939_bau_data_config.patch
  - patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch
  - patches.arch/s390-04-01-clear-high-regs.patch
  - patches.arch/s390-kvm-prefix.patch
  - patches.arch/s390-kvm-psw.patch
  - patches.arch/x86-fix-nodac
  - patches.arch/x86_mce_nfs-mig2
  - patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero
  - patches.fixes/uart-txen-race.patch
* Fri Dec 18 2009 jeffm@suse.com
- Update config files: CONFIG_STRICT_DEVMEM=n. It was enabled
  mistakenly in commit 3df90f9e and affects using tools like
  crash with a live system.
* Fri Dec 18 2009 gregkh@suse.de
- Update config files.
  CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT = n (bnc#565607)
* Fri Dec 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-{24..51}-*: 2.6.33-rc1 backport
  fixes for HDMI and new Realtek codecs (FATE#306783)
- Refresh Patch-mainline tags in patches.drivers/alsa-*
* Fri Dec 18 2009 jjolly@suse.de
- patches.arch/s390-05-01-netiucv-tx-bytes.patch: netiucv:
  displayed TX bytes value much too high (BNC#565612).
- patches.arch/s390-05-02-cmm-suspend.patch: cmm: free pages on
  hibernate. (BNC#565612).
- patches.arch/s390-05-03-iucv-suspend.patch: iucv: add work_queue
  cleanup for suspend (BNC#565612).
- patches.arch/s390-05-04-zfcp-work-queue.patch: zfcp: Assign
  scheduled work to driver queue (BNC#565612).
- patches.arch/s390-05-05-zfcp-fail-commands.patch: zfcp: Don't
  fail SCSI commands when transitioning to blocked fc_rport
  (BNC#565612,LTC#58541).
- patches.arch/s390-05-06-zfcp-adisc.patch: zfcp: Improve ELS
  ADISC handling (BNC#565612).
- patches.arch/s390-05-07-zfcp-fsf-errors.patch: zfcp: Update
  FSF error reporting (BNC#565612).
- patches.arch/s390-05-08-zfcp-block.diff: zfcp: Block SCSI EH
  thread for rport state BLOCKED (BNC#565612).
- patches.arch/s390-05-09-ctcm-suspend-wait.diff: ctcm: suspend
  has to wait for outstanding I/O (BNC#565612).
- patches.arch/s390-05-10-rework-tso.diff: qeth: rework TSO
  functions (BNC#565612).
- patches.arch/s390-05-11-atomic-volatile.patch: kernel: improve
  code generated by atomic operations. (BNC#565612).
- patches.arch/s390-05-12-tape-remove-fn.patch: tape: incomplete
  device removal (BNC#565612).
- patches.arch/s390-05-13-qeth-blkt-defaults.patch: qeth:
  set default BLKT settings dependend on OSA hw level
  (BNC#565612,LTC#58654).
- patches.arch/s390-05-14-dasd-dasd-enable-prefix.patch: dasd:
  enable prefix independent of pav support (BNC#565612).
- patches.arch/s390-05-15-dasd-s390dbf-strings.patch: dasd:
  remove strings from s390dbf (BNC#565612).
- patches.arch/s390-05-16-dasd-wait-lcu-setup.patch: dasd:
  let device initialization wait for LCU setup (BNC#565612).
* Fri Dec 18 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Fix generating /boot/Kerntypes* for
  s390/vanilla.
* Fri Dec 18 2009 nfbrown@suse.de
- patches.fixes/md-start_ro-fix: md: fix small irregularity with
  start_ro module parameter (bnc#565219).
* Fri Dec 18 2009 rjw@suse.de
- patches.xen/xen-fix-compilation-after-rename_generic_int.patch:
  XEN: Fix compilation after renaming of generic_irqs.
* Fri Dec 18 2009 rjw@suse.de
- patches.arch/bug-561946_rename_generic_int.patch: x86: UV RTC:
  Rename generic_interrupt to x86_platform_ipi (bnc#561946,
  fate#306952).
* Thu Dec 17 2009 mmarek@suse.cz
- patches.suse/s390-Kerntypes.diff: S390: Generate Kerntypes file.
- rpm/kernel-binary.spec.in: install /boot/Kerntypes-$version.
* Thu Dec 17 2009 jeffm@suse.com
- patches.fixes/powerpc-fix-cpu-name-in-show-cpuinfo: powerpc:
  fix cpu name in show-cpuinfo (bnc#565267).
* Thu Dec 17 2009 hare@suse.de
- patches.fixes/fc-transport-remove-BUG_ON: scsi_transport_fc:
  remove invalid BUG_ON (bnc#564479).
- patches.fixes/lpfc-ia64-hang: lpfc: fix hang on SGI ia64
  platform (bnc#564479).
- patches.fixes/qla2xxx-dpc-thread-can-execute-before-scsi-host:
  qla2xxx: dpc thread can execute before scsi host has been added
  (bnc#564479).
- patches.suse/fc-transport-allow-dev_loss_tmo-disable: Remove
  capping from dev_loss_tmo (bnc#492469).
* Wed Dec 16 2009 gregkh@suse.de
- Update config files.
  - fix up CONFIG_IPV6 option that was built into the kernel
    incorrectly (bnc#564357)
* Wed Dec 16 2009 jeffm@suse.com
- patches.fixes/acpi-fix-build-when-config_acpi_custom_override_initramfs-is-not-defined:
  acpi: Fix build when CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS is
  not defined.
* Wed Dec 16 2009 jbeulich@novell.com
- Update Xen patches to c/s 960.
- Update Xen EC2 config files.
- patches.xen/xen3-bug-561933_uv_pat_is_gru_range.patch: x86:
  UV SGI: Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.xen/xen3-x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.fixes/aggressive-zone-reclaim.patch: be more aggressive
  with zone reclaims (bnc#476525).
* Wed Dec 16 2009 npiggin@suse.de
- needs_update:
- patches.suse/x86-mark_rodata_rw.patch: Refresh.
* Wed Dec 16 2009 npiggin@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
* Tue Dec 15 2009 jeffm@suse.com
- patches.fixes/firewire-ohci-handle-receive-packets-with-a-data-length-of-zero:
  firewire: ohci: handle receive packets with a data length of
  zero (bnc#564712 CVE-2009-4138).
* Tue Dec 15 2009 mmarek@suse.cz
- rpm/config.sh: set OBS_PROJECT and IBS_PROJECT variables for
  osc_wrapper.
* Tue Dec 15 2009 knikanth@suse.de
- supported.conf: Mark dm-log-userspace as supported (fate#307380).
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  Fix the build failure due to previous commit.
* Tue Dec 15 2009 sjayaraman@suse.de
- patches.fixes/sched-recalculate-tunables-on-hot-add-remove:
  sched: Fix missing sched tunable recalculation on cpu add/remove
  (bnc#560317).
- patches.fixes/sched-make-tunable-scaling-configurable: sched:
  Make tunable scaling style configurable (bnc#560317).
- patches.fixes/sched-sysctl-for-normalized-tunables:  sched:
  Update normalized values on user updates via proc (bnc#560317).
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - make SCSI and ATA drivers modules again.
    (bnc#564357)
* Tue Dec 15 2009 gregkh@suse.de
- Update config files.
  - fix up USB options that were built into the kernel incorrectly
    (bnc#564357)
* Mon Dec 14 2009 jjolly@suse.de
- patches.arch/s390-04-01-clear-high-regs.patch: kernel:
  clear high-order bits after switching to 64-bit mode
  (BNC#563999,LTC#58088).
- patches.arch/s390-04-02-zcrypt-hrtimer.patch: zcrypt: Do not
  simultaneously schedule hrtimer (BNC#563999,LTC#58222).
- patches.arch/s390-04-03-dasd-diag-ro.patch: dasd: support DIAG
  access for read-only devices (BNC#563999,LTC#57147).
- patches.arch/s390-04-04-mm-fault-fix.patch: kernel: performance
  counter fix and page fault optimization (BNC#563999).
- patches.arch/s390-04-05-sclp-dump-indicator.patch: kernel:
  fix dump indicator (BNC#563999).
- patches.arch/s390-04-06-dasd-move-diag-kmsg.patch: dasd:
  move diag kmsg to generic dasd kmsg (BNC#563999).
- patches.arch/s390-04-07-cio-fix-double-free.patch: cio: double
  free under memory pressure (BNC#563999).
- patches.arch/s390-04-08-cio-fix-dev-stall.patch: cio: device
  recovery stalls after multiple hardware events (BNC#563999).
- patches.arch/s390-04-09-cio-recover-hw-changes.patch: cio:
  device recovery fails after concurrent hardware changes
  (BNC#563999).
- patches.arch/s390-04-10-cio-fix-onoffline-failure.patch: cio:
  setting a device online or offline fails for unknown reasons
  (BNC#563999).
- patches.arch/s390-04-11-cio-error-reporting.patch: cio:
  incorrect device state after device recognition and recovery
  (BNC#563999).
- patches.arch/s390-04-12-cio-avoid-panic.patch: cio: kernel
  panic after unexpected interrupt (BNC#563999).
- patches.arch/s390-04-13-cio-internal-io.patch: cio:
  initialization of I/O devices fails (BNC#563999).
- patches.arch/s390-04-14-cio-allow-offline.patch: cio: not
  operational devices cannot be deactivated (BNC#563999).
- patches.arch/s390-04-15-cio-split-pgid.patch: cio: erratic
  DASD I/O behavior (BNC#563999).
- patches.arch/s390-04-16-cio-path-verification.patch: cio:
  DASD cannot be set online (BNC#563999).
- patches.arch/s390-04-17-cio-steal-lock.patch: cio: DASD steal
  lock task hangs (BNC#563999).
- patches.arch/s390-04-18-cio-fix-memleak-chk-dev.patch: cio:
  memory leaks when checking unusable devices (BNC#563999).
- patches.arch/s390-04-19-cio-fix-deact-dev-panic.patch: cio:
  deactivated devices can cause use after free panic (BNC#563999).
* Mon Dec 14 2009 rjw@suse.de
- patches.arch/bug-561933_uv_pat_is_gru_range.patch: x86: UV SGI:
  Don't track GRU space in PAT (bnc#561933, fate#306952).
- patches.arch/bug-561939_bau_data_config.patch: x86: SGI UV
  BAU initialization (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_bios_call_hwperf.patch: x86: UV
  hardware performance counter and topology access  (bnc#561939,
  fate#306952).
- patches.arch/bug-561939_uv_gpa_is_mmr_space.patch: x86: UV -
  Introduce uv_gpa_is_mmr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_gpa_to_soc_phys_ram.patch:
  x86: UV - Introduce a means to translate from gpa ->
  socket_paddr. (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_ipi_macro.patch: x86: UV: Introduce
  uv_hub_ipi_value (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_mmap_low.patch: x86: SGI UV: Map
  low MMR ranges (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_cleanup.patch: x86: UV RTC:
  Clean up error handling (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_fixes.patch: x86: UV RTC:
  Fix early expiry handling  (bnc#561939, fate#306952).
- patches.arch/bug-561939_uv_rtc_setup_evt.patch: x86: UV RTC:
  Add clocksource only boot option (bnc#561939, fate#306952).
- patches.arch/bug-564471_x86_Fix_duplicated_UV_BAU_interrupt_vector.patch:
  x86: Fix duplicated UV BAU interrupt vector (bnc#564471).
* Mon Dec 14 2009 gregkh@suse.de
- Refresh patches to be clean of fuzz
* Mon Dec 14 2009 gregkh@suse.de
- Update to 2.6.32.1
  - security fixes
  - bugfixes
  - obsoletes:
  - patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext
  - patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects
* Mon Dec 14 2009 jjolly@suse.de
- patches.drivers/dcb-data-center-bridging-ops-s: dcb: data
  center bridging ops should be r/o (BNC#562046).
- patches.drivers/drivers-net-request_irq-remove: drivers/net:
  request_irq - Remove unnecessary leading & from second arg
  (BNC#562046).
- patches.drivers/ethtool-add-direct-attach-supp: ethtool: Add
  Direct Attach support to connector port reporting (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-al: ixgbe: Add
  support for 82599 alternative WWNN/WWPN prefix (BNC#562046).
- patches.drivers/ixgbe-add-support-for-82599-ba: ixgbe: add
  support for 82599 based Express Module X520-P2 (BNC#562046).
- patches.drivers/ixgbe-add-support-for-netdev_o: ixgbe: Add
  support for netdev_ops.ndo_fcoe_get_wwn to 82599 (BNC#562046).
- patches.drivers/ixgbe-change-default-ring-size: ixgbe: change
  default ring size (BNC#562046).
- patches.drivers/ixgbe-disable-flow-control-for: ixgbe: Disable
  Flow Control for certain devices (BNC#562046).
- patches.drivers/ixgbe-display-currently-attach: ixgbe: Display
  currently attached PHY through ethtool (BNC#562046).
- patches.drivers/ixgbe-fix-erroneous-display-of: ixgbe: Fix
  erroneous display of stats by ethtool -S (BNC#562046).
- patches.drivers/ixgbe-fix-kr-to-kx-fail-over-f: ixgbe: Fix KR
  to KX fail over for Mezzanine cards (BNC#562046).
- patches.drivers/ixgbe-fix-receive-address-regi: ixgbe:
  Fix Receive Address Register (RAR) cleaning and accounting
  (BNC#562046).
- patches.drivers/ixgbe-flush-the-lsc-mask-chang: ixgbe: Flush
  the LSC mask change to prevent repeated interrupts (BNC#562046).
- patches.drivers/ixgbe-handle-parameters-for-tx: ixgbe: handle
  parameters for tx and rx EITR, no div0 (BNC#562046).
- patches.drivers/ixgbe-links2-is-not-a-valid-re: ixgbe: LINKS2
  is not a valid register for 82598 (BNC#562046).
- patches.drivers/ixgbe-make-queue-pairs-on-sing: ixgbe: Make
  queue pairs on single MSI-X interrupts (BNC#562046).
- patches.drivers/ixgbe-modify-82599-hwrsc-stati: ixgbe: Modify
  82599 HWRSC statistics counters (BNC#562046).
- patches.drivers/ixgbe-only-set-clear-vfe-in-ix: ixgbe: Only
  set/clear VFE in ixgbe_set_rx_mode (BNC#562046).
- patches.drivers/ixgbe-performance-tweaks: ixgbe: performance
  tweaks (BNC#562046).
- patches.drivers/ixgbe-r_idx-not-used-in-ixgbe_: ixgbe: r_idx
  not used in ixgbe_msix_clean_rx() (BNC#562046).
- patches.drivers/ixgbe-select-fcoe-tx-queue-in-: ixgbe: select
  FCoE Tx queue in ndo_select_queue (BNC#562046).
- patches.drivers/ixgbe-use-eiam-to-automask-msi: ixgbe: use
  EIAM to automask MSI-X (BNC#562046).
- patches.drivers/ixgbe-use-known-user-priority-: ixgbe: use
  known user priority for FCoE when DCB is enabled (BNC#562046).
- patches.drivers/ixgbe-use-rx-buffer-length-fro: ixgbe: Use rx
  buffer length from rx ring for configuring rscctl (BNC#562046).
- patches.drivers/ixgbe-use-the-instance-of-net_: ixgbe: Use
  the instance of net_device_stats from net_device. (BNC#562046).
- patches.drivers/net-add-ndo_fcoe_get_wwn-to-ne: net: Add
  ndo_fcoe_get_wwn to net_device_ops (BNC#562046).
- patches.drivers/net-add-netdev_alloc_skb_ip_al: net: Add
  netdev_alloc_skb_ip_align() helper (BNC#562046).
- patches.drivers/net-use-netdev_alloc_skb_ip_al: net: Use
  netdev_alloc_skb_ip_align() (BNC#562046).
- patches.drivers/vlan-add-support-to-netdev_ops: vlan:
  Add support to netdev_ops.ndo_fcoe_get_wwn for VLAN device
  (BNC#562046).
- patches.fixes/fcoe-allow-scsi-fcp-to-be: fcoe: allow SCSI-FCP
  to be processed directly in softirq context (BNC#562046).
- patches.fixes/fcoe-libfc-add-get_lesb-t: fcoe, libfc: add
  get_lesb() to allow LLD to fill the link error status block
  (LESB) (BNC#562046).
- patches.fixes/libfc-add-fc-bb-5-lesb-co: libfc: add FC-BB-5
  LESB counters to fcoe_dev_stats (BNC#562046).
- patches.fixes/libfc-add-fcoe_fc_els_les: libfc: add
  fcoe_fc_els_lesb to fc_fcoe.h for FC-BB-5 LESB definitions
  (BNC#562046).
- patches.fixes/libfc-add-support-of-rece: libfc: add support
  of receiving ELS_RLS (BNC#562046).
- patches.fixes/libfc-add-target-reset-fl: libfc: Add target
  reset flag to FCP header file (BNC#562046).
- patches.fixes/libfc-fix-payload-size-pa: libfc: fix payload size
  passed to fc_frame_alloc() in fc_lport_els_request (BNC#562046).
- patches.fixes/libfcoe-add-checking-disa: libfcoe: add checking
  disable flag in FIP_FKA_ADV (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip-: libfcoe: add tracking
  FIP Missing Discovery Advertisement count (BNC#562046).
- patches.fixes/libfcoe-add-tracking-fip--0: libfcoe: add tracking
  FIP Virtual Link Failure count (BNC#562046).
* Mon Dec 14 2009 mmarek@suse.cz
- rpm/kabi.pl: Do not print harmless kabi changes by default.
* Mon Dec 14 2009 sjayaraman@suse.de
- patches.suse/sched-revert-latency-defaults: Revert sched
  latency defaults and turn FAIR_SLEEPERS off (bnc#557307).
* Mon Dec 14 2009 jkosina@suse.cz
- patches.fixes/uart-txen-race.patch: Serial: Do not read IIR in
  serial8250_start_tx when UART_BUG_TXEN (bnc#479304 bnc#509066).
* Sun Dec 13 2009 rjw@suse.de
- patches.fixes/bug-562290-Fix-isolcpus-boot-option.patch: sched:
  Fix isolcpus boot option (bnc#562290, fate#306952).
* Fri Dec 11 2009 mmarek@suse.cz
- patches.suse/supported-flag: Fix -Wmissing-prototypes warnings
  in modpost.c.
* Fri Dec 11 2009 mmarek@suse.cz
- patches.rpmify/modpost-segfault: modpost: fix segfault with
  short symbol names.
* Fri Dec 11 2009 jeffm@suse.com
- Moved kernel-docs into the git repo. It is now built automatically
  with the matching kernel sources.
* Fri Dec 11 2009 trenn@suse.de
- patches.suse/kdb_fix_ia64_build.patch: Fix ia64 - Export
  kdb_usb_kbds (none).
* Fri Dec 11 2009 trenn@suse.de
  Jeff updated kdb, try without this ugly workaround.
  If it still does not work, I have something better...
- patches.suse/kdb_x86_fix_hang.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Dec 11 2009 trenn@suse.de
  Updated MCE/MCA patches from Andi -> delete the old ones:
- patches.arch/x86_mce_hwpoison-action_result-valid-pfn.patch:
  HWPOISON: return ENXIO on invalid page number (fate#307738).
- patches.arch/x86_mce_hwpoison-is-free-page.patch: HWPOISON:
  detect free buddy pages explicitly (fate#307738).
- patches.arch/x86_mce_hwpoison-no-double-ref.patch: HWPOISON:
  avoid grabbing the page count multiple times during madvise
  injection (fate#307738).
- patches.arch/x86_mce_madvise-locking: HWPOISON: Use
  get_user_page_fast in hwpoison madvise (fate#307738).
- patches.arch/x86_mce_nfs-mig2: NFS: Fix nfs_migrate_page()
  (fate#307738).
- patches.arch/x86_mce_offline-inject: HWPOISON: Add a madvise()
  injector for soft page offlining (fate#307738).
- patches.arch/x86_mce_page-offline: HWPOISON: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_ref-to-flags: HWPOISON: Turn ref argument
  into flags argument (fate#307738).
- patches.arch/x86_mce_shake-page: HWPOISON: Be more aggressive
  at freeing non LRU caches (fate#307738).
- patches.arch/x86_mce_undef-lru: HWPOISON: Undefine short-hand
  macros after use to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_lru_cleanup.patch: Delete.
- patches.arch/x86_mce_page_offlining.patch: Delete.
- patches.arch/x86_mce_page_offlining_test_ability.patch: Delete.
- patches.arch/x86_mce_test_page.patch: Delete.
* Fri Dec 11 2009 hare@suse.de
- needs_update: Merge or delete remaining patches.
- patches.fixes/scsi-dh-emc-mode-select-10-size: DM-MPIO fails
  to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.fixes/scsi-dh-emc-rw-mismatch: Server crashes when
  path failures occur against EMC storage (bnc#474482).
- patches.fixes/scsi-dh-rdac-add-stk: STK arrays missing from
  rdac devicehandler (bnc#503855).
- patches.fixes/scsi-retry-alua-transition-in-progress: I/O
  errors for ALUA state transitions (bnc#491289).
- patches.suse/dm-mpath-no-activate-for-offlined-paths: DM-MPIO
  fails to tresspass LUNs on CLARiiON arrays (bnc#484529).
- patches.suse/dm-mpath-no-partitions-feature: Disable partitions
  scan for multipathed devices (bnc#402922,bnc#514767).
* Fri Dec 11 2009 tiwai@suse.de
- Update config files: set back to CONFIG_SOUND=m
* Fri Dec 11 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-23-hp-mute-led-gpio-fixes:
  ALSA: hda - Fix LED GPIO setup for HP laptops with IDT codecs
  (bnc#547357,bnc#523487).
* Fri Dec 11 2009 jeffm@suse.de
- patches.suse/kdb-usb-rework: Fix ia64.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files: Enable USB_SERIAL_DEBUG.
* Fri Dec 11 2009 jeffm@suse.com
- patches.suse/kdb-usb-rework: kdb: Cleanup KDB_USB.
* Fri Dec 11 2009 jeffm@suse.com
- Update config files.
  - Disabled USB_TEST and USB_LIBUSUAL.
* Thu Dec 10 2009 jeffm@suse.com
- Update config files. Re-enable missing options:
  - CONFIG_FRAMEBUFFER_CONSOLE_ROTATION=y
  - CONFIG_VIDEO_GO7007=m (and related options)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  Refresh to fix fuzz
* Thu Dec 10 2009 jeffm@suse.com
- Updated KDB to v4.4-2.6.32-3 and re-enabled USB keyboard support.
* Thu Dec 10 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: Fix vmlinux stripping on power
  (bnc#559547)
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/netxen-0000-Use-the-instance-of-net_device_stats-from-net.patch:
  netxen: Use the instance of net_device_stats from
  net_device. (bnc#560003, fate#307134).
- patches.drivers/netxen-0001-remove-sub-64-bit-mem-accesses.patch:
  netxen: remove sub 64-bit mem accesses (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0002-add-access-to-on-chip-memory-for-tools.patch:
  netxen: add access to on chip memory for tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0003-annotate-register-windowing-code.patch:
  netxen: annotate register windowing code (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0004-separate-register-and-memory-access-lock.patch:
  netxen: separate register and memory access lock (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0005-add-sysfs-entries-for-diag-tools.patch:
  netxen: add sysfs entries for diag tools (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0006-defines-for-next-revision.patch:
  netxen: defines for next revision (bnc#560003, fate#307134).
- patches.drivers/netxen-0007-128-memory-controller-support.patch:
  netxen: 128 memory controller support (bnc#560003, fate#307134).
- patches.drivers/netxen-0008-reset-sequence-changes.patch:
  netxen: reset sequence changes (bnc#560003, fate#307134).
- patches.drivers/netxen-0009-onchip-memory-access-change.patch:
  netxen: onchip memory access change (bnc#560003, fate#307134).
- patches.drivers/netxen-0010-fix-error-codes-in-for-tools-access.patch:
  netxen: fix error codes in for tools access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0011-sysfs-control-for-auto-firmware-recovery.patch:
  netxen: sysfs control for auto firmware recovery (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0012-update-version-to-4.0.62.patch:
  netxen; update version to 4.0.62 (bnc#560003, fate#307134).
- patches.drivers/netxen-0013-fix-builds-for-SYSFS-n-or-MODULES-n.patch:
  netxen: fix builds for SYSFS=n or MODULES=n (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0014-support-for-new-firmware-file-format.patch:
  netxen: support for new firmware file format (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0015-refactor-indirect-register-access.patch:
  netxen: refactor indirect register access (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0016-add-PCI-IDs-for-new-chip.patch:
  netxen: add PCI IDs for new chip (bnc#560003, fate#307134).
- patches.drivers/netxen-0017-update-module-info.patch: netxen:
  update module info (bnc#560003, fate#307134).
- patches.drivers/netxen-0018-module-firmware-hints.patch:
  netxen: module firmware hints (bnc#560003, fate#307134).
- patches.drivers/netxen-0019-update-version-to-4.0.65.patch:
  netxen: update version to 4.0.65 (bnc#560003, fate#307134).
- patches.drivers/netxen-0020-remove-PCI-IDs-of-CNA-device.patch:
  netxen: remove PCI IDs of CNA device (bnc#560003, fate#307134).
- patches.drivers/netxen-0021-fix-debug-tools-access-for-NX2031.patch:
  netxen : fix debug tools access for NX2031 (bnc#560003,
  fate#307134).
- patches.drivers/netxen-0022-fix-failure-cases-for-fw-hang-recovery.patch:
  netxen: fix failure cases for fw hang recovery (bnc#560003,
  fate#307134).
* Thu Dec 10 2009 bphilips@suse.de
- patches.drivers/qlge-0001-Use-the-instance-of-net_device_stats-from-net_.patch:
  qlge: Use the instance of net_device_stats from
  net_device. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0002-Remove-explicit-setting-of-PCI-Dev-CTL-reg.patch:
  qlge: Remove explicit setting of PCI Dev CTL reg. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0003-Set-PCIE-max-read-request-size.patch:
  qlge: Set PCIE max read request size. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0004-Add-handler-for-DCBX-firmware-event.patch:
  qlge: Add handler for DCBX firmware event. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0005-Store-firmware-revision-as-early-as-possible.patch:
  qlge: Store firmware revision as early as possible. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0006-Remove-inline-math-for-small-rx-buf-mapping.patch:
  qlge: Remove inline math for small rx buf mapping. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0007-Get-rid-of-firmware-handler-debug-code.patch:
  qlge: Get rid of firmware handler debug code. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0008-Don-t-fail-open-when-port-is-not-initialized.patch:
  qlge: Don't fail open when port is not initialized. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0009-Add-CBFC-pause-frame-counters-to-ethtool-stats.patch:
  qlge: Add CBFC pause frame counters to ethtool
  stats. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0010-Size-RX-buffers-based-on-MTU.patch:
  qlge: Size RX buffers based on MTU. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0011-Add-ethtool-get-set-pause-parameter.patch:
  qlge: Add ethtool get/set pause parameter. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0012-Add-ethtool-blink-function.patch:
  qlge: Add ethtool blink function. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0013-Add-ethtool-wake-on-LAN-function.patch:
  qlge: Add ethtool wake on LAN function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0014-Add-ethtool-register-dump-function.patch:
  qlge: Add ethtool register dump function. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0015-Add-ethtool-self-test.patch: qlge:
  Add ethtool self-test. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0016-Change-naming-on-vlan-API.patch:
  qlge: Change naming on vlan API. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0017-Fix-indentations.patch: qlge: Fix
  indentations. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0018-Add-firmware-driver-sub-command-support.patch:
  qlge: Add firmware/driver sub-command support. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0019-Clean-up-netdev-stats-usage.patch:
  qlge: Clean up netdev->stats usage. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0020-Do-not-change-frame-routing-during-suspend.patch:
  qlge: Do not change frame routing during suspend. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0021-Add-asic-reset-to-open-call.patch:
  qlge: Add asic reset to open call. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0022-Clean-up-module-parameter-name.patch:
  qlge: Clean up module parameter name. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0023-Change-version-to-v1.00.00.23.00.00-01.patch:
  qlge: Change version to v1.00.00.23.00.00-01. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0024-Bonding-fix-for-mode-6.patch: qlge:
  Bonding fix for mode 6. (bnc#560420, FATE#307130).
- patches.drivers/qlge-0025-Add-performance-change-for-non-split-headers.patch:
  qlge: Add performance change for non-split headers. (bnc#560420,
  FATE#307130).
- patches.drivers/qlge-0026-Add-firmware-core-dump.patch: qlge:
  Add firmware core dump. (bnc#560420, FATE#307130).
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete more merged fixes.
- patches.suse/dm-mpath-leastpending-path-update: Refresh.
* Thu Dec 10 2009 hare@suse.de
- needs_update: Delete merged driver fixes.
- patches.drivers/megaraid-mbox-fix-SG_IO: megaraid_mbox: Oops
  on SG_IO (bnc#475619).
* Thu Dec 10 2009 duwe@suse.de
- Disable PHYP_DUMP for all PPC flavours, per bnc#541302.
* Thu Dec 10 2009 jbenc@suse.cz
- patches.suse/novfs-fix-debug-message.patch: novfs: fix debug
  message.
* Thu Dec 10 2009 hare@suse.de
- patches.fixes/tehuti-firmware-name: Tehuti network driver
  references wrong firmware (bnc#562092).
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: fix section mismatch due to
  previous checkin
* Wed Dec  9 2009 tonyj@suse.de
- patches.suse/audit-export-logging.patch: export audit logging
  symbols.
* Wed Dec  9 2009 jbohac@suse.cz
- Update config files: added CONFIG_IP_NF_MATCH_IPV4OPTIONS
  to ppc64/trace
* Wed Dec  9 2009 jeffm@suse.com
- patches.fixes/ext4-fix-insufficient-checks-in-ext4_ioc_move_ext:
  ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT (bnc#561018
  CVE-2009-4131).
* Wed Dec  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32: Fix a potentially serious mis-merge
  in swiotlb code.
* Wed Dec  9 2009 jjolly@suse.de
- patches.fixes/nohz-delay-from-tip.diff: nohz: Introduce
  arch_needs_cpu.
- patches.fixes/reuse-ktime-from-tip.diff: nohz: Reuse ktime in
  sub-functions of tick_check_idle..
- series.conf: Moved s390 patchs to proper place
* Wed Dec  9 2009 npiggin@suse.de
- patches.fixes/ipc-ns-fix-memory-leak-idr.patch: ipc: ns fix
  memory leak (bnc#518767).
- patches.fixes/ipc-remove-unreachable-code-in-semc.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-add-a-per-semaphore-pending-list.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-if-semops-fail.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-semop-operations.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-optimize-single-sops-when-semval-is-zero.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-optimise-undo-list-search.patch:
  (bnc#518767).
- patches.fixes/ipc-semc-sem-preempt-improve.patch:  (bnc#518767).
- patches.fixes/ipc-semc-sem-use-list-operations.patch:
  (bnc#518767).
* Wed Dec  9 2009 bphilips@suse.de
- needs_update: patches moved upstream or obsoleted by upstream
* Tue Dec  8 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: Update to what will
  hopefully be in 2.6.33.
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin: Delete.
* Tue Dec  8 2009 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ipv4options: netfilter ipv4options
  match from patch-o-matic-ng (bnc#131728 - FATE#182).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-devzero-optimisation.patch: mm: /dev/zero
  optimisation (bnc#430738).
* Tue Dec  8 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-22-alc888-exclude-unusable-adcs:
  ALSA: hda - Exclude unusable ADCs for ALC88x (bnc#561235).
* Tue Dec  8 2009 mmarek@suse.cz
- patches.drivers/reenable-generic_serial: Revert "tty: Mark
  generic_serial users as BROKEN".
- Update config files: enable RIO and SX.
- rpm/generic_serial-blacklist: blacklist generic_serial users from
  automatic loading (bnc#551348).
* Tue Dec  8 2009 rgoldwyn@suse.de
- needs_update: patches merged upstream
- novfs patches to be handled by novfs team
* Tue Dec  8 2009 npiggin@suse.de
- needs_update:
- patches.suse/mm-vmalloc-fail-dump-stack.patch: mm: improve
  vmalloc reporting (bnc#511079).
* Tue Dec  8 2009 npiggin@suse.de
- needs_update: most of mine are merged. apparmor patch sent to Andreas.
* Tue Dec  8 2009 coly.li@suse.de
- patches.suse/64bytes_lvb_len.diff: use 64byte lvb len.(bnc#515645)
* Tue Dec  8 2009 agraf@suse.de
- patches.arch/s390-kvm-prefix.patch: KVM: s390: Fix prefix
  register checking in arch/s390/kvm/sigp.c (FATE#306513).
- patches.arch/s390-kvm-psw.patch: KVM: s390: Make psw available
  on all exits, not just a subset (FATE#306513).
* Mon Dec  7 2009 tiwai@suse.de
- patches.drivers/synaptics-hp-clickpad: Input: Add support of
  clickpad mode to synaptics mouse driver (bnc#547370).
* Mon Dec  7 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32 final and c/s 958.
- patches.xen/xen-dcdbas: force proper address translation
  in DCDBAS.
- patches.xen&xen-vmalloc_32: guarantee 32-bit
  (bus-)addressability of vmalloc_32() output (bnc#548010,
  bnc#552492).
- patches.xen/xen-x86_64-nx-user-mappings: set NX bit in kernel
  version of top level user mode page table entries.
- patches.xen/xen3-rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls (FATE#305733).
- patches.xen/xen3-x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
- patches.xen/xen3-x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829, bnc#482220).
- patches.xen/xen3-x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829, bnc#482220).
- Update EC2 config files (disable CAN_DEV and UIO).
* Mon Dec  7 2009 jbeulich@novell.com
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch,
  patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  Fix build warnings.
* Mon Dec  7 2009 hare@suse.de
- patches.drivers/lpfc-add-raywire-id: Add missing PCI-ID to lpfc.
* Sat Dec  5 2009 tonyj@suse.de
- config.conf: add trace flavor for ppc64 (fate# 307051)
- Update config files.
* Fri Dec  4 2009 jeffm@suse.com
- Split apparmor.diff out into separate patches to align more
  closely with the upstream AppArmor 2.4 repo.
- patches.apparmor/apparmor-fix-cap-audit_caching-preemption-disabling:
  AppArmor: Fix cap audit_caching preemption disabling.
- patches.apparmor/apparmor-fix-change_profile-failing-lpn401931:
  AppArmor: Fix change_profile failing lpn401931.
- patches.apparmor/apparmor-fix-change_profile-failure: AppArmor:
  Fix change_profile failure.
- patches.apparmor/apparmor-fix-determination-of-forced-audit-messages:
  AppArmor: Fix determination of forced AUDIT messages..
- patches.apparmor/apparmor-fix-failure-to-audit-change_hat-correctly:
  AppArmor: fix failure to audit change_hat correctly.
- patches.apparmor/apparmor-fix-file-auditing-when-quiet-is-used:
  AppArmor: Fix file auditing when quiet is used.
- patches.apparmor/apparmor-fix-leak-when-profile-transition-table-fails-unpack:
  AppArmor: Fix leak when profile transition table fails unpack.
- patches.apparmor/apparmor-fix-mediation-of-created-paths-that-look-like-deleted-paths:
  AppArmor: Fix mediation of created paths that look like
  "deleted" paths.
- patches.apparmor/apparmor-fix-oops-after-profile-removal:
  AppArmor: Fix oops after profile removal.
- patches.apparmor/apparmor-fix-oops-when-auditing-the-addition-of-profile-namespace:
  AppArmor: Fix oops when auditing the addition of profile
  namespace.
- patches.apparmor/apparmor-fix-oops-when-in-apparmor_bprm_set_creds:
  AppArmor: Fix Oops when in apparmor_bprm_set_creds.
- patches.apparmor/apparmor-fix-profile-namespace-removal:
  AppArmor: Fix profile namespace removal..
- patches.apparmor/apparmor-fix-refcounting-bug-causing-leak-of-creds-and-oops:
  AppArmor: Fix refcounting bug causing leak of creds and oops.
- patches.apparmor/apparmor-fully-close-race-condition-for-deleted-paths:
  AppArmor: Fully close race condition for deleted paths.
- patches.apparmor/apparmor-missing-unlock: AppArmor: Add missing
  unlock to next_profile.
- patches.apparmor/apparmor-policy-load-and-replacement-can-fail-to-alloc-mem:
  AppArmor: Policy load and replacement can fail to alloc mem.
- patches.apparmor/apparmor-fix-security_ops-task_setrlimit-api-use:
  AppArmor: Fix security_ops->task_setrlimit API use.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
- patches.suse/revert-usb-remove-phidget-drivers-from-kernel-tree.patch:
  Revert "USB: remove phidget drivers from kernel tree.".
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-message-catalog.diff: Updated patch
  (bnc#549193,FATE#306999,LTC#57210).
* Fri Dec  4 2009 mmarek@suse.cz
- supported.conf: Update wireless drivers.
* Fri Dec  4 2009 jjolly@suse.de
- patches.arch/s390-03-qeth-hs-traffic-analyzer.patch: qeth:
  HiperSockets Network Traffic Analyzer (bnc#560674).
* Fri Dec  4 2009 hare@suse.de
- patches.drivers/qla2xxx-8.03.01-k7-update: qla2xxx driver
  update to 8.03.01-k7 (bnc#560415).
* Fri Dec  4 2009 mmarek@suse.cz
- rpm/package-descriptions: Add description for kernel-vmi.
* Fri Dec  4 2009 trenn@suse.de
- patches.arch/x86_mce_lru_cleanup.patch: HWPOISON: Undefine lru
  define after table to avoid namespace conflict (fate#307738).
- patches.arch/x86_mce_page_offlining.patch: Add soft page
  offline support (fate#307738).
- patches.arch/x86_mce_page_offlining_test_ability.patch:
  HWPOISON: Add a madvise() injector for soft page offlining
  (fate#307738).
- patches.arch/x86_mce_test_page.patch: Expose Test pageflagA
  and set pageflagB primitive (fate#307738).
* Fri Dec  4 2009 mmarek@suse.cz
- Add the vmi flavor again.
* Fri Dec  4 2009 sjayaraman@suse.de
- patches.suse/SoN-18-netvm-skbuff-reserve.patch: add emergeny flag
  inside kmemcheck boundaries.
- patches.xen/xen3-auto-common.diff: Refresh.
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 and i386 vanilla (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for x86-64 (bnc#560402)
* Fri Dec  4 2009 gregkh@suse.de
- Update config files.
  CONFIG_DRM_I915_KMS=y for i386 (bnc#560402)
* Thu Dec  3 2009 jeffm@suse.com
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch:
  Delete. (bnc#560043)
* Thu Dec  3 2009 jeffm@suse.com
- Cleanup config files.
* Thu Dec  3 2009 bphilips@suse.de
- patches.drivers/tg3_libphy_workaround: Delete. We have all of the 57780
  phylib and tg3 changes due to 2.6.32 bump.
* Thu Dec  3 2009 duwe@suse.de
- back out cpuidle feature that is still unconsistent.
* Thu Dec  3 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  Fix the "fixed" feature patch set from IBM.
* Thu Dec  3 2009 mfasheh@suse.com
- Update config files.
- patches.suse/gfs2-ro-mounts-only.patch: gfs2: allow spectator
  mounts for migration to ocfs2 (FATE#307584).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for 2.6.32 (again).
* Thu Dec  3 2009 duwe@suse.de
- Update config files for cpuidle.
* Thu Dec  3 2009 tiwai@suse.de
- patches.drivers/8250_pnp-wacom-add: serial/8250_pnp.c: add
  new Wacom devices (bnc#544763).
* Thu Dec  3 2009 duwe@suse.de
- patches.suse/cpuidle-cleanup: Refresh.
  one lonely hunk already seems to be in 2.6.32 final
* Thu Dec  3 2009 duwe@suse.de
- bnc#552860 / FATE#307104: kernel idle low power, take 2:
- patches.suse/cpuidle-cleanup: Refresh.
- patches.suse/cpuidle-cleanup-x86: Refresh.
- patches.suse/cpuidle-eliminate-ppcmdpowersave1: Refresh.
* Thu Dec  3 2009 jeffm@suse.com
- Updated to 2.6.32-final.
  - 2 patches eliminated.
* Thu Dec  3 2009 hare@suse.de
- Update config files: Enable Hibernation for zSeries.
* Thu Dec  3 2009 mmarek@suse.cz
- Update config files: Disable CONFIG_MFD_PCF50633, the chip is
  unlikely to be used on architectures we support.
* Thu Dec  3 2009 mmarek@suse.cz
- rpm/split-modules: Print which supported modules need unsupported
  modules.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: support lis3lv02d, hp_accel needs it.
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: hp_accel is supported (FATE #306448).
* Thu Dec  3 2009 jdelvare@suse.de
- supported.conf: remove wm831x drivers, we no longer ship them.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable all new hwmon drivers on ppc
  (default and vanilla) for consistency.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Add wm831x, needed by drivers/input/misc/wm831x-on.
* Thu Dec  3 2009 mmarek@suse.cz
- supported.conf: Fix up after commit bfea0bd.
* Thu Dec  3 2009 jdelvare@suse.de
- Update config files: disable WM831x and WM8350 support entirely,
  as recommended by the drivers author. These devices are only
  found on embedded devices such as music players or mobile phones.
* Thu Dec  3 2009 hare@suse.de
- supported.conf: Mark pmcraid and igbvf as supported;
  OSD drivers as unsupported.
* Thu Dec  3 2009 jdelvare@suse.de
- Restore link from config/s390/vanilla to config/s390x/vanilla.
* Thu Dec  3 2009 jbeulich@novell.com
- supported.conf: Update Xen drivers.
* Thu Dec  3 2009 tonyj@suse.de
- needs_update: readd
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch
  patches.suse/perfmon2-remove_syscalls.patch
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: woh dluoc I tegrof ot esolc eht fi
* Thu Dec  3 2009 gregkh@suse.de
- rpm/post.sh:
- rpm/postun.sh: If this is a Moblin-based box, don't run yast-bootloader
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: stop shipping wm831x-hwmon, wm8350-hwmon,
  i2c-simtec and i2c-designware.
- supported.conf: remove i2c-simtec.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Add all new hwmon and i2c/busses drivers. The
  former unsupported, the latter supported.
* Wed Dec  2 2009 jdelvare@suse.de
- Update config files: disable CONFIG_I2C_VOODOO3.
- supported.conf: drop i2c-voodoo3, superseded by tdfxfb.
* Wed Dec  2 2009 jdelvare@suse.de
- supported.conf: Drop hwmon and i2c/chips drivers which have been
  obsoleted.
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Obsolete perfmon-kmp.
* Wed Dec  2 2009 mmarek@suse.cz
- supported.conf: Add perfmon, hid and input modules.
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: Fix vanilla configs
* Wed Dec  2 2009 tiwai@suse.de
- Update config files: disabled CONFIG_SND_SOC* in ppc configs.
* Wed Dec  2 2009 tiwai@suse.de
- Updated the sound section of supported.conf
* Wed Dec  2 2009 gregkh@suse.de
- Update config files. disable USB OTG drivers that should not
  have been enabled.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: remove some usb drivers that were deleted or renamed.
* Wed Dec  2 2009 gregkh@suse.de
- supported.conf: update usb driver section
* Wed Dec  2 2009 mmarek@suse.cz
- rpm/check-supported-list: Skip modules in Documentation and
  drivers/staging.
* Wed Dec  2 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-remote-DoS.patch: mac80211: fix
  remote DoS (bnc#558267).
* Tue Dec  1 2009 tiwai@suse.de
- Forward-port 11.2 patches:
  patches.drivers/alsa-sp1-hda-18-msi-wind-u115-fix: ALSA: hda -
    Add a position_fix quirk for MSI Wind U115.
  patches.drivers/alsa-sp1-hda-19-cx5047-test-mode-fix: ALSA:
    hda - Fix Cxt5047 test mode (bnc#559062).
  patches.drivers/alsa-sp1-hda-20-fsc-amilo-pi1505-fix: ALSA:
    hda - Add a pin-fix for FSC Amilo Pi1505 (bnc#557403).
  patches.drivers/alsa-sp1-hda-21-hp-dv3-position-fix-quirk:
    ALSA: hda - Add position_fix quirk for HP dv3 (bnc#555935).
* Mon Nov 30 2009 jeffm@suse.com
- patches.fixes/megaraid_sas-fix-permissions-on-poll_mode_io:
  megaraid_sas: Fix permissions on poll_mode_io (bnc#557180
  CVE-2009-3939).
* Mon Nov 30 2009 jeffm@suse.com
- patches.arch/x86-64-add-comment-for-rodata-large-page-retainment:
  x86-64: add comment for RODATA large page retainment
  (bnc#558249).
- patches.arch/x86-64-align-rodata-kernel-section-to-2mb-with-config_debug_rodata:
  x86-64: align RODATA kernel section to 2MB with
  CONFIG_DEBUG_RODATA (bnc#558249).
- patches.arch/x86-64-preserve-large-page-mapping-for-1st-2mb-kernel-txt-with-config_debug_rodata:
  x86-64: preserve large page mapping for 1st 2MB kernel txt
  with CONFIG_DEBUG_RODATA (bnc#558249).
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop libata patches which are already included in
  2.6.31 vanilla.
* Mon Nov 30 2009 teheo@suse.de
- needs_update: drop patches which are already included in 2.6.31
  vanilla.
* Mon Nov 30 2009 teheo@suse.de
  Forward port two x86 patches from SLE11.
- needs_update:
- patches.arch/x86-fix-nodac: x86: fix iommu=nodac parameter
  handling (bnc#463829).
- patches.arch/x86-mcp51-no-dac: x86: disallow DAC for MCP51
  PCI bridge (bnc#463829).
* Mon Nov 30 2009 agraf@suse.de
- Update config files: Enable KSM (FATE#306513)
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: acpi dock patch was hmacht's, not mine
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: sysfs debugging crash patch is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: jeffm merged novfs patches into the main novfs patch.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: qualcomm modem driver is upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: squashfs is now upstream
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: via driver bugfixes never went upstream, and people
  are complaining about them, so they were dropped.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove staging driver entries, they are all upstream.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove hv driver entries, those are upstream now.
* Sat Nov 28 2009 gregkh@suse.de
- needs_update: remove xen patches with my name on it.  Just because
  I refreshed the patch, doesn't mean I own it or even like the
  thing :)
* Sat Nov 28 2009 sjayaraman@suse.de
- patches.suse/SoN-11-mm-reserve.patch: Fix build errors in -trace
  and ppc64 flavors.
* Fri Nov 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Abort if supported modules depend on
  unsupported ones.
* Fri Nov 27 2009 mmarek@suse.cz
- supported.conf: mark cnic as supported (needed by bnx2i).
* Fri Nov 27 2009 jbenc@suse.cz
- patches.suse/panic-on-io-nmi-SLE11-user-space-api.patch: API
  fix: X86: sysctl to allow panic on IOCK NMI error (bnc#427979).
- patches.suse/kdb-common: Refresh.
- patches.suse/kdump-dump_after_notifier.patch: Refresh.
* Fri Nov 27 2009 jbohac@suse.cz
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
* Fri Nov 27 2009 trenn@suse.de
- needs_update:
  One I still have to send upstream, but it's nicer error output
  only, SP1 is fine in respect to removing all these, thanks.
* Fri Nov 27 2009 hare@suse.de
- Update config files: Compile in efivars module for
  x86_64 (FATE#306931).
* Fri Nov 27 2009 sjayaraman@suse.de
- needs_update:	sjayaraman's patches are either upstream already or
  rebased to SP1.
* Fri Nov 27 2009 sjayaraman@suse.de
- Update config files: NFS_SWAP=y.
* Fri Nov 27 2009 sjayaraman@suse.de
- patches.trace/lttng-instrumentation-swap.patch: Refresh and fix
  a build failure with fuzz factor 0.
* Fri Nov 27 2009 sjayaraman@suse.de
- Rebase Swap-over-NFS(SoN) patches:
- patches.xen/tmem: Refresh to accomodate changes due to SoN patches.
- patches.xen/xen3-auto-common.diff: Refresh to accomodate changes
  due to SoN patches.
* Fri Nov 27 2009 knikanth@suse.de
- needs_update: Verify knikanth's patches in SLE11 but not in SP1
- patches.fixes/dm-release-map_lock-before-set_disk_ro: Release
  md->map_lock before set_disk_ro  (bnc#556899 bnc#479784).
* Fri Nov 27 2009 nfbrown@suse.de
- Restore following patches from SLES11 that are still needed for
  SLES11-SP1
- patches.fixes/nfsd-05-sunrpc-cache-allow-thread-to-block-while-waiting-for.patch:
  sunrpc/cache: allow thread to block while waiting for cache
  update. (bnc#498708).
- patches.fixes/nfsd-06-sunrpc-cache-retry-cache-lookups-that-return-ETIMEDO.patch:
  sunrpc/cache: retry cache lookups that return -ETIMEDOUT
  (bnc#498708).
- patches.fixes/nfsd-07-nfsd-idmap-drop-special-request-deferal-in-favour-of.patch:
  nfsd/idmap: drop special request deferal in favour of improved
  default. (bnc#498708).
- patches.fixes/nfsd-09-fix-kabi: Fix kabi breakage in previous
  nfsd patch series (bnc#498708).
* Thu Nov 26 2009 coly.li@suse.de
- needs_update: remove patches item of coly.li, lmb and mfasheh.
- patches.fixes/dlm-enable-debug.patch: update the patch from SLES11
  to SLES11 SP1 tree.
* Thu Nov 26 2009 jslaby@suse.cz
- patches.fixes/make-note_interrupt-fast.diff: Fix performance
  regression on large IA64 systems (bnc #469589).
* Thu Nov 26 2009 mmarek@suse.cz
- rpm/old-packages.conf: obsolete kernel-kdump on ppc.
- config.conf: delete kdump configs.
- config/ppc/kdump: Delete.
- config/ppc64/kdump: Delete.
* Thu Nov 26 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-Export_memory_sysdev_class:
  Refresh. Fix "typo", memory_sysdev_class should be exported
  only to GPL'ed modules.
* Thu Nov 26 2009 hare@suse.de
  Fixup patches for series2git:
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Thu Nov 26 2009 duwe@suse.de
- config.conf: disable build of ppc kdump flavours
  (FATE#304346)
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/libata-missing-_SDD-is-not-an-error:
  libata-acpi: missing _SDD is not an error (bnc#551942).
* Thu Nov 26 2009 jbenc@suse.cz
- patches.fixes/mac80211-fix-spurious-delba-handling.patch:
  mac80211: fix spurious delBA handling (bnc#558267,
  CVE-2009-4026, CVE-2009-4027).
* Thu Nov 26 2009 tiwai@suse.de
- patches.drivers/sky2-add-register-definitions: sky2: add
  register definitions for new chips (bnc#544760).
- patches.drivers/sky2-88E8059-support: sky2: 88E8059 support
  (bnc#544760).
- patches.drivers/sky2-optima-tcp-offload-fix: net: Fix Yukon-2
  Optima TCP offload setup (bnc#544760).
- patches.drivers/sky2-optima-fix-pci-cfg: net: Add missing
  TST_CFG_WRITE bits around sky2_pci_write (bnc#544760).
* Thu Nov 26 2009 nfbrown@suse.de
- Update config files.
  disable CONFIG_MULTICOE_RAID456 as it is not yet stable.
  Enable CONFIG_ASYNC_TX_DMA for FATE#306368
* Thu Nov 26 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Nov 26 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: Delete.
  it never went upstream, so we should drop it as well.
* Wed Nov 25 2009 tonyj@suse.de
- patches.trace/lttng-*: update for 2.6.32
- patches.trace/lttng-instrumentation-timer.patch: Delete.
- patches.xen/tmem: Refresh.
- patches.xen/xen3-auto-common.diff: Refresh.
* Wed Nov 25 2009 tonyj@suse.de
- patches.fixes/oprofile_bios_ctr.patch: detect oprofile counters
  reserved by bios (FATE#307426).
* Wed Nov 25 2009 jeffm@suse.com
- patches.fixes/netfilter-remove-pointless-config_nf_ct_acct-warning:
  netfilter: Remove pointless CONFIG_NF_CT_ACCT warning
  (bnc#552033 (and others)).
* Tue Nov 24 2009 hare@suse.de
- Update config files.
- patches.drivers/mpt-fusion-4.22.00.00-update: Update MPT Fusion
  driver to 4.22.00.00-suse (bnc#556587).
- patches.drivers/mpt-fusion-4.16.00.00-update: Delete.
* Tue Nov 24 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-17-fix-mute-LED-sync-idt92h383xxx:
  ALSA: hda - Fix mute-LED sync on HP laptops with IDT92HD83xxx
  codecs (bnc#547357).
* Tue Nov 24 2009 duwe@suse.de
- patches.arch/ppc-extended_h_cede-*: Increase power savings
  by allowing the core to sleep.
  (FATE##307059, bnc#550447)
* Tue Nov 24 2009 sjayaraman@suse.de
- patches.suse/kconfig-automate-kernel-desktop: automate a few config
  options for kernel-desktop (FATE#305694).
* Tue Nov 24 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Update references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Update
  references (bnc#556135, FATE#306453).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Update references (bnc#556135, FATE#306453).
* Mon Nov 23 2009 jeffm@suse.com
- Enabled:
  patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-add-ghash-algorithm-test.patch: crypto:
  Add ghash algorithm test before provide to users (FATE#306883,
  bnc#554578).
* Mon Nov 23 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "ghash - put proper .data section in place" fix
* Mon Nov 23 2009 sjayaraman@suse.de
- Update config files.
  - Add new options KERNEL_DESKTOP and DEFAULT_VM_DIRTY_RATIO.
  - Enable KERNEL_DESKTOP for only desktop flavor.
* Mon Nov 23 2009 sjayaraman@suse.de
- patches.suse/mm-tune-dirty-limits.patch: mm: Make default
  VM dirty ratio configurable to suit different workloads
  (bnc#552883).
* Fri Nov 20 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in, rpm/mkspec: build kernel-syms only for
  supported architectures.
* Fri Nov 20 2009 jeffm@suse.com
- Enabled B43_PHY_LP=y for PHY support on certain b43 chips.
* Fri Nov 20 2009 mmarek@suse.cz
- patches.suse/export-sync_page_range: Revert "vfs: Remove
  generic_osync_inode() and sync_page_range{_nolock}()"
  (bnc#557231).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  Fix a bad-pointer warning.
* Fri Nov 20 2009 agruen@suse.de
- rpm/macros.kernel-source: Add kernel_module_package_moddir()
  macro for cross-distro compatibility (FATE 305225).
* Fri Nov 20 2009 jslaby@suse.cz
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: Update
  references (FATE#305733).
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  Update references (FATE#305733).
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  Update references (FATE#305733).
* Fri Nov 20 2009 jslaby@suse.cz
- Add writable resource limits support
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/rlim-0001-SECURITY-selinux-fix-update_rlimit_cpu-parameter.patch:
  SECURITY: selinux, fix update_rlimit_cpu parameter.
- patches.suse/rlim-0002-SECURITY-add-task_struct-to-setrlimit.patch:
  SECURITY: add task_struct to setrlimit.
- patches.suse/rlim-0003-core-add-task_struct-to-update_rlimit_cpu.patch:
  core: add task_struct to update_rlimit_cpu.
- patches.suse/rlim-0004-sys_setrlimit-make-sure-rlim_max-never-grows.patch:
  sys_setrlimit: make sure ->rlim_max never grows.
- patches.suse/rlim-0005-core-split-sys_setrlimit.patch: core:
  split sys_setrlimit.
- patches.suse/rlim-0006-core-allow-setrlimit-to-non-current-tasks.patch:
  core: allow setrlimit to non-current tasks.
- patches.suse/rlim-0007-core-optimize-setrlimit-for-current-task.patch:
  core: optimize setrlimit for current task.
- patches.suse/rlim-0008-FS-proc-make-limits-writable.patch:
  FS: proc, make limits writable.
- patches.suse/rlim-0009-core-posix-cpu-timers-cleanup-rlimits-usage.patch:
  core: posix-cpu-timers, cleanup rlimits usage.
- patches.suse/rlim-0010-core-do-security-check-under-task_lock.patch:
  core: do security check under task_lock.
- patches.suse/rlim-0011-resource-add-helpers-for-fetching-rlimits.patch:
  resource: add helpers for fetching rlimits.
- patches.suse/rlim-0012-IA64-use-helpers-for-rlimits.patch:
  IA64: use helpers for rlimits.
- patches.suse/rlim-0013-PPC-use-helpers-for-rlimits.patch: PPC:
  use helpers for rlimits.
- patches.suse/rlim-0014-S390-use-helpers-for-rlimits.patch:
  S390: use helpers for rlimits.
- patches.suse/rlim-0015-SPARC-use-helpers-for-rlimits.patch:
  SPARC: use helpers for rlimits.
- patches.suse/rlim-0016-X86-use-helpers-for-rlimits.patch: X86:
  use helpers for rlimits.
- patches.suse/rlim-0017-FS-use-helpers-for-rlimits.patch: FS:
  use helpers for rlimits.
- patches.suse/rlim-0018-MM-use-helpers-for-rlimits.patch: MM:
  use helpers for rlimits.
- patches.suse/rlim-0019-core-use-helpers-for-rlimits.patch:
  core: use helpers for rlimits.
- patches.suse/rlim-0020-misc-use-helpers-for-rlimits.patch:
  misc: use helpers for rlimits.
- patches.suse/rlim-0021-core-rename-setrlimit-to-do_setrlimit.patch:
  core: rename setrlimit to do_setrlimit.
- patches.suse/rlim-0022-core-implement-getprlimit-and-setprlimit-syscalls.patch:
  core: implement getprlimit and setprlimit syscalls.
- patches.suse/rlim-0023-unistd-add-__NR_-get-set-prlimit-syscall-numbers.patch:
  unistd: add __NR_[get|set]prlimit syscall numbers.
- patches.suse/rlim-0024-COMPAT-add-get-put_compat_rlimit.patch:
  COMPAT: add get/put_compat_rlimit.
- patches.suse/rlim-0025-x86-add-ia32-compat-prlimit-syscalls.patch:
  x86: add ia32 compat prlimit syscalls.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/phy-broadcom-bug-fixes-for-sp1.patch:
  phy/broadcom: bug fixes for SP1 (FATE#307117, bnc#556234).
- patches.drivers/tg3-update-version-to-3.104.patch: tg3: Update
  version to 3.104 (bnc#556234, FATE#307117).
* Fri Nov 20 2009 hare@suse.de
- patches.drivers/megaraid-04.12-update: megaraid: Update
  megaraid_sas to version 04.12 (FATE#307125).
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/bnx2-entropy-source.patch: bnx2: entropy source
  (FATE#307517).
- patches.drivers/e1000-entropy-source.patch: Enable e1000 as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/e1000e-entropy-source.patch: Enable e1000e as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/igb-entropy-source.patch: Enable igb as entropy
  source (disabled by default) (FATE#307517).
- patches.drivers/ixgbe-entropy-source.patch: Enable ixgbe as
  entropy source (disabled by default) (FATE#307517).
- patches.drivers/tg3-entropy-source.patch: tg3: entropy source
  (FATE#307517).
* Fri Nov 20 2009 hare@suse.de
- patches.fixes/scsi-fix-bug-with-dma-maps-on-nested-scsi-objects:
  scsi_lib_dma: fix bug with dma maps on nested scsi objects
  (bnc#556595).
- patches.fixes/scsi-introduce-helper-function-for-blocking-eh:
  scsi_transport_fc: Introduce helper function for blocking
  scsi_eh (bnc#556595).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Delete.
* Fri Nov 20 2009 hare@suse.de
  Whitespace cleanup for series2git:
- patches.arch/s390-message-catalog.diff: Refresh.
- patches.drivers/aacraid-24701-update: Refresh.
- patches.suse/crasher-26.diff: Refresh.
- patches.suse/kdb-common: Refresh.
- patches.suse/kdb-ia64: Refresh.
- patches.suse/kdb-x86: Refresh.
- patches.suse/ocfs2-allocation-resrvations.patch: Refresh.
- patches.suse/perfmon2.patch: Refresh.
- patches.suse/perfmon2_ioctl.patch: Refresh.
- patches.suse/stack-unwind: Refresh.
* Fri Nov 20 2009 bphilips@suse.de
- patches.drivers/igb-add-support-for-82576NS-SerDes-adapter.patch:
  igb: add support for 82576NS SerDes adapter (FATE#306856).
* Fri Nov 20 2009 jbeulich@novell.com
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  Fix for !CONFIG_SCSI (in -ec2).
* Fri Nov 20 2009 mfasheh@suse.com
- patches.suse/ocfs2-allocation-resrvations.patch: ocfs2:
  allocation reservations (bnc#501563 FATE#307247).
* Fri Nov 20 2009 jjolly@suse.de
- patches.suse/perfmon2.patch: Refresh.
- patches.arch/x86-self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
- patches.suse/self-ptrace.patch: Delete. (bnc#554585,LTC#57794)
* Fri Nov 20 2009 jeffm@suse.com
- Update to 2.6.32-rc8.
  - Eliminated 1 patch.
* Fri Nov 20 2009 jeffm@suse.de
- patches.fixes/enclosure-fix-oops-while-iterating-enclosure_status-array:
  enclosure: fix oops while iterating enclosure_status array
  (bnc#540997).
* Thu Nov 19 2009 tonyj@suse.de
- Update config files.
- patches.suse/perfmon2.patch: perfmon2 (FATE#303968).
- patches.suse/perfmon2_ioctl.patch: switch to ioctl interface
  for perfmon2.
- patches.suse/perfmon2_noutrace.patch: remove UTRACE code
  from perfmon2.
- patches.xen/xen3-patch-2.6.28: Refresh.
* Thu Nov 19 2009 jjolly@suse.de
- Update config files.
- patches.arch/s390-message-catalog.diff: Kernel message
  catalog. (bnc#549193,LTC#57210,FATE#306999).
- rpm/kernel-binary.spec.in:
* Thu Nov 19 2009 jbohac@suse.cz
- patches.suse/add-queue_depth-ramp-up-code.patch: add queue_depth
  ramp up code (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-a-separate-scsi-transport-template-for-npiv-vports.patch:
  fcoe: add a separate scsi transport template for NPIV vports
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-add-check-to-fail-gracefully-in-bonding-mode.patch:
  fcoe: add check to fail gracefully in bonding mode (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-call-ndo_fcoe_enable-disable-to-turn-fcoe-feature-on-off-in-lld.patch:
  fcoe: Call ndo_fcoe_enable/disable to turn FCoE feature on/off
  in LLD (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-checking-san-mac-address.patch: fcoe: Fix
  checking san mac address (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-getting-san-mac-for-vlan-interface.patch:
  fcoe: Fix getting san mac for VLAN interface (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-fix-setting-lport-s-wwnn-wwpn-to-use-san-mac-address.patch:
  fcoe: Fix setting lport's WWNN/WWPN to use san mac address
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-fix-using-vlan-id-in-creating-lport-s-wwwn-wwpn.patch:
  fcoe: Fix using VLAN ID in creating lport's WWWN/WWPN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-formatting-cleanups-and-commenting.patch:
  fcoe: Formatting cleanups and commenting (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-increase-fcoe_max_lun-to-0xffff-65535.patch:
  fcoe: Increase FCOE_MAX_LUN to 0xFFFF (65535) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-initialize-return-value-in-fcoe_destroy.patch:
  fcoe: initialize return value in fcoe_destroy (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-fix-an-libfc-issue-with-queue-ramp-down-in-libfc.patch:
  fcoe, libfc: fix an libfc issue with queue ramp down in libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-libfc-use-single-frame-allocation-api.patch:
  fcoe, libfc: use single frame allocation API (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-npiv-vport-create-destroy.patch: fcoe: NPIV
  vport create/destroy (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-remove-extra-function-decalrations.patch:
  fcoe: remove extra function decalrations (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/fcoe-remove-redundant-checking-of-netdev-netdev_ops.patch:
  fcoe: remove redundant checking of netdev->netdev_ops
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-use-netif_f_fcoe_mtu-flag-to-set-up-max-frame-size-lport-mfs.patch:
  fcoe: Use NETIF_F_FCOE_MTU flag to set up max frame size
  (lport->mfs) (fate#306857, fate#306859, bnc#551175).
- patches.suse/fcoe-vport-symbolic-name-support.patch: fcoe: vport
  symbolic name support (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-host-number-to-lport-link-up-down-messages.patch:
  libfc: add host number to lport link up/down
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-libfc-fc_libfc-ch-for-libfc-internal-routines.patch:
  libfc: Add libfc/fc_libfc.[ch] for libfc internal routines
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-queue_depth-ramp-up.patch: libfc:
  add queue_depth ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-routine-to-copy-data-from-a-buffer-to-a-sg-list.patch:
  libfc: Add routine to copy data from a buffer to a SG list
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-add-set_fid-function-to-libfc-template.patch:
  libfc: add set_fid function to libfc template (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-add-some-generic-npiv-support-routines-to-libfc.patch:
  libfc: add some generic NPIV support routines to libfc
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-can_queue-ramp-up.patch: libfc: adds
  can_queue ramp up (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-adds-missing-exch-release-for-accepted-rrq.patch:
  libfc: adds missing exch release for accepted RRQ (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-changes-to-libfc_host_alloc-to-consolidate-initialization-with-allocation.patch:
  libfc: changes to libfc_host_alloc to consolidate initialization
  with allocation (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-request-functions.patch:
  libfc: combine name server registration request functions
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-combine-name-server-registration-response-handlers.patch:
  libfc: combine name server registration response handlers
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-convert-to-scsi_track_queue_full.patch:
  libfc: convert to scsi_track_queue_full (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-do-not-use-did_no_connect-for-pkt-alloc-failures.patch:
  libfc: do not use DID_NO_CONNECT for pkt alloc
  failures. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-don-t-warn_on-in-lport_timeout-for-reset-state.patch:
  libfc: don't WARN_ON in lport_timeout for RESET state
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-export-fc-headers.patch: libfc: Export FC
  headers (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-add-fc-passthrough-support.patch: libfc,
  fcoe: Add FC passthrough support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fcoe-don-t-export_symbols-unnecessarily.patch:
  libfc, fcoe: Don't EXPORT_SYMBOLS unnecessarily (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-fixes-for-highmem-skb-linearize-panics.patch:
  libfc, fcoe: fixes for highmem skb linearize panics
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fcoe-increase-els-and-ct-timeouts.patch:
  libfc fcoe: increase ELS and CT timeouts (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-an-issue-of-pending-exch-es-after-i-f-destroyed-or-rmmod-fcoe.patch:
  libfc: fix an issue of pending exch/es after i/f destroyed or
  rmmod fcoe (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-ddp-in-fc_fcp-for-0-xid.patch: libfc: fix
  ddp in fc_fcp for 0 xid (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-fc_els_resp_type-to-correct-display-of-ct-responses.patch:
  libfc: fix fc_els_resp_type to correct display of CT responses
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-frags-in-frame-exceeding-skb_max_frags-in-fc_fcp_send_data.patch:
  libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in
  fc_fcp_send_data (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-free-of-fc_rport_priv-with-timer-pending.patch:
  libfc: fix free of fc_rport_priv with timer pending
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-memory-corruption-caused-by-double-frees-and-bad-error-handling.patch:
  libfc: fix memory corruption caused by double frees and bad
  error handling (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-rnn_id-smashing-skb-payload.patch: libfc:
  fix RNN_ID smashing skb payload (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-fix-symbolic-name-registrations-smashing-skb-data.patch:
  libfc: fix symbolic name registrations smashing skb data
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-fix-typo-in-retry-check-on-received-prli.patch:
  libfc: fix typo in retry check on received PRLI (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-fix-wrong-scsi-return-status-under-fc_data_undrun.patch:
  libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-formatting-cleanups-across-libfc.patch:
  libfc: Formatting cleanups across libfc (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-libfcoe-fdisc-els-for-npiv.patch: libfc,
  libfcoe: FDISC ELS for NPIV (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfc-lport-fix-minor-documentation-errors.patch:
  libfc: lport: fix minor documentation errors (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-move-libfc_init-and-libfc_exit-to-fc_libfc-c.patch:
  libfc: Move libfc_init and libfc_exit to fc_libfc.c
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-move-non-common-routines-and-prototypes-out-of-libfc-h.patch:
  libfc: Move non-common routines and prototypes out of libfc.h
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-reduce-can_queue-for-all-fcp-frame-allocation-failures.patch:
  libfc: reduce can_queue for all FCP frame allocation failures
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-register-fc4-features-with-the-fc-switch.patch:
  libfc: register FC4 features with the FC switch (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-node-name-rsnn_nn.patch:
  libfc: Register Symbolic Node Name (RSNN_NN) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-register-symbolic-port-name-rspn_id.patch:
  libfc: Register Symbolic Port Name (RSPN_ID) (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-remove-fc_fcp_complete.patch: libfc: Remove
  fc_fcp_complete (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-remove-unused-fc_lport-pointer-from-fc_fcp_pkt_abort.patch:
  libfc: Remove unused fc_lport pointer from fc_fcp_pkt_abort
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-initializing-fc_cpu_order-and-fc_cpu_mask-per-lport.patch:
  libfc: removes initializing fc_cpu_order and fc_cpu_mask per
  lport (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-removes-unused-disc_work-and-ex_list.patch:
  libfc: removes unused disc_work and ex_list (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-rnn_id-may-be-required-before-rsnn_nn-with-some-switches.patch:
  libfc: RNN_ID may be required before RSNN_NN with some switches
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfc-rpn_id-is-obsolete-and-unnecessary.patch:
  libfc: RPN_ID is obsolete and unnecessary (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfc-vport-link-handling-and-fc_vport-state-managment.patch:
  libfc: vport link handling and fc_vport state managment
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-allow-fip-to-be-disabled-by-the-driver.patch:
  libfcoe: Allow FIP to be disabled by the driver (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-do-not-pad-fip-keep-alive-to-full-frame-size.patch:
  libfcoe: Do not pad FIP keep-alive to full frame size
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-don-t-send-els-in-fip-mode-if-no-fcf-selected.patch:
  libfcoe: don't send ELS in FIP mode if no FCF selected
  (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fcoe-libfcoe-npiv-support.patch:
  libfcoe, fcoe: libfcoe NPIV support (fate#306857, fate#306859,
  bnc#551175).
- patches.suse/libfcoe-fcoe-simplify-receive-flogi-response.patch:
  libfcoe: fcoe: simplify receive FLOGI response (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-allow-fip-receive-to-be-called-from-irq.patch:
  libfcoe: fip: allow FIP receive to be called from
  IRQ. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-should-report-link-to-libfc-whether-selected-or-not.patch:
  libfcoe: FIP should report link to libfc whether selected or
  not (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-fip-use-scsi-host-number-to-identify-debug-messages.patch:
  libfcoe: fip: use SCSI host number to identify debug
  messages. (fate#306857, fate#306859, bnc#551175).
- patches.suse/libfcoe-formatting-and-comment-cleanups.patch:
  libfcoe: formatting and comment cleanups (fate#306857,
  fate#306859, bnc#551175).
- patches.suse/modify-change_queue_depth-to-take-in-reason-why-it-is-being-called.patch:
  modify change_queue_depth to take in reason why it is being
  called (fate#306857, fate#306859, bnc#551175).
- patches.suse/scsi-error-have-scsi-ml-call-change_queue_depth-to-handle-queue_full.patch:
  scsi error: have scsi-ml call change_queue_depth to handle
  QUEUE_FULL (fate#306857, fate#306859, bnc#551175).
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Fixup patch to apply.
* Thu Nov 19 2009 hare@suse.de
  Port patches from SLES11:
- patches.fixes/scsi-dh-queuedata-accessors: Kernel bug triggered
  in multipath (bnc#486001).
- patches.suse/dm-mpath-accept-failed-paths: Refresh.
- patches.suse/dm-mpath-detach-existing-hardware-handler:
  multipath: detach existing hardware handler if none was
  specified.
- patches.suse/dm-mpath-requeue-for-stopped-queue: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.suse/dm-mpath-evaluate-request-result-and-sense:
  multipath: Evaluate request result and sense code
  (FATE#303695,bnc#433920,bnc#442001).
* Thu Nov 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Kill support for kernel-$flavor
  symbols, we need a unified kernel-source for all flavors.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/bnx2i-use-common-iscsi-suspend-queue: bnx2i:
  use common iscsi suspend queue (FATE#307215).
- patches.fixes/iscsi-class-modify-handling-of-replacement-time:
  iscsi class: modify handling of replacement timeout
  (FATE#307215).
- patches.fixes/iser-set-tgt-and-lu-reset-timeout: iser: set
  tgt and lu reset timeout (FATE#307215).
- patches.fixes/libiscsi-add-warm-target-reset-tmf-support:
  libiscsi: add warm target reset tmf support (FATE#307215).
- patches.fixes/libiscsi-check-tmf-state-before-sending-pdu:
  libiscsi: Check TMF state before sending PDU (FATE#307215).
- patches.fixes/libiscsi-fix-login-text-checks-in-pdu-inject:
  libiscsi: fix login/text checks in pdu injection code
  (FATE#307215).
- patches.fixes/scsi-add-scsi-target-reset-support-to-ioctl:
  add scsi target reset support to scsi ioctl.
- patches.fixes/scsi-devinfo-update-hitachi-entries: scsi_devinfo:
  update Hitachi entries (v2).
- patches.fixes/scsi-fc-class-failfast-bsg-requests: [SCSI]
  fc class: fail fast bsg requests.
- patches.drivers/cxgb3i: Delete.
- patches.drivers/cxgb3i-fixed-offload-array-size: Delete.
- patches.fixes/disable-lro-per-default: Delete.
* Thu Nov 19 2009 hare@suse.de
- patches.fixes/scsi_dh-always-attach-sysfs: scsi_dh: create
  sysfs file, dh_state for all SCSI disk devices.
- patches.fixes/scsi_dh-change-activate-interface: scsi_dh: Change
  the scsidh_activate interface to be asynchronous (bnc#556144).
- patches.fixes/scsi_dh-make-alua-handler-asynchronous: scsi_dh:
  Make alua hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-hp_sw-handler-asynchronous: scsi_dh:
  Make hp hardware handler's activate() async (bnc#556144).
- patches.fixes/scsi_dh-make-rdac-handler-asynchronous: scsi_dh:
  Make rdac hardware handler's activate() async (bnc#556144).
* Thu Nov 19 2009 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Delete.
- patches.drivers/qla4xxx-sles11-update: Delete.
* Thu Nov 19 2009 hare@suse.de
- Update config files.
- patches.drivers/hpsa: hpsa: New driver SCSI driver for HP
  Smart Array (FATE#307153,bnc#555855).
- supported.conf: Mark hpsa as supported.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-01-qeth-isolation.patch: qeth: Exploit QDIO
  Data Connection Isolation (bnc#555199,LTC#57826,FATE#307015).
- patches.arch/s390-02-01-cex3-init-msg.patch:
  zcrypt: initialize ap_messages for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-02-cex3-special-command.patch:
  zcrypt: special command support for cex3 exploitation
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-03-cex3-device.patch: zcrypt: add support
  for cex3 device types (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-04-cex3-use-def.patch: zcrypt: use
  definitions for cex3 (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-05-zcrypt-speed-cex2c.patch:
  zcrypt: adjust speed rating between cex2 and pcixcc
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-02-06-zcrypt-speed-cex3.patch:
  zcrypt: adjust speed rating of cex3 adapters
  (bnc#555200,LTC#57825,FATE#307112).
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch: Delete.
* Thu Nov 19 2009 jjolly@suse.de
- patches.arch/s390-sles11sp1-01-qeth-isolation.patch:
  qeth: Exploit QDIO Data Connection Isolation
  (bnc#555199,LTC#57826,FATE#307015).
* Wed Nov 18 2009 jeffm@suse.com
- scripts/sequence-patch.sh: Add automatic generation of supported
  modules list.
* Wed Nov 18 2009 jeffm@suse.com
- Update config files: Enable CONFIG_ACPI_CUSTOM_OVERRIDE_INITRAMFS
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/acpi-generic-initramfs-table-override-support:
  ACPI: generic initramfs table override support (bnc#533555).
- patches.suse/init-move-populate_rootfs-back-to-start_kernel:
  init: move populate_rootfs back to start_kernel (bnc#533555).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  incorporate "crypto: ghash-intel - Hard-code pshufb" fix
* Wed Nov 18 2009 jeffm@suse.com
- patches.suse/hung_task_timeout-configurable-default:
  hung_task_timeout: configurable default (bnc#552820).
  - Default to runtime-disabled on all flavors except debug.
* Wed Nov 18 2009 agraf@suse.de
- patches.fixes/kvm-ioapic.patch: Ignore apic polarity
  (bnc#556564).
- patches.fixes/kvm-macos.patch: Implement some missing intercepts
  so osx doesn't blow up (bnc#556564).
* Wed Nov 18 2009 hare@suse.de
- supported.conf: mark missing 10Gb drivers as supported
  (bnc#555793)
* Wed Nov 18 2009 hare@suse.de
- patches.drivers/aacraid-24701-update: Problems with aacraid
  (bnc#524242,FATE#307437).
* Wed Nov 18 2009 hare@suse.de
  Cleanup patches for series2git:
- patches.apparmor/apparmor.diff: Refresh.
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Refresh.
- patches.suse/bootsplash: Refresh.
- patches.suse/nfs4acl-ext3.diff: Refresh.
- patches.suse/silent-stack-overflow-2.patch: Refresh.
- patches.suse/suse-ppc32-mol.patch: Refresh.
- patches.suse/xfs-dmapi-src: Refresh.
* Wed Nov 18 2009 agraf@suse.de
- Update config files to enable pv-ops for KVM clock. (bnc#556135)
* Wed Nov 18 2009 tiwai@suse.de
- patches.drivers/alsa-sp1-hda-01-select-ibexpeak-handler: ALSA:
  hda - select IbexPeak handler for Calpella (FATE#306783).
- patches.drivers/alsa-sp1-hda-02-vectorize-get_empty_pcm_device:
  ALSA: hda - vectorize get_empty_pcm_device() (FATE#306783).
- patches.drivers/alsa-sp1-hda-03-allow-up-to-4-HDMI: ALSA:
  hda - allow up to 4 HDMI devices (FATE#306783).
- patches.drivers/alsa-sp1-hda-04-convert-intelhdmi-global-references:
  ALSA: hda - convert intelhdmi global references to local
  parameters (FATE#306783).
- patches.drivers/alsa-sp1-hda-05-remove-intelhdmi-dependency-on-multiout:
  ALSA: hda - remove intelhdmi dependency on multiout
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-06-use-pcm-prepare-callbacks-for-intelhdmi:
  ALSA: hda - use pcm prepare/cleanup callbacks for intelhdmi
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-07-reorder-intelhemi-prepare-callbacks:
  ALSA: hda - reorder intelhdmi prepare/cleanup callbacks
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-08-vectorize-intelhdmi: ALSA:
  hda - vectorize intelhdmi (FATE#306783).
- patches.drivers/alsa-sp1-hda-09-get-intelhtemi-max-channels:
  ALSA: hda - get intelhdmi max channels from widget caps
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-10-auto-parse-intelhdmi-cvt-pin:
  ALSA: hda - auto parse intelhdmi cvt/pin configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-11-remove-static-intelhdmi-config:
  ALSA: hda - remove static intelhdmi configurations
  (FATE#306783).
- patches.drivers/alsa-sp1-hda-12-reset-pins-idt-codec-free:
  ALSA: hda - Reset pins of IDT/STAC codecs at free (bnc#544779).
- patches.drivers/alsa-sp1-hda-13-add-reboot-notifier: ALSA:
  hda - Add reboot notifier to each codec (bnc#544779).
- patches.drivers/alsa-sp1-hda-14-add-missing-export: ALSA: hda -
  Add missing export for snd_hda_bus_reboot_notify (bnc#544779).
- patches.drivers/alsa-sp1-hda-15-fix-build-warning: ALSA: hda -
  Add a proper ifdef to a debug code (FATE#306783).
- patches.drivers/alsa-sp1-hda-16-stac-dual-headphones-fix:
  ALSA: hda - Fix detection of dual headphones (bnc#556532).
* Wed Nov 18 2009 jkosina@suse.de
- patches.arch/x86-crypto-pclmulqdq-accelerated-implementation.patch:
  crypto: ghash - Add PCLMULQDQ accelerated implementation
  (FATE#306883, bnc#554578).
- Update config files: set CRYPTO_GHASH_CLMUL_NI_INTEL=m
- patches.xen/xen3-patch-2.6.28: Refresh to apply cleanly
* Wed Nov 18 2009 agraf@suse.de
- patches.arch/kvm-only-export-selected-pv-ops-feature-structs:
  Only export selected pv-ops feature structs (bnc#556135).
- patches.arch/kvm-replace-kvm-io-delay-pv-ops-with-linux-magic:
  Replace kvm io delay pv-ops with linux magic (bnc#556135).
- patches.arch/kvm-split-paravirt-ops-by-functionality: Split
  paravirt ops by functionality (bnc#556135).
- patches.arch/kvm-split-the-KVM-pv-ops-support-by-feature:
  Split the KVM pv-ops support by feature (bnc#556135).
- patches.xen/xen3-patch-2.6.23: Refresh.
- patches.xen/xen3-patch-2.6.31: Refresh.
* Wed Nov 18 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: Delete.
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Also enable CONFIG_DMAR (fate#306796) for vanilla flavors
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Do the same for i386
* Wed Nov 18 2009 trenn@suse.de
- Update config files.
  Enabling CONFIG_DMAR (fate#306796), introduces these changes:
    +CONFIG_HAVE_INTEL_TXT=y
  - # CONFIG_DMAR is not set
    +CONFIG_DMAR=y
    +# CONFIG_DMAR_DEFAULT_ON is not set
    +CONFIG_DMAR_FLOPPY_WA=y
    +# CONFIG_INTEL_TXT is not set
  Done for x86_64 for now only.
* Mon Nov 16 2009 jkosina@suse.de
- patches.fixes/hid-fixup-ncr-quirk.patch: HID: fixup quirk for
  NCR devices (bnc#548807).
* Fri Nov 13 2009 mmarek@suse.cz
- rpm/*.spec.in, rpm/kernel-module-subpackage: add
  Provides: multiversion(kernel) to binary kernel packages,
  kernel-source, kernel-syms and all KMPs so that zypp can be
  configured to keep multiple versions of these packages
  (fate#305311).
* Fri Nov 13 2009 npiggin@suse.de
- Disable LGUEST on x86 32. It doesn't build properly without PARAVIRT.
* Wed Nov 11 2009 jack@suse.cz
- patches.fixes/zisofs-large-pagesize-read.patch: zisofs:
  Implement reading of compressed files when PAGE_CACHE_SIZE >
  compress block size (bnc#540349).
* Wed Nov 11 2009 npiggin@suse.de
- Update config files.
* Wed Nov 11 2009 npiggin@suse.de
- Disable PARAVIRT_GUEST on x86 32 and 64.
* Tue Nov 10 2009 teheo@suse.de
- patches.drivers/libata-ahci-aspire-3810t-noncq: ahci: disable
  NCQ on Aspire 3810t (bnc#522790).
* Tue Nov 10 2009 npiggin@suse.de
- Update config files.
* Tue Nov 10 2009 npiggin@suse.de
- Update config files. Disable CONFIG_CC_STACKPROTECTOR on all
  x86 kernels except debug. Overhead is prohibitive.
* Mon Nov  9 2009 npiggin@suse.de
- patches.suse/files-slab-rcu.patch: SLAB_DESTROY_BY_RCU for
  file slab.
* Mon Nov  9 2009 npiggin@suse.de
- Update config files. Vanilla doesn't have unwinder, trace selects
  options which select frame pointers.
* Mon Nov  9 2009 npiggin@suse.de
- Disable FRAME_POINTER on i386 and x86-64, all kernels. Unwind info
  should provide all this functionality.
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-honour-server-preferred-io-size: NFS: Honour
  server-preferred io sizes (bnc#550648).
* Mon Nov  9 2009 nfbrown@suse.de
- patches.fixes/nfs-slot-table-alloc: Don't fail allocations
  for the slot table when mounting an NFS filesystem (bnc#519820).
* Fri Nov  6 2009 trenn@suse.de
- patches.arch/x86_amd_fix_erratum_63.patch: x86/amd-iommu:
  Workaround for erratum 63 (bnc#548274).
* Fri Nov  6 2009 jeffm@suse.de
- Disabled PARAVIRT_GUEST on ia64/trace and ia64/vanilla.
* Fri Nov  6 2009 trenn@suse.de
- patches.suse/kdb_x86_fix_hang.patch: X86 KDB: Reduce timeout
  for blinking LEDs (bnc#528811).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix last change.
* Fri Nov  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc6 and c/s 941.
- Update Xen config files.
- supported.conf: Add domctl.
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add the /lib/modules/.../{source,devel}
  symlinks to the -devel package (bnc#548728).
* Fri Nov  6 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kvm-kmp.
* Thu Nov  5 2009 jeffm@suse.com
- Update to 2.6.32-rc6.
  - 2 patches eliminated
  - NR_CPUS=4096 on ia64/vanilla again
* Thu Nov  5 2009 jeffm@suse.com
- Performance: Disabled CONFIG_PARAVIRT on all flavors.
* Thu Nov  5 2009 mmarek@suse.cz
- Delete unused 2.6.31.y patches.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: add libfcoe and fix typo.
* Thu Nov  5 2009 mmarek@suse.cz
- supported.conf: update so that supported modules don't require
  unsupported ones by adding following modules: async_pq
  async_raid6_recov ath blkback_pagemap crypto_hash drm_kms_helper
  fddi fscache lib80211 libfcoe libipw libiscsi_tcp llc md_mod mdio
  mfd_core nf_defrag_ipv4 p8022 psnap raid6_pq tr ttm ucb1400_core
  v4l2_compat_ioctl32.
* Thu Nov  5 2009 mmarek@suse.cz
- config.conf: remove kernel-ps3-devel (does not exist) and
  kernel-debug-devel (not needed most of the time) from
  kernel-syms.
* Thu Nov  5 2009 hare@suse.de
- Update config files: Set CONFIG_HZ to 100 for zSeries
  (bnc#552564).
* Thu Nov  5 2009 hare@suse.de
- Update config files: Increase MAX_RAW_DEVS to 4096 on
  zSeries (bnc#552565).
* Wed Nov  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete stray text.
* Tue Nov  3 2009 mmarek@suse.cz
- config.conf: remove the ec2 flavor from kernel-syms, most KMPs
  don't make any sense on ec2
  (http://lists.opensuse.org/opensuse-kernel/2009-11/msg00001.html).
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete also brocade-bfa-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: add split-modules to the src.rpm.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete enic-kmp and fnic-kmp.
* Mon Nov  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete kmps by their full name, not
  just the foo-kmp virtual dependency (bnc#472410).
* Thu Oct 29 2009 tonyj@suse.de
- Update ppc/ps3 config for CONFIG_UTRACE
* Thu Oct 29 2009 tonyj@suse.de
- patches.trace/utrace-core: Update for SP1 (FATE# 304321)
* Wed Oct 28 2009 nfbrown@suse.de
- patches.fixes/nfsd-acl.patch: nfsd: Fix sort_pacl in
  fs/nfsd/nf4acl.c to actually sort groups (bnc#549748).
* Wed Oct 28 2009 jdelvare@suse.de
- Update config files:
  CONFIG_NTFS_FS=n
  We handle NTFS through FUSE these days.
* Tue Oct 27 2009 jbohac@suse.cz
- Update config files:
  CONFIG_NETLABEL=y
  CONFIG_SECURITY_NETWORK_XFRM=y
  (fate#307284)
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix compilation failure for configs with CONFIG_SMP=n and
  CONFIG_FAR_GROUP_SCHED=y
* Tue Oct 27 2009 jbeulich@novell.com
- Update config files (MINIX_FS=m globally, NTFS_FS off for -ec2).
- supported.conf: Add fs/minix.
* Tue Oct 27 2009 jkosina@suse.de
- patches.fixes/percpu-allow-pcpu_alloc-to-be-called-with-IRQs-off:
  percpu: allow pcpu_alloc() to be called with IRQs off
  (bnc#548119).
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  Update to newer version which is going to be merged upstream.
* Fri Oct 23 2009 jeffm@suse.com
- Update to 2.6.32-rc5-git3.
* Fri Oct 23 2009 mmarek@suse.cz
- Update config files: set NR_CPUS back to 2048 for ia64/vanilla
  until there is a fix in mainline.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  fix for !CONFIG_SMP.
* Fri Oct 23 2009 mmarek@suse.cz
- patches.suse/Cleanup-and-make-boot-splash-work-with-KMS.patch:
  Cleanup and make boot splash work with KMS (bnc#544645).
* Thu Oct 22 2009 jeffm@suse.com
- Re-enabled NR_CPUS=4096 on ia64.
- patches.fixes/sched-move-rq_weight-data-array-out-of-percpu:
  sched: move rq_weight data array out of .percpu (bnc#548119).
* Tue Oct 20 2009 jbeulich@novell.com
- Update x86-64 Xen config file (NR_CPUS=512).
- Refresh a few Xen patches.
- rpm/kernel-binary.spec.in: Handle -ec2 flavor.
- rpm/package-descriptions: Describe -ec2 flavor.
- rpm/post.sh: Handle -ec2 flavor.
* Tue Oct 20 2009 jbeulich@novell.com
- patches.fixes/use-totalram_pages: Delete.
* Tue Oct 20 2009 jbeulich@novell.com
- config.conf: Add -ec2 configs (fate#305273)
- Add ec2 config files.
- patches.xen/xen-unpriv-build: No need to build certain bits
  when building non-privileged kernel.
- supported.conf: Add fs/nls/nls_base.
* Mon Oct 19 2009 jeffm@suse.com
- Temporarily reduce NR_CPUS to 2048 on ia64 to avoid build
  failures (bnc#548119)
* Mon Oct 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: [s390x] ignore errors from
  dwarfextract for now.
* Fri Oct 16 2009 jeffm@suse.com
- Update config files.
* Fri Oct 16 2009 jeffm@suse.com
- Update to 2.6.32-rc5.
* Fri Oct 16 2009 mmarek@suse.de
- patches.rpmify/ia64-sn-fix-percpu-warnings: ia64/sn: fix
  percpu warnings.
* Fri Oct 16 2009 mmarek@suse.de
- Update config files: disable MTD_GPIO_ADDR, VME_CA91CX42 and
  VME_TSI148 on ia64 to fix build.
* Fri Oct 16 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.32-rc4: Fix AGP for PowerPC.
* Fri Oct 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.32-rc4 and c/s 938.
- config.conf: Re-enable Xen.
- Update x86 config files.
* Tue Oct 13 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: Added missing sites.
* Mon Oct 12 2009 jeffm@suse.com
- patches.rpmify/staging-missing-sched.h: staging: Complete
  sched.h removal from interrupt.h.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/ptrace_may_access-fix: apparmor:
  ptrace_may_access -> ptrace_access_check.
* Mon Oct 12 2009 jeffm@suse.de
- Update config files.
* Mon Oct 12 2009 jeffm@suse.de
- Updated to 2.6.32-rc4.
  - Eliminated 4 patches.
  - Refreshed context.
* Mon Oct 12 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: Refresh and enable.
* Fri Oct  9 2009 jeffm@suse.de
- Cleanup unused patches:
  - patches.fixes/iwl3945-fix-rfkill.patch: Delete.
  - patches.fixes/iwlagn-fix-rfkill.patch: Delete.
  - patches.suse/kdb-serial-8250: Delete.
  - patches.suse/kdb-sysctl-context: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.fixes/scsi-add-tgps-setting: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/x86_64-hpet-64bit-timer.patch: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.suse/kbuild-icecream-workaround: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: Delete.
* Fri Oct  9 2009 jeffm@suse.de
- patches.arch/mm-avoid-bad-page-on-lru: Refresh and re-enable.
* Fri Oct  9 2009 jeffm@suse.de
- Update vanilla config files.
* Fri Oct  9 2009 jeffm@suse.de
- Update to 2.6.32-rc3.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/tsi148-dependency: vme/tsi148: Depend on VIRT_TO_BUS
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-x86-build-fixes: kdb: Use $srctree not $TOPDIR
  in Makefile.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-prepare_multicast: winbond: implement
  prepare_multicast and fix API usage.
- patches.rpmify/winbond_beacon_timers: winbond: use
  bss_conf->beacon_int instead of conf->beacon_int.
- patches.rpmify/winbond-build-fixes: Delete.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/rtl8192e-build-fixes: rtl8192e: Add #include
  <linux/vmalloc.h>.
* Thu Oct  8 2009 jeffm@suse.de
- patches.suse/kdb-build-fixes: kdb: Build fixes.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/iio-s390-build-fix: iio: Don't build on s390.
* Thu Oct  8 2009 jeffm@suse.de
- patches.rpmify/winbond-build-fixes: winbond: API fix.
* Thu Oct  8 2009 jeffm@suse.de
- Update vanilla config files.
* Thu Oct  8 2009 jeffm@suse.de
- Update config files.
* Thu Oct  8 2009 jeffm@suse.de
- Updated to 2.6.32-rc1 (AKA 2.6.32-rc2).
  - Eliminated 28 patches.
  - 14 patches need further review.
  - Xen and AppArmor are currently disabled.
  - USB support in KDB is disabled.
* Wed Oct  7 2009 gregkh@suse.de
- patches.kernel.org/patch-2.6.31.2-3: Linux 2.6.31.3.
  - major tty bugfix
* Wed Oct  7 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc268-automic-fix: ALSA: hda -
  Fix yet another auto-mic bug in ALC268 (bnc#544899).
* Wed Oct  7 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Fix the regression,
  "iostat reports wrong service time and utilization", introduced
  by this patch  (bnc#544926).
* Tue Oct  6 2009 gregkh@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Delete.
- patches.xen/xen3-x86-mark_rodata_rw.patch: Delete.
  - both of these were not being used anyway.
* Tue Oct  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.2.
* Tue Oct  6 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc660vd-asus-a7k-fix: ALSA: hda -
  Add a workaround for ASUS A7K (bnc#494309).
* Mon Oct  5 2009 gregkh@suse.de
- refresh patch fuzz due to 2.6.31.2 import.
* Mon Oct  5 2009 gregkh@suse.de
- Update to Linux 2.6.31.2:
  - bugfixes, lots of them.
  - security fixes
* Mon Oct  5 2009 tiwai@suse.de
- patches.drivers/alsa-hda-alc861-toshiba-fix: ALSA: hda -
  Fix invalid initializations for ALC861 auto mode (bnc#544161).
* Fri Oct  2 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: Delete.
  The code never got upstream and looks incorrect.
* Fri Oct  2 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi-04-fix-surround-side-mute: ALSA:
  ctxfi: Swapped SURROUND-SIDE mute.
- patches.drivers/alsa-hda-2.6.32-rc1-toshiba-fix: ALSA: hda -
  Added quirk to enable sound on Toshiba NB200.
- patches.drivers/alsa-hda-2.6.32-rc2: ALSA: backport 2.6.32-rc2
  fixes for HD-audio.
* Thu Oct  1 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31.1 and c/s 934.
* Thu Oct  1 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete quickcam-kmp (bnc#543361).
* Wed Sep 30 2009 gregkh@suse.de
- Update to 2.6.31.1
  - lots of bugfixes
  - security fixes
* Wed Sep 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete the sle11 ocfs2-kmp.
* Tue Sep 29 2009 trenn@suse.de
- Disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
  with +trenn (bnc#542767)
* Wed Sep 23 2009 teheo@suse.de
- Update config files.  Build pci-stub driver into the kernel so that
  built in pci drivers can be blocked from attaching to devices.
* Tue Sep 22 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: when building against Linus'
  kernels (2.6.x), append a .0 to the kernel version embedded in
  the KMP version, to ensure that such KMP is older than a KMP
  built against a subsequent stable kernel (2.6.x.y, y > 0).
* Mon Sep 21 2009 jeffm@suse.de
- Update config files.
* Mon Sep 21 2009 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Ported to
  2.6.31 (bnc#533555).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: do not remove the bootloader entry if the kernel
  version didn't change (bnc#533766).
* Sat Sep 19 2009 mmarek@suse.cz
- rpm/postun.sh: remove dead code.
* Fri Sep 18 2009 jeffm@suse.de
- patches.fixes/reiserfs-replay-honor-ro: reiserfs: Properly
  honor read-only devices (bnc#441062).
* Thu Sep 17 2009 jeffm@suse.de
- patches.arch/acpi_srat-pxm-rev-ia64.patch: Use SRAT table rev
  to use 8bit or 16/32bit PXM fields (ia64) (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-store.patch: Store SRAT table
  revision (bnc#503038).
- patches.arch/acpi_srat-pxm-rev-x86-64.patch: Use SRAT table
  rev to use 8bit or 32bit PXM fields (x86-64) (bnc#503038).
* Thu Sep 17 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-rc1: ALSA HD-audio backport
  from 2.6.32-rc1.
* Wed Sep 16 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31 final.
* Tue Sep 15 2009 teheo@suse.de
  Backport attach inhibition for builtin pci drivers from 2.6.32-rc.
- patches.drivers/pci-separate-out-pci_add_dynid: pci: separate
  out pci_add_dynid().
- patches.drivers/pci_stub-add-ids-parameter: pci-stub: add
  pci_stub.ids parameter.
* Tue Sep 15 2009 teheo@suse.de
  Backport patches from 2.6.32-rc to ease ossp testing.
- Update config files - SOUND_OSS_CORE_PRECLAIM is set to N.
- patches.drivers/implement-register_chrdev: chrdev: implement
  __register_chrdev().
- patches.drivers/sound-make-oss-device-number-claiming-optional:
  sound: make OSS device number claiming optional and schedule
  its removal.
- patches.drivers/sound-request-char-major-aliases-for-oss-devices:
  sound: request char-major-* module aliases for missing OSS
  devices.
* Mon Sep 14 2009 sdietrich@suse.de
- patches.suse/novfs-client-module: Update header todo list with
  locking nits (semaphore used as mutex / completion)
* Mon Sep 14 2009 jeffm@suse.com
- Revert back to CONFIG_M586TSC from CONFIG_M686 for default flavor
  (bnc#538849)
* Fri Sep 11 2009 jbeulich@novell.com
- patches.suse/crasher-26.diff: Add capability to also trigger a
  kernel warning.
* Fri Sep 11 2009 knikanth@suse.de
- patches.suse/block-seperate-rw-inflight-stats: Seperate read
  and write statistics of in_flight requests (fate#306525).
* Thu Sep 10 2009 gregkh@suse.de
- patch fuzz removal now that 2.6.31 is the base.
* Thu Sep 10 2009 gregkh@suse.de
- Update config files.
    CONFIG_MOUSE_PS2_ELANTECH=y
    CONFIG_MOUSE_PS2_TOUCHKIT=y
    (bnc#525607)
* Thu Sep 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh: fix misc realtek
  issues, add another Nvidia HDMI device id
* Thu Sep 10 2009 jeffm@suse.de
- Updated to 2.6.31-final.
* Tue Sep  8 2009 gregkh@suse.de
- refresh patches for fuzz due to upstream changes
* Tue Sep  8 2009 gregkh@suse.de
- Update to 2.6.31-rc9
  - obsoletes:
  - patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708
  - patches.drivers/alsa-hda-fix-02-mbp31-hp-fix
* Tue Sep  8 2009 knikanth@suse.de
- patches.fixes/scsi_dh-Provide-set_params-interface-in-emc-device-handler.patch:
  scsi_dh: Provide set_params interface in emc device handler
  (bnc#521607).
- patches.fixes/scsi_dh-Use-scsi_dh_set_params-in-multipath.patch:
  scsi_dh: Use scsi_dh_set_params() in multipath. (bnc#521607).
- patches.fixes/scsi_dh-add-the-interface-scsi_dh_set_params.patch:
  scsi_dh: add the interface scsi_dh_set_params() (bnc#521607).
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: delete obsolete macro.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: require minimum versions of
  module-init-tools and perl-Bootloader, the %%post script is no
  longer compatible with ancient versions.
* Mon Sep  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.31, the
  previous <= 2.6.30-1 didn't catch some cases obviously
  (bnc#533766).
* Fri Sep  4 2009 jeffm@suse.de
- Enabled CONFIG_SCSI_DEBUG=m (bnc#535923).
* Fri Sep  4 2009 mmarek@suse.cz
- kabi/severities, rpm/kabi.pl, rpm/kernel-binary.spec.in,
- rpm/kernel-source.spec.in: Use a simple script to check kabi by
  comparing Module.symvers files (similar to the old SLES9 one).
- rpm/built-in-where: Delete.
- rpm/symsets.pl: Delete.
- kabi/commonsyms: Delete.
- kabi/usedsyms: Delete.
* Fri Sep  4 2009 mmarek@suse.cz
- patches.suse/kbuild-rebuild-fix-for-Makefile.modbuiltin:
  kbuild: rebuild fix for Makefile.modbuiltin.
* Thu Sep  3 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  Delete, it was wrong.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen config files.
* Wed Sep  2 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc8 and c/s 931.
- patches.fixes/use-totalram_pages: use totalram_pages in favor
  of num_physpages for sizing boot time allocations (bnc#509753).
- patches.xen/xen-x86-per-cpu-vcpu-info: x86: use per-cpu storage
  for shared vcpu_info structure.
* Wed Sep  2 2009 tiwai@suse.de
- patches.drivers/alsa-hda-2.6.32-pre: Refresh; merged fixes for
  IDT92HD73* codecs
* Tue Sep  1 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: Update to latest git.
* Tue Sep  1 2009 jeffm@suse.com
- patches.arch/add_support_for_hpet_msi_intr_remap.patch:
  intr-remap: generic support for remapping HPET MSIs
  (bnc#532758).
- patches.arch/add_x86_support_for_hpet_msi_intr_remap.patch:
  x86: arch specific support for remapping HPET MSIs (bnc#532758).
* Tue Sep  1 2009 mmarek@suse.cz
- rpm/package-descriptions: fix description of the x86_64
  kernel-desktop package (bnc#535457).
* Mon Aug 31 2009 jeffm@suse.com
- Update to 2.6.31-rc8.
  - Eliminated 1 patch.
* Mon Aug 31 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-01-add-missing-mux-for-vt1708:
  ALSA: hda - Add missing mux check for VT1708 (bnc#534904).
- patches.drivers/alsa-hda-fix-02-mbp31-hp-fix: ALSA: hda -
  Fix MacBookPro 3,1/4,1 quirk with ALC889A.
- patches.drivers/alsa-hda-2.6.32-pre: Refresh.
* Wed Aug 26 2009 tiwai@suse.de
- patches.drivers/alsa-hda-[0-9]*: Delete, fold into a single patch
  patches.drivers/alsa-hda-2.6.32-pre
* Tue Aug 25 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Delete.
* Tue Aug 25 2009 jbeulich@novell.com
- scripts/run_oldconfig.sh: Consistently use $prefix.
* Mon Aug 24 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete %%name-base <= 2.6.30-1
  (bnc#530752).
* Mon Aug 24 2009 jeffm@suse.com
- Update to 2.6.31-rc7.
  - Eliminated 3 patches.
* Mon Aug 24 2009 jeffm@suse.com
- Update config files: Enable CONFIG_PROC_EVENTS.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh: Do not call /sbin/module_upgrade, the rename
  happened before SLES10.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/module-renames: Delete, we don't need to care about modules
  renamed before SLES10. Also, current mkinitrd gets the list of
  storage drivers based on pci ids.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: drop support for SLE10, the package
  can't be installed on SLE10 as is, so why not make it more
  adventurous.
* Fri Aug 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove product(openSUSE) supplements
  from the -extra subpackage which doesn't exist on openSUSE
  anymore.
* Thu Aug 20 2009 tiwai@suse.de
- patches.drivers/alsa-hda-fix-0*: Backport from 2.6.31-rc fixes
  (to be merged)
- patches.drivers/alsa-hda-32-Reword-auto-probe-messages: Refresh.
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Thu Aug 20 2009 jbeulich@novell.com
- Update config files (modularize crypto again).
- supported.conf: Add resulting modules as supported.
* Wed Aug 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc6 and c/s 928.
* Tue Aug 18 2009 tiwai@suse.de
- patches.drivers/alsa-hda-48-alc268-oops-fix: ALSA: hda -
  Fix invalid capture mixers with some ALC268 models.
* Tue Aug 18 2009 gregkh@suse.de
- patches.drivers/usb-storage-increase-the-bcd-range-in-sony-s-bad-device-table.patch:
  USB: storage: increase the bcd range in Sony's bad device
  table. (bnc#466554).
* Mon Aug 17 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: Change the range from
  0-255 to 0-7 to make it easier for HAL to handle the device without a
  need for custom scripts.
* Mon Aug 17 2009 jeffm@suse.com
- Updated to 2.6.31-rc6.
* Sun Aug 16 2009 gregkh@suse.de
- patches.drivers/samsung-backlight-driver.patch: added N120 support
  and some other devices that were integrated into the driver from
  upstream.
* Sun Aug 16 2009 coly.li@suse.de
- supported.conf:
  set kernel/fs/dlm/dlm as unsupported, since fs/dlm is provided
  separately in the ocfs2 KMP package
* Sat Aug 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-47-idt92hd8x-fix: ALSA: hda - Fix /
  clean up IDT92HD83xxx codec parser (bnc#531533).
* Sat Aug 15 2009 gregkh@suse.de
- Update config files.
- patches.drivers/samsung-backlight-driver.patch: Samsung
  backlight driver (bnc#527533, bnc#531297).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add some hints how to set the %%jobs
  macro (bnc#530535).
* Fri Aug 14 2009 mmarek@suse.cz
- rpm/modversions: for overriden functions, keep the keyword in
  - -pack.
* Thu Aug 13 2009 jeffm@suse.com
- Updated to 2.6.31-rc5-git9.
  - Eliminated 7 patches.
* Thu Aug 13 2009 tiwai@suse.de
- patches.drivers/alsa-hda-42-hp-more-quirk: ALSA: hda - Add
  quirks for some HP laptops (bnc#527284).
- patches.drivers/alsa-hda-4[35]-*: Improve Realtek codec mic
  support
- patches.drivers/alsa-hda-46-stac-lo-detect-fix: ALSA: hda -
  Enable line-out detection only with speakers (bnc#520975).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/split-modules, rpm/kernel-binary.spec.in: add the base files
  also to the main package. That way, kernel-$flavor-base is not
  needed in normal setups (fate#307154).
* Wed Aug 12 2009 mmarek@suse.cz
- rpm/find-provides: no rpm provides for drivers/staging. It's
  higly unlikely that any KMP would require them and they just
  take up space in the rpm metadata.
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-41-msi-white-list: ALSA: hda - Add
  a white-list for MSI option (bnc#529971).
* Tue Aug 11 2009 tiwai@suse.de
- patches.drivers/alsa-hda-39-dont-override-ADC-definitions:
  ALSA: hda - Don't override ADC definitions for ALC codecs
  (bnc#529467).
- patches.drivers/alsa-hda-40-auto-mic-support-for-realtek:
  ALSA: hda - Add auto-mic support for Realtek codecs.
* Tue Aug 11 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: do not rename kernel-source.rpmlintrc
  for the -rt variant.
* Mon Aug 10 2009 mmarek@suse.cz
- patches.rpmify/staging-rtl8192su-fix-build-error.patch: move to
  patches.rpmify to fix vanilla ppc builds.
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-38-fix-ALC269-vmaster: ALSA: hda -
  Add missing vmaster initialization for ALC269 (bnc#527361).
* Mon Aug 10 2009 tiwai@suse.de
- patches.drivers/alsa-hda-33-IDT-codec-updates: Refresh.
* Fri Aug  7 2009 jeffm@suse.com
- patches.fixes/recordmcount-fixup: recordmcount: Fixup wrong
  update_funcs() call.
* Fri Aug  7 2009 tiwai@suse.de
- patches.drivers/alsa-soc-fsl-build-fixes: ASoC: Add missing
  DRV_NAME definitions for fsl/* drivers (to fix PPC builds)
* Fri Aug  7 2009 tiwai@suse.de
- patches.arch/wmi-Fix-kernel-panic-when-stack-protection-enabled:
  wmi: Fix kernel panic when stack protection
  enabled. (bnc#529177).
- supported.conf: Update HD-audio modules
* Fri Aug  7 2009 mmarek@suse.cz
- make config/s390/vanilla a symlink again.
* Fri Aug  7 2009 mmarek@suse.de
- rpm/kernel-binary.spec.in: do not manually extract vmlinux
  debuginfo on ppc(64), rpm does it itself.
* Thu Aug  6 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in: Added kernel-spec-macros to Sources.
* Thu Aug  6 2009 jeffm@suse.de
- patches.suse/linux-2.6.29-even-faster-kms.patch: Disabled. It
  doesn't wake up the display on certain hardware.
* Wed Aug  5 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not split the -extra subpackage on
  openSUSE (bnc#528097).
* Wed Aug  5 2009 jeffm@suse.de
- Updated to 2.6.31-rc5-git3.
  - Eliminated 4 patches.
* Wed Aug  5 2009 gregkh@suse.de
- kernel-source.changes: remove old (pre 2008) messages, and move 2008
  to kernel-source.changes.old.  No need to spam email addresses that
  are no longer with the company for failed kernel builds.
* Wed Aug  5 2009 gregkh@suse.de
- patches.drivers/staging-rtl8192su-fix-build-error.patch:
  Staging: rtl8192su: fix build error.
* Wed Aug  5 2009 jeffm@suse.de
- patches.suse/supported-flag-enterprise: Make the supported
  flag configurable at build time (bnc#528097).
* Wed Aug  5 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910 for vanilla builds
* Tue Aug  4 2009 gregkh@suse.de
- Update config files.
  disable CONFIG_DRM_RADEON_KMS as per bnc#527910
* Tue Aug  4 2009 jeffm@suse.de
- patches.rpmify/ttm-pgprot-fixes: ttm: Use pgprot_val for
  comparing pgprot_t.
* Tue Aug  4 2009 tiwai@suse.de
- patches.drivers/alsa-hda-3[0-8]*: ALSA HD-audio updates
- Update config files: enable CONFIG_SND_HDA_CIRRUS=y
* Mon Aug  3 2009 jeffm@suse.de
- Update config files: CONFIG_FRAME_WARN=2048 on all arches, fixes
  ppc build failures.
* Mon Aug  3 2009 jeffm@suse.de
- patches.xen/xen3-patch-2.6.31-rc4-rc5: Fixup pgtable port
* Mon Aug  3 2009 jeffm@suse.de
- Updated to 2.6.31-rc5.
  - Eliminated 11 patches.
* Mon Aug  3 2009 coly.li@suse.de
- Update config files to enable CONFIG_DLM_DEBUG.
* Fri Jul 31 2009 jbeulich@novell.com
- Update Xen patches to 2.6.31-rc4 and c/s 916.
- patches.xen/xen3-driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Delete.
- patches.xen/xen3-panic-on-io-nmi.diff: Delete.
- config.conf: Re-enable Xen.
- Update config files.
* Wed Jul 29 2009 tiwai@suse.de
- Update config files: revert to CONFIG_SND=m and enabled again
  CONFIG_SND_DEBUG=y
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_PRISM2_USB on ia64 and ppc.
* Tue Jul 28 2009 mmarek@suse.cz
- Update config files: disable CONFIG_FB_UDL on ia64.
* Tue Jul 28 2009 jbeulich@novell.com
- config.conf: Remove duplicate i386/desktop entry.
* Tue Jul 28 2009 tiwai@suse.de
- patches.drivers/alsa-hda-29-Add-quirk-for-Dell-Studio-1555:
  ALSA: hda - Add quirk for Dell Studio 1555 (bnc#525244).
* Mon Jul 27 2009 tiwai@suse.de
- patches.drivers/alsa-pcm-*: ALSA PCM fixes
- Fix/enhancement patches backported from ALSA tree
  * patches.drivers/alsa-core-Add-new-TLV-types-for-dBwith-min-max:
    ALSA: Add new TLV types for dBwith min/max (for usb).
  * patches.drivers/alsa-ctxfi-*: SB X-Fi support (FATE#306935).
  * patches.drivers/alsa-hda-*: More HD-audio fixes
  * patches.drivers/alsa-ice-*: ICE17xx fixes
  * patches.drivers/alsa-midi-*: MIDI fixes
  * patches.drivers/alsa-usb-*: USB-audio/MIDI fixes
- Remove obsoleted patches: patches.drivers/alsa-ad1984a-hp-quirks,
  patches.drivers/alsa-ca0106-capture-bufsize-fix,
  patches.drivers/alsa-ctxfi
- Update config files.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, scripts/tar-up.sh: really drop
  config-subst from the package.
* Mon Jul 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: manually create a -devel-debuginfo
  subpackage with vmlinux.debug to fix build with new rpm. This
  works for ix86 and x86_64, other archs might need further fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: more ia64 fixes
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Mon Jul 27 2009 jeffm@suse.de
- patches.rpmify/rtl8192su-build-fix: rtl8192su: compile fixes.
* Sat Jul 25 2009 jeffm@suse.de
- config.conf: Re-enabled trace flavor.
* Fri Jul 24 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on i386 and x86_64
  across all flavors.
* Fri Jul 24 2009 jeffm@suse.de
- Update to 2.6.31-rc4.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: cleanup %%cpu_arch_flavor definition,
  make %%symbols a variable and only use it for selecting patches.
  Also drop the RT symbol as there are not rt patches currently.
* Thu Jul 23 2009 mmarek@suse.cz
- Change the s390(x) config layout so that each arch has its own
  subdirectory, as it is done for other archs. s390/vanilla is a
  symlink to s390x/vanilla.
* Thu Jul 23 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, rpm/kernel-spec-macros: move some common
  macros to kernel-spec-macros.
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-bufsize-fix: ALSA: ca0106 -
  Fix the max capture buffer size (bnc#521890).
* Wed Jul 22 2009 tiwai@suse.de
- patches.drivers/alsa-ctxfi: Add SoundBlaster X-Fi support
  (FATE#306935).
- Update config files.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  Delete.
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  Delete.
- patches.drivers/cpufreq_change_load_calculation_2.patch: Delete.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  Delete.
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  Delete.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  Delete.
* Wed Jul 22 2009 trenn@suse.de
  These are mainline:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Delete.
- patches.arch/thinkpad_fingers_off_backlight_igd.patch: Delete.
* Tue Jul 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: remove double-slash from include2/asm
  symlink.
* Tue Jul 21 2009 mmarek@suse.cz
- config.conf, rpm/mkspec: exclude trace, kdump and ia64/debug from
  the kernel-syms package. These flavor are often excluded in KMPs,
  so excluding them from kernel-syms reduces useless build
  dependencies. KMPs can buildrequire kernel-$flavor-devel
  explicitely if desired.
* Tue Jul 21 2009 mmarek@suse.cz
  Delete obsolete apparmor patches.
- patches.apparmor/add-path_permission.diff: Delete.
- patches.apparmor/add-security_path_permission: Delete.
- patches.apparmor/apparmor-2.6.25.diff: Delete.
- patches.apparmor/apparmor-audit.diff: Delete.
- patches.apparmor/apparmor-intree.diff: Delete.
- patches.apparmor/apparmor-lsm.diff: Delete.
- patches.apparmor/apparmor-main.diff: Delete.
- patches.apparmor/apparmor-misc.diff: Delete.
- patches.apparmor/apparmor-module_interface.diff: Delete.
- patches.apparmor/apparmor-network.diff: Delete.
- patches.apparmor/apparmor-path_permission: Delete.
- patches.apparmor/apparmor-ptrace-2.6.27.diff: Delete.
- patches.apparmor/apparmor-rlimits.diff: Delete.
- patches.apparmor/d_namespace_path.diff: Delete.
- patches.apparmor/d_namespace_path_oops_fix.diff: Delete.
- patches.apparmor/do_path_lookup-nameidata.diff: Delete.
- patches.apparmor/export-security_inode_permission-for-aufs:
  Delete.
- patches.apparmor/file-handle-ops.diff: Delete.
- patches.apparmor/fix-complain.diff: Delete.
- patches.apparmor/fix-vfs_rmdir.diff: Delete.
- patches.apparmor/fork-tracking.diff: Delete.
- patches.apparmor/fsetattr-reintro-ATTR_FILE.diff: Delete.
- patches.apparmor/fsetattr-restore-ia_file.diff: Delete.
- patches.apparmor/fsetattr.diff: Delete.
- patches.apparmor/remove_suid.diff: Delete.
- patches.apparmor/security-create.diff: Delete.
- patches.apparmor/security-getxattr.diff: Delete.
- patches.apparmor/security-link.diff: Delete.
- patches.apparmor/security-listxattr.diff: Delete.
- patches.apparmor/security-mkdir.diff: Delete.
- patches.apparmor/security-mknod.diff: Delete.
- patches.apparmor/security-readlink.diff: Delete.
- patches.apparmor/security-removexattr.diff: Delete.
- patches.apparmor/security-rename.diff: Delete.
- patches.apparmor/security-rmdir.diff: Delete.
- patches.apparmor/security-setattr.diff: Delete.
- patches.apparmor/security-setxattr.diff: Delete.
- patches.apparmor/security-symlink.diff: Delete.
- patches.apparmor/security-unlink.diff: Delete.
- patches.apparmor/security-xattr-file.diff: Delete.
- patches.apparmor/sysctl-pathname.diff: Delete.
- patches.apparmor/unambiguous-__d_path.diff: Delete.
- patches.apparmor/vfs-getxattr.diff: Delete.
- patches.apparmor/vfs-link.diff: Delete.
- patches.apparmor/vfs-listxattr.diff: Delete.
- patches.apparmor/vfs-mkdir.diff: Delete.
- patches.apparmor/vfs-mknod.diff: Delete.
- patches.apparmor/vfs-notify_change.diff: Delete.
- patches.apparmor/vfs-removexattr.diff: Delete.
- patches.apparmor/vfs-rename.diff: Delete.
- patches.apparmor/vfs-rmdir.diff: Delete.
- patches.apparmor/vfs-setxattr.diff: Delete.
- patches.apparmor/vfs-symlink.diff: Delete.
- patches.apparmor/vfs-unlink.diff: Delete.
* Tue Jul 21 2009 npiggin@suse.de
- Update config files for bnc#522686 -- set
  CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR=65536.
* Mon Jul 20 2009 jeffm@suse.de
- Update config files: Disabled optimize for size on all flavors
  (FATE#305694)
* Mon Jul 20 2009 jeffm@suse.de
- Update config files.
* Mon Jul 20 2009 jeffm@suse.com
- Update to 2.6.30.2
  - lots of security and bug fixes
  - Obsoleted patches.fixes/firmware-memmap-64bit.diff
* Mon Jul 20 2009 mmarek@suse.cz
- rpm/split-modules: set LC_COLLATE=C
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- rpm/package-descriptions: Added desktop description.
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Sat Jul 18 2009 jeffm@suse.de
- Add -desktop flavors for i386 and x86_64 (FATE#305694)
  - Disabled group scheduler and groups
  - Disabled optimize for size
  - Enabled full preemption
  - Set HZ=1000
* Fri Jul 17 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: ia64 build fix
* Fri Jul 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: simplify the add_dirs_to_filelist
  function and make it less chatty in build logs.
* Thu Jul 16 2009 jeffm@suse.com
- patches.apparmor/apparmor.diff: ia64 build fix
* Thu Jul 16 2009 jeffm@suse.com
- patches.apparmor/security-default-lsm: security: Define default
  LSM (bnc#442668).
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.apparmor/apparmor.diff: AppArmor.
* Thu Jul 16 2009 jeffm@suse.de
- patches.rpmify/sgi-hotplug-fixup: hotplug: fix sgi-hotplug
  attribute handling.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: drop the config-subst script, use
  scripts/config instead.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix debugsource generation.
* Thu Jul 16 2009 mmarek@suse.cz
- rpm/split-modules: fix last change.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/split-modules: fix for module names with underscores or
  dashes.
* Wed Jul 15 2009 jeffm@suse.de
- Update to 2.6.31-rc3.
  - Eliminated 2 patches.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: annotate in which products the
  obsoleted kmps were last used, remove "ralink-rt2860-kmp" which
  I couldn't find anywhere.
* Wed Jul 15 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: obsolete btusb-kmp (bnc#514375).
* Tue Jul 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/split-modules: move generating of
  the base / main / unsupported module lists to a separate script.
  Avoids 6k modinfo calls and fixes module dependencies
  (bnc#512179).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix include2/asm symlink (bnc#509680).
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of function symbols.
* Mon Jul 13 2009 mmarek@suse.cz
- rpm/modversions: fix overriding of unknown symbols.
* Tue Jul  7 2009 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Delete the leftover debugging patches for e1000e EEPROM corruption
  that are not needed anymore.
* Tue Jul  7 2009 aj@suse.de
- README.BRANCH: Update, kotd will become 11.2 eventually.
* Mon Jul  6 2009 jeffm@suse.com
- Update to 2.6.31-rc2.
* Fri Jul  3 2009 jeffm@suse.com
- Update to 2.6.31-rc1-git10.
  - Eliminated 28 patches.
  - Xen is disabled.
* Fri Jul  3 2009 mmarek@suse.cz
- patches.suse/kbuild-generate-modules.builtin: kbuild: generate
  modules.builtin.
- rpm/kernel-binary.spec.in: package modules.builtin for use by
  modprobe / mkinitrd.
* Fri Jul  3 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in: simplify
  the patch applying loops to reduce noise in build logs.
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: chmod +x find-provides
* Tue Jun 30 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: do not "annotate" the packaged
  Modules.symvers
- patches.suse/modpost-filter-out-built-in-depends: Delete.
* Tue Jun 30 2009 jbeulich@novell.com
- patches.arch/ia64-page-migration: Fix compiler warning.
* Mon Jun 29 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/symvers* files back to
  - base, these are needed during KMP installation.
* Mon Jun 29 2009 mmarek@suse.cz
- patches.fixes/kbuild-fix-generating-of-.symtypes-files: kbuild:
  fix generating of *.symtypes files.
- patches.suse/genksyms-add-override-flag.diff: Refresh.
- rpm/kernel-binary.spec.in: create the *.symref files in the build
  directory
* Fri Jun 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add Provides: kernel-{base,extra} to
  the subpackages (bnc#516827).
* Wed Jun 24 2009 gregkh@suse.de
- Update config files.
  revert the ACPI and thermal config changes:
    config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=m
  CONFIG_ACPI_BATTERY=m
  CONFIG_ACPI_BUTTON=m
  CONFIG_ACPI_VIDEO=m
  CONFIG_ACPI_FAN=m
  CONFIG_ACPI_PROCESSOR=m
  CONFIG_ACPI_THERMAL=m
  CONFIG_ACPI_CONTAINER=m
  CONFIG_X86_ACPI_CPUFREQ=m
  CONFIG_THERMAL=m
* Wed Jun 24 2009 gregkh@suse.de
- patches.suse/ec_merge_irq_and_poll_modes.patch: Delete.
- patches.suse/linux-2.6.29-retry-root-mount.patch: Delete.
* Wed Jun 24 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30 and c/s 908.
- Update Xen config files.
- patches.xen/tmem: Transcendent memory ("tmem") for Linux.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ACPI_AC=y
  CONFIG_ACPI_BATTERY=y
  CONFIG_ACPI_BUTTON=y
  CONFIG_ACPI_VIDEO=y
  CONFIG_ACPI_FAN=y
  CONFIG_ACPI_PROCESSOR=y
  CONFIG_ACPI_THERMAL=y
  CONFIG_ACPI_CONTAINER=y
  CONFIG_X86_ACPI_CPUFREQ=y
  CONFIG_THERMAL=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_SND_TIMER=y
  CONFIG_SND_PCM=y
  CONFIG_SND_SEQUENCER=y
  CONFIG_SND_MIXER_OSS=y
  CONFIG_SND_PCM_OSS=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  fix up config mistake in x86-64/default made in last commit.
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_VIDEO_OUTPUT_CONTROL=y
  CONFIG_SOUND=y
  CONFIG_SND=y
* Tue Jun 23 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_I2C=y
  CONFIG_HWMON=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_IPV6=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_HID=y
  CONFIG_USB_STORAGE=y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_ATA_PIIX=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_USB_EHCI_HCD=Y
  CONFIG_USB_OHCI_HCD=Y
  CONFIG_USB_UHCI_HCD=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_CFG80211=Y
  CONFIG_LIB80211=Y
  CONFIG_MAC80211=Y
  CONFIG_ATH5K=Y
* Sat Jun 20 2009 gregkh@suse.de
- Update config files.
  config/i386/pae and config/x86-64/default:
  CONFIG_X86_MSR=Y
  CONFIG_X86_CPUID=Y
* Fri Jun 19 2009 gregkh@suse.de
- comment out broken acpi patch for the moment.
* Fri Jun 19 2009 gregkh@suse.de
- move the "preload" branch into master to get 2.6.30 working
  for Moblin.
- Update config files.
- patches.drivers/alsa-ad1984a-hp-quirks: ALSA: update HP
  quirks for Zenith & co (bnc#472789, bnc#479617, bnc#502425,
  bnc#503101).
- patches.suse/driver-core-add-nodename-callbacks.patch: Driver
  Core: add nodename callbacks.
- patches.suse/driver-core-aoe-add-nodename-for-aoe-devices.patch:
  Driver Core: aoe: add nodename for aoe devices.
- patches.suse/driver-core-block-add-nodename-support-for-block-drivers.patch:
  Driver Core: block: add nodename support for block drivers..
- patches.suse/driver-core-bsg-add-nodename-for-bsg-driver.patch:
  Driver Core: bsg: add nodename for bsg driver.
- patches.suse/driver-core-devtmpfs-driver-core-maintained-dev-tmpfs.patch:
  Driver Core: devtmpfs - kernel-maintained tmpfs-based /dev.
- patches.suse/driver-core-drm-add-nodename-for-drm-devices.patch:
  Driver Core: drm: add nodename for drm devices.
- patches.suse/driver-core-dvb-add-nodename-for-dvb-drivers.patch:
  Driver Core: dvb: add nodename for dvb drivers.
- patches.suse/driver-core-input-add-nodename-for-input-drivers.patch:
  Driver Core: input: add nodename for input drivers.
- patches.suse/driver-core-misc-add-nodename-support-for-misc-devices.patch:
  Driver Core: misc: add nodename support for misc devices..
- patches.suse/driver-core-raw-add-nodename-for-raw-devices.patch:
  Driver Core: raw: add nodename for raw devices.
- patches.suse/driver-core-sound-add-nodename-for-sound-drivers.patch:
  Driver Core: sound: add nodename for sound drivers.
- patches.suse/driver-core-usb-add-nodename-support-for-usb-drivers.patch:
  Driver Core: usb: add nodename support for usb drivers..
- patches.suse/driver-core-x86-add-nodename-for-cpuid-and-msr-drivers.patch:
  Driver Core: x86: add nodename for cpuid and msr drivers..
- patches.suse/ec_merge_irq_and_poll_modes.patch: ACPI: EC:
  Merge IRQ and POLL modes.
- patches.suse/linux-2.6.29-dont-wait-for-mouse.patch: fastboot:
  remove "wait for all devices before mounting root" delay.
- patches.suse/linux-2.6.29-enable-async-by-default.patch:
  enable async_enabled by default.
- patches.suse/linux-2.6.29-even-faster-kms.patch: speed up kms
  even more.
- patches.suse/linux-2.6.29-jbd-longer-commit-interval.patch:
  jbd: longer commit interval.
- patches.suse/linux-2.6.29-kms-after-sata.patch: make kms happen
  after sata.
- patches.suse/linux-2.6.29-retry-root-mount.patch: fastboot:
  retry mounting the root fs if we can't find init.
- patches.suse/linux-2.6.29-silence-acer-message.patch: Silence
  acer wmi driver on non-acer machines.
- patches.suse/linux-2.6.29-touchkit.patch: some new touch screen
  device ids
  .
- patches.suse/uvcvideo-ignore-hue-control-for-5986-0241.patch:
  uvcvideo: ignore hue control for 5986:0241 (bnc#499152).
- patches.suse/devtmpfs.patch: Delete.
* Fri Jun 12 2009 greg@suse.de
- scripts/sequence-patch.sh: fix bug in ketchup usage
* Wed Jun 10 2009 jeffm@suse.com
- Update to 2.6.30-final.
* Wed Jun 10 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30-rc8 and c/s 898.
- Update Xen config files.
- patches.xen/pci-reserve: linux/pci: reserve io/memory space
  for bridge.
- patches.xen/xen-x86-exports: Delete.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: update copyright header and
  change indentation to what autobuild enforces on checkin. No
  functional change.
* Tue Jun  9 2009 jbeulich@novell.com
- patches.suse/stack-unwind-add-declaration.patch: Fold into ...
- patches.suse/stack-unwind: ... this one.
* Tue Jun  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: move /boot/vmlinux-*.gz to -devel
  again.
- rpm/find-provides: don't generate the ksym() provides ourself,
  let rpm do it. Add a workaround for vmlinux-*.gz in -devel.
* Mon Jun  8 2009 jeffm@suse.com
- patches.suse/reiser4-set_page_dirty_notag: mm: Add
  set_page_dirty_notag() helper for reiser4.
* Fri Jun  5 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage: add Enhances: kernel-$flavor to
  kmps (bnc#502092).
* Thu Jun  4 2009 jeffm@suse.de
- Update to 2.6.30-rc8.
* Thu Jun  4 2009 sdietrich@suse.de
- supported.conf: remove duplicate kernel/drivers/md/dm-log
* Thu Jun  4 2009 teheo@suse.de
  Conver ide major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Mon Jun  1 2009 jeffm@suse.de
- Update to 2.6.30-rc7-git4.
* Fri May 29 2009 teheo@suse.de
  Rename mangle_minor to mangle_devt and also cover sd major allocation.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_devt parameter (fate#305584).
* Fri May 29 2009 teheo@suse.de
- Update config files to enable DEBUG_BLOCK_EXT_DEVT on all configs
  except for vanilla and ppc/ps3.
- patches.suse/block-add-mangle-devt-switch: block: add
  genhd.mangle_minor parameter (fate#305584).
* Thu May 28 2009 jdelvare@suse.de
- patches.fixes/scsi-scan-blist-update: Add BLIST_REPORTLUN2 to
  EMC SYMMETRIX (bnc#185164, bnc#191648, bnc#505578).
* Wed May 27 2009 jeffm@suse.com
- Update to 2.6.30-rc7-git2.
* Wed May 27 2009 gregkh@suse.de
- patches.drivers/ath1e-add-new-device-id-for-asus-hardware.patch:
  ath1e: add new device id for asus hardware.
* Tue May 26 2009 mmarek@suse.cz
- rpm/mkspec: when using a custom release number, create a
  get_release_number.sh script for autobuild.
* Tue May 26 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround for bnc#507084: strip
  binaries in /usr/src/linux-obj/*/*/scripts.
* Tue May 26 2009 jdelvare@suse.de
- patches.drivers/r8169-allow-true-forced-mode-setting.patch:
  r8169: allow true forced mode setting (bnc#467518).
* Mon May 25 2009 mmarek@suse.cz
- switch i386 flavors back to -default (non-pae) and -pae for
  milestone2
* Sun May 24 2009 mmarek@suse.cz
- rpm/find-provides: fix for kernel-kdump.
* Sat May 23 2009 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in, rpm/symsets.pl:
  workaround to fix provides of built-in symbols: move vmlinux*.gz
  back to -base and extract the provides from it.
* Fri May 22 2009 teheo@suse.de
- patches.arch/i586-unwind-quick-fix: i586-relocs: ignore NONE
  relocation.
* Fri May 22 2009 mmarek@suse.cz
- rpm/compute-PATCHVERSION.sh, rpm/mkspec, scripts/tar-up.sh: avoid
  unpacking the patches tarballs in compute-PATCHVERSION.sh.
* Fri May 22 2009 mmarek@suse.cz
- rpm/mkspec: add --release option to set a custom release string.
- scripts/tar-up.sh: revive -rs option.
* Wed May 20 2009 mmarek@suse.cz
- patches.arch/acpi_thermal_passive_blacklist.patch,
  patches.suse/devtmpfs.patch: fix patches to apply with git-apply.
* Tue May 19 2009 sdietrich@suse.de
- patches.suse/stack-unwind-add-declaration.patch: Fix compile
  error when CONFIG_STACK_UNWIND is not set.
* Tue May 19 2009 jblunck@suse.de
- patches.rpmify/arm-arch_include_asm-fix.diff: ARM: move
  mach-types.h to arch/include/asm.
* Tue May 19 2009 jeffm@suse.com
- Set CONFIG_FRAMEBUFFER_CONSOLE=y
* Tue May 19 2009 jeffm@suse.com
- Restored CONFIG_BOOTSPLASH=y and CONFIG_FB_VESA=y on
  x86/x86_64 (bnc#504608)
* Tue May 19 2009 jbeulich@novell.com
- patches.xen/sfc-endianness: fix building with gcc 4.4.
* Tue May 19 2009 jbeulich@novell.com
- Update Xen patches to 2.6.30/rc6-git3 and c/s 873.
* Mon May 18 2009 jeffm@suse.com
- Updated to 2.6.30-rc6-git3.
  - Eliminated 4 patches.
* Fri May 15 2009 jeffm@suse.de
- doc/README.SUSE: Updated to reflect building in an external
  directory so as not to contaminate /usr/src/linux
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix path in
  /usr/src/linux-obj/.../Makefile.
* Thu May 14 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: provide kernel-$flavor-devel =
  %%version-%%source_rel in the -devel packages (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also fix kernel-$flavor-devel requires
  (bnc#503280).
* Wed May 13 2009 mmarek@suse.cz
- rpm/mkspec: fix kernel-syms requires (bnc#503280).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/dup2-retval-fix: dup2: Fix return value with
  oldfd == newfd and invalid fd (bnc#498042).
* Mon May 11 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-fixup: reiserfs: clean up ifdefs.
- patches.fixes/reiserfs-xattr-root-fixup: reiserfs: deal with
  NULL xattr root w/ xattrs disabled.
- patches.fixes/reiserfs-xattrs-disabled-perms: reiserfs: fixup
  perms when xattrs are disabled.
- patches.fixes/reiserfs-expose-privroot: reiserfs: allow exposing
  privroot w/ xattrs enabled.
* Mon May 11 2009 jeffm@suse.de
- Updated to 2.6.30-rc5-git1.
  - Eliminated 4 patches.
* Wed May  6 2009 gregkh@suse.de
- Update config files. update vanilla configs so that the build works.
* Wed May  6 2009 gregkh@suse.de
- Update config files.
- patches.suse/devtmpfs.patch: driver-core: devtmpfs - driver-core
  maintained /dev tmpfs.
* Tue May  5 2009 jeffm@suse.com
- Update config files.
* Tue May  5 2009 jeffm@suse.com
- Update to 2.6.30-rc4-git1.
- patches.rpmify/fix-unexpected-non-allocable-warnings-with-suse-gcc:
  kbuild, modpost: fix "unexpected non-allocatable" warning with
  SUSE gcc.
* Tue May  5 2009 jbeulich@novell.com
- patches.fixes/iwl3945-build: iwl3945: fix ia64/ppc build.
* Tue May  5 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.30-rc4: Fix ia64 build.
* Tue May  5 2009 jbeulich@novell.com
- patches.suse/stack-unwind: Also initialize PT_GS() on 32-bit.
- patches.arch/x86_64-unwind-annotations: Refresh.
* Tue May  5 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc4 and c/s 867.
- Update i386 and x86_64 config files.
- config.conf: Re-enable Xen.
* Tue May  5 2009 teheo@suse.de
- patches.suse/kbuild-icecream-workaround: kbuild: add workaround
  for icecream bug (bnc#495786).
* Fri May  1 2009 jeffm@suse.com
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
* Fri May  1 2009 jeffm@suse.com
- Update to 2.6.30-rc4.
  - Eliminated 2 patches.
* Fri May  1 2009 jeffm@suse.com
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
- patches.fixes/reiserfs-xattr-locking: reiserfs: Expand i_mutex
  to enclose lookup_one_len.
- patches.kernel.org/patch-2.6.30-rc3-rc4:
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch: Delete.
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: Delete.
* Thu Apr 30 2009 mmarek@suse.cz
- scripts/submit-to-bs: tentative script to submit a new kernel to
  openSUSE:Factory
* Tue Apr 28 2009 npiggin@suse.de
- patches.apparmor/unambiguous-__d_path.diff: Put a reminder in here
  to fix the lock order problem when the patch is updated to HEAD.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: Fix prepending EXTRAVERSION,
  rename the variable back to @RELEASE_PREFIX@.
* Mon Apr 27 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: prepend the EXTRAVERSION to
  the rpm release string (note that this won't have any effect in
  the openSUSE:* projects).
* Fri Apr 24 2009 gregkh@suse.de
- Update config files.
  - build rtc_cmos driver into the kernel for i386 and x86-64 default
    kernels.  This should automatically take care of the rtc/system time
    syncing so we don't need to do it in a boot script and should speed
    up booting time a lot.
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change CONFIG_ATA=y and CONFIG_SATA_AHCI=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_EXT2_FS=y and CONFIG_EXT3_FS=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to CONFIG_SCSI=y and CONFIG_BLK_DEV_SD=y
* Fri Apr 24 2009 gregkh@suse.de
- Update config files. change to use CONFIG_USB=y
* Thu Apr 23 2009 jeffm@suse.de
- Added legacy config.
* Thu Apr 23 2009 jeffm@suse.de
- Temporarily disabled patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch
* Thu Apr 23 2009 jeffm@suse.de
- Moved i386 kernel-default to kernel-legacy.
- Moved i386 kernel-pae config to kernel-default.
- Disabled CONFIG_ISA in i386 kernel-default to improve boot speed.
* Thu Apr 23 2009 jeffm@suse.de
- Update to 2.6.30-rc3.
* Thu Apr 23 2009 jeffm@suse.de
- patches.fixes/fix-periodic-mode-programming-on-amd81xx: x86:
  hpet: fix periodic mode programming on AMD 81xx.
- patches.fixes/hpet-boot-fix: Delete.
* Mon Apr 20 2009 jeffm@suse.de
- patches.fixes/hpet-boot-fix: hpet: fix "IO-APIC + timer doesn't work!"
* Mon Apr 20 2009 jeffm@suse.de
- Update to 2.6.30-rc2-git6.
* Wed Apr 15 2009 jeffm@suse.de
- Update to 2.6.30-rc2.
  - trace and xen flavors disabled.
  - CONFIG_OTUS disabled on ppc.
  - request-based multipath could use some testing.
  - Eliminated 96 patches.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/devel-post.sh, rpm/kernel-binary.spec.in: Created i586 symlink
  for i386.
* Fri Apr 10 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added /usr/src/linux-obj to -devel
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: Use xargs -r to fix case when no
  modules are supported.
* Fri Apr 10 2009 jeffm@suse.com
- Moved linux-obj symlink handling to kernel-$flavor-devel.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/package-descriptions: Add comment.
* Fri Apr 10 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh: Rename the timestamp
  file to source-timestamp instead, so that autobuild does not add
  the timestamp verbatim.
* Thu Apr  9 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29 final and c/s 854.
- patches.xen/sfc-external-sram: enable access to Falcon's
  external SRAM (bnc#489105).
- patches.xen/sfc-sync-headers: sync Solarflare accelerator
  headers (bnc#489105).
- Update Xen config files.
* Wed Apr  8 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Fix last change: do not add the
  timestamp if it is already added verbatim (by prepare_spec during
  checkin)
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Add source timestamp to package
  descriptions.
* Tue Apr  7 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, rpm/mkspec: add descriptions to
  generated spec files.
- rpm/package-descriptions: descriptions of binary packages.
* Mon Apr  6 2009 jeffm@suse.com
- Enabled STAGING on !x86 and disabled COMEDI.
* Mon Apr  6 2009 jeffm@suse.com
- patches.rpmify/split-package: Enable
* Mon Apr  6 2009 jeffm@suse.com
- Update config files: Fixed i386-vanilla.
* Mon Apr  6 2009 jeffm@suse.com
- patches.fixes/xfs-export-debug: xfs: export assertion handler.
* Mon Apr  6 2009 jeffm@suse.com
- Switch from SPARSEMEM to DISCONTIGMEM on i386.
* Sun Apr  5 2009 jeffm@suse.com
- scripts/tar-up_and_run_mbuild.sh: Added pae to the important
  specfiles list.
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Fix missing ia64-debug.
* Fri Apr  3 2009 jeffm@suse.com
- patches.xen/sfc-resource-driver: Fix uninitialized var warning.
* Fri Apr  3 2009 jeffm@suse.com
- Drop NR_CPUS back to 128 on i386.
* Fri Apr  3 2009 jeffm@suse.com
- rpm/kernel-binary.spec.in: Added CONFIG_SPLIT_PACKAGE.
* Fri Apr  3 2009 jeffm@suse.de
- Update config files: Enabled STAGING drivers on -vanilla.
* Fri Apr  3 2009 jblunck@suse.de
- patches.rpmify/rpm-kernel-config: Rediff.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: chmod +x mkspec arch-symbols
  compute-PATCHVERSION.sh
* Fri Apr  3 2009 jeffm@suse.com
- Update config files: Enabled STAGING drivers.
* Fri Apr  3 2009 jeffm@suse.com
- Sync up kernel configs for x86/x86_64 flavors.
* Fri Apr  3 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/mkspec: do not package the binary
  spec files anymore.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/modversions: keep the override keyword in --pack.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in, rpm/mkspec, scripts/tar-up.sh: remove
  @TOLERATE_UNKNOWN_NEW_CONFIG_OPTIONS@ expansion, check for a file
  named TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS in sourcedir instead.
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: set LC_ALL=C in rpm -q call
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: add @FLAVOR@ again to avoid %%%%(...)
  expansion
* Thu Apr  2 2009 mmarek@suse.cz
- rpm/mkspec: new script to generate spec files from *.spec.in
  templates
- rpm/compute-PATCHVERSION.sh, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in: add to the
  source rpm
- scripts/tar-up.sh: just tar up patches directories and call
  mkspec
* Tue Mar 31 2009 mmarek@suse.cz
- rpm/kernel-dummy.spec.in: Delete.
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
* Tue Mar 31 2009 mmarek@suse.cz
- config.conf, rpm/old-packages.conf, scripts/arch-symbols,
  scripts/run_oldconfig.sh, scripts/tar-up.sh: drop the arch
  symbols completely, only map the various ix86 archs to i386.
* Tue Mar 31 2009 mmarek@suse.cz
- doc/README.SUSE: allow_unsupported_modules needs to be set before
  installing the kernel (bnc#484664).
* Tue Mar 31 2009 jeffm@suse.de
- Add %%changelog to spec files
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Clean up %%build_$flavor macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in: Create kernel-source-vanilla
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-syms.spec.in, scripts/tar-up.sh: Depend on kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in: Create a %%using_buildservice macro
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/sequence-patch.sh, scripts/tar-up.sh:
  kernel-{binary,source}: Remove arch guards
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.SUSE, rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: Move development files from kernel-source to
  kernel-$flavor-devel
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove $CONFIG_MODULES
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Remove duplicate CONFIG_DEBUG_INFO=y
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in: Use macros for cpu_arch
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in:
  kernel-{source,binary}: Use path-related rpm macros
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in,  rpm/kernel-source.spec.in:
  Use a %%kernelrelease macro.
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-source.spec.in, rpm/source-post.sh, scripts/tar-up.sh:
  Use %%variant instead of $variant
* Tue Mar 31 2009 jeffm@suse.de
- kernel-source: Kill old obsoletes
* Tue Mar 31 2009 jeffm@suse.de
- rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  rpm/kernel-syms.spec.in, scripts/tar-up.sh:
  Use %%var instead of @VAR@ except where necessary
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Sort by flavor, not architecture
* Tue Mar 31 2009 jeffm@suse.de
- kernel-syms: Stop the architecture %%else madness
* Tue Mar 31 2009 jeffm@suse.de
- kernel-binary: Stop the architecture %%else madness
* Mon Mar 30 2009 jeffm@suse.de
- Removed -RT guards and a dead patch.
* Mon Mar 30 2009 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: Delete.
* Mon Mar 30 2009 jeffm@suse.de
- patches.suse/reiserfs-inode-init: Delete.
* Thu Mar 26 2009 mmarek@suse.cz
- rpm/config.sh: introduce rpm/config.sh, defining SRCVERSION and
  VARIANT variables.
* Tue Mar 24 2009 jeffm@suse.de
- Update to 2.6.29-final.
  - Eliminated 4 patches.
* Fri Mar 20 2009 jbeulich@novell.com
- Update Xen config files.
- Update Xen patches to 2.6.29-rc8 and c/s 821.
* Wed Mar 18 2009 mmarek@suse.cz
- rpm/kernel-*.spec.in, scripts/tar-up.sh: don't add "<RELEASE>"
  to the release, breaks plain rpmbuild.
* Tue Mar 17 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't generate symsets
- rpm/kernel-syms.spec.in: don't package symsets
- rpm/find-provides: disable symset provides
- rpm/macros.kernel-source: don't check for /boot/symsets*
  (fate#305945)
* Tue Mar 17 2009 knikanth@suse.de
- patches.fixes/loop-barriers: Delete.
- patches.fixes/loop-barriers2: Delete.
  Remove non-mainline patches to loop driver making it honour
  O_SYNC, sync requests and barriers. (bnc#485089), (bnc#471249)
* Mon Mar 16 2009 bphilips@suse.de
- README: add rough guide to updating KABI
* Fri Mar 13 2009 jeffm@suse.com
- Update to 2.6.29-rc8.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.fixes/fix-nf_conntrack_slp,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: fix build warnings.
* Thu Mar 12 2009 jbeulich@novell.com
- Update Xen patches addressing several issues in initial commit
- Update Xen config files (re-enable oprofile, disable novfs).
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind annotations
  in entry_64-xen.S.
* Thu Mar 12 2009 jbeulich@novell.com
- patches.arch/x86_64-unwind-annotations: fix unwind annotations in
  entry_64.S.
* Thu Mar 12 2009 rgoldwyn@suse.de
- patches.suse/novfs-creds-change-2.6.29: Changing credential
  according to new task_struct.
* Wed Mar 11 2009 jblunck@suse.de
- rpm/kernel-binary.spec.in: Use split_packages only if supported.conf
  is not empty.
* Mon Mar  9 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: renamed modprobe config to
  /etc/modprobe.d/50-module-renames.conf (required by new
  module-init-tools).
* Mon Mar  9 2009 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.29-rc4: fix ia64 build.
* Mon Mar  9 2009 jbeulich@novell.com
- Update Xen config files (get tracing options back in sync with
  default).
* Fri Mar  6 2009 jeffm@suse.de
- Update config files: Enable CONFIG_FRAME_POINTER on Xen.
* Fri Mar  6 2009 jeffm@suse.de
- config.conf: Enabled Xen for building.
* Fri Mar  6 2009 jbeulich@novell.com
- Update Xen patches to 2.6.29-rc7.
* Fri Mar  6 2009 jbenc@suse.cz
- Update config files: enabled wireless debugging in -debug flavors.
* Fri Mar  6 2009 mmarek@suse.cz
- rpm/get_release_number.sh.in, rpm/kernel-binary.spec.in,
  rpm/kernel-source.spec.in, rpm/kernel-syms.spec.in,
  scripts/tar-up.sh, doc/README.SUSE: finally drop kernel-dummy
- rpm/prepare-build.sh: Delete.
* Wed Mar  4 2009 jeffm@suse.com
- Update to 2.6.29-rc7.
  - Eliminated 1 patch.
* Wed Mar  4 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: workaround a bash bug (bnc#481817)
  in kernel-vanilla.spec.
* Tue Mar  3 2009 jeffm@suse.com
- patches.suse/export-security_inode_permission: Export
  security_inode_permission for aufs.
* Thu Feb 26 2009 jeffm@suse.com
- scripts/tar-up.sh: Add -u to update existing spec files.
* Thu Feb 26 2009 sven@suse.de
- rpm/kernel-binary.spec.in: Fix sub-package install-time conflict.
* Wed Feb 25 2009 mmarek@suse.cz
- scripts/tar-up.sh: create tarballs that don't change
  unnecessarily: set owner/group to nobody/nobody, mtime to time of
  the latest commit and sort the input files.
* Tue Feb 24 2009 jeffm@suse.com
- Update to 2.6.29-rc6-git1.
* Sat Feb 21 2009 mmarek@suse.cz
- rpm/kernel-syms.spec.in: also check if the package versions match
  (bnc#478462)
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix 32-bit arch_unwind_init_running().
* Fri Feb 20 2009 jbeulich@novell.com
- patches.suse/stack-unwind: fix patch fuzz.
* Fri Feb 20 2009 jbeulich@novell.com
- misc/xen-port-patches.py: Adjust fro new x86 header placement.
- patches.arch/x86_64-unwind-annotations: fix unwind annotations
  (bnc#472783).
- patches.suse/stack-unwind: Properlz hook up unwinder again.
* Fri Feb 20 2009 jeffm@suse.de
- patches.suse/kdb-common: Build fix with -I directive.
* Fri Feb 20 2009 jeffm@suse.de
- Update config files.
* Fri Feb 20 2009 jeffm@suse.de
- Update to 2.6.29-rc5-git3.
  - Eliminated 1 patch.
* Thu Feb 19 2009 mmarek@suse.cz
- rpm/symsets.pl: allow passing only Module.symvers and no modules
* Wed Feb 18 2009 olh@suse.de
- disable ppc601 support, disable unused framebuffer drivers
* Wed Feb 18 2009 olh@suse.de
- disable kdump on ppc32
* Mon Feb 16 2009 jeffm@suse.com
- Update config files.
* Sat Feb 14 2009 jeffm@suse.de
- Update to 2.6.29-rc5.
* Fri Feb 13 2009 jeffm@suse.de
- Update to 2.6.29-rc4-git7.
  - Eliminated 2 patches.
* Mon Feb  9 2009 jeffm@suse.de
- patches.rpmify/spin_is_contended-fix: spin_is_contended
  Kconfig fixes.
* Mon Feb  9 2009 jeffm@suse.de
- Updated to 2.6.29-rc4.
  - Eliminated 3 patches.
* Fri Feb  6 2009 jeffm@suse.com
- patches.fixes/fix-warning-while-mapping-0-1MB-range-with-dev-mem:
  x86, pat: fix warn_on_once() while mapping 0-1MB range.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: fix
  last change: don't pass -e to weak-modules2.
* Fri Feb  6 2009 mmarek@suse.cz
- rpm/kernel-module-subpackage, rpm/post.sh, rpm/postun.sh: pass
  down shell options like -x to weak-modules2 to make debugging
  with rpm -ivv easier.
* Tue Feb  3 2009 jeffm@suse.de
- patches.fixes/fix-nf_conntrack_slp: make nf_conntrack_slp
  actually work (bnc#470963).
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/tar-up.sh: fix branch name in KOTD packages.
* Tue Feb  3 2009 olh@suse.de
- config.conf: readde -debug flavor for ppc64
* Tue Feb  3 2009 olh@suse.de
- patches.fixes/scsi-ibmvfc_prli_initiator_fix.patch:
  Better handle other FC initiators (bnc#471217 - LTC51238)
* Tue Feb  3 2009 mmarek@suse.cz
- scripts/wd-functions.sh: display master as "master", not "HEAD"
  or "".
* Mon Feb  2 2009 jeffm@suse.de
- patches.fixes/ath9k-fix-led_device_naming.diff: ath9k: fix
  led naming.
- patches.fixes/b43legacy-fix-led_device_naming.diff: b43legacy:
  fix led naming.
- patches.fixes/iwlwifi-fix-iwl-3945_led_device_naming.diff:
  iwlwifi: another led naming fix.
- patches.fixes/iwlwifi-fix-iwl-led_device_naming.diff: iwlwifi:
  fix led naming   .
- patches.fixes/rt2x00-fix-led_device_naming.diff: rt2x00:
  fix led naming.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3-git3.
  - Eliminated 6 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Updated to 2.6.29-rc3.
  - AppArmor is disabled.
  - Xen is disabled.
  - Eliminated 745 patches.
* Mon Feb  2 2009 jeffm@suse.de
- Enabled patches.suse/reiserfs_warning-reentrant
* Mon Feb  2 2009 rw@suse.de
- patches.fixes/xpc-pass-physical,
  patches.kabi/xpc-pass-physical:
  kABI: restore upstream patch, add ABI cover-up. (bnc#458811)
* Mon Feb  2 2009 olh@suse.de
- patches.fixes/serial-jsm-enable_ms.patch:
  Add enable_ms to jsm driver (bnc#471224 - LTC51066)
* Mon Feb  2 2009 olh@suse.de
- patches.arch/ppc-optimize-sync.patch:
  Optimise smp_{r,w}mb and mutex (bnc#471222 - LTC51356)
* Sat Jan 31 2009 gregkh@suse.de
- refresh patches for fuzz due to 2.6.27.14-rc1 import.
* Sat Jan 31 2009 gregkh@suse.de
- patches.kabi/abi-fix-add-epoll_devs-back-to-struct-user_struct.patch:
  ABI fix: add epoll_devs back to struct user_struct.
* Sat Jan 31 2009 gregkh@suse.de
- Update to 2.6.27.14-rc1
  - lots of security fixes
  - lots of bugfixes
  - obsoletes:
  - patches.drivers/alsa-virtuoso-no-eeprom-overwrite
  - patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch
  - patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch
  - patches.fixes/sysfs-fix-problems-with-binary-files.patch
  - patches.fixes/xpc-fix-NULL-deref
  - patches.fixes/xpc-write-barrier
* Fri Jan 30 2009 olh@suse.de
- patches.arch/ppc-pseries-migration_hang_fix.patch:
  Fix partition migration hang under load (bnc#470563 - LTC51153)
* Fri Jan 30 2009 olh@suse.de
- disable CONFIG_DEBUG_STACKOVERFLOW and CONFIG_DEBUG_STACK_USAGE
  on ppc/ppc64
* Fri Jan 30 2009 teheo@suse.de
- patches.drivers/libata-fix-EH-device-failure-handling: libata:
  fix EH device failure handling (bnc#470845).
* Thu Jan 29 2009 jjolly@suse.de
- patches.arch/s390-08-08-add_qdio_utilization.patch: zfcp:
  queue_full is lacking the entry for qdio utilization
  (bnc#466462).
* Thu Jan 29 2009 gregkh@suse.de
- add ability to debug kernel using USB debug connector.
- Update config files.
- patches.suse/usb-move-ehci-reg-def.patch: usb: move ehci
  reg def.
- patches.suse/x86-usb-debug-port-early-console-v4.patch: x86:
  usb debug port early console, v4.
* Thu Jan 29 2009 mmarek@suse.cz
- patches.kabi/abi-fix-add-s_syncing-back-to-struct-super_block.patch
  patches.kabi/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch
  patches.kabi/export-iwl_rx_allocate
  patches.kabi/sched-kabi-compat-hack.patch: Introduce
  patches.kabi/ for patches that only work around kabi issues and
  can be safely dropped at the next SP.
* Wed Jan 28 2009 agruen@suse.de
- patches.xen/xen-x86-mark_rodata_rw.patch: Add missing pageattr.c
  changes to pageattr-xen.c (bnc#439348).
* Wed Jan 28 2009 agruen@suse.de
- patches.suse/x86-mark_rodata_rw.patch: Add mark_rodata_rw()
  to un-protect read-only kernel code pages (bnc#439348).
- patches.xen/xen-x86-mark_rodata_rw.patch: xen specific part
  (bnc#439348).
* Wed Jan 28 2009 mmarek@suse.cz
- config/s390/s390: the -man package still fails for s390, disable
  it
* Wed Jan 28 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix build of the -man subpackage on
  31bit s390
* Wed Jan 28 2009 mmarek@suse.cz
- fix kernel-default.ppc64 reference symsets
* Wed Jan 28 2009 jslaby@suse.cz
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
  [cpu_mask_to_apicid bigsmp fix]
* Wed Jan 28 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-module_alias.patch:
  map scsi proc_name to module name (bnc#459933 - LTC50724)
* Tue Jan 27 2009 jeffm@suse.de
- Update config files: Disable ftrace in -debug on ppc64
* Tue Jan 27 2009 jeffm@suse.de
- config.conf: Added -debug flavor for ppc64.
* Tue Jan 27 2009 bwalle@suse.de
- patches.drivers/libfc-set-the-release-function.diff:
  Whitespace change.
* Tue Jan 27 2009 hare@suse.de
- patches.drivers/libfc-fix-read-IO-data-integrity: libfc:
  IO data integrity issue when a IO data frame lost (bnc#469536).
* Tue Jan 27 2009 jbeulich@novell.com
- re-enable patches.xen/xen3-e1000e_Export_set_memory_ro-rw.
* Tue Jan 27 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  include prototype for PFN_UP() (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls.
  readded to avoid kabi change
* Mon Jan 26 2009 jeffm@suse.de
- config.conf: Added kernel-vmi to i386.
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  use PFN_UP() for end_pfn (bnc#462546 - LTC50009)
* Mon Jan 26 2009 mmarek@suse.cz
- kabi: import FCoE changes
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: disable
  wrong debug message again.
* Mon Jan 26 2009 rw@suse.de
- patches.fixes/taskstats-alignment:
  IA64: fill 'struct taskstats' on stack and 'memcpy' result to skb.
  (bnc#448410)
* Mon Jan 26 2009 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix calculation of reserve_size (bnc#462546 - LTC50009)
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/disable-lro-per-default: Disable LRO per default
  in igb and ixgbe. (bnc#467519)
* Mon Jan 26 2009 jbeulich@novell.com
- Just comment out patches.xen/xen3-e1000e_* (to address build error)
  until disposition of their originals is known.
* Mon Jan 26 2009 kkeil@suse.de
- patches.fixes/sctp_do_not_use_stale_copy_of_sk: Do not use
  stale copy of sk. (bnc#440104)
* Mon Jan 26 2009 jblunck@suse.de
  Renamed some patches so they get included in vanilla builds.
- patches.rpmify/firmware-path: Renamed.
- patches.rpmify/no-include-asm: Renamed.
- patches.suse/md-raid-metadata-PAGE_SIZE.patch: Renamed.
* Mon Jan 26 2009 olh@suse.de
- patches.suse/led_classdev.sysfs-name.patch: use correct name
  for /sys/devices/virtual/leds/ entries (bnc#468350)
* Mon Jan 26 2009 kkeil@suse.de
- patches.suse/e1000e_Export_set_memory_ro-rw: Delete.
- patches.suse/e1000e_allow_bad_checksum: Delete.
- patches.suse/e1000e_call_dump_eeprom: Delete.
- patches.suse/e1000e_ioremap_sanity_check: Delete.
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  Delete.
  Remove not mainline e1000e patches which were added to help with
  the e1000e NVM corruption - root issue is fixed
* Mon Jan 26 2009 kkeil@suse.de
- patches.drivers/tg3_libphy_workaround: tg3 libphy workaround.
  (bnc#468725)
* Mon Jan 26 2009 hare@suse.de
- supported.conf: Correct spelling for dm-least-pending
  path checker.
* Mon Jan 26 2009 hare@suse.de
- patches.suse/dm-mpath-check-info-before-access: Kernel Oops
  during path failover (bnc#458393).
* Sun Jan 25 2009 gregkh@suse.de
- refresh patch fuzz now that 2.6.27.13 is in tree
* Sun Jan 25 2009 gregkh@suse.de
- Update to final version of 2.6.27.13
* Sat Jan 24 2009 gregkh@suse.de
- dynamic debugging fixes backported from upstream:
- patches.drivers/driver-core-add-newlines-to-debugging-enabled-disabled-messages.patch:
  driver core: add newlines to debugging enabled/disabled
  messages.
- patches.drivers/driver-core-fix-dynamic_debug-cmd-line-parameter.patch:
  Driver core: fix 'dynamic_debug' cmd line parameter.
- patches.drivers/driver-core-fix-using-ret-variable-in-unregister_dynamic_debug_module.patch:
  driver core: fix using 'ret' variable in
  unregister_dynamic_debug_module.
* Sat Jan 24 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch:
  (fix return of an unitialized value (bnc#469017)
* Sat Jan 24 2009 mmarek@suse.cz
- update kabi files: ignore changes in struct pcie_link_state as
  it is an internal structure only.
* Sat Jan 24 2009 mmarek@suse.cz
- patches.suse/genksyms-add-override-flag.diff: genksyms: add
  - -override flag.
- rpm/kernel-binary.spec.in: set KBUILD_OVERRIDE=1
* Sat Jan 24 2009 ghaskins@suse.de
- patches.fixes/sched-kabi-compat-hack.patch: sched: leave
  RT_GROUP_SCHED structure components intact to preserve kABI.
  broke kabi with fix for 456542
* Sat Jan 24 2009 trenn@suse.de
- patches.fixes/cpufreq_export_latency.patch: CPUFREQ: Introduce
  /sys/devices/system/cpu/cpu*/cpufreq/cpuinfo_transition_latency
  (bnc#464461).
- patches.fixes/cpufreq_ondemand_adjust_sampling_rate_limit.patch:
  CPUFREQ: ondemand/conservative: sanitize sampling_rate
  restrictions (bnc#464461).
- patches.fixes/cpufreq_ondemand_performance_optimise_default_settings.patch:
  CPUFREQ: ondemand: Limit default sampling rate to 300ms
  max. (bnc#464461).
- patches.fixes/x86_cpufreq_powernow-k8_acpi_latency_values.patch:
  X86 powernow-k8 cpufreq: Get transition latency from acpi _PSS
  object (bnc#464461).
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/xfs-dmapi-fixes: xfs/dmapi: fix crash on mount
  (bnc#458027).
* Fri Jan 23 2009 ghaskins@suse.de
- Update config files: Disable RT_GROUP_SCHED (bnc#456542).
  The RT_GROUP_SCHED feature is experimental and clearly broken, so
  lets turn it off for now.
* Fri Jan 23 2009 jeffm@suse.de
- patches.fixes/hpilo-open-close-fix: hpilo open/close fix
  (bnc#466517).
* Fri Jan 23 2009 hare@suse.de
- patches.suse/dm-mpath-requeue-for-stopped-queue: Handle I/O
  on stopped queues correctly (bnc#458393).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.suse/mnt-want-write-speedup.patch,
  patches.suse/mnt_clone_write.patch: modified not to break kABI,
  enabled (bnc#436953).
* Fri Jan 23 2009 jbenc@suse.cz
- patches.fixes/iwlagn-fix-rfkill.patch: iwlagn: fix hw-rfkill
  while the interface is down (bnc#446158).
* Fri Jan 23 2009 mmarek@suse.cz
- kabi/severities: temporarily enable changes in FcOE modules.
* Fri Jan 23 2009 hare@suse.de
- patches.arch/s390-08-06-personality.patch: kernel: setting 32
  bit personality doesn't work (bnc#466462).
- patches.arch/s390-08-07-compat_wrappers.patch: kernel:
  Add missing wrapper functions for 31 bit compat
  syscalls. (bnc#466462,LTC#51229).
- patches.fixes/block-leave-the-request-timeout-timer-running:
  Delete obsolete patch.
* Fri Jan 23 2009 bwalle@suse.de
- patches.drivers/fcoe-change-fcoe_sw-sg_tablesi.diff: change
  fcoe_sw sg_tablesize to SG_ALL (bnc #459142).
- patches.drivers/fcoe-check-return-for-fc_set_m.diff: check
  return for fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-fix-frame-length-validati.diff: fix frame
  length validation in the early receive path (bnc #459142).
- patches.drivers/fcoe-fix-incorrect-use-of-struct-module.diff:
  fcoe: fix incorrect use of struct module (bnc #468051).
- patches.drivers/fcoe-improved-load-balancing-i.diff: improved
  load balancing in rx path (bnc #459142).
- patches.drivers/fcoe-logoff-of-the-fabric-when.diff: Logoff
  of the fabric when destroying interface (bnc #459142).
- patches.drivers/fcoe-remove-warn_on-in-fc_set.diff: remove
  WARN_ON in fc_set_mfs (bnc #459142).
- patches.drivers/fcoe-user_mfs-is-never-used.diff: user_mfs is
  never used (bnc #459142).
- patches.drivers/libfc-add-fc_disc-c-locking-co.diff: Add
  fc_disc.c locking comment block (bnc #459142).
- patches.drivers/libfc-ensure-correct-device_pu.diff: libfc:
  Ensure correct device_put/get usage (round 2).
- patches.drivers/libfc-fix-rport-recursive-lock.diff: libfc:
  Fix rport recursive lock on rport mutex (bnc #459142).
- patches.drivers/libfc-handle-rrq-exch-timeout.diff: libfc:
  handle RRQ exch timeout (bnc #465596).
- patches.drivers/libfc-improve-fc_lport-c-locki.diff: Improve
  fc_lport.c locking comment block (bnc #459142).
- patches.drivers/libfc-improve-fc_rport-c-locki.diff: Improve
  fc_rport.c locking comment block (459142).
- patches.drivers/libfc-make-fc_disc-inline-with.diff: make
  fc_disc inline with the fc_lport structure (bnc #459142).
- patches.drivers/libfc-make-rscn-parsing-more-r.diff: make RSCN
  parsing more robust (bnc #459142).
- patches.drivers/libfc-make-sure-we-access-the.diff: make sure
  we access the CRC safely (bnc #459142).
- patches.drivers/libfc-pass-lport-in-exch_mgr_r.diff: libfc:
  Pass lport in exch_mgr_reset (bnc #465596).
- patches.drivers/libfc-remove-debug-print-state.diff: libfc:
  Remove debug print statement, too verbose (bnc #459142).
- patches.drivers/libfc-set-the-release-function.diff: Set
  the release function for the rport's kobject (round 2)
  (bnc #459142).
- patches.drivers/libfc-updated-comment-for-orde.diff: updated
  comment for order of em and ex locks (bnc #459142).
- patches.drivers/libfc-updated-libfc-fcoe-modul.diff: updated
  libfc fcoe module ver to 1.0.6 (bnc #459142).
- patches.drivers/libfc-use-an-operations-struct.diff: use an
  operations structure for rport callbacks (bnc #459142).
- patches.drivers/libfc-when-rport-goes-away-re.diff: libfc:
  when rport goes away (re-plogi), clean up exchanges to/from
  rport (bnc #465596).
- patches.drivers/libfc_locking.diff: libfc, fcoe: fixed locking
  issues with lport->lp_mutex around lport->link_status (bnc
  [#468053]).
- patches.drivers/libfc_rport.diff: libfc: rport retry on LS_RJT
  from certain ELS (bnc #468054).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/qla2xxx-check-fc-rport-validity:
  qla2xxx: added check for fcport is valid in
  qla2x00_terminate_rport_io(). (bnc#467624).
* Fri Jan 23 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-t1616-quirk: ALSA: hda -
  Add quirk for Gateway T1616 laptop (bnc#467597).
- patches.drivers/alsa-hda-hp-dv4-quirk: ALSA: hda - Add model
  entry for HP dv4.
- patches.drivers/alsa-hda-intel-d945-ref-quirk: ALSA: hda -
  Add model=ref for Intel board with STAC9221 (bnc#406529).
* Fri Jan 23 2009 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: block: Rediff
- patches.fixes/block-use-round_jiffies_up: Block: use
  round_jiffies_up() (bnc#464155).
- Add missing patches to series.conf:
  patches.fixes/round-jiffies-up
  patches.fixes/block-use-round_jiffies_up
  patches.fixes/block-fix-blk_start_queueing
  patches.fixes/suppress-buffer-IO-errors
  patches.fixes/block-optimizations-in-blk_rq_timed_out_timer
  patches.fixes/block-add-comment-in-blk_rq_timed_out
* Fri Jan 23 2009 olh@suse.de
- update patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  handle also drivers/scsi/ibmvscsi/ibmvfc.c
* Fri Jan 23 2009 sjayaraman@suse.de
- patches.fixes/cifs-fix-oops-on-ipv6-mount: cifs: make sure we
  allocate enough storage for socket address (467691).
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-wb_sync_hold-enum-writeback_sync_modes.patch:
  ABI fix: add WB_SYNC_HOLD enum writeback_sync_modes.
* Fri Jan 23 2009 gregkh@suse.de
- patches.kernel.org/abi-fix-add-s_syncing-back-to-struct-super_block.patch:
  ABI fix: add s_syncing back to struct super_block.
* Fri Jan 23 2009 gregkh@suse.de
- update to 2.6.27.13-rc1:
  - security updates
  - lots of bugfixes
  - obsoletes:
  - patches.arch/ppc-fix_hugepage_check.patch
  - patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back
  - patches.drivers/alsa-hda-samsung-q45-quirk
  - patches.fixes/security-introduce-missing-kfree.patch
  - patches.fixes/xpc-fix-heartbeat
- Update config files.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/e1000-fix-shared-emc.patch: e1000: fix bug
  with shared interrupt during reset (bnc#396687)
* Thu Jan 22 2009 tonyj@suse.de
- patches.fixes/revert-bgcolor-line-feed-93f78da4.patch: Revert
  "vt: fix background color on line feed" (bnc#418613).
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/iwlwifi-fix-rs_get_rate-oops.patch: iwlwifi:
  fix rs_get_rate WARN_ON() (bnc#456002).
- Reordered wireless patches to group together patches touching the same
  driver.
* Thu Jan 22 2009 bphilips@suse.de
- patches.drivers/disable-catas_reset-by-default-to-avoid-problems-with-eeh.patch:
  disable catas_reset by default to avoid problems with EEH
  (bnc#456389).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  fixed kABI breakage. (bnc#458811)
* Thu Jan 22 2009 bwalle@suse.de
- scripts/tar-up_and_run_mbuild.sh: s390 (the 31 bit variant) is
  not an important spec file.
* Thu Jan 22 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: fixed kABI
  breakage, reenabled.
* Thu Jan 22 2009 mmarek@suse.cz
- rpm/modversions: eat the "override" keyword before parsing the
  symbol definition.
* Thu Jan 22 2009 olh@suse.de
- patches.fixes/scsi-ibmvscsi-vio_leak.patch:
  Correct VIO bus/device CMO accounting problems (bnc#468304 - LTC51205)
* Thu Jan 22 2009 olh@suse.de
- patches.suse/of_platform_driver.module-owner.patch:
  add missing module symlink to /sys/bus/*/driver/*
  in struct of_platform_driver.
* Thu Jan 22 2009 kkeil@suse.de
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix - new version from Intel  (bnc#465923)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
  (fix compilation on i386 and add hpet64 to kernel-parameters.txt)
* Thu Jan 22 2009 jbohac@suse.cz
- patches.arch/x86_64-hpet-64bit-timer.patch: allow 64-bit mode
  for HPET Timer0 (bnc#456700).
* Thu Jan 22 2009 rw@suse.de
- patches.fixes/xpc-pass-physical:
  sgi-xpc: need to pass the physical address, not virtual. (bnc#458811)
- patches.fixes/xpc-fix-heartbeat:
  sgi-xpc: eliminate false detection of no heartbeat. (bnc#464545)
* Thu Jan 22 2009 jkosina@suse.de
- patches.fixes/input-add-nomux-dell-vostro-1510.patch: Input:
  add Dell Vostro 1510 to nomux list (bnc#404881).
* Thu Jan 22 2009 jblunck@suse.de
- scripts/compute-PATCHVERSION.sh: Fix SRCVERSION parsing (bnc#465113).
* Thu Jan 22 2009 tiwai@suse.de
- patches.drivers/alsa-hda-add-volume-offset: ALSA: hda - Add
  extra volume offset to standard volume amp macros (bnc#466428).
- patches.drivers/alsa-hda-stac-reduce-volume-scale: ALSA: hda -
  Halve too large volume scales for STAC/IDT codecs (bnc#466428).
* Thu Jan 22 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.12-update: Update lpfc from 8.2.8.11
  to 8.2.8.12 (bnc#467713).
* Thu Jan 22 2009 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: fix missing jl arg
* Wed Jan 21 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: delete duplicate error message in the
  kabi checks
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/remove_kernel_physical_mapping_init_from_init:
  move kernel_physical_mapping_init to __meminit (bnc#467474).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: disabled, as it changes
  kABI.
* Wed Jan 21 2009 gregkh@suse.de
- patches.fixes/security-introduce-missing-kfree.patch: security:
  introduce missing kfree (bnc#467322).
- patches.fixes/sysfs-fix-problems-with-binary-files.patch:
  sysfs: fix problems with binary files.
* Wed Jan 21 2009 rw@suse.de
- patches.arch/ia64-page-migration.fix:
  fix deadlock caused by cpe_migrate.ko and mark it supported.
  (bnc#464676)
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/sn-irq-affinity: sn2: preserve irq affinity set
  in PROM (bnc#457679).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/uv_zalias_support: uv: Support for non-nasid 0
  systems (bnc#458869).
* Wed Jan 21 2009 jeffm@suse.de
- patches.fixes/xpc-fix-NULL-deref: sgi-xpc: Remove NULL pointer
  dereference. (bnc#466563).
- patches.fixes/xpc-write-barrier: sgi-xpc: ensure flags are
  updated before bte_copy (bnc#466563).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/ipw2200-workaround-firmware-restarts-when-scanning.patch:
  ipw2200: fix scanning while associated (bnc#459067).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/iwl3945-fix-rfkill.patch: iwl3945: report
  killswitch changes even if the interface is down (bnc#446013).
* Wed Jan 21 2009 jbenc@suse.cz
- patches.fixes/mac80211-add-direct-probe.patch: mac80211:
  add direct probe before association (bnc#461889).
* Wed Jan 21 2009 hare@suse.de
- patches.drivers/mptsas-discover-all-devices: mptsas driver
  fails to discover devices (bnc#459932).
* Wed Jan 21 2009 jbeulich@novell.com
- Update Xen patches to 2.6.27.12.
- patches.xen/764-netback-foreign-pages.patch: netback: handle
  non-netback foreign pages.
- patches.xen/769-evtchn-CPU-offline.patch: evtchn: Fix CPU offlining
  to switch all affected ports belonging to a particular /dev/evcthn
  user.
- patches.xen/gso-size-check.patch: gso: Ensure that the packet
  is long enough.
- patches.xen/xen-S3-MSI: fix Dom0 resume from S3 when MSI is
  in use (bnc#435596).
- patches.xen/xen3-e1000e_ioremap_sanity_check: ioremap sanity
  check to catch mapping requests exceeding the BAR sizes
  (bnc#425480).
- patches.xen/xen3-x86-fix-kmap-contig.patch: x86: contiguous
  kmap fix (bnc#449812).
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  implement correct model matching
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/dm-mpath-tracking-nr-bytes:
  lpp_end_io gets nr_bytes as third arg
* Wed Jan 21 2009 olh@suse.de
- update patches.suse/radeon-monitor-jsxx-quirk.patch:
  match all JSxx/QSxx models based on the first 4 chars in 'model'
* Wed Jan 21 2009 olh@suse.de
- update patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  Fix MSI after kexec (bnc#467633)
* Tue Jan 20 2009 gregkh@suse.de
- clean up patch fuzz after 2.6.27.12 inclusion.
* Tue Jan 20 2009 gregkh@suse.de
- Update to the real 2.6.27.12
* Tue Jan 20 2009 jeffm@suse.de
- patches.suse/reiserfs_warning-reentrant: reiserfs: eliminate
  reiserfs_warning from uniqueness functions; Fixes deadlock.
* Tue Jan 20 2009 olh@suse.de
- patches.drivers/cxgb3-ser.patch:
  reset the adapter on fatal error (bnc#466062 - LTC51042)
* Tue Jan 20 2009 jjolly@suse.de
- patches.arch/s390-08-03-iucv-cpu-hotremove.diff: iucv: failing
  cpu hot remove for inactive iucv (bnc#466462,LTC#51104).
- patches.arch/s390-08-04-compat-sigaltstack.diff:
  kernel: 31 bit compat sigaltstack syscall fails with
  - EFAULT. (bnc#466462,LTC#50888).
- patches.arch/s390-08-05-af_iucv-msgpeek-fix.patch:
  af_iucv: System hang if recvmsg() is used with MSG_PEEK
  (bnc#466462,LTC#51136).
* Tue Jan 20 2009 hare@suse.de
- patches.suse/dm-mpath-accept-failed-paths: Only accept
  non-existing paths when adding failed paths (bnc#467579)
* Tue Jan 20 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in: set CONFIG_DEBUG_INFO=y in the
  packaged .configs if builfing debug packages (bnc#460887)
* Mon Jan 19 2009 mmarek@suse.cz
- rpm/kernel-binary.spec.in: set %%tolerate_kabi_changes to 6
* Mon Jan 19 2009 mmarek@suse.cz
- patches.suse/export-iwl_rx_allocate: reintroduce
  EXPORT_SYMBOL(iwl_rx_allocate).
* Mon Jan 19 2009 mmarek@suse.cz
- import SLE11 RC2 reference kabi
* Mon Jan 19 2009 hare@suse.de
- patches.drivers/mpt-return-all-sense-data: MPT Fusion doesn't
  return all sense data (bnc#466179).
* Sat Jan 17 2009 gregkh@suse.de
- Update to 2.6.27.12-rc2
* Fri Jan 16 2009 od@suse.de
- patches.arch/x86-call-boot-IRQ-quirks-at-end-of-device-init-and-during-resume.patch:
  call boot IRQ quirks at end of device init and during resume.
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch:
  update to upstream variant of this patch:
  - integrate an older quirk to make IO-APIC mode work on AMD
    8131 rev. A0 and B0
  - fix boot IRQ disabling logic for AMD 813x
  - remove unneeded code for AMD SB700S
* Fri Jan 16 2009 jbeulich@novell.com
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Fri Jan 16 2009 olh@suse.de
- enable mptsas in kdump kernel to allow crashdump on QS2x blades
* Fri Jan 16 2009 tiwai@suse.de
  Fix STAC925x patch again
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  (yet more) STAC925x issues (bnc#460478).
* Fri Jan 16 2009 jjolly@suse.de
- patches.arch/s390-08-01-cio-fix-mp-mode.diff: cio: fix
  subchannel multipath mode setup (bnc#466462,LTC#51047).
- patches.arch/s390-08-02-zfcp-gpn-align-fix.diff: zfcp: fix
  memory alignment for GPN_FT requests. (bnc#466462).
* Thu Jan 15 2009 gregkh@suse.de
- Update config files for vanilla kernel versions due to new config
  option added in 2.6.27.12-rc1.
* Thu Jan 15 2009 gregkh@suse.de
- Update to 2.6.27.12-rc1:
  - security fixes
  - fixes CVE-2009-0029
  - bug fixes all over the place.
  - obsoletes the following patches:
  - patches.arch/ppc-cmm_no_kdump.patch
  - patches.drivers/alsa-caiaq-midi-oops-fix
  - patches.drivers/alsa-hda-hp-6730b-quirk
  - patches.drivers/ibmvfc-host_init_delay.patch
  - patches.drivers/ibmvfc-improve_sync_events.patch
  - patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch
  - patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch
  - patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch
  - patches.fixes/mm-lockless-pagecache-barrier.patch
  - patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch
  - patches.fixes/uv-remove-erroneous-BAU-init
- Update config files.
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-virtuoso-no-eeprom-overwrite: sound:
  virtuoso: do not overwrite EEPROM on Xonar D2/D2X (bnc#462365).
* Thu Jan 15 2009 bwalle@suse.de
- patches.suse/s390-System.map.diff:
  Strip L2^B symbols (bnc #456682).
* Thu Jan 15 2009 tiwai@suse.de
- patches.drivers/alsa-hda-gateway-fix: ALSA: patch_sigmatel:
  Add missing Gateway entries and autodetection (bnc#460478).
- patches.drivers/alsa-hda-gateway-fix2: ALSA: hda - More fixes
  on Gateway entries (bnc#460478).
- patches.drivers/alsa-hda-hp-dv5-mic-fix: ALSA: hda - Fix HP
  dv5 mic input (bnc#462913).
- patches.drivers/alsa-hda-hp-dv5-quirk: ALSA: hda - Add quirk
  for another HP dv5 (bnc#462913).
- patches.drivers/alsa-hda-idt92hd83-fix-typo: ALSA: hda -
  Fix a typo.
- patches.drivers/alsa-hda-samsung-q45-quirk: ALSA: hda - Add
  automatic model setting for Samsung Q45.
- patches.drivers/alsa-hda-seek-for-codec-id: ALSA: hda - Add
  a new function to seek for a codec ID (bnc#460478).
- patches.drivers/alsa-hda-sigmatel-no-hp-reset: ALSA: hda -
  Don't reset HP pinctl in patch_sigmatel.c (bnc#460478).
- patches.drivers/alsa-hda-stac925x-init-fix: ALSA: hda - Fix
  missing initialization of NID 0x0e for STAC925x (bnc#460478).
* Thu Jan 15 2009 olh@suse.de
- patches.arch/ppc-fix_hugepage_check.patch:
  is_hugepage_only_range() must account for both 4kB and 64kB
  slices (bnc#466229 - LTC51063)
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disabled PARAVIRT on vanilla and LGUEST.
* Wed Jan 14 2009 jeffm@suse.de
- Enabled patches.suse/unlock_page-speedup.patch
* Wed Jan 14 2009 rjw@suse.de
- patches.fixes/PCI-PM-Split-PCI-Express-port-suspend-resume.patch:
  PCI PM: Split PCI Express port suspend-resume (bnc#455926).
- patches.fixes/PCI-Suspend-and-resume-PCI-Express-ports-with-interrupts-disabled.patch:
  PCI: Suspend and resume PCI Express ports with interrupts
  disabled (bnc#455926).
- patches.fixes/PCI-handle-PCI-state-saving-with-interrupts-disabled.patch:
  PCI: handle PCI state saving with interrupts disabled
  (bnc#455926).
- patches.fixes/pci-rework-suspend-of-devices-with-no-drivers.patch:
  PCI: Rework default handling of suspend and resume (bnc#455926).
* Wed Jan 14 2009 jeffm@suse.de
- Update config files: Disable PARAVIRT.
* Wed Jan 14 2009 gregkh@suse.de
- refresh patches for fuzz due to update to 2.6.27.11
* Wed Jan 14 2009 gregkh@suse.de
- Update to final version of 2.6.27.11
* Wed Jan 14 2009 kkeil@suse.de
- patches.drivers/ixgbe-dcb-setstate.patch: Bugfix for ixgbe
  and kernel DCB netlink code. (bnc#458194)
- patches.drivers/ixgbe_DCB_compile_err.patch: DCB compile
  error fix. (bnc#465923)
- Update config files.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: Delete.
  It came out that this is an already fixed BIOS bug. The quirk
  is not needed anymore.
* Wed Jan 14 2009 trenn@suse.de
- patches.fixes/acpi_fix_double_slash_root_prefix_handling.patch:
  In AcpiNsGetInternalNameLength, skip the redundant backslash
  of RootPrefix (http://bugzilla.kernel.org/show_bug.cgi?id=11541
  http://www.acpica.org/bugzilla/show_bug.cgi?id=739).
- patches.fixes/acpi_video_always_update_sys.patch: video: always
  update the brightness when poking "brightness" (bnc#450149).
- patches.fixes/acpi_video_handle_reversed_brightness_info.patch:
  ACPI: video: Fix reversed brightness behavior on ThinkPad SL
  series (bnc#450149).
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/sched-fix-__load_balance_iterator-for-cfs-with-on.patch:
  fix __load_balance_iterator() for cfs with only one task
  (bnc#457594 - LTC50544)
* Wed Jan 14 2009 olh@suse.de
- patches.fixes/xfs-redirty-ENOSPC.patch: Re-dirty pages on
  ENOSPC when converting delayed allocations (bnc#433112 - LTC48749)
* Wed Jan 14 2009 npiggin@suse.de
- Added guarded patches:
- patches.suse/mnt-want-write-speedup.patch: fs: mnt_want_write
  speedup (bnc#436953).
- patches.suse/mnt_clone_write.patch: fs: introduce
  mnt_clone_write (bnc#436953).
- patches.suse/unlock_page-speedup.patch: mm: unlock_page speedup
  (bnc#436953).
* Wed Jan 14 2009 gregkh@suse.de
- Update config files.
- patches.drivers/add-via-chrome9-drm-support.patch: add Via
  chrome9 drm support.
* Wed Jan 14 2009 gregkh@suse.de
- patches.drivers/pata_via.c-support-vx855-and-future-chips-whose-ide-controller-use-0x0571.patch:
  pata_via.c: Support VX855 and future chips whose IDE controller
  use 0x0571..
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Modify patch
  after suggestions from James Bottomley (bnc#465346).
* Tue Jan 13 2009 hare@suse.de
- patches.fixes/scsi-restart-lookup-by-target: Restart
  scsi_device_lookup_by_target() (bnc#465346).
* Tue Jan 13 2009 olh@suse.de
- update patches.drivers/cxgb3-Allocate-multiqueues-at-init-time:
  Allow multiqueue setting in MSI-X mode only (bnc#464351 - LTC50966)
* Tue Jan 13 2009 olh@suse.de
- patches.drivers/cxgb3i-mainline.patch: fixes bug in tag release
  and sync-up cxgb3i with mainline state (bnc#464508 - LTC50816)
* Tue Jan 13 2009 gregkh@suse.de
- Update to 2.6.27.11-rc1:
  - lots of minor fixes
  - obsoletes:
  - patches.fixes/md-bitmap-read-do-not-overflow
  - patches.suse/scsi-scsi_transport_srp-shost_data.patch
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: add kernel/drivers/acpi/acpi_memhotplug as supported
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh: handle arch
  symlinks like i586 -> i386 in /usr/src/linux-obj.
* Mon Jan 12 2009 gregkh@suse.de
- supported.conf: updated staging and other drivers
* Mon Jan 12 2009 kkeil@suse.de
- patches.drivers/r8169-Tx-performance-tweak-helper: r8169:
  Tx performance tweak helper.
- patches.drivers/r8169-add-8168-8101-registers-description:
  r8169: add 8168/8101 registers description.
- patches.drivers/r8169-add-hw-start-helpers-for-the-8168-and-the-8101:
  r8169: add hw start helpers for the 8168 and the 8101.
- patches.drivers/r8169-additional-8101-and-8102-support: r8169:
  additional 8101 and 8102 support.
- patches.drivers/r8169-use-pci_find_capability-for-the-PCI-E-features:
  r8169: use pci_find_capability for the PCI-E features.
  (bnc#448168)
* Mon Jan 12 2009 dgollub@suse.de
- scripts/tar-up_and_run_mbuild.sh: use $BUILD_DIR instead of fixed
  "kernel-source" string, to stay in sync with with differet kernel
  variants.
* Mon Jan 12 2009 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/source-pre.sh:
  replace the /usr/src/linux-obj symlink with a directory containing
  per-flavor symlinks instead. This allows us to install kernel-source /
  syms and kernel-source-rt / syms-rt in parallel and still find
  everything below /usr/src/linux-obj/.
- rpm/kernel-binary.spec.in: for -rt, install into
    /usr/src/linux-$version-rt-obj.
- rpm/kernel-syms.spec.in: fix kernel-source requires for -rt.
* Sun Jan 11 2009 jkosina@suse.de
- patches.drivers/input-usbtouchscreen-hw-calibration.patch:
  Input: usbtouchscreen - allow reporting calibrated data
  (bnc#444814).
* Fri Jan  9 2009 mmarek@suse.cz
- patches.suse/file-capabilities-add-file_caps-switch.diff:
  fix parsing of the file_caps commandline option (bnc#264075)
* Fri Jan  9 2009 trenn@suse.de
- patches.arch/x86_fix_llc_shared_map__cpu_llc_id_anomolies.patch:
  x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
  (bnc#464329).
* Fri Jan  9 2009 olh@suse.de
- patches.arch/ppc-cmm_no_kdump.patch:
  Disable Collaborative Memory Manager for kdump (bnc#460552 - LTC50789)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/cgroup-disable-memory.patch: memcg: disable the
  memory controller by default.
- patches.suse/add-enable_cgroup-parameter.patch: Delete.
- patches.suse/disable-cgroups.patch: Delete.
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch
  fix compile errors
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/ath5k-ignore-calibration-return-value.patch:
  ath5k: ignore the return value of
  ath5k_hw_noise_floor_calibration (bnc#446541).
* Fri Jan  9 2009 jslaby@suse.de
- patches.fixes/cgroups-suppress-cloning-warning.patch: cgroups:
  suppress bogus warning messages (bnc#460961).
* Fri Jan  9 2009 olh@suse.de
- patches.suse/radeon-monitor-jsxx-quirk.patch: Add quirk for
  the graphics adapter in some JSxx (bnc#461002 - LTC50817)
* Fri Jan  9 2009 trenn@suse.de
- patches.fixes/acpi_irq_quirk_pci_irq_derive.patch: ACPI: Do not
  derive IRQ from parent bridge/device via boot param/dmi list
  (bnc#437211).
- patches.suse/acpi_osi_sle11_ident.patch: Provide possibility
  for vendors to fix BIOS issues for SLE11 only (none).
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/blk-request-based-multipath-update: Rediff.
- patches.fixes/scsi-refactor-busy-processing: refactor
  sdev/starget/shost busy checking; break out from
  blk-request-based-multipath-update.
* Fri Jan  9 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.11-update: Update lpfc from 8.2.8.10
  to 8.2.8.11 (bnc#464662).
- patches.fixes/scsi-call-unprep_request-under-lock: scsi_lib:
  only call scsi_unprep_request() under queue lock (bnc#464155).
- patches.fixes/scsi-fix-hang-in-starved-list-processing: Fix
  hang in starved list processing (bnc#464155).
* Fri Jan  9 2009 kkeil@suse.de
- patches.drivers/bnx2-Add-PCI-ID-for-5716S: bnx2: Add PCI ID
  for 5716S
- patches.drivers/bnx2-Fix-bug-in-bnx2_free_rx_mem_: bnx2:
  Fix bug in bnx2_free_rx_mem() (bnc#464130)
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/disable-cgroups.patch: Disable all cgroups
  (bnc#436025).
* Fri Jan  9 2009 hare@suse.de
- Backporting block layer fixes (bnc#464155):
  * patches.fixes/block-add-comment-in-blk_rq_timed_out: add
    comment in blk_rq_timed_out() about why next can not be 0
  * patches.fixes/block-fix-blk_start_queueing: block: Fix
    blk_start_queueing() to not kick a stopped queue.
  * patches.fixes/block-leave-the-request-timeout-timer-running:
    block: leave the request timeout timer running even on an
    empty list.
  * patches.fixes/block-optimizations-in-blk_rq_timed_out_timer:
    block: optimizations in blk_rq_timed_out_timer().
  * patches.fixes/block-suppress-buffer-IO-errors: block: Supress
    Buffer I/O errors when SCSI REQ_QUIET flag set.
  * patches.fixes/block-use-round_jiffies_up: Block: use
    round_jiffies_up().
  * patches.fixes/round-jiffies-up: Add round_jiffies_up and
    related routines.
* Fri Jan  9 2009 jbeulich@novell.com
- patches.xen/xen3-acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
* Fri Jan  9 2009 hare@suse.de
- patches.fixes/scsi_dh-retry-on-UNIT_ATTENTION: scsi_dh_rdac
  does not retry MODE SENSE on UNIT ATTENTION (bnc#464155).
- patches.suse/scsi-check-removed-device-for-offline: Only check
  for SDEV_OFFLINE and SDEV_DEL, not SDEV_CANCEL.
* Fri Jan  9 2009 jslaby@suse.cz
- patches.suse/add-enable_cgroup-parameter.patch: Add
  cgroup_enable parameter (bnc#436025).
* Fri Jan  9 2009 gregkh@suse.de
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
* Fri Jan  9 2009 gregkh@suse.de
- clean up patch fuzz
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/acpi-pci-pci-msi-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI MSI _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aer-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe AER _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-pcie-aspm-_osc-support-capabilities-called-when-root-bridge-added.patch:
  ACPI/PCI: PCIe ASPM _OSC support capabilities called when root
  bridge added (bnc#438941).
- patches.drivers/acpi-pci-remove-obsolete-_osc-capability-support-functions.patch:
  ACPI/PCI: remove obsolete _OSC capability support functions
  (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/acpi-pci-call-_osc-support-during-root-bridge-discovery.patch:
  ACPI/PCI: call _OSC support during root bridge discovery
  (bnc#438941).
- patches.drivers/acpi-pci-change-pci_osc_control_set-to-query-control-bits-first.patch:
  ACPI/PCI: Change pci_osc_control_set() to query control bits
  first (bnc#438941).
- patches.drivers/acpi-pci-fix-possible-race-condition-on-_osc-evaluation.patch:
  ACPI/PCI: Fix possible race condition on _OSC evaluation
  (bnc#438941).
- patches.drivers/acpi-pci-include-missing-acpi.h-file-in-pci-acpi.h.patch:
  ACPI/PCI: include missing acpi.h file in
  pci-acpi.h. (bnc#438941).
- patches.drivers/acpi-pci-pci-extended-config-_osc-support-called-when-root-bridge-added.patch:
  ACPI/PCI: PCI extended config _OSC support called when root
  bridge added (bnc#438941).
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/bnx2x-version-update.patch: bnx2x: Version
  Update (bnc#439679).
* Thu Jan  8 2009 jjolly@suse.de
- patches.arch/s390-07-01-zfcp-port-failed-message.diff: zfcp:
  Remove message for failed port (bnc#464466).
- patches.arch/s390-07-02-zfcp-unchained-fsf.diff: zfcp: Add
  support for unchained FSF requests (bnc#464466).
- patches.arch/s390-07-03-topology-fix.diff: kernel: fix cpu
  topology support (bnc#464466).
- patches.arch/s390-07-04-dasd-failfast.patch: dasd: Add
  'failfast' device feature. (bnc#464466,LTC#43066).
* Thu Jan  8 2009 tiwai@suse.de
- patches.drivers/alsa-caiaq-midi-oops-fix: ALSA: caiaq - Fix
  Oops with MIDI.
* Thu Jan  8 2009 knikanth@suse.de
- patches.fixes/dm-avoid-put-table-dm_any_congested: dm: avoid
  destroying table in dm_any_congested (bnc#457205).
- patches.fixes/dm-table-ref-count: dm table: rework reference
  counting (bnc#457205).
- patches.fixes/dm-unbind-drop-ref: dm table: drop reference at
  unbind (bnc#457205).
* Thu Jan  8 2009 olh@suse.de
- update kdump config, disable some unused drivers
* Thu Jan  8 2009 olh@suse.de
- refresh config files, no functional changes
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  use separate table for module alias (bnc#435215 - LTC48564)
* Thu Jan  8 2009 tiwai@suse.de
  Backport fixes for HD-audio from the upstream:
- patches.drivers/alsa-hda-ad1882-id-typo-fix: ALSA: hda -
  Fix typos for AD1882 codecs.
- patches.drivers/alsa-hda-ad1986a-laptop-eapd-model-back: ALSA:
  hda - make laptop-eapd model back for AD1986A.
- patches.drivers/alsa-hda-hp2230s-quirk: ALSA: hda - Add quirk
  for HP 2230s (bnc#461660).
- patches.drivers/alsa-hda-sigmatel-add-missing-terminators:
  ALSA: hda - Add missing terminators in patch_sigmatel.c.
* Thu Jan  8 2009 bwalle@suse.de
- Update config files: Enable CONFIG_EHEA=m (and CONFIG_IBMEBUS=y)
  for ppc/kdump and ppc64/kdump (bnc #459119).
* Thu Jan  8 2009 jblunck@suse.de
- Make kernel-source.changes incremental again
* Thu Jan  8 2009 olh@suse.de
- supported.conf: rename dm-leastpending-path to dm-leastpending
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ehea-modinfo.patch:
  add alias entry for portN properties (bnc#435215 - LTC48564)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-abort-response.patch:
  Fixup command response translation (bnc#459383 - LTC50695)
* Thu Jan  8 2009 olh@suse.de
- patches.drivers/ibmvfc-improve_sync_events.patch:
  Improve async event handling (bnc#460567 - LTC50778)
* Thu Jan  8 2009 gregkh@suse.de
- patches.drivers/via-unichrome-drm-bugfixes.patch: via: Unichrome
  DRM bugfixes.
* Thu Jan  8 2009 coly.li@suse.de
- Move patch from patches.suse/dlm-fix-shutdown-cleanup.patch to
  patches.fixes/dlm-fix-shutdown-cleanup.patch
* Thu Jan  8 2009 coly.li@suse.de
- Fixes a regression from commit
  0f8e0d9a317406612700426fad3efab0b7bbc467,
  "dlm: allow multiple lockspace creates".
* Wed Jan  7 2009 olh@suse.de
- patches.arch/ppc-pseries-cpu-migrate.patch: Update
  default_server during migrate_irqs_away (bnc#460566 - LTC50723)
* Wed Jan  7 2009 jack@suse.cz
- patches.suse/mm-increase-dirty-limits.patch: Increase limits
  for starting writeback of dirty data (bnc#449662).
* Wed Jan  7 2009 ghaskins@suse.de
- Update config files (part of bnc#448412).
* Wed Jan  7 2009 ghaskins@suse.de
- patches.fixes/ia64-configure-HAVE_UNSTABLE_SCHED_CLOCK-for-SGI_SN.patch:
  configure HAVE_UNSTABLE_SCHED_CLOCK for SGI_SN systems (bnc#448412).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/lpfc-8.2.8.10-update: Emulex 8.2.8.10 driver
  patches for SLE11 (bnc#460775).
* Wed Jan  7 2009 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Update Patch-mainline
  header. Patch is not refreshed as it breaks kabi (FATE#304489).
* Wed Jan  7 2009 hare@suse.de
- patches.drivers/cciss-driver-panic-on-volume-delete: cciss
  driver may panic if a logical volume is deleted (bnc#459553).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC to avoid deadlocks
  (bnc#461747).
* Wed Jan  7 2009 hare@suse.de
- patches.fixes/fc_transport-devloss-callback-restore: FC devloss
  callback not called when devloss timer fires (bnc#463289).
* Wed Jan  7 2009 hare@suse.de
- patches.suse/dm-mpath-leastpending-path-update: Update
  least-pending-IO dynamic load balancer (bnc#444199).
- patches.suse/dm-mpath-queue-length-load-balancing: Rediff.
- patches.suse/dm-mpath-service-time-load-balancing: Rediff.
- patches.suse/dm-mpath-tracking-nr-bytes: Rediff.
- patches.suse/dm-mpath-leastpending-path: Delete.
* Tue Jan  6 2009 jeffm@suse.de
- patches.fixes/uv-remove-erroneous-BAU-init: UV: remove erroneous
  BAU initialization (bnc#463313).
* Tue Jan  6 2009 jjolly@suse.de
- patches.arch/s390-06-01-qeth-ext-src-mac-addr.patch: qeth:
  exploit source MAC address for inbound layer3 packets
  (bnc#458339).
- patches.arch/s390-06-02-qeth-layercrash.patch: qeth: avoid
  crash in case of layer mismatch for VSWITCH (bnc#458339).
- patches.arch/s390-06-03-dasd_sim_sense_condition.patch: Fix
  unsolicited SIM sense condition. (bnc#458339).
- patches.arch/s390-06-04-qdio_ssqd_memcpy.patch: qdio: fix
  broken memcpy (bnc#458339).
- patches.arch/s390-06-05-qdio_s390dbf.patch: qdio: rework
  s390dbf usage  (bnc#458339).
- patches.arch/s390-06-06-qdio_inbound_ack.patch: qdio: rework
  inbound buffer acknowledgement (bnc#458339).
- patches.arch/s390-06-07-cio-attach_detach.patch: cio: Crashes
  when repeatetly attaching/detaching devices. (bnc#458339).
* Tue Jan  6 2009 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: Jan's comments for
  contiguous kmap fix (bnc#449812).
* Tue Jan  6 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: update.
* Mon Jan  5 2009 mmarek@suse.cz
- patches.suse/modpost-filter-out-built-in-depends: modpost:
  filter out "built-in" depends (bnc#450085).
- patches.drivers/0002-Staging-add-TAINT_CRAP-flag-to-drivers-staging-modu.patch:
  refresh.
* Mon Jan  5 2009 npiggin@suse.de
- Fix ps3 config.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/mm-lockless-pagecache-barrier.patch: mm lockless
  pagecache barrier fix.
* Mon Jan  5 2009 npiggin@suse.de
- patches.fixes/fs-symlink-write_begin-allocation-context-fix.patch:
  fs symlink write_begin allocation context fix.
* Mon Jan  5 2009 npiggin@suse.de
- Update config files.
* Mon Jan  5 2009 npiggin@suse.de
- patches.suse/cgroup-freezer.patch: cgroup freezer update (bnc#417294,
  fate#304191, fate#201036).
* Wed Dec 31 2008 npiggin@suse.de
- patches.fixes/s390-lru_add_drain_all.patch: mm: remove UP
  version of lru_add_drain_all() (bnc#458380).
* Wed Dec 31 2008 npiggin@suse.de
- patches.arch/x86-fix-kmap-contig.patch: x86: contiguous kmap
  fix (bnc#449812).
* Mon Dec 29 2008 jeffm@suse.de
- patches.arch/thinkpad_acpi-hotkey-notify-fix: thinkpad_acpi:
  Fix oops with incompatible backlight interface.
* Mon Dec 22 2008 olh@suse.de
- update patches.arch/ppc-memoryless-nodes.patch:
  fix bootmem reservation on uninitialized node (bunc#457029 - LTC50483)
* Mon Dec 22 2008 olh@suse.de
- patches.fixes/scsi-ibmvscsi-can_queue_fix.patch: Make
  max_requests module parameter more accurate (bnc#458499 - LTC50637)
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-dv7-quirk: ALSA: hda - Add quirk
  for another HP dv7 (bnc#461108).
* Sat Dec 20 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: More fixes (bnc#447624).
* Fri Dec 19 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Print more info.
* Fri Dec 19 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-capture-no-44khz: ALSA: disable
  44.1kHz capture on CA0106 (bnc#447624).
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-92hd73x-desktop-fixes: ALSA: Fix
  plaback problems on Intel desktops with IDT codecs.
* Fri Dec 19 2008 jbeulich@novell.com
- patches.arch/x86_sgi-uv-scir.patch,
  patches.suse/e1000e_ioremap_sanity_check,
  patches.suse/perfmon2-remove_get_base_syscall_attr.patch,
  patches.suse/perfmon2.patch,
  patches.suse/silent-stack-overflow-2.patch: eliminate build warnings.
* Fri Dec 19 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rt2870-wireless-driver.patch:
  Staging: add rt2870 wireless driver.
* Fri Dec 19 2008 nfbrown@suse.de
- patches.fixes/md-bitmap-read-do-not-overflow: md: Don't read
  past end of bitmap when reading bitmap. (bnc#459557).
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Fixed ordering.
* Thu Dec 18 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: Delete.
* Thu Dec 18 2008 gregkh@suse.de
- Updated to final 2.6.27.10 release
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch:
  Use apic=bigsmp on specific xseries machines (bnc#440497).
* Thu Dec 18 2008 trenn@suse.de
- patches.arch/x86_restrict_pci_early_quirks_to_root_bridges.patch:
  Only scan the root bus in early PCI quirks. (bnc#57886).
* Thu Dec 18 2008 jbeulich@novell.com
- patches.xen/746-pirq-status-page.patch: Merge in c/s 751.
- patches.xen/761-highpte.patch: blktap, gntdev: fix highpte handling.
- patches.xen/762-xencons-hvc.patch: add hvc compatibility mode to xencons.
- patches.xen/xen3-patch-2.6.27.7-8: Linux 2.6.27.8.
- patches.xen/xen3-patch-2.6.27.8-9: Linux 2.6.27.9.
- patches.xen/xen-x86-exports: export a few more symbols
  (bnc#458222).
- patches.xen/xen3-perfmon2_remove_syscalls.patch: Rename to ...
- patches.xen/xen3-perfmon2-remove_syscalls.patch: ... this.
* Thu Dec 18 2008 nfbrown@suse.de
- patches.fixes/md-disable-recovery-on-faulty-degraded-array:
  Disable recovery when degraded RAID1 array appears to be
  faulty. (bnc#447835).
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/symsets.pl: fix uninitialized variable
* Wed Dec 17 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - add genksyms reference files so that genksyms can explain why
    did checksums change
* Wed Dec 17 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Delete.  It
  oopses badly and is not needed for the HP2133 hardware, as
  it has switched to Intel chipsets.
* Wed Dec 17 2008 gregkh@suse.de
- Upate to 2.6.27.10-rc1, fixing lots of problems.
  - obsoletes:
  - patches.drivers/libata-update-ST-FLUSH-blacklist
  - patches.fixes/iwlwifi_fix_oops.patch
  - patches.fixes/v4l-dvb-avoid-writing-outside-array
* Tue Dec 16 2008 jeffm@suse.de
- patches.suse/reiserfs-barrier-default: Make reiserfs default
  to barrier=flush.
* Tue Dec 16 2008 mmarek@suse.cz
- addded symtypes-* files to the RC1 reference kabi
* Tue Dec 16 2008 jeffm@suse.de
- patches.fixes/ext3-mark-super-uptodate: ext3: always mark
  super uptodate before dirty (bnc#457043).
* Tue Dec 16 2008 hare@suse.de
- patches.fixes/blk-dont-invoke-request_fn-on-stopped-queue:
  block: only call ->request_fn when the queue is not stopped
  (bnc#457041).
- patches.fixes/blk-get-extra-reference-before-unmap: block:
  hold extra reference to bio in blk_rq_map_user_iov().
- patches.fixes/blk-move-unplug_work-init: block: move
  q->unplug_work initialization.
- patches.fixes/blk-set-segment-boundary-mask: block: fix setting
  of max_segment_size and seg_boundary mask.
- patches.fixes/dm-mpath-send-activate-to-every-path: Handle
  multiple paths in a path group properly during pg_init.
- patches.fixes/scsi_dh-add-lsi-ids-to-rdac: Adding LSI vendor
  and product IDs to RDAC device handler.
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037,bnc#458393).
- patches.suse/scsi-check-removed-device-for-offline: Check if
  device is removed in scsi_device_online() (bnc#456747).
* Tue Dec 16 2008 hare@suse.de
- Enable 3270 console (bnc#457039)
* Tue Dec 16 2008 rjw@suse.de
- Update config files.
- patches.suse/mm-do-not-disable-memory-hotplug-when-hibernation-is-enabled.patch:
  mm: Do not disable memory hotplug when hibernation is enabled
  (bnc#438914).
* Mon Dec 15 2008 jeffm@suse.de
- patches.fixes/iwlwifi_fix_oops.patch: iwlwifi: clean key table
  in iwl_clear_stations_table function (bnc#457062).
* Mon Dec 15 2008 jjolly@suse.de
- patches.drivers/cxgb3i_ddp.patch: cxgb3i - added pdu size
  check and fixed ddp page setup (bnc#449519).
* Mon Dec 15 2008 hare@suse.de
- patches.drivers/qla4xxx-5.01.00-k8_sles11-04-update: qla4xxx
  driver SLES 11 Beta6 update (bnc#458186).
* Mon Dec 15 2008 oneukum@suse.de
- patches.suse/usb_correct_config_ti_04b3_4543.diff: fix
  ti_usb_3410_5052 driver for device 04b3:4543 (bnc#395775).
* Sun Dec 14 2008 gregkh@suse.de
- Update to 2.6.27.9
  - obsoleted:
  - patches.fixes/applicom-fix-unchecked-ioctl-range
  - patches.fixes/watchdog-ib700wdt-buffer-underflow
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-ensure-nonzero-transaction: reiserfs:
  ensure nonzero transaction (bnc#447406).
* Fri Dec 12 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: Update to print accurate refcount.
* Fri Dec 12 2008 jblunck@suse.de
- .gitignore: Ignore backup files.
* Fri Dec 12 2008 hare@suse.de
- patches.fixes/scsi-check-host-lookup-failure: Correct
  scsi_host_lookup return value (bnc#456532).
- patches.suse/dm-mpath-accept-failed-paths: Accept failed paths
  for multipath maps (bnc#458037).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch: hso: rfkill type should
  be WWAN (bnc#458625).
* Fri Dec 12 2008 fseidel@suse.de
- patches.fixes/hso_killswitch.patch:
  fix hso rfkillswitch type to WWAN (bnc#458625)
* Fri Dec 12 2008 mmarek@suse.cz
- import SLE11 RC1 reference kabi
* Fri Dec 12 2008 gregkh@suse.de
- refresh patches to apply cleanly due to 2.6.27.9-rc addition.
* Fri Dec 12 2008 gregkh@suse.de
- remove patches that were obsoleted by 2.6.27.9-rc2
  - patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch
  - patches.arch/x86-hpet-use-WARN_ON_ONCE
  - patches.drivers/alsa-hda-acer-quirk
  - patches.drivers/alsa-hda-alc888-medion-add
  - patches.drivers/alsa-hda-dell-studio-15-quirk
  - patches.drivers/alsa-hda-dell-studio-1535-quirk
  - patches.drivers/alsa-hda-hp-6730s-quirk
  - patches.drivers/alsa-hda-hp-elitebook-8530p-quirk
  - patches.drivers/alsa-hda-hp-mobile-fix
  - patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch
  - patches.drivers/cell_edac.patch
  - patches.fixes/acpi-set-SCI_EN-on-MacBook.patch
  - patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch
  - patches.fixes/block-enforce-minimum-SG_IO-timeout
  - patches.fixes/cxgb3-remove-duplicate-tests-in-lro
  - patches.fixes/cxgb3_fix_race_in_EEH
  - patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch
  - patches.fixes/pci_aspm_check_endless_loop_safe.patch
  - patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch
  - patches.fixes/x86-arch_add_memory-remove-debug
  - patches.fixes/x86-memory-hotplug-off-by-one
* Fri Dec 12 2008 gregkh@suse.de
- update to 2.6.27.9-rc2:
  - lots of bugfixes
  - some security updates
* Thu Dec 11 2008 gregkh@suse.de
- intermediate commit as part of adding 2.6.27.9-rc1 to the tree.
* Thu Dec 11 2008 hare@suse.de
- Compile in zfcpdump module for S/390 (bnc#446367).
* Thu Dec 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: one more fix to make kabi checks work
* Thu Dec 11 2008 teheo@suse.de
- patches.drivers/libata-update-ST-FLUSH-blacklist: libata:
  fix Seagate NCQ+FLUSH blacklist (bnc#458192).
* Wed Dec 10 2008 nfbrown@suse.de
- patches.suse/SoN-fix-sync: Cope with racy nature of sync_page
  in swap_sync_page (441793).
* Wed Dec 10 2008 jjolly@suse.de
- patches.arch/s390-05-09-cleanup-of-portopen-requests.patch:
  zfcp: fix erp timeout cleanup for port open requests
  (bnc#450096).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/watchdog-ib700wdt-buffer-underflow: ib700wdt.c -
  fix buffer_underflow bug (bnc#457898).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/applicom-fix-unchecked-ioctl-range: applicom: Fix
  an unchecked user ioctl range and an error return (bnc#457897).
* Wed Dec 10 2008 jeffm@suse.de
- patches.fixes/block-enforce-minimum-SG_IO-timeout: Enforce a
  minimum SG_IO timeout (bnc#457896).
* Wed Dec 10 2008 mmarek@suse.cz
- rpm/find-provides: don't fail if a subpackage doesn't contain
  any modules (such as the -man subpackage on s390x)
* Wed Dec 10 2008 tiwai@suse.de
- patches.drivers/alsa-hda-hp-6730b-quirk: ALSA: hda - Add quirk
  for HP6730B laptop (bnc#457909).
- patches.drivers/alsa-hda-hp-6730s-quirk: ALSA: hda - Add
  another HP model (6730s) for AD1884A.
- patches.drivers/alsa-hda-hp-elitebook-8530p-quirk: ALSA: hda -
  Make the HP EliteBook 8530p use AD1884A model laptop.
* Wed Dec 10 2008 olh@suse.de
- patches.drivers/ibmvfc-add_sync.patch:
  Fix errors due to inconsistent command data (bnc#456654 - LTC50451)
- patches.drivers/ibmvfc-host_init_delay.patch:
  Delay NPIV login retry and add retries (bnc#456654 - LTC50451)
* Wed Dec 10 2008 teheo@suse.de
- patches.drivers/libata-pata_hpt366-fix-cable-detection:
  pata_hpt366: fix cable detection, (bnc#362159).
- patches.drivers/libata-pata_hpt366-fix-clock-detection:
  pata_hpt366: fix clock detection (bnc#362159).
- patches.drivers/libata-pata_hpt366-no-ATAPI-DMA: pata_hpt366:
  no ATAPI DMA (bnc#362159).
- patches.drivers/libata-pata_hpt366-reimplement-mode-programming:
  pata_hpt366: reimplement mode programming (bnc#362159).
* Tue Dec  9 2008 agruen@suse.de
- supported.conf: Mark xfs_dmapi as supported (bnc#457668).
* Tue Dec  9 2008 jeffm@suse.de
- patches.fixes/x86-arch_add_memory-remove-debug: x86: remove
  debug code from arch_add_memory() (bnc#457526).
- patches.fixes/x86-memory-hotplug-off-by-one: x86, memory
  hotplug: remove wrong -1 in calling init_memory_mapping()
  (bnc#457526).
* Tue Dec  9 2008 agruen@suse.de
- rpm/{kernel-module-subpackage,macros.kernel-source}: Remove
  a leftover hardcoded dependency on the kernel-source package so
  that KMPs can alternatively be built against a kernel other
  than (kernel-source + kernel-syms), such as (kernel-source-rt +
  kernel-syms-rt).
* Tue Dec  9 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop_safe.patch: PCIe:
  ASPM: Break out of endless loop waiting for PCI config bits
  to switch (bnc#449799).
* Tue Dec  9 2008 mmarek@suse.cz
- rpm/symsets.pl:
  - add --required-modules option to tell which modules this
    subpackage requires via dependencies. This is needed to
    preserve symsets when modules move from one subpackage to
    another.
  - add POD help and --help option.
- rpm/kernel-binary.spec.in: make use of --required-modules
* Tue Dec  9 2008 nfbrown@suse.de
- patches.fixes/xfs-barrier-fix.patch: Fix propagation of
  EOPNOTSUPP when barriers are not supported. (bnc#438608).
* Mon Dec  8 2008 rjw@suse.de
- patches.fixes/tg3-fix-default-wol.patch: net (tg3): Fix failure
  to enable WoL by default when possible (bnc#447371).
* Mon Dec  8 2008 olh@suse.de
- patches.arch/ppc-valid-hugepage-size-hugetlb_get_unmapped_area.patch:
  Check for valid hugepage size in hugetlb_get_unmapped_area
  (bnc#456433 - LTC50170).
* Mon Dec  8 2008 trenn@suse.de
- patches.fixes/pci_aspm_check_endless_loop.patch: Delete.
* Mon Dec  8 2008 rw@suse.de
- patches.drivers/sgi-xp-no-uv:
  SGI SN: Eliminate dependency of the XP/XPC drivers on GRU. (bnc#442442)
* Mon Dec  8 2008 rw@suse.de
- Update config files for ia64:
  Disable PERMIT_BSP_REMOVE.  (bnc#386714)
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/find-provides, rpm/kernel-binary.spec.in: figure out what
  subpackage is being processed in find-provides and just print
  the symsets computed in the spec.
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: use flavor-rpmarch to match boards on powerpc
* Mon Dec  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: skip empty KMPs with a warning in
  the kmp %%%%postun
* Mon Dec  8 2008 jjohansen@suse.de
- Update config files.
- patches.apparmor/fix-complain.diff: fix enforcement of deny
  rules in complain mode (bnc#426159).
- patches.apparmor/fix-security-param.diff: fix recognition of
  security= boot parameter (bnc#442668).
- patches.apparmor/fork-tracking.diff: fix log messages to enable
  tools profile learning (bnc#447564).
* Mon Dec  8 2008 olh@suse.de
- rpm/post.sh: update board detection to use rpmarch instead flavor
* Mon Dec  8 2008 hare@suse.de
- patches.fixes/block-integrity-update: Block integrity update
  (FATE#304345).
- patches.suse/dm-block-integrity: Block integrity support for
  DM and MD (FATE#304345).
- patches.suse/dm-mpath-add-start-io: dm-mpath: add a path
  selector interface (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-queue-length-load-balancing: dm-mpath: add
  queue-length dynamic load balancer (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-service-time-load-balancing:
  dm-mpath: add service-time oriented dynamic load balancer
  (FATE#303862,FATE#302108).
- patches.suse/dm-mpath-tracking-nr-bytes: dm-mpath:
  interface change for service-time dynamic load balancer
  (FATE#303862,FATE#302108).
- supported.conf: Update to correctly reference dynamic load
  balancer modules (bnc#444199)
* Mon Dec  8 2008 tonyj@suse.de
- patches.suse/perfmon2-add_ioctl_interface.patch: switch to
  ioctl interface for perfmon2.
- patches.suse/perfmon2-fix_disabled.patch: fix initializion of
  perfmon disabled.
- patches.suse/perfmon2-remove_get_base_syscall_attr.patch:
  remove perfmon syscall_base attribyute.
- patches.suse/perfmon2-remove_syscalls.patch: drop additional
  perfmon2 syscalls.
- patches.xen/xen3-perfmon2_remove_syscalls.patch: drop additional
  perfmon2 syscalls.
* Sat Dec  6 2008 trenn@suse.de
- patches.arch/acpi_ec_provide_non_interrupt_mode_boot_param.patch:
  ACPI: EC: Don't degrade to poll mode at storm
  automatically. (bnc#446142).
- patches.fixes/pci_aspm_check_endless_loop.patch: PCIE Break
  out of endless loop waiting for PCI config bits to switch
  (bnc#449799).
* Sat Dec  6 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Sat Dec  6 2008 gregkh@suse.de
- Update to final 2.6.27.8 release
  - contains 2 changes from 2.6.27.8-rc1
* Fri Dec  5 2008 jbeulich@novell.com
- patches.xen/xen-configurable-guest-devices: fix a typo.
* Fri Dec  5 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  move crq_queue_create at the end of initialization (bnc#455929).
* Fri Dec  5 2008 hare@suse.de
- patches.drivers/open-fcoe-fnic-patches: Open-FCoE bugfixes
  for fnic.
- patches.drivers/open-fcoe-rc1-update: Update open-FCoE with
  latest patches from Intel (bnc#438954).
* Fri Dec  5 2008 jbeulich@novell.com
- Update Xen x86-64 config (2k guest devices, 1k outstanding transmits
  in netback).
* Fri Dec  5 2008 hare@suse.de
- patches.arch/s390-zfcp-synchronize-scsi-register: No udev
  events for zfcp online / offline (bnc#443667).
- patches.fixes/scsi-remove-scmd-timeout: Fix block timeout
  residue problems (bnc#447249,bnc#441335).
- patches.fixes/scsi-eh_stu-timeout: Delete obsolet patch.
* Fri Dec  5 2008 bphilips@suse.de
- patches.fixes/saa7134-fix-resource-map-sanity-check-conflict.patch:
  saa7134: fix resource map sanity check conflict (bnc#446733).
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-rtl8187se-driver.patch: Staging:
  add rtl8187se driver.  Needed for MSI Wind and other netbooks.
* Fri Dec  5 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-serverengines-benet-10gb-ethernet-driver.patch:
  Staging: Add ServerEngines benet 10Gb ethernet driver.
* Fri Dec  5 2008 gregkh@suse.de
- update the wlan-ng driver to the latest upstream version, making
  it much more useful (it actually works now...)
* Fri Dec  5 2008 nfbrown@suse.de
- patches.fixes/sunrpc-module-refcount-fix: Add a reference to
  sunrpc in svc_addsock (443379).  This avoid a bug where
  refcount on sunrpc can go zero or negative.
* Thu Dec  4 2008 jeffm@suse.de
- patches.fixes/reiserfs-debug-1036: reiserfs: print more
  information when an empty journal list is encountered
  (bnc#447406 bnc#399966).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/atm-duplicate-listen-on-socket-corrupts-the-vcc-table.patch:
  ATM: duplicate listen() on socket corrupts the vcc table
  (CVE-2008-5079).
* Thu Dec  4 2008 jack@suse.cz
- Update config files.
* Thu Dec  4 2008 jack@suse.cz
  XFS update on request from SGI:
- patches.apparmor/vfs-notify_change.diff: Add a vfsmount
  parameter to notify_change(). (refreshed)
- patches.suse/xfs-account-for-allocated-blocks-when-expanding-directories:
  Account for allocated blocks when expanding directories
  (bnc#450658).
- patches.suse/xfs-check-for-valid-transaction-headers-in-recovery:
  XFS: Check for valid transaction headers in recovery
  (bnc#450658).
- patches.suse/xfs-dmapi-enable: VFS changes to support DMAPI
  (bnc#450658).
- patches.suse/xfs-dmapi-src: DMAPI Source  (bnc#450658).
- patches.suse/xfs-dmapi-xfs-enable: DMAPI support for xfs
  (bnc#450658).
- patches.suse/xfs-handle-memory-allocation-failures-during-log-initialisation:
  handle memory allocation failures during log initialisation
  (bnc#450658).
- patches.suse/xfs-nfsd-dmapi-aware: Make NFSD DMAPI aware
  (74107, 173874, bnc#450658).
- patches.suse/xfs-wait-for-all-IO-on-truncate-to-zero: Wait
  for all I/O on truncate to zero file size (bnc#450658).
- patches.suse/xfs-dmapi-2.6.27: Delete.
- patches.suse/xfs-dmapi-xfs-2.6.27: Delete.
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-mpic-dont-reset-affinity-for-secondary-MPIC-on-boot.patch:
  Don't reset affinity for secondary MPIC on boot (bnc#456408 - LTC50397).
* Thu Dec  4 2008 jjolly@suse.de
- Update config files.
- patches.arch/s390-05-04-fix_rport_status_check.patch: zfcp:
  fix remote port status check (bnc#450096).
- patches.arch/s390-05-05-stp-etr-stop-machine.patch: stp/etr:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-06-stp-etr-mutex.patch: stp/etr: serialize
  work. (bnc#450096).
- patches.arch/s390-05-07-generic-ipi.patch: kernel:
  smp_call_function races. (bnc#450096).
- patches.arch/s390-05-08-topology.patch: kernel: disable cpu
  topology support by default (bnc#450096,LTC#50392).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-cell-gdb-watchpoints.patch:
  Fix GDB watchpoints on Cell (bnc#456405 - LTC50396).
* Thu Dec  4 2008 olh@suse.de
- patches.arch/ppc-syscall-xer.so.1.patch: Fix system calls on
  Cell entered with XER.SO=1 (bnc#456406 - LTC50395).
* Thu Dec  4 2008 hare@suse.de
- patches.suse/genhd-disk-ro-uevents: Send uevents for
  write_protect changes (bnc#440959).
* Thu Dec  4 2008 mmarek@suse.cz
- supported.conf: mark kernel/net/ipv4/ipvs/ip_vs/* and
  kernel/net/ipv4/netfilter/ipt_CLUSTERIP as unsupported,
  a supported variant will be provided in a separate KMP
  (bnc#455959)
* Thu Dec  4 2008 schwab@suse.de
- Set CONFIG_IA64_CPE_MIGRATE=m.
* Thu Dec  4 2008 jbeulich@novell.com
- supported.conf: Mark pciback as support, sfc_resource, sfc_netback,
  and sfc_netutil as externally supported, add sfc_netfront, and mark
  xenscsi and xen-scsibk as unsupported.
* Thu Dec  4 2008 mszeredi@suse.de
- patches.suse/SoN-fix-uninitialized-variable.patch: Fix use of
  uninitialized variable in cache_grow() (bnc#444597).
* Thu Dec  4 2008 hare@suse.de
- patches.fixes/scsi-eh_stu-timeout: make scsi_eh_try_stu use
  block timeout (bnc#447249,bnc#441335).
* Thu Dec  4 2008 gregkh@suse.de
- patches.fixes/jbd2-create-proc-entry-fix.patch: Delete. It's not needed
  anymore now that 2.6.27.8-rc1 has a similar fix.
* Wed Dec  3 2008 gregkh@suse.de
- Update to 2.6.27.8-rc1:
  - lots of bugfixes
  - some security fixes as well.
  - obsoletes lots of existing patches:
  - patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
  - patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  - patches.drivers/libata-fix-ata_tf_read_block-overflow
  - patches.drivers/libata-fix-ata_tf_to_lba48-overflow
  - patches.drivers/libata-seagate-firmware-bug
  - patches.drivers/parport-serial-array-overflow-fix
  - patches.fixes/af_unix-soft-lockup-fix.patch
  - patches.fixes/cifs-add-cifs_sock_list
  - patches.fixes/cifs-cleanup-cifs_mount
  - patches.fixes/cifs-cleanup-proto-handling
  - patches.fixes/cifs-disable-sess-sharing
  - patches.fixes/cifs-fix-build-breakage
  - patches.fixes/cifs-fix-data-corruption
  - patches.fixes/cifs-fix-dead-tcon-check
  - patches.fixes/cifs-fix-oops-on-failed-mount
  - patches.fixes/cifs-fix-reconnection-flags
  - patches.fixes/cifs-fix-smb-send2
  - patches.fixes/cifs-fix-writepages
  - patches.fixes/cifs-reinstate-sess-sharing-sans-races
  - patches.fixes/cifs-reinstate-treecon-sharing
  - patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors
  - patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully
  - patches.fixes/ext4_fix_whitespace_checkpatch_issues
  - patches.fixes/ext4_update-flex-bg-counters-when-resizing
  - patches.fixes/fix-inotify-watch-removal-umount-races
  - patches.fixes/hpwdt-execute-page.diff
  - patches.fixes/hpwdt-kdump.diff
  - patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch
  - patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch
* Wed Dec  3 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.19: Fix a kernel warning during shutdown.
- patches.xen/xen3-patch-2.6.27,
  patches.xen/xen-netback-notify-multi,
  patches.xen/xen-virq-per-cpu-irq: Refresh.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch: change
  init order to fill in shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- patches.suse/scsi-netlink-ml: Use GFP_ATOMIC for
  skb allocation.
* Wed Dec  3 2008 olh@suse.de
- patches.suse/scsi-scsi_transport_srp-shost_data.patch:
  add debug for Scsi_Host->shost_data (bnc#455929).
* Wed Dec  3 2008 hare@suse.de
- supported.conf: mark dm-leastpending-path as supported
  (bnc#444199)
* Wed Dec  3 2008 teheo@suse.de
  Patch updated to remove strcmp() on NULL strings.
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Wed Dec  3 2008 jbeulich@novell.com
- Update Xen patches to c/s 728 (plus several indivual ones)
- patches.xen/735-balloon-exit.patch: remove sysfs files during balloon
  module exit.
- patches.xen/737-kexec-free.patch: kexec: Don't pass
  limit_pages_to_max_mfn() regions to xen_destroy_contiguous_region().
- patches.xen/740-blkback-resource-leak.patch: blkback, blktap: Fix
  potential resource leak.
- patches.xen/746-pirq-status-page.patch: use shared page indicating
  the need for an EOI notification
- patches.xen/747-x86-undo-mfn-limit.patch: revert the effect of
  xen_limit_pages_to_max_mfn()
- patches.xen/748-x86-ioapic-cleanup.patch: cleanup IO-APIC code
- patches.xen/panic-on-io-nmi-xen.diff: Rename to ...
- patches.xen/xen3-panic-on-io-nmi.diff: ... this.
- patches.xen/uv-sysfs-no-xen.diff: Replace by ...
- patches.xen/xen3-uv_setup_irq.diff: ... this.
- patches.xen/xen3-x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
- patches.xen/xen-fb-bad-irq: Delete.
* Wed Dec  3 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.9-update: Update Emulex lpfc driver
  to 8.2.8.9 (bnc#420767).
* Wed Dec  3 2008 knikanth@suse.de
- patches.suse/cfq-ioc-race: Exiting queue and task might race
  to free cic (bnc#444346).
* Wed Dec  3 2008 sjayaraman@suse.de
- patches.fixes/cifs-reinstate-sess-sharing-sans-races: Adjust as it
  didn't apply cleanly.
* Wed Dec  3 2008 sjayaraman@suse.de
- Fix data corruption issues (411655).
  patches.fixes/cifs-fix-data-corruption
  patches.fixes/cifs-fix-smb-send2
- Fix multiple oopses, memory corruption due to mount/umount races
  (https://bugzilla.samba.org/show_bug.cgi?id=5720).
  patches.fixes/cifs-add-cifs_sock_list
  patches.fixes/cifs-cleanup-cifs_mount
  patches.fixes/cifs-cleanup-proto-handling
  patches.fixes/cifs-disable-sess-sharing
  patches.fixes/cifs-fix-build-breakage
  patches.fixes/cifs-fix-dead-tcon-check
  patches.fixes/cifs-fix-oops-on-failed-mount
  patches.fixes/cifs-fix-reconnection-flags
  patches.fixes/cifs-fix-writepages
  patches.fixes/cifs-reinstate-sess-sharing-sans-races
  patches.fixes/cifs-reinstate-treecon-sharing
* Tue Dec  2 2008 jeffm@suse.de
- scripts/git-create-branch: Helper script to create a new
  branch.
* Tue Dec  2 2008 mmarek@suse.cz
- rpm/get_release_number.sh.in, scripts/tar-up.sh: append first
  eight digits of the commit id to the release string. This makes
  it easier to match rpm release numbers with commits.
* Tue Dec  2 2008 mszeredi@suse.de
- patches.fixes/af_unix-soft-lockup-fix.patch: net: Fix soft
  lockups/OOM issues w/ unix garbage collector (bnc#449739
  CVE-2008-5300).
* Tue Dec  2 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01.02.11.0-k9-update: qla2xxx:
  additional fixes/updates for SLES11 (bnc#450197).
- patches.fixes/scsi-fixup-failfast-definitions: fc_transport:
  fix old bug on bitflag definitions (bnc#447814).
* Tue Dec  2 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff
- patches.suse/novfs-merge-changes.diff: Modified to revert
  some changes in novfs_set_map_drive()
- patches.suse/novfs-clear-mappeddrives.patch: Unlink mapped
  drives on exit (bnc#449451).
* Tue Dec  2 2008 mmarek@suse.cz
- supported.conf: mark ocfs2 as unsupported, a supported variant
  will be provided in a separate KMP (bnc#449824)
* Tue Dec  2 2008 olh@suse.de
- patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch:
  update error message (bnc#448301 - LTC50134)
* Tue Dec  2 2008 hare@suse.de
- Update config files for S/390: Disable FCoE and sync
  default and s390.
- supported.conf: Mark KVM as supported.
* Tue Dec  2 2008 jjolly@suse.de
- ...and added the patches to the series.conf (bnc#450096)
* Tue Dec  2 2008 jjolly@suse.de
- patches.arch/s390-05-01-zfcp-message-linebreak.patch: zfcp:
  Wrong placement of linebreak in message (bnc#450096).
- patches.arch/s390-05-02-zfcp-invalid-non-null-return.patch:
  zfcp: invalid return value on failing fsf_req creation
  (bnc#450096).
- patches.arch/s390-05-03-zfcp-wka-port.patch: zfcp: Fix opening
  of wka ports (bnc#450096).
* Mon Dec  1 2008 kkeil@suse.de
- patches.drivers/cxgb3-Add-1G-fiber-support: cxgb3: Add 1G
  fiber support.
- patches.drivers/cxgb3-Allocate-multiqueues-at-init-time: cxgb3:
  Allocate multiqueues at init time.
- patches.drivers/cxgb3-More-flexible-support-for-PHY-interrupts:
  cxgb3: More flexible support for PHY interrupts..
- patches.drivers/cxgb3-Support-for-Aeluros-2005-PHY: cxgb3:
  Support for Aeluros 2005 PHY.
- patches.drivers/cxgb3-allow-for-PHY-reset-status: cxgb3:
  allow for PHY reset status.
- patches.drivers/cxgb3-commnonize-LASI-phy-code: cxgb3:
  commnonize LASI phy code.
- patches.drivers/cxgb3-eeprom-read-fixes.patch:
  cxgb3 - eeprom read fixes.
- patches.drivers/cxgb3-enable-lro-through-ethtool: cxgb3 -
  enable lro control through ethtool.
- patches.drivers/cxgb3-simplify-port-type-struct-and-usage:
  cxgb3: simplify port type struct and usage.
- patches.drivers/cxgb3-update-driver-version: cxgb3: update
  driver version. (bnc#446739)
* Mon Dec  1 2008 mmarek@suse.cz
- rpm/macros.kernel-source: one more fix to the flavor selection
  code (for some reason %%* contained a newline)
* Mon Dec  1 2008 trenn@suse.de
- patches.arch/acpi_x2APIC_madt_enhancements.patch: ACPICA:
  x2APIC support: changes for MADT and SRAT ACPI tables (fate
  303948 and fate 303984).
- patches.fixes/acpi_check_for_invalid_handle.patch: ACPICA:
  Add check for invalid handle in acpi_get_object_info
  (http://www.acpica.org/bugzilla/show_bug.cgi?id=474).
- patches.fixes/acpi_dereference_object_if_possible.patch:
  ACPICA: Add function to dereference returned reference objects
  (http://bugzilla.kernel.org/show_bug.cgi?id=11105).
- patches.fixes/acpi_do_not_load_acpi_cpufreq_acpioff.patch:
  ACPI: don't load acpi_cpufreq if acpi=off (no reference).
* Mon Dec  1 2008 trenn@suse.de
- patches.fixes/acpi_copy_tables_fix_suspend.patch: ACPICA:
  Copy dynamically loaded tables to local buffer (bnc#410726).
* Sat Nov 29 2008 nfbrown@suse.de
- patches.fixes/SUNRPC-Fix-autobind-on-cloned-rpc-clients.patch:
  SUNRPC: Fix autobind on cloned rpc clients.
  Importantly, this removes a 'BUG_ON' that fires. (450083).
* Sat Nov 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-borked-tecra-m4-broken-suspend:
  ata_piix: add borked Tecra M4 to broken suspend list
  (bnc#398270).
* Sat Nov 29 2008 bwalle@suse.de
- UV updates from SGI (bnc#442455, #442455).
  o patches.fixes/ia64_uv_partition_id.diff:
    Add partition id, coherence id, and region size to UV
  o patches.fixes/ia64_uv_watchlist.diff:
    Add UV watchlist suppor
  o patches.fixes/null_irq_desc_name.diff:
    genirq: NULL struct irq_desc's member 'name' in
    dynamic_irq_cleanup()
  o patches.fixes/uv-bios_call_memprotect.diff:
    Add UV bios call to change memory protections
  o patches.fixes/uv-bios_call_partition.diff:
    x86: Add UV partition call
  o patches.fixes/uv-bios_call_reserve_page.diff:
    Add UV bios call to get the address of the reserved page
  o patches.fixes/uv-bios_call_watchlist.diff:
    Add UV bios calls to allocate and free watchlists
  o patches.fixes/uv-bios_common.diff:
    x86: Add UV bios call infrastructure
  o patches.fixes/uv-efi_bios.diff:
    x86: Add UV EFI table entry
  o patches.fixes/uv-sn_region_size.diff:
    Use consistent names for region size and conherence id on x86
    and ia64
  o patches.fixes/uv-sysfs.diff:
    x86: Add UV sysfs entries
  o patches.fixes/uv-xp-change_memprotect.diff:
    Define xp_expand_memprotect() and xp_restrict_memprotect()
  o patches.fixes/uv-xpc-get_sn_info.diff:
    Define xp_partition_id and xp_region_size
  o patches.fixes/uv-xpc_create_gru_mq_uv.diff:
    Add the code to create the activate and notify gru message
    queues
  o patches.fixes/uv-xpc_get_part_rsvd_page.diff:
    Add support for getting the address of a partition's reserved
    page
  o patches.fixes/uv_setup_irq.diff:
    x86, UV: add uv_setup_irq() and uv_teardown_irq() functions, v3
- Refresh Xen patches
  o patches.xen/xen3-auto-arch-x86.diff
  o patches.xen/xen3-patch-2.6.19
- patches.xen/xen-x86-no-lapic: Add uv_irq.o
- patches.xen/uv-sysfs-no-xen.diff:
  Don't build UV sysfs support on Xen.
* Fri Nov 28 2008 trenn@suse.de
- patches.fixes/x86_cpufreq_powernow-k8_handle_invalid_state_gracefully.patch:
  powernow-k8: ignore out-of-range PstateStatus value (no
  bug avail).
* Fri Nov 28 2008 sassmann@suse.de
- Update config files.
  activate ALTIVEC in ps3 config
* Fri Nov 28 2008 hare@suse.de
- patches.drivers/open-fcoe-beta4-update: rediff.
- patches.drivers/open-fcoe-beta6-update: Incremental Open-FCoE
  for Beta6 (bnc#438954).
* Fri Nov 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sony-vaio-vgn-sr19xn-quirk: ALSA:
  hda - Add quirk for Sony VAIO VGN-SR19XN (bnc#450080).
* Fri Nov 28 2008 olh@suse.de
- rpm/kernel-binary.spec.in: move Module.symvers creation into
  CONFIG_MODULES section, a static kernel exports nothing
* Fri Nov 28 2008 olh@suse.de
- rpm/post*.sh: kernel-vanilla has now vmlinux-vanilla symlink
* Fri Nov 28 2008 teheo@suse.de
  Block layer timer bug fixed.  Multipath patch update is just patch
  refresh.
- patches.drivers/block-internal-dequeue-shouldnt-start-timer:
  block: internal dequeue shouldn't start timer (bnc#449880).
- patches.drivers/blk-request-based-multipath-update: Block layer
  fixes for request-based multipathing (References: FATE#302108).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix no-op macro args
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: fix compile on ppc32
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: always create a dummy initrd because
  mkinitrd is called unconditionally
* Thu Nov 27 2008 olh@suse.de
- rpm/kernel-binary.spec.in: kernel-ps3 needs a suffix
* Thu Nov 27 2008 olh@suse.de
- remove last traces of kernel-um handling
* Thu Nov 27 2008 hare@suse.de
- patches.fixes/qla2xxx-disable-automatic-queue-tracking: qla2xxx:
  Conditionally disable queue_full tracking (bnc#449386).
* Thu Nov 27 2008 olh@suse.de
- patches.suse/8250-sysrq-ctrl_o.patch: no sysrq on Cell QS21/QS22
  serial console (bnc#422987,bnc#96313 - LTC47675/LTC16841).
* Thu Nov 27 2008 olh@suse.de
- patches.arch/ppc-memoryless-nodes.patch: fix booting with
  memoryless nodes (443280 - LTC49675)
* Thu Nov 27 2008 teheo@suse.de
- patches.drivers/libata-seagate-firmware-bug: libata: blacklist
  Seagate drives which time out FLUSH_CACHE when used with NCQ
  (bnc#449531).
* Wed Nov 26 2008 agruen@suse.de
- rpm/macros.kernel-source: Fix the kernel flavor selection logic
  for the %%kernel_module_package macro.
* Wed Nov 26 2008 hare@suse.de
- patches.fixes/blk-leave-sync-timer-running: move to
  correct place in series.conf and rediff
- patches.drivers/cciss-newids.patch: Delete.
* Wed Nov 26 2008 hare@suse.de
- patches.drivers/cciss-newids.patch: Support for newcciss
  controller (bnc#448416).
- patches.fixes/blk-leave-sync-timer-running: block: leave
  request timeout timer running on an empty list (bnc#447249).
* Tue Nov 25 2008 mszeredi@suse.de
- patches.fixes/slab-alloc_slabmgmt-fix.patch: slab: remove
  GFP_THISNODE clearing from alloc_slabmgmt() (bnc#444597).
* Tue Nov 25 2008 sjayaraman@suse.de
- patches.suse/SoN-11-mm-page_alloc-emerg.patch: Fix accidental side-effect
  that this patch introduced by reverting patches.fixes/oom-warning
  (bnc #444597).
* Tue Nov 25 2008 tiwai@suse.de
- patches.drivers/alsa-ca0106-pm-support: ALSA: ca0106 - Add
  power-amangement support (bnc#447624).
- patches.drivers/alsa-hda-dell-92hd73xx-models: ALSA: hda -
  Check model for Dell 92HD73xx laptops (bnc#446025).
- patches.drivers/alsa-hda-dell-studio-1535-quirk: ALSA: hda -
  mark Dell studio 1535 quirk (bnc#446025).
- patches.drivers/alsa-hda-spdif-bits-cache-fix: ALSA: hda -
  Fix caching of SPDIF status bits.
- patches.drivers/alsa-hda-stac-no-hp-as-line-out-switch: ALSA:
  hda - No 'Headphone as Line-out' swich without line-outs
  (bnc#446025).
- patches.drivers/alsa-hda-stac-yet-more-fixes: ALSA: hda -
  Fix AFG power management on IDT 92HD* codecs (bnc#446025).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/fix-inotify-watch-removal-umount-races: Fix
  inotify watch removal/umount races (bnc#446973 CVE-2008-5182).
* Tue Nov 25 2008 jeffm@suse.de
- patches.fixes/uv-redundant-creation-of-proc-dir: UV: redundant
  creation of sgi_uv (bnc#444799).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid45 depends on a few more modules
  (bnc#440208, bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Switch from a no_file_caps command line switch to file_caps={0,1}
  for enabling/disabling file capabilities, and make file_caps=0
  the default: we cannot get the no_file_caps option added to the
  kernel command line anymore (perl-Bootloader, bnc#418366).
* Mon Nov 24 2008 agruen@suse.de
- supported.conf: dm-raid4-5 was renamed to dm-raid45 (bnc#440208,
  bnc#441310).
* Mon Nov 24 2008 agruen@suse.de
- Update config files: switch from CONFIG_PREEMPT_VOLUNTARY to
  CONFIG_PREEMPT_NONE.
* Mon Nov 24 2008 ghaskins@suse.de
- patches.fixes/sched-fix-bug-in-sched-domain-degenerate.patch:
  sched: fix a bug in sched domain degenerate (bnc#442464).
* Mon Nov 24 2008 mmarek@suse.cz
- doc/README.SUSE: document that setting allow_unsupported_modules
  to 1 in /etc/modprobe.d/unsupported-modules is required to make
  self-compiled kernels work.
* Mon Nov 24 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff: Sync with latest upstream
  submission.
* Sun Nov 23 2008 trenn@suse.de
- patches.arch/x86_sgi_uv_early_detect_oem.patch: x86, uv:
  add early detection of UV system types (bnc#429984).
* Sat Nov 22 2008 olh@suse.de
- enable CONFIG_CGROUP_NS on ia64, s390 and powerpc (bnc#447507 - LTC50053)
* Sat Nov 22 2008 rjw@suse.de
- patches.fixes/ia64-fix-boot-panic-caused-by-offline-CPUs.patch:
  fix boot panic caused by offline CPUs (bnc#440386).
* Fri Nov 21 2008 agruen@suse.de
- config/x86_64/maxcpus: Delete.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: s/CVS/GIT/
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: fix module names in export lists
  (kernel/irq/built-in was printed as irq/built-in)
* Fri Nov 21 2008 agruen@suse.de
- Update x86_64/{debug,default,trace,vanilla} config files:
  increase NR_CPUS to 512.
* Fri Nov 21 2008 mmarek@suse.cz
- rpm/symsets.pl: Replace the bash and awk scripts around symsets
  and kabi checking with a single script that generates symsets,
  reuses symsets from older kernels and checks for kabi changes for
  each of the split packages (kabi checking and symset reuse
  require a set of reference files, which does not exist yet)
- rpm/list-exported-symbols: Delete.
- rpm/split-into-symsets: Delete.
- scripts/kabi-checks: Delete.
- kabi/severities: table of kabi change severities
- rpm/built-in-where, rpm/find-provides,
  rpm/kernel-binary.spec.in, rpm/kernel-source.spec.in,
  scripts/tar-up.sh: update to use symsets.pl
* Fri Nov 21 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: include additional fixes from
  Intel (bnc#442411)
* Fri Nov 21 2008 kkeil@suse.de
- patches.fixes/igb_ethtool.patch: add missing ethtool hooks
  (bnc#435551)
* Fri Nov 21 2008 jjolly@suse.de
- patches.arch/s390-04-08-cio-ungroup-race-fix.patch:
  cio: ccwgroup online vs. ungroup race condition
  (bnc#445100,LTC#50092).
- patches.arch/s390-04-09-zfcp-host-busy-count-fix.patch: zfcp:
  prevent double decrement on host_busy counter (bnc#445100).
* Fri Nov 21 2008 agruen@suse.de
- rpm/macros.kernel-source:
  + Rename the -s option to -t in the %%kernel_module_package macro
    for improved cross-distro compatibility.
  + Define %%kernel_module_package_release as 1 for feature tests.
  + Define %%kernel_module_package_buildreqs for use by KMPs: that
    way, KMPs can either use this macro for compatibility, or
    they can substitute other packages for special cases.
* Fri Nov 21 2008 hare@suse.de
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3i-fixed-offload-array-size: cxgb3i -
  fixed offload wr array size (bnc#447409).
- patches.fixes/dm-table-switch-to-readonly: dm multipath devices
  are not getting created for readonly devices (bnc#382705).
- patches.suse/dm-mpath-null-pgs: Allow zero paths for multipath
  priority groups (bnc#372684).
- patches.suse/scsi-netlink-ml: Netlink interface for SCSI
  sense codes (FATE#303789).
* Fri Nov 21 2008 goldwyn@suse.de
- patches.suse/novfs-map-drives-correctly.diff: Fix oops in
  set_map_drive (bnc#446824, bnc#444469).
* Fri Nov 21 2008 jbeulich@novell.com
- patches.xen/xen3-x86-vmware-tsc-03-detect-from-hypervisor:
  Fix Xen pv driver build.
* Fri Nov 21 2008 olh@suse.de
- patches.arch/ppc-spufs-01-use-inc_nlink.patch: use inc_nlink
- patches.arch/ppc-spufs-02-add-a-missing-mutex_unlock.patch
- patches.arch/ppc-spufs-03-sputrace-Only-enable-logging-on-open.patch
- patches.arch/ppc-spufs-04-sputrace-Don-t-block-until-the-read.patch
- patches.arch/ppc-spufs-05-Use-state_mutex-for-switch_log-lockin.patch
- patches.arch/ppc-spufs-06-Don-t-require-full-buffer-in-switch_l.patch
- patches.arch/ppc-spufs-07-Don-t-spu_acquire_saved-unnecessarily.patch
- patches.arch/ppc-spufs-08-Use-kmalloc-rather-than-kzalloc-for-s.patch
- patches.arch/ppc-spufs-09-Improve-search-of-node-for-contexts-w.patch
- patches.arch/ppc-spufs-10-Explain-conditional-decrement-of-aff_.patch
- patches.arch/ppc-spufs-11-Fix-spinning-in-spufs_ps_fault-on-sig.patch
  update spufs to current mainline state (bnc#447133 - LTC50070)
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/parport-serial-array-overflow-fix: Fix array
  overflow in parport_serial.c (bnc#447067).
* Fri Nov 21 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-15-quirk: ALSA: hda -
  Add a quirk for Dell Studio 15 (bnc#446025).
- patches.drivers/alsa-hda-stac-dell-m4-3-quirk: ALSA: hda:
  Add STAC_DELL_M4_3 quirk (bnc#446025).
* Fri Nov 21 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap. Try again.
* Fri Nov 21 2008 gregkh@suse.de
- Refresh patches to apply cleanly after 2.6.27.7 update.
* Fri Nov 21 2008 gregkh@suse.de
- Update to 2.6.27.7
  - lots of bugfixes and security updates.
  - obsoletes:
  - patches.arch/s390-04-05-topology-lock.diff
  - patches.drivers/bnx2x-zero-PMF
  - patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch
  - patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch
  - patches.fixes/sony_laptop_fix_suspend.patch
  - patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch
  - patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch
  - patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
* Fri Nov 21 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-clear-spurious-IRQ: ata_piix:
  detect and clear spurious IRQs (bnc#445872).
* Fri Nov 21 2008 npiggin@suse.de
- patches.fixes/mm-madvise-fix.patch: mm: madvise correct return
  code (bnc#352998).
* Thu Nov 20 2008 jack@suse.cz
- patches.suse/ocfs2-Change-quotafile-names.patch: ocfs2: Change
  file names of local quota files to be consistent (fate#302681).
- patches.suse/ocfs2-Fix-hang-in-quota-recovery-code.patch:
  ocfs2: Fix hang in quota recovery code (fate#302681).
- patches.suse/ocfs2-Fix-oops-when-one-quotatype-enabled: ocfs2:
  Fix oops when only usrquota or grpquota feature is enabled
  (fate#302681).
* Thu Nov 20 2008 garloff@suse.de
- patches.suse/panic-on-io-nmi.diff
  patches.xen/panic-on-io-nmi-xen.diff:
  New kernel sysctl panic-on-io-nmi, which is set will cause a
  kernel panic on receiving an IOCK NMI (bnc#427979).
* Thu Nov 20 2008 jjolly@suse.de
- patches.arch/s390-04-06-cio-sac-update.diff: cio: update sac
  values (bnc#445100).
- patches.arch/s390-04-07-als.patch: kernel: Add processor type
  march=z10 and a processor type safety check. (bnc#445100).
* Thu Nov 20 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-gpio-switch-fix: ALSA: hda:
  STAC_DELL_M6 EAPD (bnc#446025).
* Thu Nov 20 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.6 and c/s 724.
- Update Xen config files.
- patches.xen/xen-fb-bad-irq: xenfb: don't use irq before it
  gets set up (bnc#445659).
- patches.xen/xen-netback-notify-multi: netback: use multicall
  for send multiple notifications.
- patches.xen/xen-netback-nr-irqs: netback: reduce overhead of
  IRQ recording.
* Thu Nov 20 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: removed (no SR-IOV) (bnc#440614)
* Thu Nov 20 2008 olh@suse.de
- disable patches.arch/ppc-efika-bestcomm-ata-dma.patch
  crashes the sound driver
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: excluded vanilla build from creating
  the man package
* Thu Nov 20 2008 hare@suse.de
- patches.drivers/ibmvfc-async-events-oops: ibmvfc oops while
  processing async events (bnc#445541).
- patches.drivers/mpt-fusion-4.16.00.00-update: MPT fusion driver
  update to 4.16.00.00 (bnc#425660).
- patches.fixes/dm-mpath-NULL-pgpath-in-activate_path: Do not
  call activate_path() if pgpath is NULL (bnc#442676).
- patches.fixes/scsi-dh-rdac-initialize-passive-path: Initialize
  path state to be passive when path is not owned (bnc#442676).
- patches.suse/dm-mpath-leastpending-path: Dynamic load balancing
  policy for device mapper multipath (bnc#444199).
* Thu Nov 20 2008 olh@suse.de
- patches.fixes/bug-437171_1_sched_clock_lock.patch: sched: only
  update rq->clock while holding rq->lock (437171 - LTC47404).
- patches.fixes/bug-437171_2_sched_delta_weight.patch: sched:
  revert back to per-rq vruntime (437171 - LTC47404).
- patches.fixes/bug-437171_3_rework_wakeup_preemption.patch:
  sched: rework wakeup preemption (437171 - LTC47404).
- patches.fixes/bug-437171_4_sched_reinstate_vruntime_wakeup.patch:
  sched: re-instate vruntime based wakeup preemption (437171 -
  LTC47404).
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  Fixed debug build, added dependent config option.
* Thu Nov 20 2008 trenn@suse.de
- Update config files.
  - > unified i386/x86_64 debug kernels:
  - added CONFIG_NO_HZ=y to i386-debug
  - added CONFIG_DEBUG_INFO to x86_64-debug
  Differ method to receive processor_id depending whether the processor
  got declared as a regular ACPI device or as a processor object:
- patches.arch/acpi_behave_uniquely_based_on_processor_declaration.patch:
  ACPI: Behave uniquely based on processor declaration definition
  type (bnc#440062).
- patches.arch/acpi_disambiguate_processor_declaration_type.patch:
  ACPI: Disambiguate processor declaration type (bnc#440062).
- patches.arch/acpi_processor_cleanups.patch: ACPI: 80 column
  adherence and spelling fix (no functional change) (bnc#440062).
- patches.xen/xen3-auto-common.diff: xen3 common.
  Fix missing bit for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
- patches.fixes/sony_laptop_fix_suspend.patch: sony-laptop:
  Ignore missing _DIS method on pic device (bnc#446487).
* Thu Nov 20 2008 hare@suse.de
- patches.fixes/dm-mpath-reattach-dh: Do not detach hardware
  handler when removing multipath maps (bnc#435688).
- patches.fixes/scsi-dh-alua-send-stpg: Always send STPG for
  explicit tgps mode.
* Thu Nov 20 2008 jjolly@suse.de
- rpm/kernel-binary.spec.in: Added kernel man package for s390x
* Thu Nov 20 2008 olh@suse.de
- patches.arch/ppc-of-irq-map.patch: fix IRQ assignment if
  interrupts property is missing (bnc#446610 - LTC50006)
* Thu Nov 20 2008 rjw@suse.de
- patches.fixes/acpi-set-SCI_EN-on-MacBook.patch: ACPI suspend:
  Blacklist boxes that require us to set SCI_EN directly on resume
  (bnc#444786).
* Wed Nov 19 2008 tiwai@suse.de
- patches.arch/x86-hpet-pre-read: x86: workaround for mccreary
  HPET read problem (bnc#433746).
* Wed Nov 19 2008 trenn@suse.de
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
  - > Fix typo, must not invert logic at this point
* Wed Nov 19 2008 kkeil@suse.de
- patches.drivers/e1000e_add_ECC: e1000e: enable ECC (bnc#445829)
* Wed Nov 19 2008 mmarek@suse.cz
- scripts/tar-up.sh: record the git branch name in the spec files
  (no branch name means master)
* Wed Nov 19 2008 jkosina@suse.de
- patches.drivers/elousb.patch: fix values of maximum X and Y
  coordinates so that they are compliant with the values that
  the device contains in its descriptor (bnc#442865)
* Wed Nov 19 2008 goldwyn@suse.de
- patches.suse/novfs-merge-changes.diff: Merge changes left out
  during code pull (bnc#445000).
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-multinode.patch: Add support for
  multiple BSR nodes in the device tree. (bnc#443665 - LTC49817)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-cmm-pagecounter.patch:
  Update page in counter for CMM (bnc#445540 - LTC49942)
* Wed Nov 19 2008 olh@suse.de
- patches.arch/ppc-pseries-bsr-4k.patch: Unable to Use Small
  BSR register on Power LPAR (bnc#443673 - LTC49749)
* Wed Nov 19 2008 jjolly@suse.de
- config/s390/s390: Update config files: added CONFIG_UTRACE=y and
  CONFIG_HAVE_ARCH_TRACEHOOK=y
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/ehca-fix-possible-nullpointer-access-v2.patch:
  ehca: fix a possible nullpointer access (bnc#441966).
* Wed Nov 19 2008 jjolly@suse.de
- patches.arch/ppc-axon-missing-msi-workaround-5.diff:
  powerpc/cell/axon-msi: retry on missing interrupt (bnc#445964).
* Wed Nov 19 2008 jjolly@suse.de
- patches.drivers/0001-IB-ehca-Fix-problem-with-max-number-of-QPs-and-CQs.patch:
  Fix problem with max number of QPs and CQs (bnc#441619).
* Tue Nov 18 2008 bwalle@suse.de
- Disable CONFIG_STRICT_DEVMEM for i386 and x86_64 (bnc#443852).
* Tue Nov 18 2008 jjolly@suse.de
- Update config files.
- patches.trace/s390-syscall-get-nr.diff: fix syscall_get_nr..
- patches.trace/s390-utrace-enablement.patch: Backport s390
  kernel components required for utrace enablement.
* Tue Nov 18 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: on s390(x) call dwarfextract to create the
  Kerntypes file for use with old lcrash debuggers.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-92hd71bxx-gpio-fix: ALSA:
  hda - Fix GPIO initialization in patch_stac92hd71bxx()
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-gpio-unsol-resume-fix:
  ALSA: hda - Fix resume of GPIO unsol event for STAC/IDT
  (bnc#445321,bnc#445161).
- patches.drivers/alsa-hda-stac-hp-pavilion-quirks: ALSA: hda -
  Add quirks for HP Pavilion DV models (bnc#445321,bnc#445161).
* Tue Nov 18 2008 tiwai@suse.de
- patches.arch/x86-hpet-use-WARN_ON_ONCE: x86: HPET: convert
  WARN_ON to WARN_ON_ONCE (bnc#433746).
* Tue Nov 18 2008 sdietrich@suse.de
  RT development has moved to slert-devel branch.
- Remove RT patches from master branch.
  (itemized RT patch list suppressed)
* Tue Nov 18 2008 olh@suse.de
- patches.arch/ppc-efika-bestcomm-ata-dma.patch: use ATA DMA (bnc#445856)
* Tue Nov 18 2008 olh@suse.de
- config/ppc/ppc64: reenable 64k PAGE_SIZE to keep the config
  flavor on ppc and ppc64 in sync
  the last change had also no bug number to fix the possible bug
  in the Xserver.
* Tue Nov 18 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-acer-dmic: ALSA: hda - Split
  ALC268 acer model (bnc#420048).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-04-01-qdio_prevent_double_shutdown.patch:
  qdio: prevent double qdio shutdown in case of I/O
  errors. (bnc#445100).
- patches.arch/s390-04-02-qdio-osa-port-count.patch: qdio:
  fix qeth port count detection. (bnc#445100).
- patches.arch/s390-04-03-kmsg.patch: kmsg: do not change pr_xyz
  messages without KMSG_COMPONENT (bnc#445100).
- patches.arch/s390-04-04-dasd_fatal_error_log_sense.patch:
  dasd: log sense for fatal errors. (bnc#445100).
- patches.arch/s390-04-05-topology-lock.diff: kernel: Fix locking
  in cpu topology code. (bnc#445100).
* Tue Nov 18 2008 jjolly@suse.de
- patches.arch/s390-personality-mask.patch: fix s390x_newuname.
* Tue Nov 18 2008 gregkh@suse.de
- patches.drivers/staging-rt2860-enable-wpa_supplicant-support.patch:
  Staging: rt2860: enable WPA_SUPPLICANT support (bnc#437959).
* Mon Nov 17 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.7-update: Update lpfc to 8.2.8.7
  (bnc#420767).
- patches.drivers/qla4xxx-5.01.00-k8_sles11-03-update: Update
  qla4xxx to 5.01.00-k8_sles11-03     (bnc#444884).
- patches.fixes/dm-mpath-reattach-dh: Reattach device handler
  for multipath devices (bnc#435688).
- patches.fixes/scsi-add-tgps-setting: Add TGPS setting to
  scsi devices.
- patches.fixes/scsi-dh-alua-retry-UA: Retry ALUA device handler
  initialization on Unit Attention.
* Mon Nov 17 2008 jeffm@suse.de
- patches.fixes/v4l-dvb-avoid-writing-outside-array: V4L/DVB
  (9621): Avoid writing outside shadow.bytes array (bnc#445569).
* Mon Nov 17 2008 fseidel@suse.de
- patches.fixes/ipw2200-send-noassoc.patch: ipw2200: fix oops
  in ipw_tx_skb (bnc#397390).
* Sat Nov 15 2008 rjw@suse.com
- patches.fixes/hibernate-x86-fix-breakage-on-x86_32-with-PAE.patch:
  x86: Hibernate: Fix breakage on x86_32 with CONFIG_NUMA set
  (bnc#439126).
* Sat Nov 15 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-hp-m4-check-fix: ALSA:
  hda - Check model type instead of SSID in patch_92hd71bxx()
  (bnc#444349).
- patches.drivers/alsa-hda-sigmatel-vref-event-fix: ALSA: hda:
  STAC_VREF_EVENT value change (bnc#444349).
* Sat Nov 15 2008 gregkh@suse.de
- patches.kernel.org/memory-hotplug-fix-page_zone-calculation-in-test_pages_isolated.patch:
  memory hotplug: fix page_zone() calculation in
  test_pages_isolated() (bnc#445163).
* Fri Nov 14 2008 gregkh@suse.de
- patches.drivers/input-alps-add-signature-for-dualpoint-found-in-dell-latitude-e6500.patch:
  Input: ALPS - add signature for DualPoint found in Dell Latitude
  E6500 (bnc#436719).
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 hare@suse.de
- patches.fixes/scsi-eh-timed-out-missing-braces: scsi_error:
  fix indentation and braces disagreement - add braces.
- patches.fixes/scsi-retry-TASK_ABORTED: scsi_error: TASK ABORTED
  status handling improvement.
- patches.fixes/scsi-retry-transport-error: scsi_error regression:
  Fix idempotent command handling.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/hpwdt-execute-page.diff:
  [WATCHDOG] [hpwdt] Set the mapped BIOS address space as
  executable (bnc#430680).
* Fri Nov 14 2008 tiwai@suse.de
- patches.arch/x86-vmware-tsc-01-add-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-02-add-X86_FEATURE_HYPERVISOR,
  patches.arch/x86-vmware-tsc-03-detect-from-hypervisor,
  patches.arch/x86-vmware-tsc-04-use-TSC_RELIABLE,
  patches.arch/x86-vmware-tsc-05-skip-tsc-clocksource,
  patches.arch/x86-vmware-tsc-06-fix-vmware_get_tsc,
  patches.arch/x86-vmware-tsc-07-DMI-product-serial-key,
  patches.xen/xen-x86-vmware-tsc-fix:
    VMware tsc clocksource workaround (bnc#441338).
* Fri Nov 14 2008 tiwai@suse.de
- Fixed a typo in definition of X86_FEATURE_XTOPOLOGY (bnc#443293)
  in patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4
* Fri Nov 14 2008 agruen@suse.de
- Update CONFIG_X86_RESERVE_LOW_64K in config/x86_64/maxcpus as
  well.
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff:
  rename to patches.suse/mem_cgroup_stat-dynamic-alloc, and update
  to newer version.
* Fri Nov 14 2008 bwalle@suse.de
- patches.fixes/kdump-x86-sparsemem.diff: x86, kdump: fix invalid
  access on i386 sparsemem (bnc#440525).
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  Refresh.
* Thu Nov 13 2008 gregkh@suse.de
- patches.kernel.org/iwlagn-avoid-sleep-in-softirq-context.patch:
  iwlagn: avoid sleep in softirq context (bnc#444382).
* Thu Nov 13 2008 philips@suse.de
- patches.fixes/cdc-acm.c-fix-recursive-lock-in-acm_start_wb-error-path.patch:
  cdc-acm.c: fix recursive lock in acm_start_wb error path.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K for i386 and x86-64 vanilla
  configs.
* Thu Nov 13 2008 gregkh@suse.de
- enable CONFIG_X86_RESERVE_LOW_64K on i386 and x86-64 to fix some
  suspend/resume issues (option added in 2.6.27.6)
* Thu Nov 13 2008 gregkh@suse.de
- refresh patches so that everything applies cleanly.
* Thu Nov 13 2008 gregkh@suse.de
- Update to 2.6.27.6:
  - fixes some security issues
  - lots of bugfixes
  - obsoletes:
  - patches.arch/acpi-dock-avoid-check-_STA-method.patch:
  - patches.arch/ppc-gigantic-page-fix2.patch:
  - patches.arch/ppc-gigantic-page-fix3.patch:
  - patches.drivers/alsa-hda-dell-eq-option:
  - patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  - patches.drivers/cciss-fix-sysfs-symlink.patch:
  - patches.drivers/libata-fix-last_reset-timestamp-handling:
  - patches.kernel.org/md-raid10-recovoery-fix.path:
* Thu Nov 13 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: package modules.order (bnc#441384)
* Thu Nov 13 2008 agruen@suse.de
- config.conf: Add x86_64/maxcpus as the 4096-cpu configuration
  and switch back to at most 128 cpus in the other configs. This
  avoids wasting memory on all but the most extreme x86_64
  systems.
- rpm/kernel-binary.spec.in: define a kernel-$flavor symbol to
  allow per-flavor patches. (Use this for testing only!)
- patches.suse/bug-425240_nr_cpus-mem_cgroup_stat-fix.diff: Add
  this patch conditionally for x86_64/maxcpus for now pending
  test results from bnc#425240.
* Thu Nov 13 2008 tiwai@suse.de
- patches.drivers/alsa-hda-beep-dig-switch: ALSA: hda - Add
  digital beep playback switch for STAC/IDT codecs (#444572).
- patches.drivers/alsa-hda-beep-null-check-fix: ALSA: hda -
  Missing NULL check in hda_beep.c.
* Thu Nov 13 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: fix to
  make it work with iSCSI (bnc#444234)
* Thu Nov 13 2008 olh@suse.de
- mark some powerpc device drivers as supported to move them out of
  kernel-extra, otherwise installation-images will not pick them up
- ps3vram, mtd, mtdblock, mtd_blkdevs (bnc#444220)
- PowerMac, Efika and Pegasos2 storage and network drivers
* Wed Nov 12 2008 bwalle@suse.de
- patches.fixes/firmware-memmap-64bit.diff: Always use 64 bit
  addresses for the firmware memory map.
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-powermac-ibook-g4-mic-fix: ALSA: powermac -
  Rename mic-analog loopback mixer element (bnc#444194).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac-hp-detect-fix: ALSA: hda -
  Fix IDT/STAC multiple HP detection (bnc#443267).
* Wed Nov 12 2008 agruen@suse.de
- patches.suse/module-ref-dynamic-alloc: fall back to vmalloc if
  kmalloc fails (bnc#425240).
* Wed Nov 12 2008 tiwai@suse.de
- patches.drivers/alsa-hda-stac9200-missing-mux-capture: ALSA:
  hda - Add missing analog-mux mixer creation for STAC9200
  (bnc#443738).
- patches.drivers/alsa-hda-stac92xx-mic-pin-fix: ALSA: hda -
  Fix input pin initialization for STAC/IDT codecs (bnc#443738).
* Tue Nov 11 2008 philips@suse.de
- rpm/kernel-binary.spec.in: remove Recommends: kerneloops, opt-in will
  be implemented in the 11.2 installer
* Tue Nov 11 2008 jeffm@suse.de
- patches.fixes/reiserfs-error-buffer-locking: reiserfs: add
  locking around error buffer.
- patches.fixes/reiserfs-varargs-fix: reiserfs: prepare_error_buf
  wrongly consumes va_arg.
* Tue Nov 11 2008 tiwai@suse.de
- patches.suse/module-ref-dynamic-alloc: Allocate module.ref
  array dynamically (bnc#425240).
- Update config files: back to NR_CPUS=4096
* Tue Nov 11 2008 jblunck@suse.de
- Update config files: Set NR_CPUS on x86_64 back to 128 again for
  now: with NR_CPUS=4096, the size of eack .ko file increases by
  496 KiB because of the static struct module in
  .gnu.linkonce.this_module.
* Tue Nov 11 2008 schwab@suse.de
- patches.arch/ppc-select: Fix wrong error code from ppc32 select.
* Tue Nov 11 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: also encode the architecture into the
  packageand supplements.
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-fix-ata_tf_read_block-overflow: libata:
  Avoid overflow in ata_tf_read_block() when tf->hba_lbal > 127
  (bnc#443661).
- patches.drivers/libata-fix-ata_tf_to_lba48-overflow: libata:
  Avoid overflow in ata_tf_to_lba48() when tf->hba_lbal > 127
  (bnc#443661).
* Tue Nov 11 2008 teheo@suse.de
- patches.drivers/libata-pata_sch-slave-poss: pata_sch: slave
  devices (bnc#443657).
* Mon Nov 10 2008 schwab@suse.de
- config/ppc/ppc64: Disable 64k pages to work around X server bug.
* Mon Nov 10 2008 olh@suse.de
- rpm/kernel-binary.spec.in: fix variable assignment in last change
* Mon Nov 10 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: encode the architecture into
  subpackage dependencies (bnc#440961)
* Mon Nov 10 2008 olh@suse.de
- handle arch differences for cpu and kbuild correctly
* Mon Nov 10 2008 schwab@suse.de
- patches.arch/ia64-page-migration. patches.arch/mm-avoid-bad-page-on-lru:
  migrade pages off of pages with correctable errors.
* Mon Nov 10 2008 mmarek@suse.cz
- scripts/tar-up.sh: do not generate kernel-source-rt.spec and
  kernel-syms-rt.spec if RT is not enabled.
* Mon Nov 10 2008 sdietrich@suse.de
- config.conf: Suppress RT configurations.
* Sun Nov  9 2008 jeffm@suse.de
- config.conf: Removed previous workaround.
- rpm/kernel-binary.spec.in: Remove @FLAVOR@ from %%symbols.
* Sat Nov  8 2008 jeffm@suse.de
- config.conf: Workaround for kernel-ppc64 on head-ppc.
* Sat Nov  8 2008 gregkh@suse.de
- Update to the "real" 2.6.27.5.  No code changes from what we had
  in our tree previously, with the exception for the version number
  change.
* Fri Nov  7 2008 bwalle@suse.de
- patches.fixes/kdb-read-CR.diff:
  Support '\n' in KDB (bnc#442808).
* Fri Nov  7 2008 gregkh@suse.de
- disable perfmon support in the -trace kernels as it doesn't build
  properly.
* Fri Nov  7 2008 schwab@suse.de
- patches.arch/compat-sys-swapcontext: Fix msr check in sys_swapcontext.
* Fri Nov  7 2008 hare@suse.de
- patches.drivers/ixgbe-add-bcna-support: DCB: Add BCNA support
  to ixgbe.
- patches.drivers/open-fcoe-beta3-update: Open-FCoE update for
  Beta3 (bnc#438954).
- patches.drivers/open-fcoe-beta4-update: Open-FCoE: Update for
  Beta4 (bnc#438954).
- patches.drivers/open-fcoe-beta5-update: Open-FCoE: Update for
  Beta5 (bnc#438954).
- patches.fixes/dcb-fix-setpfcstate: Fix setpfcstate (bnc#438954).
- patches.fixes/dcb-setting-pg-will-cause-tx-hang: DCB: setting
  pg will cause tx unit hangs (bnc#438954).
- patches.fixes/multiq-requeue-should-rewind-current_band:
  multiq: requeue should rewind the current_band (bnc#438954).
- patches.fixes/scsi-dh-rdac-retry-mode-select: Retry mode select
  in RDAC device handler (bnc#441337).
- patches.fixes/scsi-dh-rdac-set-default-ownership: scsi_dh_rdac:
  make sure the ownership is set correctly (bnc#441337).
- patches.fixes/scsi-skip-nonscsi-device-for-dma: Update patch
  to check for ->bus instead of ->type (bnc#431294).
* Fri Nov  7 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dell-studio-probe-fix: ALSA: hda -
  Fix probe errors on Dell Studio Desktop (bnc#440907).
- patches.drivers/alsa-hda-hp-3013-master-fix: ALSA: hda -
  Fix ALC260 hp3013 master switch (bnc#441068).
* Fri Nov  7 2008 jjolly@suse.de
- patches.arch/s390-03-07-qeth_hsi_mcl_string.patch:
  qeth: pre z9 systems return HiperSocket version string
  different. (bnc#440610,LTC#49052).
- patches.arch/s390-03-08-zfcp-abort-race.patch: zfcp: eliminate
  race between validation and locking. (bnc#440610).
- patches.arch/s390-03-09-zfcp-oops-during-target-scan.patch:
  zfcp: prevent SCSI target scan for vanished rport
  (bnc#440610,LTC#49373).
* Fri Nov  7 2008 olh@suse.de
- Update config files for RT
* Fri Nov  7 2008 olh@suse.de
- build a kernel-default in dist ppc64, its identical to kernel-ppc64
  otherwise unused
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-source.spec.in: map ppc/ppc64 to powerpc
* Fri Nov  7 2008 kkeil@suse.de
- patches.drivers/igb-pf.patch: VF enabled igb driver (fate#305004)
* Fri Nov  7 2008 olh@suse.de
- stop building kernel-default and kernel-ps3 in dist ppc64,
  they are openSuSE only packages
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: extracting debuginfo from vdso fails
  on powerpc, disable vdso_install for the time being
* Fri Nov  7 2008 jbeulich@novell.com
- patches.xen/xen3-intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
* Fri Nov  7 2008 olh@suse.de
- rpm/post.sh: reject legacy iSeries again
* Fri Nov  7 2008 olh@suse.de
- build a 32bit and a 64bit vanilla kernel on powerpc
* Fri Nov  7 2008 olh@suse.de
- rpm/kernel-binary.spec.in: no vdso in vanilla and ps3 kernel
* Fri Nov  7 2008 gregkh@suse.de
- patches.kernel.org/net-fix-recursive-descent-in-__scm_destroy.patch:
  net: Fix recursive descent in __scm_destroy()..
* Fri Nov  7 2008 olh@suse.de
- remove patches.arch/ppc64-rpanote-relocate-firmware.patch
  older firmware versions can handle relocation properly (bnc#427960)
* Fri Nov  7 2008 jjolly@suse.de
- patches.drivers/cxgb3-get_drvinfo-deadlock.patch: RDMA/cxgb3:
  deadlock in iw_cxgb3 can cause hang when configuring
  interface. (bnc#430998).
* Fri Nov  7 2008 gregkh@suse.de
- patches.suse/perfmon2.patch: perfmon2 (bnc#430298).
* Fri Nov  7 2008 nfbrown@suse.de
- patches.fixes/nfs-write.c-bug-removal.patch: Revert "NFS:
  Allow redirtying of a completed unstable write." (442267).
  It causes a BUG().
* Fri Nov  7 2008 nfbrown@suse.de
- patches.kernel.org/md-raid10-recovoery-fix.path: md: fix bug
  in raid10 recovery..
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped..:  Removed much of this patch as it turned out
  to be both buggy and unnecessary (the ioctl can be done from
  mdadm).
* Thu Nov  6 2008 kkeil@suse.de
- patches.drivers/ixgbe-sfp.patch: ixgbe driver update to add
  Longcove (SFP+) NIC support for FCoE needs (bnc#442411)
* Thu Nov  6 2008 gregkh@suse.de
- enable CONFIG_X86_SUMMIT, CONFIG_X86_ES7000, and CONFIG_X86_BIGSMP
  for the i386 default kernel, so that the installer can actually
  boot on "modern" multiprocessor i386 boxes (bnc#428247)
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install only on x86 and ppc.
* Thu Nov  6 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Call make vdso_install to install the
  vdso shared objects for debugging.
* Thu Nov  6 2008 jjolly@suse.de
- patches.drivers/intel-ibex-peak-device-ids.patch: x86/PCI: irq
  and pci_ids patch for Intel Ibex Peak DeviceIDs (bnc#415383).
- patches.drivers/intel-ibex-peak-device-support.patch: i2c-i801:
  Add support for Intel Ibex Peak (bnc#415383).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: Fixed patch for build
- patches.arch/s390-03-04-qdio_multicast_performance.patch: dasd:
  fix  message flood for unsolicited interrupts (bnc#440610).
- patches.arch/s390-03-05-dasd-block-uevent.patch: dasd: DASD
  uevents are not sent correctly (bnc#440610,LTC#49429).
- patches.arch/s390-03-06-zfcp-hexdump.patch: zfcp: fix hexdump
  data in s390dbf traces (bnc#440610).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-03-01-stp-init.patch: kernel: Fix
  initialization of stp. (bnc#440610,LTC#49639).
- patches.arch/s390-03-02-setup_memory.patch: kernel: Fix range
  for add_active_range() in setup_memory() (bnc#440610,LTC#49639).
- patches.arch/s390-03-03-dasd_unsolicited_interrupt.patch:
  dasd: fix  message flood for unsolicited interrupts
  (bnc#440610,LTC#49639).
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-02-10-zfcp-scan-online.patch: wait for port
  scan when setting FCP device online (bnc#434333).
* Thu Nov  6 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27.4 and c/s 718.
- Update Xen config files.
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch: Include
  pv-ops-Xen changes here
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: Delete.
- patches.xen/xen-configurable-guest-devices: allow number of
  guest devices to be configurable.
- patches.xen/xen-cpufreq-report: make /proc/cpuinfo track
  CPU speed.
- patches.xen/xen-ipi-per-cpu-irq: fold IPIs onto a single
  IRQ each.
- patches.xen/xen-rtl2860-build: Rename to ...
- patches.xen/xen-rt2860-build: ... this.
- patches.xen/xen-sysdev-suspend: use base kernel suspend/resume
  infrastructure.
- patches.xen/xen-virq-per-cpu-irq: fold per-CPU VIRQs onto a
  single IRQ each.
- patches.xen/xen-x86-mmu-batching: Delete.
- patches.xen/xen3-patch-2.6.27.3-4: Linux 2.6.27.4.
- patches.xen/xen3-x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.xen/xen3-x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.xen/xen3-x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
* Thu Nov  6 2008 sassmann@suse.de
- patches.arch/ppc-ps3-introduce-ps3_gpu_mutex.patch: required for
  new ps3vram patch
- patches.arch/ppc-ps3-ps3vram-mtd.patch: updated ps3vram patch
  that works with firmware 2.50 (bnc#442227)
* Thu Nov  6 2008 olh@suse.de
- remove unneeded BuildRequires for dtc
* Thu Nov  6 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: Feature removed
  (bnc#417299)
* Thu Nov  6 2008 gregkh@suse.de
- patches.suse/file-capabilities-add-no_file_caps-switch.patch:
  file capabilities: add no_file_caps switch (v4).
  add the patch back into the tree.
* Wed Nov  5 2008 jblunck@suse.de
- patches.suse/coredump_filter-add-elfhdr-default.patch: Dump
  elf headers to core per default.
* Wed Nov  5 2008 teheo@suse.de
  Fix !CONFIG_DMI case.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
* Wed Nov  5 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: update patch
  to skip all devices with no dma_parms (bnc#431294)
* Wed Nov  5 2008 agruen@suse.de
- rpm/kernel-module-subpackage: Remove the obsolete kernel-$flavor
  dependency (bnc#440961).
* Wed Nov  5 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Removed and replaced with
  v3 of the patch from IBM (bnc#417300)
- patches.arch/s390-01-05-kmsg-v3.patch: Kernel message catalog
  infrastucture and message generation (bnc#417300).
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Patch edited to allow new kmsg patch
* Wed Nov  5 2008 agruen@suse.de
- Update config files: set CONFIG_MODULE_FORCE_LOAD=y to allow
  ignoring ABI mismatches. (This is still unsafe to do!)
* Wed Nov  5 2008 tiwai@suse.de
  Backport fixes from 2.6.28-rc.
- patches.drivers/alsa-hda-acer-quirk: ALSA: hda - Add a quirk
  for another Acer Aspire (1025:0090) (bnc#426935).
- patches.drivers/alsa-hda-alc888-medion-add: ALSA: hda - Add
  a quirk for MEDION MD96630 (bnc#412548).
- patches.drivers/alsa-hda-dell-eq-option: ALSA: hda: make a
  STAC_DELL_EQ option.
- patches.drivers/alsa-hda-proc-gpio-fix: ALSA: hda - Limit the
  number of GPIOs show in proc.
* Wed Nov  5 2008 gregkh@suse.de
- refresh -rt patches to remove fuzz.
* Wed Nov  5 2008 teheo@suse.de
  Backport two more device specific workarounds from 2.6.28-rc.
- patches.drivers/libata-add-and-use-HORKAGE_ATAPI_MOD16_DMA:
  libata: implement ATA_HORKAGE_ATAPI_MOD16_DMA and apply it.
- patches.drivers/libata-whitelist-good-bridges: libata: add
  whitelist for devices with known good pata-sata bridges.
* Wed Nov  5 2008 gregkh@suse.de
- refresh patches to remove fuzz
* Wed Nov  5 2008 teheo@suse.de
  Backport double spin off workaround.
- patches.drivers/dmi-introduce-dmi_first_match: DMI:
  Introduce dmi_first_match to make the interface more flexible
  (bnc#441721).
- patches.drivers/libata-ahci-blacklist-double-spin-off: SATA
  AHCI: Blacklist system that spins off disks during ACPI power
  off (bnc#441721).
- patches.drivers/libata-ata_piix-blacklist-double-spin-off:
  SATA PIIX: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/libata-implement-NO_SPINDOWN: SATA: Blacklisting
  of systems that spin off disks during ACPI power off (rev. 2)
  (bnc#441721).
- patches.drivers/libata-sata_sil-blacklist-double-spin-off:
  SATA Sil: Blacklist system that spins off disks during ACPI
  power off (bnc#441721).
- patches.drivers/power-introduce-system_entering_hibernation:
  Hibernation: Introduce system_entering_hibernation (bnc#441721).
* Wed Nov  5 2008 gregkh@suse.de
- fix rt tree that was broken by 2.6.27.5-rc1
* Wed Nov  5 2008 olh@suse.de
- update patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix booting on ppc32 (bnc#439491 - LTC48584)
* Wed Nov  5 2008 teheo@suse.de
  Backport sata_via fixes from 2.6.28-rc.
- patches.drivers/libata-sata_via-fix-support-for-5287: sata_via:
  fix support for 5287 (bnc#441718).
- patches.drivers/libata-sata_via-load-DEVICE-register-when-CTL-changes:
  sata_via: load DEVICE register when CTL changes (bnc#441718).
- patches.drivers/libata-sata_via-restore-vt-_prepare_host-error-handling:
  sata_via: restore vt*_prepare_host error handling (bnc#441718).
* Wed Nov  5 2008 teheo@suse.de
  Backport laptop table and pci device ID table entries from 2.6.28-rc.
- patches.drivers/libata-ata_piix-add-Hercules-EC-900-mini-to-laptop-tbl:
  ata_piix: add Hercules EC-900 mini-notebook to ich_laptop
  short cable list.
- patches.drivers/libata-ata_piix-add-intel-ibex-pci-ids:
  ata_piix: IDE Mode SATA patch for Intel Ibex Peak DeviceIDs.
* Wed Nov  5 2008 teheo@suse.de
  Backport slave_link from 2.6.28-rc to fix ata_piix probing problem.
- patches.drivers/libata-ata_piix-use-slave_link: ata_piix:
  drop merged SCR access and use slave_link instead (bnc#441420).
- patches.drivers/libata-eh-fix-slave-link-EH-action-mask-handling:
  libata-eh: fix slave link EH action mask handling (bnc#441420).
- patches.drivers/libata-implement-slave_link: libata: implement
  slave_link (bnc#441420).
- patches.drivers/libata-make-SCR-access-ops-per-link: libata:
  make SCR access ops per-link (bnc#441420).
- patches.drivers/libata-misc-updates-to-prepare-for-slave-link:
  libata: misc updates to prepare for slave link (bnc#441420).
- patches.drivers/libata-reimplement-link-iterator: libata:
  reimplement link iterator (bnc#441420).
- patches.drivers/libata-set-device-class-to-NONE-if-phys_offline:
  libata: set device class to NONE if phys_offline (bnc#441420).
- patches.drivers/libata-transfer-EHI-control-flags-to-slave-ehc.i:
  libata: transfer EHI control flags to slave ehc.i (bnc#441420).
* Wed Nov  5 2008 gregkh@suse.de
- Update to 2.6.27.5-rc1:
  - fixes lots of things, including a few CVE entries
  - obsoletes, and caused to be deleted:
  - patches.arch/ppc-pseries_16g-numa.patch
  - patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  - patches.arch/ppc-pseries_mem-limit-16g.patch
  - patches.arch/s390-02-02-smp-sysdev.patch
  - patches.drivers/alsa-hda-reboot-notifier
  - patches.drivers/libata-sata_nv-hardreset-fix
  - patches.fixes/acpi-clear-wake-status.patch
  - patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch
  - patches.suse/file-capabilities-add-no_file_caps-switch.diff
  - patches.suse/file-capabilities-turn-on-by-default.diff
- Update config files.
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/bnx2-Add-bnx2_shutdown_chip: bnx2: Add
  bnx2_shutdown_chip()
- patches.drivers/bnx2-check-running.patch: Check netif_running
  in most ethtool operations    (bnc#440052)
* Wed Nov  5 2008 kkeil@suse.de
- patches.drivers/ixgbe-copper_pond.patch: ixgbe: add device
  support for 82598AT (copper 10GbE) adapters (bnc#441471)
* Tue Nov  4 2008 tonyj@suse.de
- patches.rt/fork_init_nrcpus.patch: Fix oops in fork_init.
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: fix typo
* Tue Nov  4 2008 rw@suse.de
- patches.drivers/bnx2x-zero-PMF:
  bnx2x: Removing the PMF indication when unloading.  (bnc#439679)
* Tue Nov  4 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: make also -base and -extra x86
  subpackages not installable on x86_64
* Tue Nov  4 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-3-v2.patch: (kernel):FCP -
  Performance Data colletion & analysis patch update (bnc#417243).
- patches.arch/s390-01-04-fcpperf-3.patch: Removed for update
* Tue Nov  4 2008 miklos@szeredi.hu
- patches.apparmor/d_namespace_path_oops_fix.diff: fix oops in
  d_namespace_path (bnc#433504).
* Tue Nov  4 2008 hare@suse.de
- patches.fixes/scsi-skip-nonscsi-device-for-dma: scsi_lib_dma.c :
  fix bug w/ dma on virtual fc ports (bnc#431294).
* Tue Nov  4 2008 sdietrich@suse.de
- Update RT config files: Enable CONFIG_NO_HZ on i386/rt_debug.
  - Refresh config files.
* Tue Nov  4 2008 teheo@suse.de
- patches.drivers/libata-fix-last_reset-timestamp-handling:
  libata: fix last_reset timestamp handling (bnc#441340).
* Tue Nov  4 2008 hare@suse.de
- patches.drivers/qla2xxx-8.02.01-k9-update: Update qla2xxx to
  8.02.01-k9 (bnc#439208).
* Tue Nov  4 2008 gregkh@suse.de
- refresh patches to apply cleanly.
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Compile fix.
* Mon Nov  3 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy-fixes: ALSA: emu10k1 -
  Add more invert_shared_spdif flag to Audigy models (bnc#440862).
- patches.drivers/alsa-hda-alc269-fsc-amilo: ALSA: hda - Add
  ALC269 fujitsu model (bnc#440626).
* Mon Nov  3 2008 jeffm@suse.de
- patches.suse/dm-raid45_2.6.27_20081027.patch: Update dmraid45.
* Mon Nov  3 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Fix dm table
  ref count (FATE#304489).
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach (bnc#440980).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-dont-restore-DET-on-detach: libata:
  mask off DET when restoring SControl for detach.
* Mon Nov  3 2008 olh@suse.de
- add patches.arch/ppc-clock_gettime-nanoseconds.patch
  update also nanoseconds (bnc#439908 - LTC49499)
* Mon Nov  3 2008 teheo@suse.de
- scripts/vc: s/GIT_COMMITER_EMAIL/GIT_COMMITTER_EMAIL and add
  SUSE_COMMITTER_EMAIL.
* Mon Nov  3 2008 teheo@suse.de
  BNC reference added.
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression (bnc#429344).
* Mon Nov  3 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-hardreset-fix: sata_nv: fix
  generic, nf2/3 detection regression.
* Sun Nov  2 2008 sdietrich@suse.de
- Update RT config files: enable more lock debugging,
  latency features, make x86_64 and i386 consistent.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/kprobes_make_pointer_decl_consistent.patch: Make
  kprobe locking consistent with lock-type declarations
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
  Use raw_smp_processor_id in __mem_cgroup_stat_add_safe.
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/mem_cgroup_charge_statistics-smp_processor_id.patch:
* Sun Nov  2 2008 sdietrich@suse.de
- patches.rt/workqueue-introduce-create_rt_workqueue.patch:
  workqueue: introduce create_rt_workqueue. (from 2.6.28)
  Refresh to eliminate fuzz:
  - patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 sdietrich@suse.de
- Update RT config files:
  - Sync with SLES 11 default/debug configs
  - Limit CPUS to 32
  - Disable CONFIG_RADIX_TREE_CONCURRENT
  - Disable CONFIG_RADIX_TREE_OPTIMISTIC
  - Disable CONFIG_PREEMPT_RCU_BOOST
  - Enable CONFIG_RTMUTEX_CHECK
- Adapt RT patches to changes made by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/mitigate-resched-flood-update.patch: Update
    smp_send_reschedule_allbutself_cpumask mask parameter.
  - patches.rt/x86-nmi-send_IPI_mask-pointer-fix.patch: Update
    smp_send_nmi_allbutself  mask parameter.
  Resolve conflicts introduced by:
  x86_sgi_cpus4096-05-update-send_IPI_mask.patch
  - patches.rt/nmi-profiling-base.patch
  - patches.rt/send-nmi-all-preempt-disable.patch
  Refresh to eliminate fuzz
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
* Sat Nov  1 2008 bwalle@suse.de
- patches.fixes/kdb-fix-stack-overflow.patch:
  kdb: fix stack overflow for large NR_CPUS count (bnc#440361).
* Fri Oct 31 2008 trenn@suse.de
  Fate 304268 and 304266. SGI scir driver (replaces the more intrusive
  leds one) and the rather intrusive x86_64 4096 CPU support patches:
- Update config files.
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
- patches.arch/x86_sgi-uv-scir.patch: SGI X86 UV: Provide a
  System Activity Indicator driver (FATE304268 bnc#426066).
- patches.arch/x86_sgi_cpus4096-01-fix-smp_call_function.patch:
  smp: reduce stack requirements for smp_call_function_mask
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-02-fix-send_call_func_ip.patch:
  x86: reduce stack requirements for send_call_func_ipi
  (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-05-update-send_IPI_mask.patch:
  x86 cpumask: Updates to support NR_CPUS=4096 (bnc#425240
  FATE304266).
- patches.arch/x86_sgi_cpus4096-06-optimize-cpumask-in-sched_c.patch:
  Additional cpumask fixups (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-04-add-for_each_cpu_mask_and.patch:
  Add for_each_cpu_mask_and (bnc#425240 FATE304266).
- patches.arch/x86_sgi_cpus4096-07_pae_compile_fixups.patch:
  more cpumask cleanups for previous (x86_sgi_cpu4096..) patches
  (Additional cpumask fixups).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc8-x86-1 (FATE#303971).
- patches.xen/xen3-patch-2.6.27: Linux: Update to 2.6.27.
- patches.xen/x86_sgi_xen-x86-cpus4096.patch: x86 cpumask xen:
  Updates to support NR_CPUS=4096 (Additional cpumask fixups).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-alc269-dmic: ALSA: hda -
  Add digital-mic for ALC269 auto-probe mode (bnc#440626).
- patches.drivers/alsa-hda-realtek-mic-automute-fix: ALSA: hda -
  Disable broken mic auto-muting in Realtek codes (bnc#440626).
* Fri Oct 31 2008 hare@suse.de
- Update config files.
- patches.drivers/cxgb3i: add cxgb3i iscsi driver
  (FATE#304154,bnc#433500).
- patches.drivers/cxgb3-private-iscsi-ip-addresses: cxgb3 -
  manage private iSCSI IP addresses (FATE#304154,bnc#433500).
- patches.drivers/open-iscsi-offloading-support: support for iscsi
  pdu digest offload and payload DDP. (FATE#304154,bnc#433500).
- patches.fixes/cxgb3-remove-duplicate-tests-in-lro: cxgb3 -
  remove duplicate tests in lro (FATE#304154, bnc#430538).
- supported.conf: Mark cxgb3i as supported.
* Fri Oct 31 2008 bwalle@suse.de
- patches.suse/kdb-resolve-uv-conflict.diff:
  Resolve KDB conflicts with UV (bnc#440376).
* Fri Oct 31 2008 tiwai@suse.de
- patches.drivers/alsa-hda-sigmatel-spdif-fix: ALSA: hda -
  Fix SPDIF mute on IDT/STAC codecs.
- patches.drivers/alsa-hda-reboot-notifier: ALSA: hda - Add
  reboot notifier.
* Fri Oct 31 2008 jack@suse.cz
- patches.suse/ocfs2-Fix-mount-cleanup-after-quota-failure.patch:
  ocfs2: Fix mount cleanup after quota failure (fate#302681).
- patches.suse/ocfs2-Fix-oop-in-recovery-without-quotas:
  ocfs2: Fix recovery of nodes when quota feature is disabled
  (fate#302681).
- patches.suse/ocfs2-Fix-grace-time-syncing.patch: ocfs2: Fix
  grace time syncing (fate#302681).
* Fri Oct 31 2008 teheo@suse.de
- patches.drivers/block-del-timer-after-dequeue: blk: move
  blk_delete_timer call in end_that_request_last (bnc#440076
  bnc#440173).
* Thu Oct 30 2008 trenn@suse.de
- patches.arch/x86_agpgart-g33-stoeln-fix-2.patch: Avoid oops
  on G33 in 1MB stolen Mem case (bnc#391261).
* Thu Oct 30 2008 gregkh@suse.de
- patches.fixes/agp-fix-stolen-memory-counting-on-g4x.patch:
  agp: Fix stolen memory counting on G4X. (bnc#437618).
* Thu Oct 30 2008 oneukum@suse.de
- patches.fixes/sd_liberal_28_sense_invalid.diff: fix medium
  presence misdetection in usb storage device  (bnc#362850).
* Thu Oct 30 2008 olh@suse.de
- add patches.fixes/scsi-ibmvscsi-show-config.patch
  use 4k buffer to transfer config data (439970 - LTC49349)
* Thu Oct 30 2008 teheo@suse.de
- patches.drivers/block-add-timeout-on-dequeue: block: add timer
  on blkdev_dequeue_request() not elv_next_request() (bnc#440076).
* Wed Oct 29 2008 sdietrich@suse.de
  Refresh RT patches:
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT (debug
  builds).
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/partreadd-lttng-instrumentation-irq.patch: readd
  RT compatible version of lttng-instrumentation-irq.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/start_irq_thread.patch: Linux-RT 2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
* Wed Oct 29 2008 gregkh@suse.de
- s/rtl2860/rt2860/
- remove driver from the Xen build as it's dying for some reason.
- add obsoletes for ralink-rt2860-kmp
* Wed Oct 29 2008 olh@suse.de
- update patches.arch/ppc-oprofile-spu.patch
  add missing ARRAY_SIZE(pm_signal_local)
* Wed Oct 29 2008 hare@suse.de
- patches.arch/s390-symmetrix-ioctl.patch: Add ioctl support
  for EMC Symmetrix Subsystem Control I/O (bnc#439221)
* Wed Oct 29 2008 jbeulich@suse.de
- patches.xen/xen-rtl2860-build: fix issue with Windows-style
  types used in rtl2680.
* Wed Oct 29 2008 olh@suse.de
- build af_packet as a module on powerpc (bnc#433540)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu-mutex-locking.patch
  Fix mutex locking for cell spu-oprofile (bnc#422501 - LTC47617)
* Wed Oct 29 2008 olh@suse.de
- add patches.arch/ppc-oprofile-spu.patch
  fix local array size in activate spu profiling function (bnc#439553 - LTC48925)
* Wed Oct 29 2008 olh@suse.de
- update patches.drivers/ehea.patch
  Add hugepage detection (bnc#439599 - LTC48958)
* Wed Oct 29 2008 gregkh@suse.de
- patches.drivers/staging-add-agnx-wireless-driver.patch: Staging:
  add agnx wireless driver.
- patches.drivers/staging-add-otus-atheros-wireless-network-driver.patch:
  Staging: add otus Atheros wireless network driver.
- patches.drivers/staging-add-rtl2860-wireless-driver.patch:
  Staging: add rtl2860 wireless driver (bnc#437959).
- Update config files.
* Tue Oct 28 2008 jkosina@suse.de
- patches.suse/silent-stack-overflow-2.patch: disabled, as it
  causes kernel hangs triggered by grub (bnc#439448).
* Tue Oct 28 2008 kkeil@suse.de
- update patches.suse/SoN-17-net-ps_rx.patch
  fix i/o corruption on rx in ixgbe (bnc#438929)
* Tue Oct 28 2008 jdelvare@suse.de
- config/powerpc/*: Fixup configuration files after last change.
* Tue Oct 28 2008 jdelvare@suse.de
- config/*: Include many multimedia drivers which has been dropped
  accidentally. This includes the pwc, ivtv, zr36067 drivers and
  many old webcam drivers (bnc#439489).
- supported.conf: Add all these drivers again.
* Tue Oct 28 2008 tiwai@suse.de
- patches.drivers/alsa-hda-analog-update,
  patches.drivers/alsa-hda-atihdmi-update,
  patches.drivers/alsa-hda-beep,
  patches.drivers/alsa-hda-hp-mobile-fix,
  patches.drivers/alsa-hda-nvidia-hdmi,
  patches.drivers/alsa-hda-probe-fix,
  patches.drivers/alsa-hda-proc-fix,
  patches.drivers/alsa-hda-realtek-update,
  patches.drivers/alsa-hda-sigmatel-update,
  patches.drivers/alsa-hda-spdif-slave,
  patches.drivers/alsa-hda-via-rec-fix,
  patches.drivers/alsa-hda-via-update:
    ALSA updates, mostly taken from 2.6.28-rc1 patches
- Update config files.
* Tue Oct 28 2008 jdelvare@suse.de
- Actually CONFIG_SND_HDA_HWDEP is a boolean, sorry.
* Tue Oct 28 2008 jdelvare@suse.de
- config/ia64/vanilla, config/x86_64/vanilla: fix configuration
  discrepancy, CONFIG_SND_HDA_HWDEP=m.
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-pcibios_allocate_bus_resources.patch
  add patches.arch/ppc-powerpc-debug-pci-hotplug.patch
  fix DLPAR on pseries (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- add patches.arch/ppc-powerpc-fix-pci-unmap-io.patch
  Fix unmapping of IO space on 64-bit (bnc#439491 - LTC48584)
* Tue Oct 28 2008 olh@suse.de
- update ps3 config, remove unneeded options to reduce vmlinux size
* Tue Oct 28 2008 neilb@suse.de
- patches.suse/md-notify-when-stopped: md: notify udev when an
  md array is stopped. (fate#303894).
* Tue Oct 28 2008 gregkh@suse.de
- use the panasonic laptop driver that was accepted by upstream, not the
  pcc-acpi driver, which was rejected:
  - patches.drivers/staging-add-pcc-acpi-driver.patch: Delete.
  - patches.drivers/panasonic-laptop-add-panasonic-let-s-note-laptop-extras-driver-v0.94.patch:
    panasonic-laptop: add Panasonic Let's Note laptop extras
    driver v0.94.
- Update config files.
* Mon Oct 27 2008 gregkh@suse.de
- patches.drivers/via-framebuffer-driver.patch: Via Framebuffer
  driver.
- Update config files.
* Mon Oct 27 2008 bwalle@suse.de
- patches.fixes/hpwdt-kdump.diff:
  Don't change permission of sysfs file (did that accidentally
  when changing the default value).
* Mon Oct 27 2008 trenn@suse.de
- patches.arch/x86_uv_early_detect.patch: Delete hacks that were
  necessary while waiting for x2apic code. (bnc#429984).
* Mon Oct 27 2008 tj@suse.de
  Refresh the govault patch.
- patches.drivers/libata-add-waits-for-govault: libata: add
  waits for GoVault (bnc#246451).
* Sun Oct 26 2008 bwalle@suse.de
- patches.fixes/kdb-oops-panic.diff:
  Fix NULL pointer dereference when regs == NULL (bnc#439007).
- patches.fixes/hpwdt-kdump.diff:
  Fix kdump when using hpwdt (bnc#436786).
* Sun Oct 26 2008 gregkh@suse.de
- refresh patches to apply cleanly and properly.
* Sun Oct 26 2008 gregkh@suse.de
- Update to 2.6.27.4
* Sat Oct 25 2008 agruen@suse.de
- Fix the dependencies between the split kernel packages and KMPs
  (FATE 303631).
- Fix for kernel paclages which are not split.
- rpm/kernel-source.spec.in: Update list of scripts to include.
* Sat Oct 25 2008 jjolly@suse.de
- patches.arch/s390-02-02-smp-sysdev.patch: kernel: sysdev class
  file creation (bnc#434333)
- patches.arch/s390-02-03-zfcp.patch: Fix zfcp problems that have
  been found (bnc#434333)
- patches.arch/s390-02-04-qeth-mac.patch: qeth: use firmware
  MAC-address for layer2 hsi-devices (bnc#434333)
- patches.arch/s390-02-05-qeth-recovery.patch: qeth: qeth recovery
  fails (bnc#434333)
- patches.arch/s390-02-06-qeth-offset.patch: qeth: fix offset error
  in non prealloc header path (bnc#434333,LTC#48840)
- patches.arch/s390-02-07-qeth-ipv6check.patch: qeth: remove
  unnecessary support ckeck in sysfs route6 (bnc#434333)
- patches.arch/s390-02-08-qeth-panic.patch: qeth: avoid
  skb_under_panic for malformatted inbound data (bnc#434333)
- patches.arch/s390-02-09-tape-lock.patch: tape device driver:
  improve locking (bnc#434333)
* Sat Oct 25 2008 neilb@suse.de
- patches.kernel.org/touch_mnt_namespace-when-the-mount-flags-change.patch:
  touch_mnt_namespace when the mount flags change (FATE#304218).
* Fri Oct 24 2008 gregkh@suse.de
- Updated to 2.6.27.4-rc3:
  - fixed ath5k suspend/resume regression
  - fixed pvrusb2 so it actually works
* Fri Oct 24 2008 jack@suse.cz
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681). - fixed 64-bit division
* Fri Oct 24 2008 jeffm@suse.de
- Update config files for -rt.
* Fri Oct 24 2008 hare@suse.de
- patches.suse/cgroup-freezer.patch: Add TIF_FREEZE for s390.
* Fri Oct 24 2008 olh@suse.de
- move patches.suse/md-raid-metadata-PAGE_SIZE.patch
  to patches.kernel.org/md-raid-metadata-PAGE_SIZE.patch
  to allow raid0 with 64k PAGE_SIZE
* Fri Oct 24 2008 jack@suse.cz
- Update config files.
- supported.conf: Added new quota module
- patches.suse/xfs-dmapi-enable: Enable XFS DMAPI. - Refreshed
  Quotas for OCFS2:
- patches.suse/quota-Add-callbacks-for-allocating-and-destroying-d.patch:
  quota: Add callbacks for allocating and destroying dquot
  structures (fate#302681).
- patches.suse/quota-Increase-size-of-variables-for-limits-and-ino.patch:
  quota: Increase size of variables for limits and inode usage
  (fate#302681).
- patches.suse/quota-Remove-bogus-optimization-in-check_idq-an.patch:
  quota: Remove bogus 'optimization' in check_idq() and
  check_bdq() (fate#302681).
- patches.suse/quota-Make-_SUSPENDED-just-a-flag.patch: quota:
  Make _SUSPENDED just a flag (fate#302681).
- patches.suse/quota-Allow-to-separately-enable-quota-accounting-a.patch:
  quota: Allow to separately enable quota accounting and enforcing
  limits (fate#302681).
- patches.suse/ext3-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext3: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/ext4-Use-sb_any_quota_loaded-instead-of-sb_any_qu.patch:
  ext4: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled() (fate#302681).
- patches.suse/reiserfs-Use-sb_any_quota_loaded-instead-of-sb_an.patch:
  reiserfs: Use sb_any_quota_loaded() instead of
  sb_any_quota_enabled(). (fate#302681).
- patches.suse/quota-Remove-compatibility-function-sb_any_quota_en.patch:
  quota: Remove compatibility function sb_any_quota_enabled()
  (fate#302681).
- patches.suse/quota-Introduce-DQUOT_QUOTA_SYS_FILE-flag.patch:
  quota: Introduce DQUOT_QUOTA_SYS_FILE flag (fate#302681).
- patches.suse/quota-Move-quotaio_v-12-.h-from-include-linux-to-f.patch:
  quota: Move quotaio_v[12].h from include/linux/ to fs/
  (fate#302681).
- patches.suse/quota-Split-off-quota-tree-handling-into-a-separate.patch:
  quota: Split off quota tree handling into a separate file
  (fate#302681).
- patches.suse/quota-Convert-union-in-mem_dqinfo-to-a-pointer.patch:
  quota: Convert union in mem_dqinfo to a pointer (fate#302681).
- patches.suse/quota-Allow-negative-usage-of-space-and-inodes.patch:
  quota: Allow negative usage of space and inodes (fate#302681).
- patches.suse/quota-Keep-which-entries-were-set-by-SETQUOTA-quota.patch:
  quota: Keep which entries were set by SETQUOTA quotactl
  (fate#302681).
- patches.suse/quota-Add-helpers-to-allow-ocfs2-specific-quota-ini.patch:
  quota: Add helpers to allow ocfs2 specific quota initialization,
  freeing and recovery (fate#302681).
- patches.suse/quota-Implement-function-for-scanning-active-dquots.patch:
  quota: Implement function for scanning active dquots
  (fate#302681).
- patches.suse/ocfs2-Fix-check-of-return-value-of-ocfs2_start_tran.patch:
  ocfs2: Fix check of return value of ocfs2_start_trans()
  (fate#302681).
- patches.suse/ocfs2-Support-nested-transactions.patch: ocfs2:
  Support nested transactions (fate#302681).
- patches.suse/ocfs2-Fix-checking-of-return-value-of-new_inode.patch:
  ocfs2: Fix checking of return value of new_inode()
  (fate#302681).
- patches.suse/ocfs2-Let-inode-be-really-deleted-when-ocfs2_mknod_.patch:
  ocfs2: Let inode be really deleted when ocfs2_mknod_locked()
  fails (fate#302681).
- patches.suse/ocfs2-Assign-feature-bits-and-system-inodes-to-quot.patch:
  ocfs2: Assign feature bits and system inodes to quota feature
  and quota files (fate#302681).
- patches.suse/ocfs2-Mark-system-files-as-not-subject-to-quota-acc.patch:
  ocfs2: Mark system files as not subject to quota accounting
  (fate#302681).
- patches.suse/ocfs2-Implementation-of-local-and-global-quota-file.patch:
  ocfs2: Implementation of local and global quota file handling
  (fate#302681).
- patches.suse/ocfs2-Add-quota-calls-for-allocation-and-freeing-of.patch:
  ocfs2: Add quota calls for allocation and freeing of inodes
  and space (fate#302681).
- patches.suse/ocfs2-Enable-quota-accounting-on-mount-disable-on.patch:
  ocfs2: Enable quota accounting on mount, disable on umount
  (fate#302681).
- patches.suse/ocfs2-Implement-quota-syncing-thread.patch: ocfs2:
  Implement quota syncing thread (fate#302681).
- patches.suse/ocfs2-Implement-quota-recovery.patch: ocfs2:
  Implement quota recovery (fate#302681).
* Fri Oct 24 2008 kkeil@suse.de
- patches.fixes/cxgb3_fix_race_in_EEH: cxgb3: fix race in EEH.
  (bnc#430093)
* Fri Oct 24 2008 jeffm@suse.de
- Refreshed context for -RT patches so they apply again.
* Fri Oct 24 2008 rw@suse.de
- patches.drivers/sgi-ioc4-request-submodules:
  Make ioc4 request dependant modules.  (bnc#429215)
* Fri Oct 24 2008 hare@suse.de
- Update config files: Disable FAIL_MAKE_REQUEST.
* Fri Oct 24 2008 tiwai@suse.de
- patches.drivers/alsa-usb-exclude-1st-slot: Delete this old ugly
  workaround patch.
* Fri Oct 24 2008 hare@suse.de
- Include patches from upstream:
  - patches.fixes/block-use-bio_has_data: Implement bio_has_data().
  - patches.fixes/block-git-fixes: Block layer fixes for 2.6.28.
  - patches.fixes/block-rq-affinity: Implement rq affinity.
  - patches.fixes/dm-mpath-remove-is_active: dm mpath: remove
    is_active from struct dm_path.
  - patches.fixes/block-discard-requests: Implement block discard.
  - patches.drivers/dm-abort-queue-on-failed-paths: dm: Call
    blk_abort_queue on failed paths (bnc#417544).
  - patches.drivers/block-call-sync-on-cleanup: block:
    blk_cleanup_queue() should call blk_sync_queue().
- Refaktor and update request-based multipath patches:
  - patches.drivers/blk-request-based-multipath-update:
    Update request-based multipathing patches to upstream version
    (bnc#434105).
  - patches.suse/rq-based-multipath: Update to latest version
    of request-based multipathing patchset (bnc#434105)
  - patches.drivers/block-abort-request-rq-complete-marking:
    use rq complete marking in blk_abort_request (bnc#434105).
  - patches.fixes/scsi-atomic-blk-timer-deletes: Delete.
  - patches.fixes/dm-mpath-abort-queue: Delete.
  - patches.suse/rq-based-block-layer: Delete.
  - patches.suse/rq-based-dm-interface: Delete.
  - patches.suse/rq-based-multipath-functions: Delete.
  - patches.suse/rq-based-init-crash: Delete.
- Update patches to upstream version:
  - patches.drivers/bdev-resize-check-for-device-resize
  - patches.drivers/bdev-resize-added-flush_disk
  - patches.drivers/bdev-resize-call-flush_disk
  - patches.drivers/bdev-resize-sd-driver-calls
  - patches.drivers/block-timeout-handling
  - patches.drivers/bdev-resize-adjust-block-device-size
  - patches.drivers/bdev-resize-wrapper-for-revalidate_disk
  - patches.drivers/block-abort-queue
  - patches.fixes/scsi-enhance-error-codes
- Rediff patches:
  - patches.fixes/scsi-misc-git-update
  - patches.suse/dm-barrier-single-device
  - patches.suse/kdb-common
  - patches.drivers/lpfc-8.2.8-update
  - patches.drivers/lpfc-8.2.8.3-update
  - patches.drivers/mpt-fusion-4.00.43.00-update
* Fri Oct 24 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch: Add sysctl also
  to kernel/sysctl_check.c.
* Fri Oct 24 2008 bwalle@suse.de
- Obsolete uvcvideo-kmp.
* Fri Oct 24 2008 jbeulich@suse.de
- rpm/kernel-binary.spec.in: Provide 'kernel' also for Xen (bnc#362918).
* Fri Oct 24 2008 jbeulich@suse.de
- patches.arch/x86_64-unwind-annotations: fix unwind annotations.
- patches.xen/xen3-x86_64-unwind-annotations: fix unwind
  annotations.
* Fri Oct 24 2008 jbeulich@suse.de
- Update Xen patches to 2.6.27.3 and c/s 704
- patches.xen/xen3-x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.xen/xen3-x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.xen/xen-kconfig-compat-3.2.0: add 3.2.0-compatibility
  configure option.
- patches.xen/xen-x86-exit-mmap: be more aggressive about
  de-activating mm-s under destruction.
- patches.xen/xen-x86-machphys-prediction: properly predict
  phys<->mach translations.
- patches.xen/xen-x86-mmu-batching: utilize
  arch_{enter,leave}_lazy_cpu_mode().
- patches.xen/xen-x86-no-lazy-tlb: ensure inadvertent uses of
  lazy TLB data are caught during the build.
- Update Xen config files.
* Fri Oct 24 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in:
  - do not split kernel-kdump into -base and -extra
  - fix case when a build results in no unsupported modules
* Fri Oct 24 2008 bwalle@suse.de
- patches.fixes/kdb-kdump.diff:
  Fix CONFIG_KDB_KDUMP on xSeries (bnc#436454).
* Fri Oct 24 2008 agruen@suse.de
- supported.conf: Mark dmapi as supported (by SGI).
* Fri Oct 24 2008 olh@suse.de
- disable all unsupported drivers in kernel-kdump
* Fri Oct 24 2008 npiggin@suse.de
- patches.suse/silent-stack-overflow-2.patch: avoid silent stack
  overflow over the heap (bnc#44807 bnc#211997).
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc2
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_SYSFS_DEPRECATED_V2 from powerpc/rt config file
* Fri Oct 24 2008 gregkh@suse.de
- Update to 2.6.27.4-rc1
  - lots of bugfixes, and obsoletes some current patches:
  - patches.fixes/ext3-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/ext2-avoid-printk-flood-with-dir-corruption: Delete.
  - patches.fixes/wdm_autoload.diff: Delete.
* Fri Oct 24 2008 npiggin@suse.de
- Fix ppc and ps3 configs
* Fri Oct 24 2008 npiggin@suse.de
- Update config files.
- patches.suse/cgroup-freezer.patch: cgroup freezer (bnc#417294,
  fate#304191, fate#201036).
* Fri Oct 24 2008 npiggin@suse.de
- Update config files. Enable cgroups for all archs (bnc#417527)
* Fri Oct 24 2008 npiggin@suse.de
- patches.arch/ppc-gigantic-page-fix2.patch: powerpc gigantic
  pages fix 2 (bnc#434026).
- patches.arch/ppc-gigantic-page-fix3.patch: powerpc gigantic
  pages fix 3 (bnc#434026).
- patches.trace/lttng-instrumentation-hugetlb.patch: de-fuzz
* Fri Oct 24 2008 gregkh@suse.de
- disabled CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64
  vanilla kernel.
* Fri Oct 24 2008 gregkh@suse.de
- patches.drivers/cciss-fix-procfs-firmware-regression.patch:
  cciss: fix procfs firmware regression (bnc435644).
- patches.drivers/cciss-fix-sysfs-symlink.patch: cciss: fix
  sysfs symlink (bnc435644).
* Fri Oct 24 2008 gregkh@suse.de
- disable CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT on x86-64.  To use
  Calgary iommu systems, you now must manually pass "iommu=calgary" to
  get this hardware support back enabled.  This is the recommended
  proceedure right now, from IBM, otherwise the hardware crashes.
  bnc#436450.
* Fri Oct 24 2008 gregkh@suse.de
- clean up all fuzz in patches to get them to apply cleanly.
* Thu Oct 23 2008 gregkh@suse.de
- delete patches.arch/s390-01-03-cmm2-v2.patch as it touched core
  kernel code and was rejected from upstream.
  - patches.arch/s390-01-03-cmm2-v2.patch: Delete.
  - patches.arch/s390-01-03-cmm2-v2a.patch: Delete.
* Thu Oct 23 2008 gregkh@suse.de
- Update to version 3.4 of squashfs:
  - patches.suse/squashfs3.3-patch: Delete.
  - patches.suse/squashfs-patch-2.6.25: Delete.
  - patches.suse/squashfs-patch-2.6.27: Delete.
  - patches.suse/squashfs-3.4.patch: squashfs v3.4.
* Thu Oct 23 2008 jeffm@suse.de
- patches.fixes/block-sanitize-invalid-partition-table-entries:
  block: sanitize invalid partition table entries (bnc#371657).
* Thu Oct 23 2008 olh@suse.de
- add patches.arch/ppc-pseries_mem-limit-16g.patch
  Don't use a 16G page if beyond mem= limits (bnc#438111 - LTC49329)
* Thu Oct 23 2008 kkeil@suse.de
- Update x86 64bit config files to include WAN support (bnc#437692)
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/cell_edac.patch
  Fix incorrect edac_mode in csrow causing oops (bnc#437757 - LTC49143)
* Thu Oct 23 2008 olh@suse.de
- update patches.suse/nameif-track-rename.patch
  print also application and pid
* Thu Oct 23 2008 jkosina@suse.de
- patches.fixes/hid-rdesc-quirk-for-sony-vaio-VGX-TP1E.patch:
  HID: Fix Sony Vaio VGX report descriptor (bnc#437758).
* Thu Oct 23 2008 olh@suse.de
- add patches.drivers/ehca-rejecting-dynamic-mem-add-remove.patch
  reject dynamic memory add/remove (bnc#434651 - LTC48744)
* Thu Oct 23 2008 npiggin@suse.de
- Update config files.
* Thu Oct 23 2008 npiggin@suse.de
- patches.suse/x86-gb-linear-map.patch: Enable GB mapped linear
  KVA on x86 (bnc#437674).
- patches.xen/xen3-patch-2.6.26: merge
* Wed Oct 22 2008 gregkh@suse.de
- update to 2.6.27.3
  - lots of bugfixes
  - CVE-2008-3831 fix
* Wed Oct 22 2008 jeffm@suse.de
- scripts/vc: Handle unset $EDITOR
* Wed Oct 22 2008 jeffm@suse.de
- patches.suse/export-release_open_intent: Export
  release_open_intent for NFS branches with aufs.
* Wed Oct 22 2008 jdelvare@suse.de
- supported.conf: Mark the ibmaem and ibmpex hwmon drivers as
  supported by IBM.
- supported.conf: Mark the i5k_amb hwmon driver as supported.
* Wed Oct 22 2008 olh@suse.de
- add patches.drivers/ehea.patch
  Fix memory hotplug support (436447 - LTC48713)
* Wed Oct 22 2008 olh@suse.de
- add patches.arch/ppc-pseries_hugepage_pagetable_allocation.patch
  Cleanup hugepage pagetable allocation (bnc# 433503 - LTC48757)
* Wed Oct 22 2008 sassmann@suse.de
  Add PS3 audio patches:
- patches.arch/ppc-ps3-add-passthrough-support-for-non-audio-streams.patch:
  ps3: Add passthrough support for non-audio streams.
- patches.arch/ppc-ps3-add-ps3av-audio-mute-analog.patch:
  ps3: Add ps3av_audio_mute_analog().
- patches.arch/ppc-ps3-add-support-for-SPDIF-HDMI-passthrough.patch:
  ps3: Add support for SPDIF/HDMI passthrough.
* Tue Oct 21 2008 sdietrich@suse.de
- patches.rt/genirq-usb.patch: Make status_cache u32
- patches.rt/genirq-ohci1394.patch: Enable ohci1394 IRQ
  threading.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: rediff.
- patches.fixes/scsi-atomic-blk-timer-deletes: scsi: atomic blk
  timer deletes (LTC#48990, bnc#434105).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  rediff.
* Tue Oct 21 2008 hare@suse.de
- patches.fixes/scsi-inquiry-too-short-ratelimit: INQUIRY result
  too short (5) message flood (bnc#432535).
* Tue Oct 21 2008 npiggin@suse.de
- patches.suse/filp-slab-rcu: Delete.
* Tue Oct 21 2008 sdietrich@suse.de
  USB IRQ threading (experimental: guarded by genirq):
- patches.rt/genirq1-make-irqreturn_t-an-enum: genirq: make
  irqreturn_t an enum.
- patches.rt/genirq2-add-quick-check-handler.patch: genirq:
  add a quick check handler.
- patches.rt/genirq3-add-threaded-irq-handler-support: genirq:
  add threaded interrupt handler support.
- patches.rt/genirq4-add-helper-to-check-whether-irq-thread-should-run:
  genirq: add a helper to check whether the irqthread should run.
- patches.rt/genirq5-make-irq-threading-robust: genirq: make
  irq threading robust.
- patches.rt/genirq-usb.patch: genirq threading for ehci, ohci
  and uhci USB hosts..
- patches.rt/genirq-wlan-ng-compat.patch: Remove redundant,
  obsolete 2.4 compatibility code in wlan-ng.
  Ack:
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
* Mon Oct 20 2008 gregkh@suse.de
- patches.arch/x2APIC_PATCH_x86-mach_apicdef.h-need-to-include-before-smp.h.patch:
  x86: mach_apicdef.h need to include before smp.h.
  fixes build error on i386 pae kernels.
* Mon Oct 20 2008 bwalle@suse.de
- patches.suse/kdump-dump_after_notifier.patch:
  Add dump_after_notifier sysctl (bnc#436678).
* Mon Oct 20 2008 gregkh@suse.de
- scripts/wd-functions.sh: reverse git and cvs checks (check for
  cvs before git).  This solves the problem if you are using a cvs
  tree, yet it happens to live in a directory that way up the
  directory chain is in a git tree (like for people who keep portions
  of their $HOME in git).
* Mon Oct 20 2008 gregkh@suse.de
- Update config files: enable CONFIG_GENERICARCH and CONFIG_BIGSMP
  on i386-pae kernels. (bnc#428247)
* Mon Oct 20 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: fix the order of arguments in
  /proc/$pid/syscall on x86_64.
* Mon Oct 20 2008 bwalle@suse.de
- Update config files: Enable CONFIG_KVM_KMP for RT config, run
  oldconfig.
* Mon Oct 20 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff: Correct to reflect mainline
  state.
* Mon Oct 20 2008 hare@suse.de
- Update config files.
- patches.suse/kvm-as-kmp: Allow KVM to be built as KMP
  (FATE#303679).
* Mon Oct 20 2008 jjolly@suse.de
- patches.arch/s390-01-05-kmsg-v2.patch: Instrument the kernel
  components such that a kernel message catalog as well as related
  man pages can be automatically generated. (bnc#417300)
- patches.arch/s390-01-06-zfcp-cleanup-v2.patch: Update patch to
  fit on recent kmsg patch changes. (bnc#417550)
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  Update patch to fit on recent kmsg patch changes.
- config/s390/{default,s390}: Added CONFIG_KMSG_IDS=y
* Mon Oct 20 2008 bwalle@suse.de
- supported.conf: Mark 'crasher' as supported to avoid installing
  the "extra" package only for that module.
* Mon Oct 20 2008 olh@suse.de
- add patches.arch/ppc-pseries_16g-numa.patch
  fix crash with more 2 numa nodes and 16G hugepage (bnc#436452 - LTC48839)
* Sat Oct 18 2008 gregkh@suse.de
- Update to 2.6.27.2.
  - lots of bugfixes
* Sat Oct 18 2008 tonyj@suse.de
- patches.rt/fix-preempt-none.patch: Fix preempt-none build
  errors
* Fri Oct 17 2008 jeffm@suse.de
- patches.suse/SoN-20-netvm-reserve-inet.patch-fix: SoN: Fix
  initialization of ipv4_route_lock (bnc#435994).
* Fri Oct 17 2008 kkeil@suse.de
- patches.drivers/tg3-Add-57780-ASIC-revision.patch: tg3: Add
  57780 ASIC revision. (bnc#434147)
- patches.drivers/broadcom-Add-support-for-the-57780-integrated-PHY.patch:
  broadcom: Add support for the 57780 integrated PHY. (bnc#434147)
- patches.drivers/bnx2x-eeh.patch: bnx2x: EEH recovery fix.(bnc#433875)
* Fri Oct 17 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: Add the auto-generated (by mkdumprd)
  kdump initrd to %%ghost so that the file gets removed when
  uninstalling the kernel.
* Fri Oct 17 2008 mfasheh@suse.com
- ocfs2 ACL / security attribute support
  - patches.suse/ocfs2-Remove-unused-function-restore_extent_block.patch
  - patches.suse/ocfs2-Merge-transactions-during-xattr-set.patch
  - patches.suse/ocfs2-xattr.-ch-definition-cleanups.patch
  - patches.suse/ocfs2-Add-security-xattr-support-in-ocfs2.patch
  - patches.suse/ocfs2-Add-POSIX-ACL-support-in-ocfs2.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 fixes / updates from 2.6.28 merge window
  - patches.suse/ocfs2-xattr.c-Fix-a-bug-when-inserting-xattr.patch
  - patches.suse/ocfs2-Add-empty-bucket-support-in-xattr.patch
  - patches.suse/ocfs2-Remove-pointless.patch
  - patches.suse/ocfs2-make-la_debug_mutex-static.patch
  - patches.suse/ocfs2-Documentation-update-for-user_xattr-nouser_.patch
  - patches.suse/ocfs2-use-smaller-counters-in-ocfs2_remove_xattr_cl.patch
  - patches.suse/ocfs2-Don-t-check-for-NULL-before-brelse.patch
  - patches.suse/ocfs2-Uninline-ocfs2_xattr_name_hash.patch
  - patches.suse/ocfs2-Move-trusted-and-user-attribute-support-into.patch
  - patches.suse/ocfs2-Calculate-EA-hash-only-by-its-suffix.patch
  - patches.suse/ocfs2-Refactor-xattr-list-and-remove-ocfs2_xattr_ha.patch
  - patches.suse/ocfs2-Separate-out-sync-reads-from-ocfs2_read_block.patch
  - patches.suse/ocfs2-Require-an-inode-for-ocfs2_read_block-s.patch
  - patches.suse/ocfs2-Simplify-ocfs2_read_block.patch
  - patches.suse/ocfs2-Move-ocfs2_bread-into-dir.c.patch
  - patches.suse/ocfs2-Kill-the-last-naked-wait_on_buffer-for-cach.patch
  - patches.suse/ocfs2-Make-cached-block-reads-the-common-case.patch
  - patches.suse/ocfs2-fix-build-error.patch
* Thu Oct 16 2008 mfasheh@suse.com
- ocfs2 dynamic local alloc patches
* Thu Oct 16 2008 jslaby@suse.de
- patches.drivers/tpm-bcm0102-workaround.patch: tpm: work around
  bug in Broadcom BCM0102 chipset (bnc#425747 FATE304221).
- patches.drivers/tpm-correct-timeouts.patch: tpm: correct tpm
  timeouts to jiffies conversion (bnc#425747 FATE304221).
* Thu Oct 16 2008 ihno@suse.de
- added patches.arch/s390-01-03-cmm2-v2a.patch
  fix the sequence of initilisations.
* Thu Oct 16 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Make the kernel-$flavor-extra packages
  supplement kernel-$flavor on openSUSE and SLED so that those
  packages will get installed by default, using the product(...)
  dependencies provided by the *-release packages.
* Thu Oct 16 2008 tonyj@suse.de
- Previous checkin was totally broken wrt rt config files.
  Revert to previous versions and incorporate any changes from
  run_oldconfig. Sole changes to previous versions is to remove
  CONFIG_DYNAMIC_FTRACE from rt_debug configs which is consistent
  with change in 2.6.27.1
* Thu Oct 16 2008 gregkh@suse.de
- Update to 2.6.27.1
  - disables a problem config option, only affected the vanilla,
    debug, and rt kernel variants.
* Wed Oct 15 2008 olh@suse.de
- add patches.arch/ppc-pseries_pfn-mem-rm.patch
  fix hotplug memory remove (bnc#435181 - LTC48640)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/post.sh, rpm/postun.sh: run weak-modules, depmod and mkinitrd
  on older distros (bnc#435246)
  Fixed fix for bnc#435104 ("/boot/" was missing in some places)
* Wed Oct 15 2008 mmarek@suse.cz
- rpm/kernel-binary.spec.in: don't recommend the -extra subpackage
  (fate#303631)
- rpm/postun.sh, rpm/post.sh: remove the temporary workaround
* Wed Oct 15 2008 olh@suse.de
- drop patches.arch/ppc-iseries-remove-AVAILABLE_VETH.patch
  not needed anymore
* Wed Oct 15 2008 nfbrown@suse.de
- patches.fixes/nfs-file-cred-context-null: nfs_file_cred should
  cope if 'file' hasn't been opened properly (bnc#431785).
* Wed Oct 15 2008 tonyj@suse.de
- Update RT patches to latest .27 Windriver version (all patches)
- Disable patches.rt/swap-spinlock-fix.patch
- Guard filp-slab-rcu for RT
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-5710-to-nomux.patch: Input:
  Add Acer Aspire 5710 to nomux blacklist (bnc#404881).
* Tue Oct 14 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: Delete.
  in mainline now. done to the right tree.
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/postun.sh, rpm/post.sh: temporarily ignore errors from
  weak-modules2 --{add,remove}-kernel-modules until
  module-init-tools has rebuilt
* Tue Oct 14 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Delete.
  The patch is already upstream in 2.6.27
* Tue Oct 14 2008 jeffm@suse.de
- patches.suse/osync-error: Update position after check for -EIO
  (bnc#434910).
* Tue Oct 14 2008 npiggin@suse.de
- patches.suse/rlimit-memlock-64k.patch: Increase default
  RLIMIT_MEMLOCK to 64k (bnc#329675).
* Tue Oct 14 2008 sjayaraman@suse.de
- Update config files: CIFS_EXPERIMENTAL=y and CIFS_DFS_UPCALL=y
  (FATE#303758).
* Tue Oct 14 2008 jbeulich@novell.com
- patches.xen/xen-irq-probe: restrict IRQ probing (bnc#431572).
* Tue Oct 14 2008 ptesarik@suse.cz
- patches.trace/utrace-core: undo overzealous #ifdef's, which
  removed too much code in case UTRACE_CONFIG was unset.
* Tue Oct 14 2008 jbeulich@novell.com
- patches.fixes/reiserfs-commit-ids-unsigned-ints: Remove L suffix
  from constant compared against.
* Tue Oct 14 2008 olh@suse.de
- call bootloader_entry without leading /boot/ (bnc#435104)
* Tue Oct 14 2008 mmarek@suse.cz
- rpm/kernel-source.spec.in, rpm/source-post.sh, rpm/functions.sh:
  kill functions.sh, put the relink() function to source-post.sh
  directly
- rpm/postun.sh, rpm/pre.sh, rpm/preun.sh, rpm/post.sh,
  rpm/kernel-binary.spec.in: unify generation of the scriptlets,
  switch to the new weak-modules2 script
* Tue Oct 14 2008 olh@suse.de
- disable unused ide_platform driver
* Tue Oct 14 2008 jdelvare@suse.de
- supported.conf: Remove i2c-core and i2c-piix4 from base.
* Tue Oct 14 2008 gregkh@suse.de
- supported.conf: remove ide-core and ide-cdrom from base on request
  from Tejun.
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-add-pcc-acpi-driver.patch: Staging:
  add pcc-acpi driver.
- rpm/kernel-binary.spec.in: Obsoletes pcc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: it's pcc-acpi and it's not obsolete, yet.
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes at76_usb-kmp
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: obsoletes et131x-kmp, ivtv-kmp, and
  ppc-acpi-kmp
* Mon Oct 13 2008 gregkh@suse.de
- Update config files.
- patches.drivers/staging-at76_usb-wireless-driver.patch: staging:
  at76_usb wireless driver.
* Mon Oct 13 2008 gregkh@suse.de
- refresh all patches (except xen and rt) to apply cleanly
* Mon Oct 13 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: add Obsoletes: wlan-ng-kmp as the needed
  driver is now included from the staging tree.
* Mon Oct 13 2008 gregkh@suse.de
- put proper Patch-mainline: markings on staging patches
* Mon Oct 13 2008 gregkh@suse.de
- patches.drivers/staging-workaround-build-system-bug.patch:
  Staging: workaround build system bug.
* Mon Oct 13 2008 aj@suse.de
- rpm/post.sh: Fix typo that breaks script.
* Mon Oct 13 2008 gregkh@suse.de
- disabled staging drivers for -rt trees
* Mon Oct 13 2008 gregkh@suse.de
- Add -staging tree:
  - added TAINT_CRAP flag
  - added eth131x network driver
  - added slicoss network driver
  - added sgx network driver
  - added me4000 data collection driver
  - added go7007 video capture driver
  - added USB/IP host and client driver
  - added w35und wifi network driver
  - added prism2 usb wifi network driver
  - added echo cancellation driver
- only enabled these on x86 platforms
* Mon Oct 13 2008 jjolly@suse.de
- patches.arch/s390-02-01-xpram.patch: xpram: per device block
  request queues (bnc#434333,LTC#49030)
* Mon Oct 13 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Updated supported.conf checker to
  eliminate false positives.
* Mon Oct 13 2008 sjayaraman@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Fix a compiler warning.
* Mon Oct 13 2008 jbenc@suse.cz
- supported.conf: mark drivers/net/wireless/b43* and
  driver/net/wireless/rt2x00/* as unsupported because of known
  problems we cannot fix.
* Mon Oct 13 2008 oneukum@suse.de
- patches.fixes/wdm_autoload.diff:  add MODULE_DEVICE_TABLE to
  cdc-wdm driver to compute a proper alias (bnc#433817).
* Mon Oct 13 2008 ptesarik@suse.cz
- Update config files (CONFIG_UTRACE for rt flavours).
* Mon Oct 13 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.27-rc3: Fix uninitialized data issue.
* Mon Oct 13 2008 ptesarik@suse.cz
- patches.trace/utrace-core: utrace core (FATE#304321).
  CONFIG_UTRACE enabled only for kernel-trace.
- Update config files.
* Mon Oct 13 2008 aj@suse.de
- patches.suse/SoN-14-mm-reserve.patch: Add cast to fix compiler warning.
* Mon Oct 13 2008 sjayaraman@suse.de
- Remove another stale swap-over-nfs patch.
  patches.suse/SoN-29-nfs-alloc-recursions.patch: Delete.
* Fri Oct 10 2008 jeffm@suse.de
- Updated to 2.6.27 final.
* Fri Oct 10 2008 tonyj@suse.de
- Update config files
- Fix conflicts, remove most -RT guards added in recent RT update
  patches.rt/apic-dumpstack.patch: refresh
  patches.rt/preempt-irqs-core.patch: refresh
  patches.rt/print-might-sleep-hack.patch: refresh
  patches.rt/partrevert-lttng-instrumentation-irq.patch: add
  patches.rt/partreadd-lttng-instrumentation-irq.patch: add
- Drop unused RT patches
  patches.rt/mips-change-raw-spinlock-type.patch
  patches.rt/nmi-watchdog-disable.patch
  patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch
  patches.rt/lockstat-fix-contention-points.patch
  patches.rt/sched-cpupri-priocount.patch
  patches.rt/nmi-watchdog-fix-1.patch
  patches.rt/cache_pci_find_capability.patch
  patches.rt/fix-emac-locking-2.6.16.patch
  patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch
  patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch
  patches.rt/tie-pi-into-task.patch
  patches.rt/idle2-fix.patch
  patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch
  patches.rt/rtmutex-initialize-waiters.patch
  patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch
  patches.rt/add-generalized-pi-interface.patch
  patches.rt/warn-on-rt-scatterlist.patch
  patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch
  patches.rt/trace-eip2ip.patch
  patches.rt/sched_rt-fixup.patch
  patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch
  patches.rt/trace_hist-latediv.patch
  patches.rt/sched-cpupri-hotplug-support.patch
  patches.rt/idle-fix.patch
  patches.rt/ftrace-fix-get-kprobe-wreckage.patch
  patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch
  patches.rt/ftrace-function-record-nop.patch
  patches.rt/ftrace-document-update1.patch
  patches.rt/26-rt1-chirag.patch
  patches.rt/trace_hist-divzero.patch
  patches.rt/latency-tracing-ppc.patch
  patches.rt/rtmutex-defer-pi-until-sleepy.patch
  patches.rt/pmtmr-override.patch
  patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
  patches.rt/rtmutex-use-runtime-init.patch
  patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch
  patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch
  patches.rt/lockdep-lock_set_subclass.patch
  patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch
  patches.rt/rt-mutex-irq-flags-checking.patch
  patches.rt/ftrace-upstream.patch
  patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch
  patches.rt/ftrace-preempt-trace-check.patch
  patches.rt/rtmutex-add_readers.patch
  patches.rt/lockdep-avoid-fork-waring.patch
  patches.rt/arm-omap-02.patch
  patches.rt/fix-acpi-build-weirdness.patch
  patches.rt/cycles-to-ns-trace-fix.patch
  patches.rt/ftrace-compile-fixes.patch
  patches.rt/ftrace-wakeup-rawspinlock.patch
  patches.rt/rtmutex-convert-to-libpi.patch
  patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch
  patches.rt/ftrace-trace-sched.patch
* Fri Oct 10 2008 mfasheh@suse.com
- supported.conf: mark kernel/fs/gfs2 unsupported
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-cs5530 unsupported due
  to sb16 dependancy issues
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/account-reserved-pages: Delete.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Updated to build with
  CONFIG_MODULES=n.
* Thu Oct  9 2008 jeffm@suse.de
- Updated to 2.6.27-rc9, but still disabled:
  - patches.suse/silent-stack-overflow
  - patches.xen/xen3-silent-stack-overflow
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: thermal_sys, not thermal_sysfs.
* Thu Oct  9 2008 jeffm@suse.de
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Updated against
  2.6.27-rc9.
* Thu Oct  9 2008 jdelvare@suse.de
- supported.conf: Fix the name of the thermal_sys module.
- config/x86_64/rt_timing: THERMAL_HWMON is a boolean.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/netfilter-ipv4options: Updated to 2.6.27-rc9,
  enabled, and marked supported (bnc#131728 - FATE#182).
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/serial8250_console_write-ier: Delete.
- patches.fixes/fix-serial-8250-UART_BUG_TXEN-test: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark kernel/sound/pci/snd-als4000 unsupported due
  to dependancy on isa sb16 driver.
* Thu Oct  9 2008 jeffm@suse.de
- patches.fixes/dont-writeback-fd-bdev-inodes.patch: Delete.
- patches.arch/s390-ccwgroup-attribute-ignore-newline: Delete.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark drivers/net/wan/hdlc_x25 unsupported due to
  symbol dependancy tree.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/osync-error: make sure O_SYNC writes properly
  return -EIO (bnc#58622).
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-vmcoreinfo.diff:
  Add additional symbols to /sys/kernel/vmcoreinfo data for
  ppc(64).
* Thu Oct  9 2008 trenn@suse.de
- patches.xen/xen-x2APIC_build_fix.patch: Adopt Xen to x2APIC
  patchset (fate#303984 and fate#303948).
- Update config files.
  Disable interrupt remapping for Xen -> this is something for
  the hypervisor.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y in vanilla configs.
* Thu Oct  9 2008 jeffm@suse.de
- Update config files: THERMAL_HWMON=y; is boolean and enables
  functionality in the already modular THERMAL module.
* Thu Oct  9 2008 jeffm@suse.de
- patches.suse/supported-flag-sysfs: Export supported status
  via sysfs.
* Thu Oct  9 2008 carnold@novell.com
- Update config files.  Disabled the in kernel KVM modules in
  preference to using them as KMPs.  See also brogers@novell.com
* Thu Oct  9 2008 jeffm@suse.de
- Added a -iu|--ignore-unsupported-deps option to allow builds
  with supported.conf problems.
* Thu Oct  9 2008 jdelvare@suse.de
- config/i386/*, config/x86_64/*, config/ia64/*, supported.conf:
  Build hwmon and thermal as modules.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark hdlc_ppp unsupported as syncppp is unsupported.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ubifs as unsupported as it relies on mtd/ubi/
* Thu Oct  9 2008 bwalle@suse.de
- patches.arch/ppc-dynamic-reconfiguration.diff:
  powerpc: Add support for dynamic reconfiguration memory in
  kexec/kdump kernels (bnc#431492).
* Thu Oct  9 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: package kernel-xen has dependency to
  xen (bnc#431215).
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark TPM drivers a supported, as IBM and others
  rely on them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: fix a dependancy link with the isa sb driver with
  unsupported symbols
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark ieee80122 modules as supported, as other
  supported modules need them.
* Thu Oct  9 2008 gregkh@suse.de
- supported.conf: mark all of the mtd drivers as unsupported to fix
  the build errors (and to reflect our policy here.)
* Thu Oct  9 2008 bwalle@suse.de
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC to 0 (bnc#429910).
* Thu Oct  9 2008 jdelvare@suse.de
- Don't build the tps65010 driver, it's only used on OMAP at the
  moment.
* Thu Oct  9 2008 mmarek@suse.cz
- rpm/built-in-where: make it work with a four-column
  Modules.symvers (bnc#433533)
* Thu Oct  9 2008 bwalle@suse.de
- Update KDB to v4.4-2.6.27-rc8.
* Thu Oct  9 2008 olh@suse.de
- disable legacy iseries (bnc#433685 - LTC48946)
* Thu Oct  9 2008 olh@suse.de
- enable battery_pmu on ppc32
* Thu Oct  9 2008 trenn@suse.de
- supported.conf:
  Marked these unsupported:
  cpufreq-nforce2
  e_powersaver
  gx-suspmod
  longhaul
  longrun
  p4-clockmod
  powernow-k6
  powernow-k7
  speedstep-ich
  speedstep-smi
  Even Via CPUs are exporting cpu freq steps via ACPI and work fine
  with acpi-cpufreq. No need to support the old, some are known
  broken, drivers.
* Thu Oct  9 2008 olh@suse.de
- add patches.suse/md-raid-metadata-PAGE_SIZE.patch
  ignore PAGE_SIZE in md metadata, for raid0 (bnc#429490)
* Thu Oct  9 2008 teheo@suse.de
- patches.xen/xen3-auto-common.diff: minor patch apply fix after
  libata-prefer-over-ide.
* Wed Oct  8 2008 teheo@suse.de
- patches.drivers/libata-prefer-over-ide: libata: prefer libata
  drivers over ide ones (bnc#433105).
* Wed Oct  8 2008 carnold@novell.com
- patches.xen/xen-op-packet: add support for new operation type
  BLKIF_OP_PACKET (fate#300964).
- patches.xen/xen-blkfront-cdrom: implement forwarding of CD-ROM
  specific commands (fate#300964).
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: major update.  Lots of new drivers added as this
  file hadn't been updated for a lot of kernel revisions.
  This should close out a lot of bugs about "unsupported" modules,
  like bnc#433541.
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: sorted the file correctly so we can start determining
  what we are not supporting easier.
* Wed Oct  8 2008 jeffm@suse.de
- Updated -rt for context against -rc9 and the x2APIC patches:
  - patches.rt/new-softirq-code.patch
  - patches.rt/preempt-irqs-core.patch
  - patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch
  - CONFIG_INTR_REMAP=n for now
  - patches.rt/preempt-softirqs-core.patch
  - patches.rt/rt-slab-new.patch
  - patches.rt/slab-irq-nopreempt-fix.patch
  - Update config files: NFS_SWAP=n
* Wed Oct  8 2008 trenn@suse.de
  x2APIC and interrupt remapping enablement.
  Xen needs further work to build again.
  Commit ids are from x86 tip git tree:
- patches.arch/x2APIC_fix_section_mismatch.patch: Fix several
  section mismatches (none).
- patches.arch/x2APIC_PATCH_01_0f4896665a02b465ddca59a560983b24ec28c64b:
  dmar: fix dmar_parse_dev() devices_cnt error condition check
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_01_of_41_e61d98d8dad0048619bb138b0ff996422ffae53b:
  x64, x2apic/intr-remap: Intel vt-d, IOMMU code reorganization
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_228324076234ca6a8cd34be89be78022773459f1:
  dmar: use list_for_each_entry_safe() in dmar_dev_scope_init()
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_02_of_41_c42d9f32443397aed2d37d37df161392e6a5862f:
  x64, x2apic/intr-remap: fix the need for sequential array
  allocation of iommus (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_03_3f1fdb3673bb5638fa94186dc391cbc4879590bc:
  dmar: initialize the return value in dmar_parse_dev() (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_03_of_41_1886e8a90a580f3ad343f2065c84c1b9e1dac9ef:
  x64, x2apic/intr-remap: code re-structuring, to be used by both
  DMA and Interrupt remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_f12c73e7fa7ebf9ad6defee2c4fb2664e743e970:
  dmar: fix using early fixmap mapping for DMAR table parsing
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_04_of_41_aaa9d1dd63bf89b62f4ea9f46de376ab1a3fbc6c:
  x64, x2apic/intr-remap: use CONFIG_DMAR for DMA-remapping
  specific code (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_05_7be42004065ce4df193aeef5befd26805267d0d9:
  x86, lguest: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_caf43bf7c6a55e89b6df5179df434d67e24aa32e:
  x86, xen: fix apic_ops build on UP (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_06_of_41_ad3ad3f6a2caebf56869b83b69e23eb9fa5e0ab6:
  x64, x2apic/intr-remap: parse ioapic scope under vt-d structures
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_511d9d34183662aada3890883e860b151d707e22:
  x86: apic_ops for lguest (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_07_of_41_cf1337f0447e5be8e66daa944f0ea3bcac2b6179:
  x64, x2apic/intr-remap: move IOMMU_WAIT_OP() macro to
  intel-iommu.h (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_08_of_41_fe962e90cb17a8426e144dee970e77ed789d98ee:
  x64, x2apic/intr-remap: Queued invalidation infrastructure
  (part of VT-d) (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_09_94a8c3c2437c8946f1b6c8e0b2c560a7db8ed3c6:
  x86: let 32bit use apic_ops too - fix (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_09_of_41_2ae21010694e56461a63bfc80e960090ce0a5ed9:
  x64, x2apic/intr-remap: Interrupt remapping infrastructure
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_10_of_41_b6fcb33ad6c05f152a672f7c96c1fab006527b80:
  x64, x2apic/intr-remap: routines managing Interrupt remapping
  table entries. (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_11_of_41_72b1e22dfcad1daca6906148fd956ffe404bb0bc:
  x64, x2apic/intr-remap: generic irq migration support from
  process context (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_12_of_41_d94d93ca5cc36cd78c532def62772c98fe8ba5d7:
  x64, x2apic/intr-remap: 8259 specific mask/unmask routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_13_of_41_4dc2f96cacd1e74c688f94348a3bfd0a980817d5:
  x64, x2apic/intr-remap: ioapic routines which deal with initial
  io-apic RTE setup (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_14_of_41_0c81c746f9bdbfaafe64322d540c8b7b59c27314:
  x64, x2apic/intr-remap: introduce read_apic_id() to genapic
  routines (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_15_of_41_2d7a66d02e11af9ab8e16c76d22767e622b4e3d7:
  x64, x2apic/intr-remap: Interrupt-remapping and x2apic support,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_16_of_41_1b374e4d6f8b3eb2fcd034fcc24ea8ba1dfde7aa:
  x64, x2apic/intr-remap: basic apic ops support (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_17_of_41_32e1d0a0651004f5fe47f85a2a5c725ad579a90c:
  x64, x2apic/intr-remap: cpuid bits for x2apic feature (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_18_of_41_1cb11583a6c4ceda7426eb36f7bf0419da8dfbc2:
  x64, x2apic/intr-remap: disable DMA-remapping if
  Interrupt-remapping is detected (temporary quirk) (fate #303948
  and fate #303984).
- patches.arch/x2APIC_PATCH_19_of_41_13c88fb58d0112d47f7839f24a755715c6218822:
  x64, x2apic/intr-remap: x2apic ops for x2apic mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_20_of_41_cff73a6ffaed726780b001937d2a42efde553922:
  x64, x2apic/intr-remap: introcude self IPI to genapic routines
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_21_of_41_12a67cf6851871ca8df42025c94f140c303d0f7f:
  x64, x2apic/intr-remap: x2apic cluster mode support (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_22_of_41_5c520a6724e912a7e6153b7597192edad6752750:
  x64, x2apic/intr-remap: setup init_apic_ldr for UV (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_23_of_41_89027d35aa5b8f45ce0f7fa0911db85b46563da0:
  x64, x2apic/intr-remap: IO-APIC support for interrupt-remapping
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_24_of_41_75c46fa61bc5b4ccd20a168ff325c58771248fcd:
  x64, x2apic/intr-remap: MSI and MSI-X support for interrupt
  remapping infrastructure (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_1_of_41_4c9961d56ec20c27ec5d02e49fd7427748312741:
  x86: make read_apic_id return final apicid (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_25_2_of_41_c535b6a1a685eb23f96e2c221777d6c1e05080d5:
  x86: let 32bit use apic_ops too (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_25_of_41_6e1cb38a2aef7680975e71f23de187859ee8b158:
  x64, x2apic/intr-remap: add x2apic support, including enabling
  interrupt-remapping (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_26_of_41_2d9579a124d746a3e0e0ba45e57d80800ee80807:
  x64, x2apic/intr-remap: support for x2apic physical mode support
  (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_27_of_41_9fa8c481b55e80edd8c637573f87853bb6b600f5:
  x64, x2apic/intr-remap: introduce CONFIG_INTR_REMAP (fate
  [#303948] and fate #303984).
- patches.arch/x2APIC_PATCH_28_1_of_41_f910a9dc7c865896815e2a95fe33363e9522f277:
  x86: make 64bit have get_apic_id (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_29_of_41_277d1f5846d84e16760131a93b7a67ebfa8eded4:
  x2apic: uninline uv_init_apic_ldr() (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_30_of_41_ad66dd340f561bdde2285992314d9e4fd9b6191e:
  x2apic: xen64 paravirt basic apic ops (fate #303948 and fate
  [#303984]).
- patches.arch/x2APIC_PATCH_34_of_41_1b9b89e7f163336ad84200b66a17284dbf26aced:
  x86: add apic probe for genapic 64bit, v2 (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_35_of_41_d25ae38b7e005af03843833bbd811ffe8c5f8cb4:
  x86: add apic probe for genapic 64bit - fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_36_of_41_276605dddb74cbf1b77696e32c4a947e42cec52d:
  x2apic: use x2apic id reported by cpuid during topology
  discovery (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_40_of_41_bbb65d2d365efe9951290e61678dcf81ec60add4:
  x86: use cpuid vector 0xb when available for detecting cpu
  topology (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_41_of_41_11c231a962c740b3216eb6565149ae5a7944cba7:
  x86: use x2apic id reported by cpuid during topology discovery,
  fix (fate #303948 and fate #303984).
- patches.arch/x2APIC_PATCH_42_of_41_77322deb4bc676a5ee645444e7ed1a89f854473d:
  x86: io-apic - interrupt remapping fix (fate #303948 and
  fate #303984).
- patches.arch/x2APIC_PATCH_43_of_41_2c72d93f6593f386f5760ca8e7ac7026948c31d7:
  x2apic: fix reserved APIC register accesses in
  print_local_APIC() (fate #303948 and fate #303984).
- patches.drivers/sgi-uv-led: SGI UV: Provide a LED driver and
  some System Activity Indicators (FATE#304268).
- patches.suse/kdb-x86: kdb-v4.4-2.6.27-rc5-x86-1 (FATE#303971).
- patches.xen/xen-x86-no-lapic: Disallow all accesses to the
  local APIC page (191115).
- patches.xen/xen3-auto-arch-x86.diff: xen3 arch-x86.
- patches.xen/xen3-patch-2.6.19: Linux 2.6.19.
- patches.xen/xen3-patch-2.6.26: 2.6.26.
- Update config files:
  Added CONFIG_INTR_REMAP to all x86_64 flavors
* Wed Oct  8 2008 gregkh@suse.de
- rpm/kernel-binary.spec.in: added Obsoletes: atl2-kmp as this
  driver is now included in the kernel package.
* Wed Oct  8 2008 jjolly@suse.de
- patches.arch/s390-01-04-fcpperf-4-v2.patch: Update for fcpperf-4
  patch to bring in sync with upstream version. (bnc#417243)
- patches.arch/s390-01-04-fcpperf-4.patch: Removed, replaced by
  updated patch
* Wed Oct  8 2008 sjayaraman@suse.de
- Remove stale swap-over-nfs patches.
- patches.suse/SoN-05-page_alloc-reserve.patch: Delete.
- patches.suse/SoN-06-reserve-slub.patch: Delete.
* Wed Oct  8 2008 agruen@suse.de
- No uml patches left, so remove the code referring to
  patches.uml.tar.bz2.
* Wed Oct  8 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/fix-up-comment.patch: RT: Remove comment that is
  no longer true.
- patches.rt/check-for-migration-during-push.patch: RT: fix
  push_rt_task() to handle dequeue_pushable properly.
* Wed Oct  8 2008 agruen@suse.de
- Add DMAPI patches (supported by SGI).
- Update config files: enable DMAPI.
* Wed Oct  8 2008 sjayaraman@suse.de
- Doh, forgot to remove stale files from cvs
- Update config files NFS_SWAP=y.
* Wed Oct  8 2008 sjayaraman@suse.de
- Refreshed to -v19 of swap over nfs patchset.
  o netns, ipv6 fixes
  o patch ordering changes due to additional patches
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict.
* Wed Oct  8 2008 bwalle@suse.de
- Enable CONFIG_MFD_SM501_GPIO also for RT.
* Wed Oct  8 2008 bwalle@suse.de
- Refresh patches.rt/mips-remove-duplicate-kconfig.patch.
* Wed Oct  8 2008 bwalle@suse.de
- Update to 2.6.27-rc9.
- Enable new configuration option CONFIG_MFD_SM501_GPIO.
- Drop following patches (mainline):
  o patches.suse/e1000e_debug_contention_on_NVM_SWFLAG
  o patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context
  o patches.suse/e1000e_drop_stats_lock, e1000e_fix_lockdep_issues
  o patches.suse/e1000e_mmap_range_chk,
  o patches.suse/e1000e_reset_swflag_after_resetting_hardware
  o patches.suse/e1000e_update_versione1000e_write_protect_ichx_nvm
- Adjust/refresh following patches:
  o patches.arch/s390-01-03-cmm2-v2.patch
  o patches.drivers/e1000e_add_82574L.patch
  o patches.drivers/e1000e_add_ICH9_BM.patch
  o patches.drivers/e1000e_add_LOM_devices.patch
  o patches.suse/e1000e_allow_bad_checksum
  o patches.suse/e1000e_call_dump_eeprom
  o patches.suse/e1000e_ioremap_sanity_check
  o patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory
* Wed Oct  8 2008 mmarek@suse.cz
- rpm/kernel-module-subpackage: switch KMPs to the new
  weak-modules2 script, which handles running depmod and mkinitrd
* Wed Oct  8 2008 hare@suse.de
- supported.conf: mark igb as supported.
* Wed Oct  8 2008 agruen@suse.de
- kernel-source-rt must not provide a kernel-source symbol: this
  would break dependencies.
* Wed Oct  8 2008 olh@suse.de
- update patches.suse/ppc-no-LDFLAGS_MODULE.patch
  use suggested patch from kernel.org bugzilla
* Wed Oct  8 2008 olh@suse.de
- add patches.arch/ppc-pseries_remove_lmb-PAGE_SHIFTT.patch
  fix oops in pseries_remove_lmb with 64k PAGE_SIZE (bnc#431380)
* Wed Oct  8 2008 gregkh@suse.de
- supported.conf: mark efivars.ko as supported
* Wed Oct  8 2008 gregkh@suse.de
- enable yealink driver (bnc#432841)
* Tue Oct  7 2008 oneukum@suse.de
- patches.fixes/ehci_sched.diff: fix hang in disable_periodic
  (bnc#403346).
* Tue Oct  7 2008 trenn@suse.de
- patches.fixes/fujisu_laptop_fix_section_mismatch.patch: Fix
  section mismatch in fujitsu_laptop driver (none).
* Tue Oct  7 2008 hare@suse.de
- patches.fixes/sd-needs-updating: Driver 'sd' needs updating
  (bnc#406656).
* Tue Oct  7 2008 agruen@suse.de
- rpm/post.sh: Catch mkinitrd error code indicating missing
  required modules. Only add a bootloader entry if an initrd
  could be created, but re-add the bootloader entry even if
  the initrd already existed before (bnc#431703).
* Tue Oct  7 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.4-update: Update lpfc to 8.2.8.4
  (bnc#420767).
- patches.drivers/qla4xxx-sles11-update: qla4xxx driver fixes
  for SLES11 (bnc#432976).
* Tue Oct  7 2008 olh@suse.de
- mark legacy iseries storage as supported
* Mon Oct  6 2008 jdelvare@suse.de
- supported.conf: Add the ad7414, adcxx and ibmaem hwmon drivers as
  unsupported.
* Mon Oct  6 2008 jdelvare@suse.de
- config/ia64/*: Don't built i2c-amd756-s4882 and i2c-nforce2-s4985
  on ia64, these are motherboard-specific drivers for x86_64
  motherboards.
- config/powerpc/*: Don't built i2c-isch on powerpc, it is a driver
  for x86 hardware.
- config/*: Don't built i2c-simtec on i386, x86_64 and ia64, there
  is no Simtec hardware based on these architectures.
* Sun Oct  5 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: Fix the logic splitting up the symbols
  defined in vmlinux by subsystem. (Actually, per directory, under
  the assumption that there is enough of a correlation).
* Sun Oct  5 2008 greg@suse.de
- supported.conf: add ohci-hcd to base.  Fix up other USB drivers
  (USB network drivers had moved, others were missing)
* Sun Oct  5 2008 gregkh@suse.de
- patches.drivers/atl2-add-atl2-network-driver.patch: atl2:
  add atl2 network driver.
- Update config files (even the rt ones).
* Fri Oct  3 2008 jkosina@suse.de
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: fix bogus
  WARN_ON() condition, as per upstream commit 95b866d5a
* Fri Oct  3 2008 olh@suse.de
- mark ibmvfc as supported (bnc#417555 - fate#304178 - LTC46935)
* Fri Oct  3 2008 olh@suse.de
- compile windfarm_pm121 into the kernel
* Fri Oct  3 2008 jeffm@suse.de
- doc/README.SUSE, scripts/tar-up_and_run_mbuild.sh,
  scripts/run_oldconfig.sh,
  scripts/sequence-patch.sh: Eliminated defconfig.$flavor
* Fri Oct  3 2008 olh@suse.de
- mark Cell drivers as supported
* Fri Oct  3 2008 tonyj@suse.de
- Update config files
  rt configs not updated for per-module-dynamic-debug-messages.patch
* Fri Oct  3 2008 gregkh@suse.de
- change patches.suse/supported-flag to show which modules are
  unsupported and externally supported in oops messages.  Also change
  the taint values as the documentation was totally wrong.
* Fri Oct  3 2008 tonyj@suse.de
- Reenable RT debug builds, compile tested only
- Update config files
- Fix tracer issues
  patches.rt/event-trace-hrtimer-trace.patch
  patches.rt/trace-events-handle-syscalls.patch
  patches.rt/trace-ktime-scalar.patch
  patches.rt/tracer-event-trace.patch
- patches.rt/kdb-disable-ist.patch: Disable stackfault and debug stacks for kdb
- patches.rt/kdb-rtmisc.patch: Misc KDB fixes for RT
- patches.rt/novfs-rtmisc.patch: Misc NOVFS fixes for RT
* Fri Oct  3 2008 gregkh@suse.de
- patches.drivers/driver-core-basic-infrastructure-for-per-module-dynamic-debug-messages.patch:
  driver core: basic infrastructure for per-module dynamic
  debug messages.
- refresh patches.trace/tracepoints.patch: Kernel Tracepoints.
- Update config files.
* Thu Oct  2 2008 agruen@suse.de
- Introduce kernel-source-rt and kernel-syms-rt packages, needed
  for building real-time KMPs.
* Thu Oct  2 2008 schwab@suse.de
- Don't clean <asm/nr-irqs.h>.
* Thu Oct  2 2008 jblunck@suse.de
- supported.conf: add qeth_l2 and qeth_l3 as supported modules
* Thu Oct  2 2008 jkosina@suse.de
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: update to
  the latest version of the patch as provided by Intel
* Thu Oct  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc8 and c/s 684.
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Replace by ...
- patches.xen/xen3-e1000e_Export_set_memory_ro-rw: this, and put
  in proper place in series.conf.
- patches.xen/xen-rwlocks-enable-interrupts: Replace by ...
- patches.xen/xen3-rwlocks-enable-interrupts: this, and put in
  proper place in series.conf.
* Wed Oct  1 2008 jeffm@suse.de
- scripts/sequence-patch.sh
- scripts/run_oldconfig.sh: x86 defconfigs go under arch/x86.
* Wed Oct  1 2008 olh@suse.de
- enable msi on ppc64 (bnc#430937)
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Remove /lib/modules from file list
  as it's already in filesystem
* Wed Oct  1 2008 tiwai@suse.de
- rpm/kernel-source.spec.in: Fixed missing endif
* Wed Oct  1 2008 tiwai@suse.de
- Update config files: make floppy module on i386, too
* Wed Oct  1 2008 tiwai@suse.de
- supported.conf: update sound drivers
* Wed Oct  1 2008 tonyj@suse.de
- update RT to 2.6.27-rc8
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
* Wed Oct  1 2008 agruen@suse.de
- Update -rt config files.
* Tue Sep 30 2008 gregkh@suse.de
- update to 2.6.27-rc8
  - obsoletes these patches:
  - patches.arch/ia64-kdump_proc_iomem.diff
  - patches.drivers/qla2xxx-defer-risc-interrupt-enablement
  - patches.fixes/usb-hcd-interrupt-shared.patch
* Tue Sep 30 2008 jkosina@suse.de
- additional patches to track down and fix e1000e NVM corruption
- patches.suse/e1000e_ioremap_sanity_check: ioremap sanity check
  to catch mapping requests exceeding the BAR sizes (bnc#425480).
- patches.suse/e1000e_write_protect_ichx_nvm: e1000e: write
  protect ICHx NVM to prevent malicious write/erase (bnc#425480).
* Tue Sep 30 2008 hare@suse.de
- Update config files.
* Tue Sep 30 2008 hare@suse.de
- patches.drivers/mpt-fusion-4.00.43.00-update: Update MPT Fusion
  driver to v4.00.43.00 (bnc#425660).
- patches.kernel.org/gdth-section-conflict: Add missing annotations.
* Tue Sep 30 2008 sassmann@suse.de
- Update config files: Disabled everything unnecessary in
  ps3 config file
* Tue Sep 30 2008 olh@suse.de
- disable ninja32 and ns87415 pata drivers on ppc64
* Tue Sep 30 2008 sdietrich@suse.de
- config.conf: enable rt for i386/x86_64
- Update config files: Preliminary sync with default and debug configs.
- config/x86_64/rt_timing: Delete.
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.27-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.27-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.27-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.27-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.27-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.27-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.27-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.27-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.27-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.27-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.27-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.27-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.27-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.27-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.27-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.27-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.27-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.27-RT
  event-tracer: add clockevent trace.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.27-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.27-RT
  Fix a previously reverted "fix".
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.27-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.27-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.27-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.27-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.27-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.27-RT
  floppy: suspend/resume fix.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT rt: remove call to stop tracer.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: document updates.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.27-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: define function trace nop.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.27-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: only trace preempt off with
  preempt tracer.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.27-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.27-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.27-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: trace sched.c.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.27-RT
  ftrace: avoid lockdep recursion.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: user raw spin lock for wakeup
  function trace.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.27-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.27-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.27-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.27-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.27-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.27-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.27-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.27-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.27-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.27-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.27-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.27-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.27-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.27-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.27-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.27-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT lockdep: lock_set_subclass - reset a held
  lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.27-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.27-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.27-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.27-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.27-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.27-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.27-RT
  mapping_nrpages-fix.patch.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.27-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT RT: change from raw_spinlock_t to
  __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.27-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.27-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.27-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.27-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.27-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.27-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.27-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.27-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.27-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.27-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.27-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.27-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.27-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.27-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.27-RT
  nfs: fix missing preemption check.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT x86_64: do not enable the NMI watchdog
  by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.27-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT local_bh_enable() is safe for
  irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.27-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.27-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.27-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.27-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.27-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.27-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.27-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.27-RT.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT pmtmr: allow command line override of
  ioport.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.27-RT
  powerpc: ftrace stop on crash.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.27-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.27-RT
  don't trace early init functions for ppc32.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.27-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.27-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.27-RT.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.27-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.27-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.27-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.27-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.27-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.27-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.27-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.27-RT
  lockdep: add +1 to radix tree array.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.27-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.27-RT
  radix-tree: optimistic locking.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.27-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.27-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.27-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.27-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.27-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.27-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.27-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.27-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.27-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.27-RT
  rt: plist_head_splice.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.27-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.27-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.27-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.27-RT
  rtmutex-debug-fix.patch.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.27-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.27-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.27-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.27-RT
  rwlocks multi downgrade write.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.27-RT.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.27-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.27-RT
  rwlock: rwlock torture test.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.27-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.27-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.27-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.27-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.27-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.27-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.27-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.27-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.27-RT
  sched-fix-dequeued-race.patch.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.27-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.27-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.27-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.27-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.27-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.27-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.27-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.27-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.27-RT
  rt: dont disable irqs in usb.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.27-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.27-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.27-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT Re: 2.6.25.4-rt4.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.27-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.27-RT.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.27-RT
  ftrace: print ktime values in readable form.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.27-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.27-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.27-RT.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT remove warn on for scatterlist in preempt
  rt.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.27-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.27-RT.
- patches.rt/26-rt1-chirag.patch: Linux-RT 2.6.27-RT
  This patch should solve some of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: Linux-RT
  2.6.27-RT
  add generalized priority-inheritance interface.
- patches.rt/rtmutex-add_readers.patch: Linux-RT 2.6.27-RT
  RT: wrap the rt_rwlock "add reader" logic.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: Linux-RT
  2.6.27-RT
  rtmutex: pi-boost locks as late as possible.
- patches.rt/rtmutex-initialize-waiters.patch: Linux-RT 2.6.27-RT
  rtmutex: formally initialize the rt_mutex_waiters.
- patches.rt/rtmutex-use-runtime-init.patch: Linux-RT 2.6.27-RT
  rtmutex: use runtime init for rtmutexes.
- patches.rt/tie-pi-into-task.patch: Linux-RT 2.6.27-RT
  sched: add the basic PI infrastructure to the task_struct.
- patches.rt/rtmutex-convert-to-libpi.patch: Linux-RT 2.6.27-RT
  rtmutex: convert rtmutexes to fully use the PI library.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  Linux-RT 2.6.27-RT
  ftrace: fix elevated preempt_count in wakeup-tracer.
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  Linux-RT 2.6.27-RT
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.27-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.27-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.27-RT
  Linux-RT 2.6.26-RT.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.27-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.27-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.27-RT.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.27-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.27-RT.
- patches.rt/bit-spinlocks-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/compat_rwsem-fix-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/drivers_base_mutex.patch: Linux-RT 2.6.27-RT.
- patches.rt/fix-net-bug-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-ppc-define-mcount.patch: Linux-RT 2.6.27-RT.
- patches.rt/ftrace-report-failure.patch: Linux-RT 2.6.27-RT
  ftrace: warn on failure to disable mcount callers.
- patches.rt/ftrace-upstream-temp.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-fifo-warn-sysctl.patch: Linux-RT 2.6.27-RT.
- patches.rt/futex-trivial-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/hrtimers-stuck-in-waitqueue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/lockdep-atomic-fixup.patch: Linux-RT 2.6.27-RT.
- patches.rt/namespace-lock-fixes.patch: Linux-RT 2.6.27-RT.
- patches.rt/nmi-prof-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/plist-fix-static-node-init.patch: Linux-RT 2.6.27-RT.
- patches.rt/powerpc-01-separate-the-irq-radix-tree-insertion.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/powerpc-02-make-the-irq-reverse-mapping-radix-tree-lockless.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/ppc-fix-prev-revert-fix-again.patch: Linux-RT
  2.6.27-RT.
- patches.rt/prof-sysctl-compile.patch: Linux-RT 2.6.27-RT.
- patches.rt/rcu-apply-rcu_process_callbacks-from-mainline.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rcu-preempt-tracing-preempt-disable-fix.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/rt-wq-flush_work.patch: Linux-RT 2.6.27-RT.
- patches.rt/rtmutex-debug-magic.patch: Linux-RT 2.6.27-RT
  rtmutex: check integrity.
- patches.rt/sched-add-needs_post_schedule.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-generic-hide-smp-warning.patch: Linux-RT
  2.6.27-RT
  suppress warning of smp_processor_id use..
- patches.rt/sched-make-double-lock-balance-fair.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-if-pushable.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-only-push-once-per-queue.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sched-properly-account-irq-and-rt-load.patch:
  Linux-RT 2.6.27-RT
  sched: properly account IRQ and RT load in .
- patches.rt/sched-rt-runtime-lock-raw.patch: Linux-RT 2.6.27-RT.
- patches.rt/seqlock-01-make-sure-that-raw_seqlock-retries.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-02-fix-elevated-preempt-count.patch:
  Linux-RT 2.6.27-RT.
- patches.rt/seqlock-serialize-against-writers.patch: Linux-RT
  2.6.27-RT.
- patches.rt/seqlocks-handle-rwlock-and-spin.patch: Linux-RT
  2.6.27-RT
  seqlock - fix for both PREEMPT_RT and non PREEMPT_RT.
- patches.rt/shorten-posix-cpu-timers-name.patch: Linux-RT
  2.6.27-RT.
- patches.rt/sysctl-compile-fix.patch: Linux-RT 2.6.27-RT.
- patches.rt/tracepoint-backport.patch: Linux-RT 2.6.27-RT.
- patches.rt/x86-tlbstate-lock-raw.patch: Linux-RT 2.6.27-RT.
* Tue Sep 30 2008 olh@suse.de
- enable ipmi message handler on ppc64 (bnc#430705)
* Tue Sep 30 2008 olh@suse.de
- create flavor symlinks unconditionally
  they do not depend on presence of modules
* Mon Sep 29 2008 agruen@suse.de
- Update config files after Swap-over-NFS backout.
* Mon Sep 29 2008 agruen@suse.de
- kernel-vanilla and kernel-p3 are not split into main, -base, and
  - extra packages. Fix the bogus dependencies on those packages.
* Mon Sep 29 2008 jkosina@suse.de
- disabled the following Swap-over-NFS patches, as they cause panic
  in IPv6 code:
  - patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
    gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
    serialize access to min_free_kbytes (FATE#303834).
  - patches.suse/SoN-03-doc.patch: swap over network documentation
    (FATE#303834).
  - patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
    expose gfp_to_alloc_flags() (FATE#303834).
  - patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
    pages (FATE#303834).
  - patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
    of reserve pages (FATE#303834).
  - patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
    kmem_alloc_estimate() (FATE#303834).
  - patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
    PF_MEMALLOC from softirq context (FATE#303834).
  - patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
    pool (FATE#303834).
  - patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
    system wide ALLOC_NO_WATERMARK (FATE#303834).
  - patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
    __GFP_MEMALLOC (FATE#303834).
  - patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
    management (FATE#303834).
  - patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
    tag avc cache alloc as non-critical (FATE#303834).
  - patches.suse/SoN-14-net-backlog.patch: net: wrap
    sk->sk_backlog_rcv() (FATE#303834).
  - patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
    api (FATE#303834).
  - patches.suse/SoN-16-net-sk_allocation.patch: net:
    sk_allocation() - concentrate socket related allocations
    (FATE#303834).
  - patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
    infrastructure (FATE#303834).
  - patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
    reserves. (FATE#303834).
  - patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
    skb allocation to reserves (FATE#303834).
  - patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
    emergency skbs. (FATE#303834).
  - patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
    a stream specific deadlock (FATE#303834).
  - patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
    NF_QUEUE vs emergency skbs (FATE#303834).
  - patches.suse/SoN-23-netvm.patch: netvm: skb processing
    (FATE#303834).
  - patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
    non block device backed swap files (FATE#303834).
  - patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
    for teaching filesystems about PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
    client how to treat PG_swapcache pages (FATE#303834).
  - patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
    revalidation for swapfiles (FATE#303834).
  - patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
    (FATE#303834).
  - patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
    memory recursions possible with swap over NFS. (FATE#303834).
  - patches.xen/xen3-auto-common.diff: xen3 common.
* Mon Sep 29 2008 ptesarik@suse.cz
- patches.arch/x86-tracehook: x86 tracehook (FATE#304321).
  Provide the base infrastructure for utrace on x86.
* Mon Sep 29 2008 schwab@suse.de
- config/powerpc/vanilla: configure to 64bit.
* Mon Sep 29 2008 schwab@suse.de
- rpm/functions.sh: remove readlink emulation.
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.3-update: Update lpfc to 8.2.8.3
  (bnc#420767).
* Mon Sep 29 2008 rw@suse.de
- Update ia64 config files.  (bnc#429881)
* Mon Sep 29 2008 jjolly@suse.de
- patches.drivers/ehca-flush-cqe.patch: adds software flush CQE
  generation (bnc#430344)
* Mon Sep 29 2008 jkosina@suse.de
- patches.suse/e1000e_allow_bad_checksum: fix infinite loop bug in
  e1000_probe() in case the card has invalid EEPROM checksum
* Mon Sep 29 2008 agruen@suse.de
- Do not split kernels which have modules disabled (kernel-ps3)
  or which do not differentiate between supported and unsupported
  modules (kernel-vanilla).
* Mon Sep 29 2008 hare@suse.de
- patches.drivers/open-fcoe-dcb-support: Fix section annotation
  for ixgbe.
- patches.fixes/scsi-enhance-error-codes: Add missing hunk.
- patches.fixes/open-iscsi-git-update: Open-iSCSI updates
  (FATE#304283).
- patches.kernel.org/gdth-section-conflict: Fixup gdth
  section annotations.
* Mon Sep 29 2008 aj@suse.de
- Silence /etc/rpm/macros.kernel-source via rpmlintrc.
* Mon Sep 29 2008 jbeulich@novell.com
- Enable Solarflare driver link and resource driver patches.
- Update x86 config files.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spc.in: Try to get rid of a hack that makes
  uname -r pretend in build environments that the kernel from
  the installed kernel-source package is the running kernel:
  packages assuming this are completely broken ans should really
  be fixed.
* Mon Sep 29 2008 agruen@suse.de
- rpm/kernel-source.spec.in: Prepare for the upcoming introduction
  of kernel-source-rt (and kernel-syms-rt) for producing KMPs for
  real-time kernels.
- rpm/install-configs: Remove; this script didn't improve things.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.rpmlintrc: New file to silence warnings about
  zero size files
- rpm/kernel-source.spec.in: Install it.
- rpm/kernel-source.spec.in: Make /etc/rpm/macros.kernel-source
  a config file to silence rpmlint.
* Sun Sep 28 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-i810, i2c-prosavage and i2c-savage4 are gone.
  - i2c-isch and i2c-nforce2-s4985 are new, mark as supported.
* Sun Sep 28 2008 aj@suse.de
- rpm/kernel-source.spec.in: Do not package .gitignore files.
* Sun Sep 28 2008 agruen@suse.de
- Fix CONFIG_MODULES=n case.
- config.conf: Some cleanups.
* Sat Sep 27 2008 agruen@suse.de
- Split the binary kernel packages into three parts:
  + kernel-$flavor-base: very reduced hardware support, intended
  to be used in virtual machine images
  + kernel-$flavor: extends the base package; contains all kernel
  modules we can support
  + kernel-$flavor-extra: all other kernel modules which may be
  useful, but which we cannot support.
* Sat Sep 27 2008 agruen@suse.de
- Hardlink duplicate files automatically: It doesn't save much,
  but it keeps rpmlint from breaking the package build.
* Sat Sep 27 2008 agruen@suse.de
- Add consistency check: supported modules must not depend on
  unsupported ones ... and guess what, there was a large number of
  such modules. Fix this by adding all the dependent modules to
  supported.conf.
* Sat Sep 27 2008 knikanth@suse.de
- patches.suse/dm-barrier-single-device: Implement barrier
  support for single device DM devices (FATE#304489).
* Fri Sep 26 2008 jeffm@suse.de
- scripts/tar-up_and_run_mbuild.sh: Added -xen flavor to default
  mbuild spec list.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls for xen. (bnc#425480).
* Fri Sep 26 2008 kkeil@suse.de
- patches.suse/e1000e_mmap_range_chk:check ranges in pci_mmap
  * updated version with better reporting (bnc#425480)
* Fri Sep 26 2008 kkeil@suse.de
- patches to track down and fix the e1000e NVM corruption
  (bnc#425480)
- patches.suse/e1000e_allow_bad_checksum: e1000e: allow bad
  checksum
- patches.suse/e1000e_call_dump_eeprom: e1000e: dump eeprom to
  dmesg for ich8/9
- patches.suse/e1000e_debug_contention_on_NVM_SWFLAG: e1000e:
  debug contention on NVM SWFLAG
- patches.suse/e1000e_do_not_ever_sleep_in_interrupt_context:
  e1000e: do not ever sleep in interrupt context
- patches.suse/e1000e_drop_stats_lock: e1000e: drop stats lock
- patches.suse/e1000e_Export_set_memory_ro-rw: Export
  set_memory_ro() and set_memory_rw() calls
- patches.suse/e1000e_fix_lockdep_issues: e1000e: fix lockdep
  issues
- patches.suse/e1000e_mmap_range_chk: check ranges in pci_mmap
- patches.suse/e1000e_reset_swflag_after_resetting_hardware:
  e1000e: reset swflag after resetting hardware
- patches.suse/e1000e_update_version: update version
- patches.suse/e1000e_use_set_memory_ro-rw_to_protect_flash_memory:
  e1000e: Use set_memory_ro()/set_memory_rw() to protect flash
  memory
-   cleanup old not longer used patches
  * patches.drivers/e1000-7.6.5-napi-tail.patch
  * patches.drivers/e1000-7.6.9.2
  * patches.drivers/e1000-7.6.9.2-napi
* Fri Sep 26 2008 kkeil@suse.de
- Enable CONFIG_SGI_IOC4=m in x86_64 (bnc#430275)
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-export-hotplug_execute: acpi: export
  acpi_os_hotplug_execute.
* Fri Sep 26 2008 jeffm@suse.de
- patches.xen/xen-rwlocks-enable-interrupts: add missing
  __raw_{read,write}_lock_flags to xen's asm/spinlock.h.
* Fri Sep 26 2008 jeffm@suse.de
- patches.arch/acpi-bay-remove-from-makefile: acpi: remove bay.c
  from makefile.
* Fri Sep 26 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Disabled sparse checking. Too many
  false positives.
* Fri Sep 26 2008 trenn@suse.de
  No functional change:
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
  Dock bug fixes (kacpid runs amok on Dells after suspend):
- patches.arch/acpi-dock-avoid-check-_STA-method.patch: avoid
  check _STA method (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-eject-request-process.patch: fix
  eject request process (fate#304731,bnc#401740).
  More Dock improvements, unrelated to above fixes:
- patches.arch/acpi-bay-remove-useless-code.patch: remove useless
  code (fate#304731,bnc#401740).
- patches.arch/acpi-dock-Fix-duplicate-notification-handler-register.patch:
  Fix duplicate notification handler register
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-_LCK-support-for-dock.patch: add _LCK
  support for dock (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-for-bay-in-a-dock-station.patch:
  fix for bay in a dock station (fate#304731,bnc#401740).
- patches.arch/acpi-dock-fix-hotplug-race.patch: fix hotplug race
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-introduce-.uevent-for-devices-in-dock.patch:
  introduce .uevent for devices in dock (fate#304731,bnc#401740).
- patches.arch/acpi-libata-hotplug-to-align-with-dock-driver.patch:
  libata hotplug to align with dock driver
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-makeing-dock-driver-supports-bay-and-battery-hotplug.patch:
  makeing dock driver supports bay and battery hotplug
  (fate#304731,bnc#401740).
- patches.arch/acpi-dock-add-type-sysfs-file-for-dock.patch:
  add 'type' sysfs file for dock (fate#304731,bnc#401740).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
* Fri Sep 26 2008 jeffm@suse.de
- Update config files: NFS_SWAP=y
* Fri Sep 26 2008 ptesarik@suse.cz
- patches.suse/rwlocks-enable-interrupts: Allow rwlocks to
  re-enable interrupts (bnc#387784).
- patches.arch/ia64-rwlocks-enable-interrupts: ia64: re-enable
  interrupts when waiting for a rwlock (bnc#387784).
* Fri Sep 26 2008 sjayaraman@suse.de
- Add Swap over NFS patchset.
- Adjust patches.xen/xen3-auto-common.diff to avoid conflict on skbuff.h
  as both xen and swap-over-nfs want to add some bits to the skbuff structure.
- patches.suse/SoN-01-mm-gfp-to-alloc_flags.patch: mm:
  gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-02-mm-setup_per_zone_pages_min.patch: mm:
  serialize access to min_free_kbytes (FATE#303834).
- patches.suse/SoN-03-doc.patch: swap over network documentation
  (FATE#303834).
- patches.suse/SoN-04-mm-gfp-to-alloc_flags-expose.patch: mm:
  expose gfp_to_alloc_flags() (FATE#303834).
- patches.suse/SoN-05-page_alloc-reserve.patch: mm: tag reseve
  pages (FATE#303834).
- patches.suse/SoN-06-reserve-slub.patch: mm: slb: add knowledge
  of reserve pages (FATE#303834).
- patches.suse/SoN-07-mm-kmem_estimate_pages.patch: mm:
  kmem_alloc_estimate() (FATE#303834).
- patches.suse/SoN-08-mm-PF_MEMALLOC-softirq.patch: mm: allow
  PF_MEMALLOC from softirq context (FATE#303834).
- patches.suse/SoN-09-mm-page_alloc-emerg.patch: mm: emergency
  pool (FATE#303834).
- patches.suse/SoN-10-global-ALLOC_NO_WATERMARKS.patch: mm:
  system wide ALLOC_NO_WATERMARK (FATE#303834).
- patches.suse/SoN-11-mm-page_alloc-GFP_EMERGENCY.patch: mm:
  __GFP_MEMALLOC (FATE#303834).
- patches.suse/SoN-12-mm-reserve.patch: mm: memory reserve
  management (FATE#303834).
- patches.suse/SoN-13-mm-selinux-emergency.patch: selinux:
  tag avc cache alloc as non-critical (FATE#303834).
- patches.suse/SoN-14-net-backlog.patch: net: wrap
  sk->sk_backlog_rcv() (FATE#303834).
- patches.suse/SoN-15-net-ps_rx.patch: net: packet split receive
  api (FATE#303834).
- patches.suse/SoN-16-net-sk_allocation.patch: net:
  sk_allocation() - concentrate socket related allocations
  (FATE#303834).
- patches.suse/SoN-17-netvm-reserve.patch: netvm: network reserve
  infrastructure (FATE#303834).
- patches.suse/SoN-18-netvm-reserve-inet.patch: netvm: INET
  reserves. (FATE#303834).
- patches.suse/SoN-19-netvm-skbuff-reserve.patch: netvm: hook
  skb allocation to reserves (FATE#303834).
- patches.suse/SoN-20-netvm-sk_filter.patch: netvm: filter
  emergency skbs. (FATE#303834).
- patches.suse/SoN-21-netvm-tcp-deadlock.patch: netvm: prevent
  a stream specific deadlock (FATE#303834).
- patches.suse/SoN-22-emergency-nf_queue.patch: netfilter:
  NF_QUEUE vs emergency skbs (FATE#303834).
- patches.suse/SoN-23-netvm.patch: netvm: skb processing
  (FATE#303834).
- patches.suse/SoN-24-mm-swapfile.patch: mm: add support for
  non block device backed swap files (FATE#303834).
- patches.suse/SoN-25-mm-page_file_methods.patch: mm: methods
  for teaching filesystems about PG_swapcache pages (FATE#303834).
- patches.suse/SoN-26-nfs-swapcache.patch: nfs: teach the NFS
  client how to treat PG_swapcache pages (FATE#303834).
- patches.suse/SoN-27-nfs-swapper.patch: nfs: disable data cache
  revalidation for swapfiles (FATE#303834).
- patches.suse/SoN-28-nfs-swap_ops.patch: nfs: enable swap on NFS
  (FATE#303834).
- patches.suse/SoN-29-nfs-alloc-recursions.patch: nfs: fix various
  memory recursions possible with swap over NFS. (FATE#303834).
- patches.xen/xen3-auto-common.diff: xen3 common.
* Fri Sep 26 2008 ptesarik@suse.cz
- split patches.arch/s390-01-01-self-ptrace-v3.patch to make it
  more obvious that the patch is not constrained to s390.
  The new series is:
    patches.suse/self-ptrace.patch: the generic pieces
    patches.arch/x86-self-ptrace.patch: implementation for x86
    patches.arch/s390-01-01-self-ptrace-v3.patch: dtto for s390
* Thu Sep 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc7 and c/s 676.
* Thu Sep 25 2008 olh@suse.de
- add patches.arch/ppc64-rpanote-relocate-firmware.patch
  update RPA note for firmware relocation (bnc#427960 - LTC48297)
* Wed Sep 24 2008 jblunck@suse.de
  This adds some tracepoint instrumentation taken from the LTTng patch
  series. Tracepoints are enabled for kernel-debug and kernel-trace only. I
  disabled ftrace for all flavors except kernel-debug and kernel-trace as well.
- Update config files.
- rpm/kernel-source.spec.in,kernel-binary.spec.in, config.conf: Add trace
  flavor
- patches.fixes/ia64-sparse-fixes.diff: ia64-kvm: fix sparse
  warnings.
- patches.xen/xen3-fixup-common: rediff
- patches.xen/xen3-auto-common.diff: rediff
- patches.xen/xen3-patch-2.6.21: rediff
- patches.xen/xen3-patch-2.6.26: rediff
- patches.trace/rcu-read-sched.patch
- patches.trace/markers-use-rcu-read-lock-sched.patch
- patches.trace/tracepoints.patch
- patches.trace/tracepoints-use-table-size-macro.patch
- patches.trace/tracepoints-documentation.patch
- patches.trace/tracepoints-tracepoint-synchronize-unregister.patch
- patches.trace/tracepoints-documentation-fix-teardown.patch
- patches.trace/tracepoints-samples.patch
- patches.trace/tracepoints-samples-fix-teardown.patch
- patches.trace/lttng-instrumentation-irq.patch
- patches.trace/lttng-instrumentation-scheduler.patch
- patches.trace/lttng-instrumentation-timer.patch
- patches.trace/lttng-instrumentation-kernel.patch
- patches.trace/lttng-instrumentation-filemap.patch
- patches.trace/lttng-instrumentation-swap.patch
- patches.trace/lttng-instrumentation-memory.patch
- patches.trace/lttng-instrumentation-page_alloc.patch
- patches.trace/lttng-instrumentation-hugetlb.patch
- patches.trace/lttng-instrumentation-net.patch
- patches.trace/lttng-instrumentation-ipv4.patch
- patches.trace/lttng-instrumentation-ipv6.patch
- patches.trace/lttng-instrumentation-socket.patch
- patches.trace/lttng-instrumentation-fs.patch
- patches.trace/lttng-instrumentation-ipc.patch
- patches.trace/ftrace-port-to-tracepoints.patch
- patches.trace/ftrace-framepointer.diff
* Tue Sep 23 2008 jjolly@suse.de
- patches.arch/s390-01-03-cmm2-v2.patch: kernel (new function):
  Collaborative Memory Management Stage II (bnc#417244)
- patches.xen/xen3-auto-common.diff: Modified patch to allow for
  the new patch
* Tue Sep 23 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Enable sparse checking and section
  mismatch checking.
* Tue Sep 23 2008 jeffm@suse.de
- patches.kernel.org/arch-include-asm-fixes: kbuild: Properly
  handle arch/$arch/include/asm (bnc#427473).
* Mon Sep 22 2008 jeffm@suse.de
- patches.fixes/ext2-avoid-printk-flood-with-dir-corruption:
  ext2: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
- patches.fixes/ext3-avoid-printk-flood-with-dir-corruption:
  ext3: Avoid printk floods in the face of directory corruption
  (bnc#427244 CVE-2008-3528).
* Mon Sep 22 2008 jeffm@suse.de
- Update to 2.6.27-rc7.
  - Eliminated 2 patches.
  - patches.arch/s390-01-04-fcpperf-4.patch: Fixed up context.
* Mon Sep 22 2008 trenn@suse.de
  Workaround for ThinkPad brightness switching:
- patches.arch/acpi_video_thinkpad_exclude_IGD_devices.patch:
  Do not use video backlight switching for Lenovo ThinkPads.
  Commented out for now, possibly to be included later
- patches.drivers/cpufreq_add_cpu_number_paramater_1.patch:
  cpufreq: Add a cpu parameter to __cpufreq_driver_getavg()..
- patches.drivers/cpufreq_add_idle_microaccounting_6.patch:
  cpufreq,ondemand: Use get_cpu_idle_time_us() to get
  micro-accounted idle information.
- patches.drivers/cpufreq_change_load_calculation_2.patch:
  cpufreq, ondemand: Change the load calculation, optimizing
  for dependent cpus.
- patches.drivers/cpufreq_changes_to_get_cpu_idle_us_5.patch:
  export get_cpu_idle_time_us() .
- patches.drivers/cpufreq_get_cpu_idle_time_changes_3.patch:
  cpufreq,ondemand: Prepare changes for doing micro-accounting.
- patches.drivers/cpufreq_parameterize_down_differential_4.patch:
  cpufreq, ondemand: Use a parameter for down differential.
  Added CONFIG_PCIEASPM for rt, xen, powerpc and IA64 to be more
  consistent across different kernel flavors as suggested on the
  kernel list:
- Update config files.
* Mon Sep 22 2008 hare@suse.de
- patches.drivers/open-fcoe-libfc: Fix build error on IA64.
- patches.fixes/scsi-terminate-target-reset: Target reset hangs
  (bnc#427267).
- supported.conf: Update to include supported SCSI adapters.
* Fri Sep 19 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Re-enable after removing FTRACE
  related change.
- Update x86 non-debug config files: Turn off FRAME_POINTER and FTRACE.
* Fri Sep 19 2008 nfbrown@suse.de
- patches.fixes/md-Allow-metadata_version-to-be-updated-for-externa.patch:
  md: Allow metadata_version to be updated for externally managed
  metadata. (FATE#304218).
- patches.fixes/md-Don-t-try-to-set-an-array-to-read-auto-if-it-i.patch:
  md: Don't try to set an array to 'read-auto' if it is already
  in that state. (FATE#304218).
* Thu Sep 18 2008 jbeulich@novell.com
- patches.suse/no-frame-pointer-select: Disable.
- Re-enable CONFIG_FRAME_POINTER in x86 config files.
* Thu Sep 18 2008 jbeulich@novell.com
- Update i386 and x86-64 config files (disable CONFIG_FRAME_POINTER in
  non-debug configs).
- patches.suse/stack-unwind: Add missing put_cpu()-s for x86-64.
- patches.suse/no-frame-pointer-select: Fix stack unwinder Kconfig
  (bnc#402518).
* Thu Sep 18 2008 hare@suse.de
- Update config files.
- patches.drivers/open-fcoe-driver: fcoe: Fibre Channel over
  Ethernet driver (FATE#303913).
- patches.drivers/open-fcoe-libfc: libfc: a modular software
  Fibre Channel implementation (FATE#303913).
- patches.drivers/open-fcoe-header-files: FC protocol definition
  header files (FATE#303913).
- patches.drivers/open-fcoe-dcb-support: FCoE: Add DCB support
  (FATE#303913).
- patches.drivers/ixgbe-fcoe-bugfixes: ixgbe: Bugfixes for FCoE.
- patches.fixes/vlan-gso-size-fix: vlan: device not reading gso
  max size of parent. (FATE#303913).
- patches.fixes/pkt_action-skbedit: pkt_action: add new action
  skbedit.
- patches.fixes/pkt_sched_multiq_support: pkt_sched: Add
  multiqueue scheduler support (FATE#303913).
- supported.conf: Update to include FCoE and device_handler
  modules
* Wed Sep 17 2008 jbeulich@novell.com
- supported.conf: adjust name of ide-cd (is now ide-cd_mod).
* Wed Sep 17 2008 hare@suse.de
- patches.drivers/qla2xxx-defer-risc-interrupt-enablement:
  qla2xxx: Defer enablement of RISC interrupts until ISP
  initialization completes (FATE#304113).
- patches.drivers/qla2xxx-8.02.01-k8-update: Update qla2xxx to
  8.02.01-k8 (FATE#304113).
* Wed Sep 17 2008 hare@suse.de
- patches.fixes/scsi-retry-hardware-error: make scsi_check_sense
  HARDWARE_ERROR return ADD_TO_MLQUEUE on retry (FATE#304042)
* Tue Sep 16 2008 olh@suse.de
- disable CONFIG_SPARSEMEM_VMEMMAP on ppc64 to allow memory remove
  (bnc#417537)
* Mon Sep 15 2008 jkosina@suse.de
- Update config files (build elousb driver as module)
- patches.drivers/elousb.patch: Elo USB touchscreen driver
  (FATE#304972).
* Mon Sep 15 2008 hare@suse.de
- patches.fixes/dm-mpath-abort-queue: Abort queued requests for
  multipath (FATE#304151).
* Mon Sep 15 2008 hare@suse.de
- Update config files: Disable CONFIG_OCFS2_COMPAT_JBD
* Mon Sep 15 2008 hare@suse.de
- patches.xen/xen-scsifront-block-timeout-update: Update XEN
  scsifront driver to request timeouts.
* Mon Sep 15 2008 sdietrich@suse.de
- Update config files: Enable GROUP_SCHED, FAIR_GROUP_SCHED,
  RT_GROUP_SCHED, CGROUP_SCHED
* Mon Sep 15 2008 hare@suse.de
- patches.drivers/block-timeout-handling: Fix typo.
* Fri Sep 12 2008 duwe@suse.de
- Add LED driver for SGI "UV" systems (FATE#304268)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/bdev-resize-added-flush_disk: Added
  flush_disk to factor out common buffer cache flushing code
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-adjust-block-device-size:
  Adjust block device size after an online resize of a
  disk. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-call-flush_disk: Call flush_disk()
  after detecting an online resize. (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-check-for-device-resize:
  Check for device resize when rescanning partitions
  (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-sd-driver-calls: SCSI sd driver
  calls revalidate_disk wrapper (FATE#302348,FATE#303786).
- patches.drivers/bdev-resize-wrapper-for-revalidate_disk:
  Wrapper for lower-level revalidate_disk
  routines. (FATE#302348,FATE#303786).
- patches.drivers/block-timeout-handling: block: unify request
  timeout handling (FATE#304151,bnc#417544).
- patches.fixes/scsi-misc-git-update: SCSI misc fixes
  (FATE#303485,FATE#303484).
- patches.fixes/scsi-enhance-error-codes: Separate failfast into
  multiple bits (FATE#303485,FATE#303484).
- patches.suse/rq-based-block-layer: rediff.
- patches.suse/rq-based-multipath-functions: rediff.
- patches.suse/no-partition-scan: rediff.
* Fri Sep 12 2008 hare@suse.de
- patches.fixes/scsi-misc-git-update: SCSI misc fixes,
  required by the driver updates (FATE#303485,FATE#303484)
* Fri Sep 12 2008 hare@suse.de
- patches.drivers/lpfc-8.2.8.1-update: Update lpfc to 8.2.8.1
  (bnc#420767).
- patches.drivers/lpfc-8.2.8-update: Emulex lpfc driver update
  to 8.2.8 (FATE#303485,bnc#420767).
* Fri Sep 12 2008 bwalle@suse.de
- patches.arch/ia64-kdump_proc_iomem.diff:
  IA64: assign a distinguishable label to uncached memory in
  /proc/iomem (to fix MCA on kdump boot).
* Thu Sep 11 2008 jack@suse.cz
  Latest ext4 fixes from ext4 patch queue:
- patches.fixes/ext4-Add-inode-to-journal-handle-after-block-alloca.patch:
  ext4: Don't add the inode to journal handle until after the
  block is allocated (fate#303783).
- patches.fixes/ext4_add-missing-unlock-to-ext4-check-descriptors:
  ext4: add missing unlock in ext4_check_descriptors() on error
  path (fate#303783).
- patches.fixes/ext4-Add-percpu-dirty-block-accounting.patch:
  ext4: Add percpu dirty block accounting. (fate#303783).
- patches.fixes/ext4_create-proc-ext4-stats-file-more-carefully:
  ext4: fix #11321: create /proc/ext4/*/stats more carefully
  (fate#303783).
- patches.fixes/ext4_fix_longlong_checkpatch_issues: ext4:
  Fix long long checkpatch warnings (fate#303783).
- patches.fixes/ext4_fix_printk_checkpatch_issues: ext4:
  Add printk priority levels to clean up checkpatch warnings
  (fate#303783).
- patches.fixes/ext4_fix_whitespace_checkpatch_issues: ext4:
  Fix whitespace checkpatch warnings/errors (fate#303783).
- patches.fixes/ext4_i_disksize_lock_race_fix.patch: ext4:
  Properly update i_disksize. (fate#303783).
- patches.fixes/ext4_invalidate_pages_when_delalloc_alloc_fail.patch:
  ext4: invalidate pages if delalloc block allocation
  fails. (fate#303783).
- patches.fixes/ext4-Make-sure-all-the-block-allocation-paths-reser.patch:
  ext4: Make sure all the block allocation paths reserve blocks
  (fate#303783).
- patches.fixes/ext4_nonmballoc_reservation_ENOSPC_fix.patch:
  ext4: Fix ext4 nomballoc allocator for ENOSPC (fate#303783).
- patches.fixes/ext4-Retry-block-allocation-if-we-have-free-blocks.patch:
  ext4: Retry block allocation if we have free blocks left
  (fate#303783).
- patches.fixes/ext4-Retry-block-reservation.patch: ext4: Retry
  block reservation (fate#303783).
- patches.fixes/ext4-Signed-arithematic-fix.patch: ext4: Signed
  arithematic fix (fate#303783).
- patches.fixes/ext4-Switch-to-non-delalloc-mode-when-we-are-low-on.patch:
  ext4: Switch to non delalloc mode when we are low on free
  blocks count. (fate#303783).
- patches.fixes/ext4_truncate_block_allocated_on_a_failed_ext4_write_begin.patch:
  ext4: truncate block allocated on a failed ext4_write_begin
  (fate#303783).
- patches.fixes/ext4_update-flex-bg-counters-when-resizing:
  Update flex_bg free blocks and free inodes counters when
  resizing. (fate#303783).
- patches.fixes/percpu_counter_sum_cleanup.patch: percpu counter:
  clean up percpu_counter_sum_and_set() (fate#303783).
* Thu Sep 11 2008 bwalle@suse.de
- Enable KDB for i386 and x86_64 in "default" and "pae"
  configuration with CONFIG_KDB_OFF set to "y" (FATE#303971).
- Set CONFIG_KDB_CONTINUE_CATASTROPHIC=2 in all configurations
  that have KDB enabled.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  enable PID_NS and USER_NS
  (FATE#303785, FATE#304371)
* Thu Sep 11 2008 jeffm@suse.de
- Update config files.
  - Enabled CONFIG_XFRM_SUB_POLICY (FATE#303781)
* Thu Sep 11 2008 mfasheh@suse.com
- Added POSIX File Locks support for Ocfs2  (FATE#110294)
  - patches.suse/ocfs2-POSIX-file-locks-support.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 JBD2 Support  (FATE#302877)
  - patches.suse/ocfs2-Limit-inode-allocation-to-32bits.patch
  - patches.suse/ocfs2-Add-the-inode64-mount-option.patch
  - patches.suse/ocfs2-Switch-over-to-JBD2.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Added Ocfs2 Extended Attributes Support (FATE#302067)
  - patches.suse/ocfs2-Modify-ocfs2_num_free_extents-f.patch
  - patches.suse/ocfs2-Use-ocfs2_extent_list-instead-o.patch
  - patches.suse/ocfs2-Abstract-ocfs2_extent_tree-in-b.patch
  - patches.suse/ocfs2-Make-high-level-btree-extend-co.patch
  - patches.suse/ocfs2-Add-the-basic-xattr-disk-layout-in-ocf.patch
  - patches.suse/ocfs2-Add-helper-function-in-uptodate.patch
  - patches.suse/ocfs2-Add-extent-tree-operation-for-x.patch
  - patches.suse/ocfs2-reserve-inline-space-for-extend.patch
  - patches.suse/ocfs2-Add-extended-attribute-support.patch
  - patches.suse/ocfs2-Add-xattr-index-tree-operations.patch
  - patches.suse/ocfs2-Add-xattr-bucket-iteration-for.patch
  - patches.suse/ocfs2-Add-xattr-lookup-code-xattr-btr.patch
  - patches.suse/ocfs2-Optionally-limit-extent-size-in.patch
  - patches.suse/ocfs2-Enable-xattr-set-in-index-btree.patch
  - patches.suse/ocfs2-Delete-all-xattr-buckets-during.patch
  - patches.suse/ocfs2-Add-incompatible-flag-for-exten.patch
  - patches.suse/ocfs2-fix-printk-format-warnings.patch
  - patches.suse/ocfs2-Prefix-the-extent-tree-operations-structure.patch
  - patches.suse/ocfs2-Prefix-the-ocfs2_extent_tree-structure.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-get-put-instead-of-all.patch
  - patches.suse/ocfs2-Make-private-into-object-on-ocfs2_extent_.patch
  - patches.suse/ocfs2-Provide-the-get_root_el-method-to-ocfs2_ext.patch
  - patches.suse/ocfs2-Use-struct-ocfs2_extent_tree-in-ocfs2_num_fre.patch
  - patches.suse/ocfs2-Determine-an-extent-tree-s-max_leaf_clusters.patch
  - patches.suse/ocfs2-Create-specific-get_extent_tree-functions.patch
  - patches.suse/ocfs2-Add-an-insertion-check-to-ocfs2_extent_tree_o.patch
  - patches.suse/ocfs2-Make-ocfs2_extent_tree-the-first-class-repres.patch
  - patches.suse/ocfs2-Comment-struct-ocfs2_extent_tree_operations.patch
  - patches.suse/ocfs2-Change-ocfs2_get_-_extent_tree-to-ocfs2_ini.patch
  - patches.suse/ocfs2-bug-fix-for-journal-extend-in-xattr.patch
  - patches.suse/ocfs2-Resolve-deadlock-in-ocfs2_xattr_free_.patch
  - patches.suse/ocfs2-Add-xattr-mount-option-in-ocfs2_show_options.patch
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/jbd2-create-proc-entry-fix.patch
  jbd2: Create proc entry with bdevname+i_ino.
  (FATE#302877)
* Thu Sep 11 2008 mfasheh@suse.com
- Add patches.fixes/dlm-allow-multiple-lockspaces.patch
  dlm: allow multiple lockspace creates
  (FATE#110294)
* Thu Sep 11 2008 schwab@suse.de
- Update kdb patches.
* Thu Sep 11 2008 jslaby@suse.de
- Update config files.
  change CONFIG_NODES_SHIFT from 6 to 9
  (FATE#304261)
* Wed Sep 10 2008 trenn@suse.de
- Update config files.
  Added: CONFIG_PCIEASPM
* Wed Sep 10 2008 kkeil@suse.de
- patches.drivers/e1000e_add_82574L.patch: e1000e: add support
  for new 82574L part.
- patches.drivers/e1000e_add_ICH9_BM.patch: e1000e: add support
  for the 82567LM-4 device.
- patches.drivers/e1000e_add_LOM_devices.patch: e1000e: add
  support for 82567LM-3 and 82567LF-3 (ICH10D).
  (FATE#303916)
* Wed Sep 10 2008 hare@suse.de
- patches.suse/no-partition-scan: Implement 'no_partition_scan'
  commandline option (FATE#303697)
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/ipmi-section-conflict.diff: ipmi: Fix
  section type conflicts.
- patches.kernel.org/psmouse-section-conflict.diff: psmouse:
  fix section type conflict.
- patches.kernel.org/carmine-section-mismatch: video: Fix section
  mismatch in carminefb.
- patches.kernel.org/md-section-conflict: md: Fix section
  conflicts.
- patches.kernel.org/setup_APIC_timer-section-mismatch: x86:
  Fix section conflict with kvm_setup_secondary_clock.
* Wed Sep 10 2008 trenn@suse.de
- patches.arch/thinkpad_fingers_off_backlight_igd.patch:
  Serve ThinkPad IGD devices backlight functionality through
  thinkpad_acpi (fate #302883).
- supported.conf: Add most important laptop drivers as supported:
    kernel/drivers/misc/asus_laptop
    kernel/drivers/misc/eeepc-laptop
    kernel/drivers/misc/msi-laptop
    kernel/drivers/misc/fujitsu-laptop
    kernel/drivers/acpi/wmi
    kernel/drivers/misc/hp-wmi
* Wed Sep 10 2008 jeffm@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: Fixed up
  some section conflicts.
* Wed Sep 10 2008 jeffm@suse.de
- Update to 2.6.27-rc6.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Added missing netfilter modules.
* Wed Sep 10 2008 jeffm@suse.de
- supported.conf: Updated netfilter module names.
* Wed Sep 10 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: Updated header.
* Wed Sep 10 2008 jkosina@suse.de
- Update config files: support more than 4 serial ports
  (FATE#303314)
* Wed Sep 10 2008 olh@suse.de
- set CONFIG_CMM=y instead of =m to simplify virtual partition memory
  (bnc#417554)
* Tue Sep  9 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: add Recommends: kerneloops
* Tue Sep  9 2008 olh@suse.de
- Updated to 2.6.27-rc5-git10
* Mon Sep  8 2008 olh@suse.de
- Updated to 2.6.27-rc5-git9
* Fri Sep  5 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v3.patch: system call
  notification with self_ptrace (bnc#417299)
- patches.arch/s390-01-02-dcss-64-v2.patch: dcssblk (new function):
  Add support for >2G DCSS and stacked contiguous DCSS support.
  (bnc#417246)
- patches.arch/s390-01-04-fcpperf-{1-4}.patch: (kernel):FCP -
  Performance Data colletion & analysis (bnc#417243)
* Fri Sep  5 2008 olh@suse.de
- add patches.fixes/usb-hcd-interrupt-shared.patch
  fix interrupt handling for shared irqs, for PS3 (bnc#409961)
* Fri Sep  5 2008 olh@suse.de
- Updated to 2.6.27-rc5-git7
* Thu Sep  4 2008 olh@suse.de
- build with CONFIG_POWER4_ONLY (bnc#417566)
  this disables support for POWER3 and RS64 cpus
* Thu Sep  4 2008 jkosina@suse.de
- switch from Reno to Cubic as default TCP congestion algorithm
  (bnc#422825)
* Thu Sep  4 2008 bwalle@suse.de
- Update KDB patches. Fix build on x86_64-debug.
* Wed Sep  3 2008 jeffm@suse.de
- mark crc-t10dif as supported
* Wed Sep  3 2008 olh@suse.de
- mark pata_pdc2027x as supported
* Wed Sep  3 2008 olh@suse.de
- mark spidernet as supported
* Wed Sep  3 2008 olh@suse.de
- mark ehea as supported
* Wed Sep  3 2008 trenn@suse.de
- supported.conf:
  Mark dock (libata depends on it), bay, acpi_memhotplug, hpilo
  as supported
  Remove or adjust supported laptop drivers that went from
  drivers/acpi to drivers/misc
* Wed Sep  3 2008 hare@suse.de
- supported.conf: Mark virtio modules as supported.
* Tue Sep  2 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc5 and c/s 651.
* Tue Sep  2 2008 jjolly@suse.de
- patches.arch/s390-01-01-self-ptrace-v2.patch: kernel
  (new function): System call notification with self_ptrace
  (bnc#417299,FATE#304021)
* Mon Sep  1 2008 agruen@suse.de
- File capabilities: replace our no_file_caps patch with what is
  supposed to end up in 2.6.28.
* Mon Sep  1 2008 bwalle@suse.de
- patches.arch/ia64-node_mem_map-node_start_pfn.diff:
  Fix memory map for ia64/discontmem for kdump.
* Mon Sep  1 2008 olh@suse.de
- Updated to 2.6.27-rc5-git2
* Fri Aug 29 2008 jeffm@suse.de
- Updated to 2.6.27-rc5.
  - Eliminated 2 patches.
  - KDB has an incompatible change on x86_64, so kernel-debug
    will fail there.
* Fri Aug 29 2008 olh@suse.de
- update message in post.sh to display also the rpm FLAVOR
* Thu Aug 28 2008 olh@suse.de
- update patches.suse/dm-raid45-2.6.25-rc2_20080221.patch
  rename rh_init to region_hash_init to avoid conflict
  with existing powerpc symbol on powerpc
* Thu Aug 28 2008 olh@suse.de
- disable musb, not useful, does not compile
* Tue Aug 26 2008 trenn@suse.de
  Vendor specific drivers vs generic video driver.
  Distinguish which ACPI driver should do backlight switching.
  This patch series is queued up for 2.6.28 in the ACPI branch:
- patches.arch/0000-ACPI-video-Ignore-devices-not-present.patch:
  ACPI: video: Ignore devices that aren't present in hardware.
- patches.arch/0001-Check-for-ACPI-backlight-support.patch: Check
  for ACPI backlight support otherwise use vendor ACPI drivers.
- patches.arch/0002-Acer-WMI-fingers-off-backlight-video.ko.patch:
  Acer-WMI: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0003-Asus-acpi-fingers-off-backlight.patch:
  asus-acpi: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0004-Compal-fingers-off-backlight.patch: compal:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0005-eeepc-laptop-fingers-off.patch: eeepc-laptop:
  fingers off backlight if video.ko is serving this functionality.
- patches.arch/0006-fujitsu-laptop-fingers-off-backlight.patch:
  fujitsu-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0007-msi-laptop-fingers-off-backlight.patch:
  msi-laptop: fingers off backlight if video.ko is serving this
  functionality.
- patches.arch/0008-sony-laptop-fingers-off-backlight.patch:
  sony-laptop: fingers off backlight if video.ko is serving
  this functionality.
- patches.arch/0009-thinkpad_acpi-fingers-off-backlight.patch:
  thinkpad_acpi: fingers off backlight if video.ko is serving
  this functionality.
  I had to refresh these. While one patch was broken,
  two lines were missing, "patch" from 11.0 still worked, while
  "patch" from 10.3 did not:
- patches.xen/add-console-use-vt: add console_use_vt.
- patches.xen/linux-2.6.19-rc1-kexec-move_segment_code-i386.patch:
  kexec: Move asm segment handling code to the assembly file
  (i386).
* Mon Aug 25 2008 jeffm@suse.de
- Disabled patches.kernel.org/ia64-asm-nr-irqs
* Mon Aug 25 2008 jeffm@suse.de
- patches.fixes/pseries-compile-fix: pseries: compile fix.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/musb-powerpc-conflict: musb: compile fix
  for powerpc.
* Mon Aug 25 2008 jeffm@suse.de
- patches.kernel.org/ia64-asm-nr-irqs: ia64: nr-irqs.h generation
  should place it in arch/../asm.
* Mon Aug 25 2008 jeffm@suse.de
- Update config files.
* Mon Aug 25 2008 jeffm@suse.de
- Updated to 2.6.27-rc4.
  - Refreshed context.
* Mon Aug 25 2008 trenn@suse.de
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch:
  x86, pci: introduce pci=noioapicquirk kernel cmdline option.
  Mysterious patch problem in include/asm-x86/pci.h
- patches.fixes/acpi-clear-wake-status.patch: Clear wak_sts
  register on resume.
* Mon Aug 25 2008 trenn@suse.de
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  Delete.
* Mon Aug 25 2008 jbeulich@novell.com
- Update Xen patches to 2.6.27-rc4.
- patches.xen/xen-x86_64-dump-user-pgt: dump the correct page
  tables for user mode faults.
- patches.xen/xen-x86_64-pgd-alloc-order: don't require order-1
  allocations for pgd-s.
- patches.xen/xen-x86_64-pgd-pin: make pinning of pgd pairs
  transparent to callers.
- patches.xen/xen-blktap-write-barriers: blktap: Write Barriers.
- patches.xen/xen-x86-pmd-handling: consolidate pmd/pud/pgd entry
  handling.
- patches.xen/xen-x86-bigmem: fix issues with the assignment of
  huge amounts of memory.
- patches.xen/xen-msix-restore: print at least a message if MSI-X
  restore failed.
- config.conf: Re-enable Xen.
- patches.xen/sfc-i2c: Delete.
- Update config files.
* Fri Aug 22 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Adjust and re-enable.
- Update config files.
* Tue Aug 19 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: Delete.
* Tue Aug 19 2008 jeffm@suse.de
- Removed unused patches.
* Tue Aug 19 2008 tiwai@suse.de
- Update config files: Use CONFIG_INPUT_PCSPKR=m (bnc#225221)
* Mon Aug 18 2008 schwab@suse.de
- Update config files.
* Mon Aug 18 2008 schwab@suse.de
- Update kdb patches.
* Fri Aug 15 2008 tiwai@suse.de
- patches.arch/ppc-ipic-suspend-without-83xx-fix: Fix build_error
  without CONFIG_PPC_83xx.
- Update config files.
* Fri Aug 15 2008 tiwai@suse.de
- Update config files: disable CONFIG_IPIC for ppc/default and
  vanilla again to fix build
* Fri Aug 15 2008 tiwai@suse.de
- rpm/kernel-binary.spec.in: fix build without firmware files
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/no-include-asm: kbuild: correctly link
  include/asm in external builds.
* Fri Aug 15 2008 jeffm@suse.de
- patches.kernel.org/ath9k-workaround-gcc-ICE-again-on-powerpc:
  ath9k: work around gcc ICE again.
* Thu Aug 14 2008 jeffm@suse.de
- patches.suse/novfs-gregorian-day-fix: novfs: Fix GregorianDay
  conflict.
* Thu Aug 14 2008 jeffm@suse.de
- Enabled patches.kernel.org/firmware-path
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Fixed duplicate
  export of security_inode_permission.
* Thu Aug 14 2008 jeffm@suse.de
- patches.apparmor/add-security_path_permission: Add missing
  stub for security_path_permission when CONFIG_SECURITY_APPARMOR=n
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/firmware-path: firmware: Allow
  release-specific firmware dir.
- rpm/kernel-binary.spec.in: Add firmware files.
* Thu Aug 14 2008 jeffm@suse.de
- patches.kernel.org/ia64-export-cpu_core_map: ia64: Export
  cpu_core_map for topology_core_siblings.
* Thu Aug 14 2008 jeffm@suse.de
- Updated to 2.6.27-rc3.
  - AppArmor mostly merged. There may be some hiccups.
  - Xen and RT temporarily disabled for merging.
  - 17 patches eliminated.
* Thu Aug 14 2008 ghaskins@suse.de
  Guarded by +RT
- patches.rt/seqlock-make-raw-seqlocks-spin-during-write.patch:
  seqlock: make sure that raw_seqlock_t retries readers while
  writes are pending.
- patches.rt/ftrace-fix-elevated-preempt-count-in-wakeup-tracer.patch:
  ftrace: fix elevated preempt_count in wakeup-tracer.
* Fri Aug  8 2008 hare@suse.de
- Update config files for RT kernel to activate SCSI
  device handler.
* Fri Aug  8 2008 jbeulich@novell.com
- patches.xen/xen3-fixup-common, patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.24, patches.xen/xen3-patch-2.6.25: Fix
  a couple of bugs and inconsistencies.
* Fri Aug  8 2008 schwab@suse.de
- Fix reference to $RPM_BUILD_ROOT in makefiles.
* Fri Aug  8 2008 hare@suse.de
- patches.fixes/dm-mpath-hp-sw.patch: Delete.
- Update config files.
- patches.fixes/dm-2.6.27-update: Upstream device-mapper patches
  (FATE#302108).
- patches.fixes/scsi_dh-2.6.27-update: SCSI device handler update
  (FATE#302269,FATE#303696,FATE#303754,FATE#304125).
- patches.suse/rq-based-block-layer: rq-based multipathing:
  block layer changes (FATE#302108).
- patches.suse/rq-based-dm-interface: rq-based multipathing:
  device-mapper interface (FATE#302108).
- patches.suse/rq-based-multipath-functions: rq-based
  multipathing: request-based functions to multipath
  (FATE#302108).
* Thu Aug  7 2008 jbeulich@novell.com
- Update Xen patches to c/s 623.
- patches.xen/sfc-network-driver: Delete.
- patches.xen/xen-balloon-hvm-min: Delete.
- patches.xen/xen-netfront-flip-prod: Delete.
- patches.xen/xen-x86_64-init-cleanup: Delete.
- patches.xen/sfc-i2c: sfc: Use kernel I2C system and i2c-algo-bit
  driver (disabled).
- patches.xen/sfc-driverlink: Solarflare: Resource driver (disabled).
- Update Xen config files.
* Wed Aug  6 2008 olh@suse.de
- add patches.suse/ppc-no-LDFLAGS_MODULE.patch
  do not link external modules against arch/powerpc/lib/crtsavres.o
* Tue Aug  5 2008 jeffm@suse.de
- patches.fixes/reiserfs-commit-ids-unsigned-ints: reiserfs:
  audit transaction ids to always be unsigned ints (bnc#410847).
* Tue Aug  5 2008 jeffm@suse.de
- README.BRANCH: Took ownership of 11.1 tree.
* Tue Aug  5 2008 jeffm@suse.de
- README: Changed w3d links to wiki links.
* Tue Aug  5 2008 ghaskins@suse.de
  Fixed misnamed rt_trace to rt_timing
- config/x86_64/rt_trace: Delete.
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Added x86_64/rt_trace kernel flavor (based on ftrace)
- Update config files.
- config.conf:
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Fix rtmutex-tester build problem with rt_debug
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
* Tue Aug  5 2008 ghaskins@suse.de
  Guarded by +RT
- Remove version.patch to stop build breakage
* Tue Aug  5 2008 jjohansen@suse.de
- update apparmor patches with fixes for
  - broken getcwd (bnc#413915)
  - ref counting bug in getcwd and d_namespace_path when used
    on disconnected paths (bnc#414607)
  - typeo in patches that keep selinux from compiling (bnc#414609)
  - incorporate smack patch into base apparmor patches, so
    that smack can be built (bnc#414610)
* Tue Aug  5 2008 jslaby@suse.de
- patches.fixes/ath5k-fix-memory-corruption.patch: Ath5k: fix
  memory corruption (bnc#414635).
- patches.fixes/ath5k-kill-tasklets-on-shutdown.patch: Ath5k:
  kill tasklets on shutdown (bnc#414638).
* Mon Aug  4 2008 gregkh@suse.de
- README.BRANCH: added file.
* Mon Aug  4 2008 olh@suse.de
- disable CONFIG_SECURITY_ROOTPLUG because /init in initrd will
  not run if USB is compiled in and a specific USB device is not
  present
* Mon Aug  4 2008 jslaby@suse.de
- patches.fixes/tpm-write-data-types.patch: tpm: Use correct
  data types for sizes in tpm_write() and tpm_read() (bnc#400211).
* Fri Aug  1 2008 ghaskins@suse.de
  PI rework v0.5 and a fix from upstream for 26-rt1
- patches.rt/26-rt1-chirag.patch: This patch should solve some
  of the bug messages..
- patches.rt/add-generalized-pi-interface.patch: add generalized
  priority-inheritance interface.
- patches.rt/tie-pi-into-task.patch: sched: add the basic PI
  infrastructure to the task_struct.
- patches.rt/rtmutex-initialize-waiters.patch: rtmutex: formally
  initialize the rt_mutex_waiters.
- patches.rt/rtmutex-add_readers.patch: RT: wrap the rt_rwlock
  "add reader" logic.
- patches.rt/rtmutex-use-runtime-init.patch: rtmutex: use runtime
  init for rtmutexes.
- patches.rt/rtmutex-convert-to-libpi.patch: rtmutex: convert
  rtmutexes to fully use the PI library.
- patches.rt/rtmutex-defer-pi-until-sleepy.patch: rtmutex:
  pi-boost locks as late as possible.
* Fri Aug  1 2008 schwab@suse.de
- Reenable EFI_RTC.
* Fri Aug  1 2008 trenn@suse.de
- Update config files.
  Unset on forgotten archs:
  CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS
* Fri Aug  1 2008 trenn@suse.de
- patches.fixes/x86_hpet_amd_quirk.patch: Workaround a hpet BIOS
  bug which is common on latest AMD driven boards (bnc#387053).
* Fri Aug  1 2008 sassmann@suse.de
  Add boot interrupt patches from linux-2.6-tip
- patches.arch/x86-acpi-reroute-PCI-interrupt-to-legacy-boot-interrupt.patch
- patches.arch/x86-add-PCI-IDs-for-devices-that-need-boot-irq-quirk.patch
- patches.arch/x86-disable-AMD-ATI-boot-interrupt-generation.patch
- patches.arch/x86-disable-broadcomm-boot-interrupt-generation.patch
- patches.arch/x86-disable-intel-boot-interrupt-generation.patch
- patches.arch/x86-introduce-config-option-for-pci-reroute-quirks.patch
- patches.arch/x86-introduce-pci-ioapicreroute-kernel-cmdline.patch
- patches.arch/x86-introduce-pci-noioapicquirk-kernel-cmdline.patch
- Update config files.
  * reroute of boot interrupts is enabled for RT only!
* Thu Jul 31 2008 sdietrich@suse.de
  Update to 2.6.26-rt1:
- config.conf: Enable i386/x86_64 - RT / RT_debug
- Update config files:
  * Sync to default config.
  * Disable (broken):
  - Novell Netware Filesystem support (novfs) (EXPERIMENTAL) (NOVFS)
  - ISP 1760 HCD support (USB_ISP1760_HCD)
  - KDB
  - QLogic InfiniPath Driver (INFINIBAND_IPATH)
  Remove obsolete patches:
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-omap-03.patch: Delete.
- patches.rt/arm-omap-04.patch: Delete.
- patches.rt/disable-sched-rt-groups.patch: Delete.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Delete.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch: Delete.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Delete.
- patches.rt/drivers-edac-new-amd64.patch: Delete.
- patches.rt/drivers-edac-new-k8-rev-f.patch: Delete.
- patches.rt/drivers-edac-prevent-potential-printk-storm: Delete.
- patches.rt/drivers-edac-test_device.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/fix-alternate_node_alloc.patch: Delete.
- patches.rt/fix-irq-flags-size.patch: Delete.
- patches.rt/foo.patch: Delete.
- patches.rt/ftrace-add-nr_syscalls.patch: Delete.
- patches.rt/ftrace-alloc-pages.patch: Delete.
- patches.rt/ftrace-cpu-clock-update.patch: Delete.
- patches.rt/ftrace-debug-use-preempt-disable-notrace.patch:
  Delete.
- patches.rt/ftrace-direct-calls.patch: Delete.
- patches.rt/ftrace-disable-daemon.patch: Delete.
- patches.rt/ftrace-dont-use-raw-irq-save.patch: Delete.
- patches.rt/ftrace-eventtrace-fixup.patch: Delete.
- patches.rt/ftrace-filter-functions.patch: Delete.
- patches.rt/ftrace-fix-ip.patch: Delete.
- patches.rt/ftrace-flip-fix.patch: Delete.
- patches.rt/ftrace-handle-time-outside-of-lockdep.patch: Delete.
- patches.rt/ftrace-irqsoff-smp-processor-id-fix.patch: Delete.
- patches.rt/ftrace-lockdep-notrace-annotations.patch: Delete.
- patches.rt/ftrace-max-update-fixes.patch: Delete.
- patches.rt/ftrace-move-memory-management-to-generic.patch:
  Delete.
- patches.rt/ftrace-nop-calls.patch: Delete.
- patches.rt/ftrace-peterz-cpu_clock.patch: Delete.
- patches.rt/ftrace-remove-max-printks.patch: Delete.
- patches.rt/ftrace-safe-traversal-hlist.patch: Delete.
- patches.rt/ftrace-stop-function-trace-fix.patch: Delete.
- patches.rt/ftrace-unlock-mutex-in-output.patch: Delete.
- patches.rt/ftrace-update-cnt-stat-fix.patch: Delete.
- patches.rt/ftracer-build-fix.patch: Delete.
- patches.rt/futex-performance-hack-sysctl-fix.patch: Delete.
- patches.rt/futex-performance-hack.patch: Delete.
- patches.rt/git-ignore-module-markers.patch: Delete.
- patches.rt/irq-flags-unsigned-long.patch: Delete.
- patches.rt/kernel-bug-after-entering-something-from-login.patch:
  Delete.
- patches.rt/kthread-cpus-allowed-init.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/netfilter-more-debugging.patch: Delete.
- patches.rt/page-alloc-use-real-time-pcp-locking-for-page-draining.patch:
  Delete.
- patches.rt/pcounter-percpu-protect.patch: Delete.
- patches.rt/percpu-locked-powerpc-fixups-a6.patch: Delete.
- patches.rt/powerpc-rearrange-thread-flags-to-work-with-andi-instruction.patch:
  Delete.
- patches.rt/ppc-add-mcount.patch: Delete.
- patches.rt/ppc-add-ppc32-mcount.patch: Delete.
- patches.rt/ppc-mark-notrace-mainline.patch: Delete.
- patches.rt/ppc-mcount-dummy-functions.patch: Delete.
- patches.rt/ppc-rename-xmon-mcount.patch: Delete.
- patches.rt/ppc-select-mcount.patch: Delete.
- patches.rt/preempt-irqs-ppc-celleb-beatic-eoi.patch: Delete.
- patches.rt/preempt-irqs-softirq-in-hardirq.patch: Delete.
- patches.rt/preempt-realtime-powerpc-a7.patch: Delete.
- patches.rt/preempt-realtime-ppc-more-resched-fixups.patch:
  Delete.
- patches.rt/preempt-realtime-ppc-need-resched-delayed.patch:
  Delete.
- patches.rt/preempt-realtime-sh.patch: Delete.
- patches.rt/preempt-realtime-supress-cpulock-warning.patch:
  Delete.
- patches.rt/rcu-preempt-trace-markers-1.patch: Delete.
- patches.rt/rcu-preempt-trace-markers-2.patch: Delete.
- patches.rt/rcu-various-fixups.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-delayed-resched.patch: Delete.
- patches.rt/rt-mutex-drop-generic-TIF_NEED_RESCHED_DELAYED.patch:
  Delete.
- patches.rt/rt-time-starvation-fix.patch: Delete.
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/sched-fix-rt-task-wakeup.patch: Delete.
- patches.rt/sched-fix-sched-fair-wakeup.patch: Delete.
- patches.rt/sched-rt-push-only-new.patch: Delete.
- patches.rt/schedule_on_each_cpu-enhance-rt.patch: Delete.
- patches.rt/tasklet-fix-preemption-race.patch: Delete.
- patches.rt/tasklet-more-fixes.patch: Delete.
- patches.rt/time-gcc-linker-error.patch: Delete.
- patches.rt/tracer-use-sched-clock.patch: Delete.
- patches.rt/write-try-lock-irqsave.patch: Delete.
- patches.rt/x86-delay-enable-preempt-tglx.patch: Delete.
  Introduce 2.6.26-RT1:
- patches.rt/2.6.21-rc6-lockless3-radix-tree-gang-slot-lookups.patch:
  Linux-RT 2.6.26-RT
  radix-tree: gang slot lookups.
- patches.rt/2.6.21-rc6-lockless5-lockless-probe.patch: Linux-RT
  2.6.26-RT
  mm: lockless probe.
- patches.rt/2.6.21-rc6-lockless6-speculative-get-page.patch:
  Linux-RT 2.6.26-RT
  mm: speculative get page.
- patches.rt/2.6.21-rc6-lockless7-lockless-pagecache-lookups.patch:
  Linux-RT 2.6.26-RT
  mm: lockless pagecache lookups.
- patches.rt/2.6.21-rc6-lockless8-spinlock-tree_lock.patch:
  Linux-RT 2.6.26-RT
  mm: spinlock tree_lock.
- patches.rt/Add-dev-rmem-device-driver-for-real-time-JVM-testing.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/Allocate-RTSJ-memory-for-TCK-conformance-test.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/RT_utsname.patch: Linux-RT 2.6.26-RT.
- patches.rt/aacraid-compat-sem.patch: Linux-RT 2.6.26-RT.
- patches.rt/adapt-remove-extra-try-to-lock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-adjust-pi-wakeup.patch: Linux-RT 2.6.26-RT.
- patches.rt/adaptive-earlybreak-on-steal.patch: Linux-RT
  2.6.26-RT
  rtmutex: break out early on first run.
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch: Linux-RT
  2.6.26-RT.
- patches.rt/adaptive-spinlock-lite-v2.patch: Linux-RT 2.6.26-RT
  adaptive spinlocks lite.
- patches.rt/adaptive-task-oncpu.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-dumpstack.patch: Linux-RT 2.6.26-RT.
- patches.rt/apic-level-smp-affinity.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-compile-fix.patch: Linux-RT 2.6.26-RT
  ARM: compile fix for event tracing.
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-latency-tracer-support.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-02.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-omap-05.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-preempt-config.patch: Linux-RT 2.6.26-RT.
- patches.rt/arm-trace-preempt-idle.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-state-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/bh-uptodate-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/cache_pci_find_capability.patch: Linux-RT 2.6.26-RT
  Cache calls to pci_find_capability.
- patches.rt/call_rcu_bh-rename-of-call_rcu.patch: Linux-RT
  2.6.26-RT
  just rename call_rcu_bh instead of making it a macro.
- patches.rt/cond_resched_softirq-WARN-fix.patch: Linux-RT
  2.6.26-RT
  WARNING: at kernel/sched.c:5071 2.6.23-rc1-rt7.
- patches.rt/cputimer-thread-rt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/cputimer-thread-rt_A0.patch: Linux-RT 2.6.26-RT.
- patches.rt/cycles-to-ns-trace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/dev-queue-xmit-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-irqpoll.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-ist-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/disable-lpptest-on-nonlinux.patch: Linux-RT
  2.6.26-RT.
- patches.rt/disable-run-softirq-from-hardirq-completely.patch:
  Linux-RT 2.6.26-RT
  Disable running softirqs from hardirqs completely!.
- patches.rt/dont-disable-preemption-without-IST.patch: Linux-RT
  2.6.26-RT.
- patches.rt/dont-let-rt-rw_semaphores-do-non_owner-locks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/dont-unmask-io_apic.patch: Linux-RT 2.6.26-RT.
- patches.rt/drain-all-local-pages-via-sched.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-tracer-syscall-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/event-tracer-syscall-x86_64.patch: Linux-RT
  2.6.26-RT.
- patches.rt/export-schedule-on-each-cpu.patch: Linux-RT
  2.6.26-RT.
- patches.rt/filemap-dont-bug-non-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-acpi-build-weirdness.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-bug-on-in-filemap.patch: Linux-RT 2.6.26-RT
  Change bug_on for atomic to pagefault_disabled..
- patches.rt/fix-circular-locking-deadlock.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-compilation-for-non-RT-in-timer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/fix-emac-locking-2.6.16.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-emergency-reboot.patch: Linux-RT 2.6.26-RT
  call reboot notifier list when doing an emergency reboot.
- patches.rt/fix-migrating-softirq.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-softirq-checks-for-non-rt-preempt-hardirq.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch: Linux-RT 2.6.26-RT.
- patches.rt/floppy-resume-fix.patch: Linux-RT 2.6.26-RT
  floppy: suspend/resume fix.
- patches.rt/ftrace-compile-fixes.patch: Linux-RT 2.6.26-RT
  rt: remove call to stop tracer.
- patches.rt/ftrace-dont-trace-markers.patch: Linux-RT 2.6.26-RT
  ftrace: dont trace markers.
- patches.rt/ftrace-fix-header.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-function-record-nop.patch: Linux-RT 2.6.26-RT
  ftrace: define function trace nop.
- patches.rt/ftrace-print-missing-cmdline.patch: Linux-RT
  2.6.26-RT
  ftrace: fix the command line printing.
- patches.rt/ftrace-record-comm-on-ctrl.patch: Linux-RT 2.6.26-RT
  ftrace: record comm on function ctrl change.
- patches.rt/ftrace-trace-sched.patch: Linux-RT 2.6.26-RT
  ftrace: trace sched.c.
- patches.rt/ftrace-upstream.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-use-preempt-disable-not-irq-disable.patch:
  Linux-RT 2.6.26-RT
  ftrace: avoid lockdep recursion.
- patches.rt/gcc-warnings-shut-up.patch: Linux-RT 2.6.26-RT.
- patches.rt/genhd-protect-percpu-var.patch: Linux-RT 2.6.26-RT.
- patches.rt/genirq-soft-resend.patch: Linux-RT 2.6.26-RT
  x86: activate HARDIRQS_SW_RESEND.
- patches.rt/git-ignore-script-lpp.patch: Linux-RT 2.6.26-RT.
- patches.rt/gtod-optimize.patch: Linux-RT 2.6.26-RT.
- patches.rt/hack-convert-i_alloc_sem-for-direct_io-craziness.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/hack-fix-rt-migration.patch: Linux-RT 2.6.26-RT.
- patches.rt/handle-pending-in-simple-irq.patch: Linux-RT
  2.6.26-RT
  handle IRQ_PENDING for simple irq handler.
- patches.rt/highmem-redo-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem-revert-mainline.patch: Linux-RT 2.6.26-RT.
- patches.rt/highmem_rewrite.patch: Linux-RT 2.6.26-RT
  mm: remove kmap_lock.
- patches.rt/hrtimer-no-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/hrtimers-overrun-api.patch: Linux-RT 2.6.26-RT.
- patches.rt/i386-mark-atomic-irq-ops-raw.patch: Linux-RT
  2.6.26-RT.
- patches.rt/i386-nmi-watchdog-show-regs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ioapic-fix-too-fast-clocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/irda-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/irq-mask-fix.patch: Linux-RT 2.6.26-RT
  genirq: fix simple and fasteoi irq handlers.
- patches.rt/jbd_assertions_smp_only.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-i386-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kmap-atomic-prepare.patch: Linux-RT 2.6.26-RT.
- patches.rt/kprobes-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/kstat-add-rt-stats.patch: Linux-RT 2.6.26-RT
  add rt stats to /proc/stat.
- patches.rt/kstat-fix-spurious-system-load-spikes-in-proc-loadavgrt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/latency-measurement-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/latency-tracing-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/latency-tracing-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/loadavg_fixes_weird_loads.patch: Linux-RT 2.6.26-RT.
- patches.rt/local_irq_save_nort-in-swap.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lock-init-plist-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/lock_list.patch: Linux-RT 2.6.26-RT
  lock_list - a fine grain locked double linked list.
- patches.rt/lock_page_ref.patch: Linux-RT 2.6.26-RT
  mm: lock_page_ref.
- patches.rt/lockdep-avoid-fork-waring.patch: Linux-RT 2.6.26-RT
  ftrace: fix if define to prove locking.
- patches.rt/lockdep-lock_set_subclass.patch: Linux-RT 2.6.26-RT
  lockdep: lock_set_subclass - reset a held lock's subclass.
- patches.rt/lockdep-more-entries.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockdep-prettify.patch: Linux-RT 2.6.26-RT
  lockdep: prettify output.
- patches.rt/lockdep-rt-mutex.patch: Linux-RT 2.6.26-RT
  lockdep-rt: annotate PREEMPT_RT DEFINE_MUTEX.
- patches.rt/lockdep-rt-recursion-limit-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockdep-show-held-locks.patch: Linux-RT 2.6.26-RT
  lockdep: show held locks when showing a stackdump.
- patches.rt/lockdep_lock_set_subclass_fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/lockstat-fix-contention-points.patch: Linux-RT
  2.6.26-RT
  lockstat: fix contention points.
- patches.rt/lockstat-output.patch: Linux-RT 2.6.26-RT
  lockstat: warn about disabled lock debugging.
- patches.rt/lockstat-rt-hooks.patch: Linux-RT 2.6.26-RT.
- patches.rt/lockstat_bounce_rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/loopback-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/mapping_nrpages.patch: Linux-RT 2.6.26-RT
  mm/fs: abstract address_space::nrpages.
- patches.rt/mips-change-raw-spinlock-type.patch: Linux-RT
  2.6.26-RT
  RT: change from raw_spinlock_t to __raw_spinlock_t.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Linux-RT 2.6.26-RT
  RT: remove conflicting rtc_lock declaration.
- patches.rt/mips-remove-duplicate-kconfig.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mips-remove-finish-arch-switch.patch: Linux-RT
  2.6.26-RT
  RT: remove finish_arch_switch.
- patches.rt/mitigate-resched-flood.patch: Linux-RT 2.6.26-RT.
- patches.rt/mm-concurrent-pagecache-rt.patch: Linux-RT 2.6.26-RT
  mm: -rt bits for concurrent pagecache.
- patches.rt/mm-concurrent-pagecache.patch: Linux-RT 2.6.26-RT
  mm: concurrent pagecache write side.
- patches.rt/mm-fix-latency.patch: Linux-RT 2.6.26-RT
  reduce pagetable-freeing latencies.
- patches.rt/move-native-irq.patch: Linux-RT 2.6.26-RT.
- patches.rt/msi-suspend-resume-workaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/multi-reader-account.patch: Linux-RT 2.6.26-RT
  map tasks to reader locks held.
- patches.rt/multi-reader-limit.patch: Linux-RT 2.6.26-RT
  implement reader limit on read write locks.
- patches.rt/multi-reader-lock-account.patch: Linux-RT 2.6.26-RT
  map read/write locks back to their readers.
- patches.rt/multi-reader-pi.patch: Linux-RT 2.6.26-RT
  read lock Priority Inheritance implementation.
- patches.rt/native-sched-clock-booboo.patch: Linux-RT 2.6.26-RT.
- patches.rt/neptune-no-at-keyboard.patch: Linux-RT 2.6.26-RT.
- patches.rt/net-core-preempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/netpoll-8139too-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/new-softirq-code.patch: Linux-RT 2.6.26-RT
  softirq preemption: optimization.
- patches.rt/nf_conntrack-fix-smp-processor-id.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nf_conntrack-weird-crash-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/nmi-profiling-base.patch: Linux-RT 2.6.26-RT
  nmi-driven profiling for /proc/profile.
- patches.rt/nmi-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-show-regs-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-disable.patch: Linux-RT 2.6.26-RT
  x86_64: do not enable the NMI watchdog by default.
- patches.rt/nmi-watchdog-fix-1.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-2.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-3.patch: Linux-RT 2.6.26-RT.
- patches.rt/nmi-watchdog-fix-4.patch: Linux-RT 2.6.26-RT.
- patches.rt/no-warning-for-irqs-disabled-in-local-bh-enable.patch:
  Linux-RT 2.6.26-RT
  local_bh_enable() is safe for irqs_disabled().
- patches.rt/ntfs-local-irq-save-nort.patch: Linux-RT 2.6.26-RT.
- patches.rt/numa-slab-freeing.patch: Linux-RT 2.6.26-RT.
- patches.rt/only-run-softirqs-from-irq-thread-when-irq-affinity-is-set.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/pagefault-disable-cleanup.patch: Linux-RT 2.6.26-RT
  clean up the page fault disabling logic.
- patches.rt/panic-dont-stop-box.patch: Linux-RT 2.6.26-RT.
- patches.rt/paravirt-function-pointer-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/pause-on-oops-head-tail.patch: Linux-RT 2.6.26-RT
  introduce pause_on_oops_head/tail boot options.
- patches.rt/percpu-locked-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-netfilter2.patch: Linux-RT 2.6.26-RT.
- patches.rt/percpu-locked-powerpc-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/percpu_list.patch: Linux-RT 2.6.26-RT
  percpu_list.
- patches.rt/plist-debug.patch: Linux-RT 2.6.26-RT.
- patches.rt/posix-cpu-timers-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/powerpc-count_active_rt_tasks-is-undefined-for-non-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-flush_tlb_pending-is-no-more.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/powerpc-match-__rw_yield-function-declaration-to-prototype.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-chpr-set-rtc-lock.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-gtod-notrace-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-hacks-to-allow-rt-to-run-kernbench.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ppc-make-tlb-batch-64-only.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc-tlbflush-preempt.patch: Linux-RT 2.6.26-RT.
- patches.rt/ppc32-latency-compile-hack-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ppc32_notrace_init_functions.patch: Linux-RT
  2.6.26-RT
  don't trace early init functions for ppc32.
- patches.rt/preempt-irqs-Kconfig.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-direct-debug-keyboard.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-hrtimer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-idle-poll-loop-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-i386-ioapic-mask-quirk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-ack-irq-fixups.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b5.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-b6.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc-fix-more-fasteoi.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-irqs-ppc-preempt-schedule-irq-entry-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64-ioapic-mask-quirk.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-acpi.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-bagde4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-footbridge.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-integrator.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-arm-pxa.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm-shark.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-compile-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-console.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-debug-sysctl.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-fs-block.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ftrace.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ia64.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ide.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-init-show-enabled-debugs.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-input.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-ipc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-irqs.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-loopback.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mellanox-driver-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mmdrop-delayed.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-drivers.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-net-softirq-fixups.patch: Linux-RT
  2.6.26-RT
  NOHZ: local_softirq_pending with tickless.
- patches.rt/preempt-realtime-net.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-add-raw-relax-macros.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b3.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-b4.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-celleb-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-missing-raw-spinlocks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-tlb-batching.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-powerpc-update.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-powerpc.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-prevent-idle-boosting.patch:
  Linux-RT 2.6.26-RT
  Premmpt-RT: Preevent boosting of idle task.
- patches.rt/preempt-realtime-printk.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-profiling.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rawlocks.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-rcu.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sched-cpupri.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched-i386.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-sound.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-nohz-softirq-warning.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-supress-rtc-printk.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-realtime-timer.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-usb.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-warn-and-bug-on.patch: Linux-RT
  2.6.26-RT.
- patches.rt/preempt-rt-no-slub.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-softirqs-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/preempt-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/print-might-sleep-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-dont-bug-on-sched.patch: Linux-RT 2.6.26-RT.
- patches.rt/printk-in-atomic-hack-fix.patch: Linux-RT 2.6.26-RT
  fix printk in atomic hack.
- patches.rt/printk-in-atomic.patch: Linux-RT 2.6.26-RT.
- patches.rt/proportions-raw-locks.patch: Linux-RT 2.6.26-RT.
- patches.rt/qrcu.patch: Linux-RT 2.6.26-RT
  QRCU with lockless fastpath.
- patches.rt/quicklist-release-before-free-page-fix.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/quicklist-release-before-free-page.patch: Linux-RT
  2.6.26-RT.
- patches.rt/radix-concurrent-lockdep.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-percpu-hack-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-concurrent.patch: Linux-RT 2.6.26-RT
  radix-tree: concurrent write side support.
- patches.rt/radix-tree-optimistic-hist.patch: Linux-RT 2.6.26-RT
  debug: optimistic lock histogram.
- patches.rt/radix-tree-optimistic.patch: Linux-RT 2.6.26-RT
  radix-tree: optimistic locking.
- patches.rt/random-driver-latency-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-hrt-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-new-7.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-default.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-boost-sdr.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-fix-bad-dyntick-accounting.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/rcu-preempt-hotplug-hackaround.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rcu-torture-preempt-update.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcu-trace-fix-free.patch: Linux-RT 2.6.26-RT.
- patches.rt/rcupreempt-boost-early-init.patch: Linux-RT
  2.6.26-RT.
- patches.rt/realtime-preempt-warn-about-tracing.patch: Linux-RT
  2.6.26-RT.
- patches.rt/relay-fix.patch: Linux-RT 2.6.26-RT
  relay: fix timer madness.
- patches.rt/remove-check-pgt-cache-calls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/replace-bugon-by-warn-on.patch: Linux-RT 2.6.26-RT.
- patches.rt/root-domain-kfree-in-atomic.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-apis.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-avoid-deadlock-in-swap.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-delayed-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: propagate prio for delayed work.
- patches.rt/rt-kmap-scale-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-list-mods.patch: Linux-RT 2.6.26-RT
  rt: list_splice2.
- patches.rt/rt-move-update-wall-time-back-to-do-timer.patch:
  Linux-RT 2.6.26-RT
  rt: move update_wall_time back to do timer.
- patches.rt/rt-mutex-arm.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-compat-semaphores.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-i386.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-irq-flags-checking.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-mips.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc-fix-a5.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-ppc.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-preempt-debugging.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-mutex-trivial-route-cast-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-trivial-tcp-preempt-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-mutex-x86-64.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-page_alloc.patch: Linux-RT 2.6.26-RT
  rt-friendly per-cpu pages.
- patches.rt/rt-plist-mods.patch: Linux-RT 2.6.26-RT
  rt: plist_head_splice.
- patches.rt/rt-s_files-kill-a-union.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-sched-groups.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-shorten-softirq-thread-names.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rt-slab-new.patch: Linux-RT 2.6.26-RT.
- patches.rt/rt-workqeue-prio.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue support.
- patches.rt/rt-workqueue-barrier.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: fix barriers.
- patches.rt/rt-wq-barrier-fix.patch: Linux-RT 2.6.26-RT
  rt: PI-workqueue: wait_on_work() fixup.
- patches.rt/rt_mutex_setprio.patch: Linux-RT 2.6.26-RT
  rt: rename rt_mutex_setprio to task_setprio.
- patches.rt/rtmutex-debug.h-cleanup.patch: Linux-RT 2.6.26-RT
  lock debugging: clean up rtmutex-debug.h.
- patches.rt/rtmutex-lateral-steal.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-rearrange.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-remove-xchg.patch: Linux-RT 2.6.26-RT
  rtmutex - remove double xchg.
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-implement-downgrade-write.patch: Linux-RT
  2.6.26-RT
  rwlocks multi downgrade write.
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlocks-fix-no-preempt-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix non PREEMPT_RT case.
- patches.rt/rwlocks-multiple-readers.patch: Linux-RT 2.6.26-RT
  implement rwlocks management.
- patches.rt/rwsems-multiple-readers.patch: Linux-RT 2.6.26-RT
  add framework for multi readers on rwsems.
- patches.rt/s_files-pipe-fix.patch: Linux-RT 2.6.26-RT
  s_files: free_write_pipe() fix.
- patches.rt/s_files-schedule_on_each_cpu_wq.patch: Linux-RT
  2.6.26-RT.
- patches.rt/s_files.patch: Linux-RT 2.6.26-RT
  remove global files_lock.
- patches.rt/sched-clock-nmi.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-enable-irqs-in-preempt-in-notifier-call.patch:
  Linux-RT 2.6.26-RT
  CFS: enable irqs in fire_sched_in_preempt_notifier.
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-rt-stats.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/sched-wake_up_idle_cpu-rt.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_prio.patch: Linux-RT 2.6.26-RT.
- patches.rt/sched_rt-fixup.patch: Linux-RT 2.6.26-RT.
- patches.rt/schedule-tail-balance-disable-irqs.patch: Linux-RT
  2.6.26-RT.
- patches.rt/schedule_on_each_cpu-enhance.patch: Linux-RT
  2.6.26-RT.
- patches.rt/select-error-leak-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/send-nmi-all-preempt-disable.patch: Linux-RT
  2.6.26-RT.
- patches.rt/seq-irqsave.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-locking-rt-cleanup.patch: Linux-RT 2.6.26-RT.
- patches.rt/serial-slow-machines.patch: Linux-RT 2.6.26-RT.
- patches.rt/slab-irq-nopreempt-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/smp-processor-id-fixups.patch: Linux-RT 2.6.26-RT.
- patches.rt/softirq-per-cpu-assumptions-fixes.patch: Linux-RT
  2.6.26-RT.
- patches.rt/softlockup-add-irq-regs-h.patch: Linux-RT 2.6.26-RT
  core: make asm/irq_regs.h available on every platform.
- patches.rt/spinlock-trylock-cleanup-sungem.patch: Linux-RT
  2.6.26-RT.
- patches.rt/swap-spinlock-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-busy-loop-hack.patch: Linux-RT 2.6.26-RT.
- patches.rt/tasklet-redesign.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-freq-tweaks.patch: Linux-RT 2.6.26-RT.
- patches.rt/timer-warning-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-add-event-markers-arm.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-events-handle-syscalls.patch: Linux-RT
  2.6.26-RT.
- patches.rt/trace-histograms.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace_hist-divzero.patch: Linux-RT 2.6.26-RT
  trace_hist.c: divide-by-zero problem (2).
- patches.rt/trace_hist-latediv.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-add-event-markers.patch: Linux-RT 2.6.26-RT.
- patches.rt/tracer-event-trace.patch: Linux-RT 2.6.26-RT.
- patches.rt/use-edge-triggered-irq-handler-instead-of-simple-irq.patch:
  Linux-RT 2.6.26-RT
  [AT91: PATCH]: Use edge triggered interrupt handling for
  AT91-GPIO instead of simple_irq-handler.
- patches.rt/user-no-irq-disable.patch: Linux-RT 2.6.26-RT.
- patches.rt/version.patch: Linux-RT 2.6.26-RT
  add -rt extra-version.
- patches.rt/vortex-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/watchdog_use_timer_and_hpet_on_x86_64.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/x86-64-tscless-vgettimeofday.patch: Linux-RT
  2.6.26-RT
  x86_64 GTOD: offer scalable vgettimeofday.
- patches.rt/x86_64-tsc-sync-irqflags-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/event-trace-hrtimer-trace.patch: Linux-RT 2.6.26-RT
  event-tracer: add clockevent trace.
- patches.rt/ftrace-hotplug-fix.patch: Linux-RT 2.6.26-RT
  ftrace: cpu hotplug fix.
- patches.rt/ftrace-wakeup-rawspinlock.patch: Linux-RT 2.6.26-RT
  ftrace: user raw spin lock for wakeup function trace.
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.26-RT.
- patches.rt/radix-tree-lockdep-plus1.patch: Linux-RT 2.6.26-RT
  lockdep: add +1 to radix tree array.
- patches.rt/rwlock-fixes.patch: Linux-RT 2.6.26-RT
  rwlock: fix pi_list race conditions.
- patches.rt/rwlock-prio-fix.patch: Linux-RT 2.6.26-RT
  rwlock: reset prio on unlocks and wakeups.
- patches.rt/rwlock-torture.patch: Linux-RT 2.6.26-RT
  rwlock: rwlock torture test.
- patches.rt/sched-cpupri-hotplug-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/sched-cpupri-priocount.patch: Linux-RT 2.6.26-RT.
- patches.rt/trace-eip2ip.patch: Linux-RT 2.6.26-RT
  Re: 2.6.25.4-rt4.
- patches.rt/bz235099-idle-load-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/fix-adaptive-hack.patch: Linux-RT 2.6.26-RT
  fix-adaptive-hack.patch.
- patches.rt/fix-a-previously-reverted-fix.patch: Linux-RT
  2.6.26-RT
  Fix a previously reverted "fix".
- patches.rt/fix-config-debug-rt-mutex-lock-underflow-warnings.patch:
  Linux-RT 2.6.26-RT
  Fix CONFIG_DEBUG_RT_MUTEX lock underflow warnings.
- patches.rt/frace-use-tsc.patch: Linux-RT 2.6.26-RT.
- patches.rt/ftrace-document-event-tracer.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-document-update1.patch: Linux-RT 2.6.26-RT
  ftrace: document updates.
- patches.rt/ftrace-fix-get-kprobe-wreckage.patch: Linux-RT
  2.6.26-RT
  ftrace-fix-missing-kprobe-include.pathc.
- patches.rt/ftrace-m68knommu-add-FTRACE-support.patch: Linux-RT
  2.6.26-RT.
- patches.rt/ftrace-m68knommu-generic-stacktrace-function.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/ftrace-preempt-trace-check.patch: Linux-RT 2.6.26-RT
  ftrace: only trace preempt off with preempt tracer.
- patches.rt/ftrace-stop-trace-on-crash.patch: Linux-RT 2.6.26-RT
  fix-tracer-wreckage-wtf-is-this-code-all-features.patch.
- patches.rt/generic-cmpxchg-use-raw-local-irq-variant.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/idle2-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/idle-fix.patch: Linux-RT 2.6.26-RT.
- patches.rt/m68knommu_fixes_ontop_of_v2.6.26.patch: Linux-RT
  2.6.26-RT.
- patches.rt/m68knommu-make-cmpxchg-RT-safe.patch: Linux-RT
  2.6.26-RT.
- patches.rt/mapping_nrpages-fix.patch: Linux-RT 2.6.26-RT
  mapping_nrpages-fix.patch.
- patches.rt/nfs-stats-miss-preemption.patch: Linux-RT 2.6.26-RT
  nfs: fix missing preemption check.
- patches.rt/pmtmr-override.patch: Linux-RT 2.6.26-RT
  pmtmr: allow command line override of ioport.
- patches.rt/powerpc-ftrace-stop-on-oops.patch: Linux-RT 2.6.26-RT
  powerpc: ftrace stop on crash.
- patches.rt/ppc64-fix-preempt-unsafe-paths-accessing-per_cpu-variables.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-irqs-m68knommu-make-timer-interrupt-non-threaded.patch:
  Linux-RT 2.6.26-RT.
- patches.rt/preempt-realtime-mm.patch~: Linux-RT 2.6.26-RT.
- patches.rt/raw-spinlocks-for-nmi-print.patch: Linux-RT
  2.6.26-RT.
- patches.rt/revert-preempt-bkl-revert.patch: Linux-RT 2.6.26-RT.
- patches.rt/rtmutex-debug-fix.patch: Linux-RT 2.6.26-RT
  rtmutex-debug-fix.patch.
- patches.rt/rt-mutex-namespace.patch: Linux-RT 2.6.26-RT
  rt-mutex-namespace.patch.
- patches.rt/rt-mutex-use-inline.patch: Linux-RT 2.6.26-RT
  rt-mutex-cleanup.patch.
- patches.rt/rt-rwlock-conservative-locking.patch: Linux-RT
  2.6.26-RT
  rwlock: be more conservative in locking reader_lock_count.
- patches.rt/rwlock-pi-lock-reader.patch: Linux-RT 2.6.26-RT.
- patches.rt/rwlock-protect-reader_lock_count.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix2.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-slowunlock-mutex-fix.patch: Linux-RT
  2.6.26-RT.
- patches.rt/rwlock-torture-no-rt.patch: Linux-RT 2.6.26-RT
  rwlock: fix torture test to handle non-rt.
- patches.rt/sched-fix-dequeued-race.patch: Linux-RT 2.6.26-RT
  sched-fix-dequeued-race.patch.
- patches.rt/serial-locking-rt-cleanup.patch~: Linux-RT 2.6.26-RT.
- patches.rt/sub-dont-disable-irqs.patch: Linux-RT 2.6.26-RT
  rt: dont disable irqs in usb.
- patches.rt/trace-do-not-wakeup-when-irqs-disabled.patch:
  Linux-RT 2.6.26-RT
  trace-do-not-wakeup-when-irqs-disabled.patch.
- patches.rt/trace-ktime-scalar.patch: Linux-RT 2.6.26-RT
  ftrace: print ktime values in readable form.
- patches.rt/warn-on-rt-scatterlist.patch: Linux-RT 2.6.26-RT
  remove warn on for scatterlist in preempt rt.
* Tue Jul 29 2008 trenn@suse.de
- patches.arch/acpi_thermal_passive_blacklist.patch: Avoid
  critical temp shutdowns on specific ThinkPad T4x(p) and R40
  (https://bugzilla.novell.com/show_bug.cgi?id=333043).
- patches.fixes/acpi_use_acpi_exception.patch: ACPI dock/bay:
  Use ACPI_EXCEPTION instead of printk(KERN_ERR.
- patches.suse/acpi_provide_non_windows_osi_boot_param.patch:
  ACPI: Provide a spec conform OSI interface to the BIOS.
* Mon Jul 28 2008 bphilips@suse.de
- rpm/kernel-binary.spec.in: uvcvideo merged.  Add Obsoletes.
* Fri Jul 25 2008 mszeredi@suse.cz
- supported.conf: Mark fuse as supported.
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_MARKERS
* Thu Jul 24 2008 gregkh@suse.de
- Enable CONFIG_SECURITY_SELINUX
* Thu Jul 24 2008 agruen@suse.de
- Fix for using relative paths in /usr/src/linux-obj/$arch/
  $flavor/Makefile (bnc#409982).
* Fri Jul 18 2008 hare@suse.de
- Update config files for S/390.
* Thu Jul 17 2008 bwalle@suse.de
- patches.fixes/show-OSRELEASE-in-VMCOREINFO.diff:
  kdump: Report actual value of VMCOREINFO_OSRELEASE in VMCOREINFO
* Thu Jul 17 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Removed Supplements handling
  entirely. Use preamble instead.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.26: Fix 32-bit build.
* Thu Jul 17 2008 jbeulich@novell.com
- Update Xen patches for 2.6.26.
- patches.xen/540-blkif-nr-segments-check.patch: Delete.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: Delete.
- patches.xen/xen3-patch-2.6.25.1: Delete.
- Update i386 and x86-64 config files.
- config.conf: Re-enable Xen configs.
* Thu Jul 17 2008 jbeulich@novell.com
- patches.fixes/seccomp-disable-tsc-option: Also handle x86-64 (191123).
- Update x86-64 config files.
- patches.suse/raw_device_max_minors_param.diff: Fix uninitialized
  return value.
- patches.apparmor/remove_suid.diff: Also handle fuse.
- supported.conf: Add e1000e, rtc-core, rtc-lib, and rtc-cmos.
* Mon Jul 14 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: Delete.
* Mon Jul 14 2008 olh@suse.de
- disable unused fsl-diu-fb driver
* Mon Jul 14 2008 jeffm@suse.de
- Updated to 2.6.26-final.
* Mon Jul 14 2008 bwalle@suse.de
- patches.fixes/move-crashkernel-reservation.diff:
  x86: Move crashkernel reservation before dma32_reserve_bootmem().
* Mon Jul 14 2008 rgoldwyn@suse.de
- Enable patches.suse/convert-novfs-to-open-soure-coding-standards.patch
  Fix oops in novfs_daemon_lib_ioctl
* Fri Jul 11 2008 jeffm@suse.de
- Updated squashfs to v3.3. (bnc#373285)
* Thu Jul 10 2008 jeffm@suse.de
- Update config files: Enable raw devices on s390.
* Thu Jul 10 2008 jack@suse.cz
- patches.suse/raw_device_max_minors_param.diff: Allow setting
  of number of raw devices as a module parameter (FATE 302178).
* Thu Jul 10 2008 jeffm@suse.de
- patches.kernel.org/fsl-diu-fb-compile-fix: fsl-diu-fb:
  compile fix.
* Wed Jul  9 2008 jeffm@suse.de
- patches.suse/kdb-common: Removed obsolete file_lock_operations
  printing.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: Upstreamed with
  - git5.
* Wed Jul  9 2008 jeffm@suse.de
- patches.fixes/reiserfs-discard-xattr-prealloc: reiserfs:
  discard prealloc in reiserfs_delete_inode (bnc#389656).
* Wed Jul  9 2008 jeffm@suse.de
- Updated to 2.6.26-rc9-git5.
  - Eliminated 2 patches.
* Wed Jul  9 2008 jbohac@suse.cz
- Update config files.
- patches.suse/netfilter-ip_conntrack_slp.patch: connection
  tracking helper for SLP (fate#301134).
* Wed Jul  9 2008 olh@suse.de
- enable PHYP-assisted OS dump (fate#304131)
* Mon Jul  7 2008 trenn@suse.de
- patches.fixes/acpi_thermal_passive_cleanup.patch: Delete.
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-gericom-bellagio-to-nomux.patch: Input:
  add Gericom Bellagio to nomux blacklist (bnc#404892).
* Wed Jul  2 2008 jkosina@suse.de
- patches.fixes/input-add-acer-aspire-1360-to-nomux.patch: Input:
  add Acer Aspire 1360 to nomux blacklist (bnc#216857).
* Wed Jul  2 2008 jeffm@suse.de
- patches.apparmor/__d_path-keep-connected.diff
  patches.apparmor/mount-consistent-__d_path.diff
  patches.suse/kdb-ia64: Edited to apply with --fuzz=0
- Added --fuzz=0 (-F0) to sequence-patch.sh and spec files
* Fri Jun 27 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: don't generate the makedumpfile.config
  any more, the new kernel, kexec-tools and makedumpfile is able to
  extract that information from the running kernel and pass it
  as ELF NOTE (in /proc/vmcore)
* Thu Jun 26 2008 olh@suse.de
- add patches.arch/ppc-ibmebus-modalias.patch
  autoload ehea and ehca (bnc#394602 - LTC44938)
* Thu Jun 26 2008 sdietrich@suse.de
- RT:  Update config files - enable CONFIG_CGROUPS
* Thu Jun 26 2008 sdietrich@suse.de
- Update config files - enable CPUSETs support:
  CONFIG_CGROUPS, CONFIG_CGROUP_NS, CONFIG_CGROUP_DEVICE,
  CONFIG_CPUSET, CONFIG_CGROUP_CPUACCT,
  CONFIG_RESOURCE_COUNTERS, CONFIG_MM_OWNER,
  CONFIG_CGROUP_MEM_RES_CTLR, CONFIG_PROC_PID_CPUSET
- debug only: CONFIG_CGROUP_DEBUG
* Wed Jun 25 2008 jeffm@suse.de
- Updated to 2.6.26-rc8
  - Eliminated 1 patch.
* Wed Jun 25 2008 jeffm@suse.de
- rpm/kernel-module-subpackage: Added Supplements tag copying and added
    coreutils and grep to Requires
- rpm/macros.kernel-source: Added kernel-syms to BuildRequires
* Wed Jun 25 2008 olh@suse.de
- enable 64K pages in config ppc64 (fate#304100)
- enable up to 1024 cpus in config ppc64 (fate#304180)
- enable up to 4 cpus in config kdump
- enable powermanagement in config ppc64
- enable cell be cpufreq
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Update the list of i2c bus drivers.
  - i2c-isa is gone.
  - i2c-i810, i2c-prosavage and i2c-savage4 are deprecated and will
    be removed soon, mark as unsupported.
  - i2c-voodoo3 has very limited usefulness, mark as unsupported.
  - i2c-powermac is new, mark as supported.
- supported.conf: Update the list of i2c chip drivers.
  - ds1337, ds1374, rtc8564 and x1205 are gone (RTC drivers, moved
    to drivers/rtc).
  - pca9539, pcf8574 and pcf8575 are deprecated (new GPIO drivers
    exist in drivers/gpio), mark as unsupported.
  - ds1682, max6875 and tsl2550 are new, mark as supported.
* Wed Jun 25 2008 jdelvare@suse.de
- supported.conf: Add two new hwmon drivers (dme1737 and thmc50,
  both unsupported.)
- supported.conf: Mark hwmon and hwmon-vid as supported. These are
  simple, software-only utility modules, it makes little sense
  to taint the kernel just because they are loaded.
* Mon Jun 23 2008 tiwai@suse.de
- disable CONFIG_SND_PCSP as it conflicts with input pcspkr and
  disturbs the order of sound devices
* Mon Jun 23 2008 agruen@suse.de
- genksyms: add support for checking against a reference ABI.
* Wed Jun 18 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git5.
  - Eliminated 2 patches.
* Fri Jun 13 2008 jeffm@suse.de
- Removed kABI reference symbols
- Restored make-symsets check for ignoring/tolerating kABI changes.
* Fri Jun 13 2008 jeffm@suse.de
- Update config files (vanilla).
* Fri Jun 13 2008 jeffm@suse.de
- Update config files.
* Fri Jun 13 2008 jeffm@suse.de
- Updated to 2.6.26-rc6-git1.
  - Eliminated 2 patches.
* Thu Jun 12 2008 sdietrich@suse.de
- config.conf: Suppress RT until forward-port is complete
* Thu Jun 12 2008 jeffm@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: Delete.
* Thu Jun 12 2008 olh@suse.de
- update ps3 config, disable unused drivers
- disable patches.arch/ppc-efika-slowdown.patch
* Thu Jun 12 2008 jeffm@suse.de
- Updated to 2.6.26-rc5-git5.
  - Eliminated 91 patches.
  - Disabled OCFS2 userspace heartbeat.
  - Disabled Xen.
* Thu Jun 12 2008 sdietrich@suse.de
  Build fix: drop patches merged into 2.6.25.5
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: Delete.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  Delete.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: Delete.
  Update to 2.6.25-RT6:
- Update config files: enable (M) CONFIG_RWLOCK_TORTURE_TEST
  Resolve conflicts:
- patches.rt/preempt-realtime-x86_64.patch: Linux-RT 2.6.25.4-RT.
  Add:
- patches.rt/trace-eip2ip.patch: Re: 2.6.25.4-rt4 Compile Fix.
- patches.rt/rwlock-prio-fix.patch: rwlock: reset prio on unlocks
  and wakeups.
- patches.rt/rwlock-fixes.patch: rwlock: fix pi_list race
  conditions.
- patches.rt/event-trace-hrtimer-trace.patch: event-tracer:
  add clockevent trace.
- patches.rt/rwlock-torture.patch: rwlock: rwlock torture test.
- patches.rt/ftrace-wakeup-rawspinlock.patch: ftrace: user raw
  spin lock for wakeup function trace.
- patches.rt/radix-tree-lockdep-plus1.patch: lockdep: add +1 to
  radix tree array.
- patches.rt/sched-cpupri-hotplug-support.patch: sched: fix
  cpupri hotplug support.
- patches.rt/sched-cpupri-priocount.patch: sched: fix cpupri
  priocount.
- patches.rt/ftrace-hotplug-fix.patch: ftrace: cpu hotplug fix.
* Wed Jun 11 2008 agruen@suse.de
- rpm/make-symsets: update to the latest version which will ignore
  symset changes if the symset includes a symbol marked to be
  ignored.
* Wed Jun 11 2008 agruen@suse.de
- rpm/kernel-binary.spec.in: only generate symsets for kernels
  with CONFIG_MODULES=y.
- rpm/macros.kernel-source: remove the ps3 specific check: we
  really want to check whether the kernel mas modules enabled,
  which is covered by the symsets check already now.
* Wed Jun 11 2008 gregkh@suse.de
- patches.drivers/usb-don-t-use-reset-resume-if-drivers-don-t-support-it.patch:
  USB: don't use reset-resume if drivers don't support it.
* Wed Jun 11 2008 gregkh@suse.de
- comment out
  patches.suse/convert-novfs-to-open-soure-coding-standards.patch in the
  series file as it is reported to fail some regression tests.
* Wed Jun 11 2008 gregkh@suse.de
- patches.suse/convert-novfs-to-open-soure-coding-standards.patch:
  Convert novfs to open soure coding standards.
* Mon Jun  9 2008 gregkh@suse.de
- patches.fixes/mptbase-vmware-fix: Delete as it's not needed anymore
* Mon Jun  9 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Mon Jun  9 2008 gregkh@suse.de
- Update to 2.6.25.6
  - loads of bugfixes
  - remove the following patches that were already included in this release:
  - patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch
  - patches.drivers/libata-force-hardreset-if-link-pm
  - patches.fixes/input-hid-apple-numlock-emulation.patch
  - patches.arch/check-for-acpi-resource-conflicts-in-i2c-bus-drivers.patch
* Mon Jun  9 2008 gregkh@suse.de
- patches.drivers/usb-sierra-option.patch: USB: update sierra
  and option device ids (bnc#374637).
* Mon Jun  9 2008 teheo@suse.de
- patches.drivers/libata-ahci-mcp65-workarounds: ahci: workarounds
  for mcp65 (bnc#398573).
* Mon Jun  9 2008 jkosina@suse.de
- patches.fixes/input-i8042-add-ctr-resume-timeout.patch: Input:
  add retry logic to resume with respect to CTR (bnc#351119).
* Sat Jun  7 2008 gregkh@suse.de
- Update to 2.6.25.5.
  - fixes CVE-2008-1673
* Fri Jun  6 2008 tiwai@suse.de
- add missing patches.rt/ftrace-add-nr_syscalls.patch for fixing
  i386-rt_debug
* Thu Jun  5 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25: netfront (bnc#394575) and page table
  handling (bnc#396858) fixes.
- patches.xen/540-blkif-nr-segments-check.patch: Avoid theoretical
  TOCTTOU bug in block backend nr_segments checking.
- patches.xen/560-x86_64-no-irq-affinity-break-msg.patch: x86_64:
  Remove warning message about 'Breaking affinity for irq'.
- patches.xen/xen-netfront-flip-prod: fix updating of req_prod_pvt
  in the receive ring for the flipping case.
* Wed Jun  4 2008 jblunck@suse.de
- patches.drivers/libata-acpi-fix-hotplug: Don't call ata_port_freeze()
  in ata_acpi_detach_device().
* Wed Jun  4 2008 schwab@suse.de
- Don't clean asm-offsets.h.
* Wed Jun  4 2008 jjohanse@suse.de
- patches.apparmor/apparmor-module_interface.diff: AppArmor:
  Update patch to properly set profile name_table size (bnc#396993)
* Tue Jun  3 2008 jkosina@suse.de
- patches.fixes/input-add-amilo-pro-v-to-nomux.patch: Add
  Fujitsu-Siemens Amilo Pro 2010 and 2030 to nomux list
  (bnc#345699 bnc#389169)
* Tue Jun  3 2008 tiwai@suse.de
- patches.drivers/alsa-hda-realtek-auto-resume-fix: hda - Fix
  resume of auto-config mode with Realtek codecs (bnc#385473).
* Tue Jun  3 2008 bphilips@suse.de
  Backport: e1000e for montevina systems
- patches.drivers/e1000e-backport-0001-remove-no-longer-used-e1000e_read_nvm_spi.patch:
  e1000e: remove no longer used e1000e_read_nvm_spi.
- patches.drivers/e1000e-backport-0002-remove-irq_sem.patch:
  e1000e: remove irq_sem.
- patches.drivers/e1000e-backport-0003-rename-mc_addr_list_update.patch:
  e1000e: rename mc_addr_list_update.
- patches.drivers/e1000e-backport-0004-reorganize-PHY-and-flow-control-interface.patch:
  e1000e: reorganize PHY and flow control interface.
- patches.drivers/e1000e-backport-0005-Make-arrays-out-of-these-Rx-Tx-registers.patch:
  e1000e: Make arrays out of these Rx/Tx registers.
- patches.drivers/e1000e-backport-0006-rename-a-few-functions.patch:
  e1000e: rename a few functions.
- patches.drivers/e1000e-backport-0007-cleanup-several-stats-issues.patch:
  e1000e: cleanup several stats issues.
- patches.drivers/e1000e-backport-0008-Fix-HW-Error-on-es2lan-ARP-capture-issue-by.patch:
  e1000e: Fix HW Error on es2lan, ARP capture issue by BMC.
- patches.drivers/e1000e-backport-0009-Add-support-for-BM-PHYs-on-ICH9.patch:
  e1000e: Add support for BM PHYs on ICH9.
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: Delete.
- patches.drivers/alsa-hda-backport-2.6.26-rc4: Backport ALSA
  HDA-Intel patches from 2.6.26-rc4 (bnc#390473).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-asus-a9t-fix: ac97 - Fix ASUS A9T laptop
  output (bnc#363987).
* Mon Jun  2 2008 jeffm@suse.de
- patches.fixes/reiserfs-prealloc-fix: reiserfs: Use list_del_init
  in use_preallocated_list_if_available (bnc#378095).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-hp2133-mic-fix: hda - Fix mic input on
  HP2133 (bnc#388540).
* Mon Jun  2 2008 tiwai@suse.de
- patches.drivers/alsa-emu10k1-audigy2-digital-fix: emu10k1 - Fix
  inverted Analog/Digital mixer switch on Audigy2 (bnc#396204).
* Sat May 31 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt4 (refreshed patches suppressed)
- Update config files.
  Added:
- patches.rt/adapt-remove-extra-try-to-lock.patch
- patches.rt/adaptive-adjust-pi-wakeup.patch
- patches.rt/adaptive-earlybreak-on-steal.patch
- patches.rt/adaptive-optimize-rt-lock-wakeup.patch
- patches.rt/adaptive-task-oncpu.patch
- patches.rt/arm-fix-compile-error-trace-exit-idle.patch
- patches.rt/arm-omap-02.patch
- patches.rt/arm-omap-03.patch
- patches.rt/arm-omap-04.patch
- patches.rt/arm-omap-05.patch
- patches.rt/fix_vdso_gtod_vsyscall64_2.patch
- patches.rt/ftrace-compile-fixes.patch
- patches.rt/ftrace-disable-daemon.patch
- patches.rt/ftrace-dont-trace-markers.patch
- patches.rt/ftrace-fix-header.patch
- patches.rt/ftrace-function-record-nop.patch
- patches.rt/ftrace-print-missing-cmdline.patch
- patches.rt/ftrace-record-comm-on-ctrl.patch
- patches.rt/ftrace-safe-traversal-hlist.patch
- patches.rt/ftrace-trace-sched.patch
- patches.rt/ftrace-update-cnt-stat-fix.patch
- patches.rt/git-ignore-module-markers.patch
- patches.rt/git-ignore-script-lpp.patch
- patches.rt/lockdep-avoid-fork-waring.patch
- patches.rt/lockstat-fix-contention-points.patch
- patches.rt/lockstat-output.patch
- patches.rt/nmi-show-regs-fix.patch
- patches.rt/preempt-realtime-ftrace-disable-ftraced.patch
- patches.rt/realtime-preempt-warn-about-tracing.patch
- patches.rt/rtmutex-rwlock-cmpxchg-typecast.patch
- patches.rt/rwlock-implement-downgrade-write.patch
- patches.rt/rwlocks-fix-no-preempt-rt.patch
- patches.rt/sched-fix-rt-task-wakeup.patch
- patches.rt/sched-fix-sched-fair-wakeup.patch
- patches.rt/sched-nr-migrate-lower-default-preempt-rt.patch
- patches.rt/sched-prioritize-non-migrating-rt-tasks.patch
- patches.rt/sched-wake_up_idle_cpu-rt.patch
- patches.rt/trace_hist-divzero.patch
- patches.rt/trace_hist-latediv.patch
- patches.rt/x86-delay-enable-preempt-tglx.patch
  Removed:
- patches.rt/rtmutex-optimize-wakeup.patch
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch
- patches.rt/rtmutex-remove-extra-try.patch
- patches.rt/ftrace-remove-print-of-max.patch
* Thu May 29 2008 sdietrich@suse.de
  RT: Update IBM EDAC and PRTM
- Update config files.
- patches.rt/drivers-edac-add-support-for-HS21XM-SMI-remediation:
  Add support for HS21XM SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-add-support-for-HS21_LS21-SMI-remediation:
  Add support for HS21/LS21 SMI Remediation to the 2.6.22-based
  SLERT kernel.
- patches.rt/drivers-edac-i5000-turn-off-unsupported-check:
  Turn off unsupported EDAC check on the i5000 controller.
- patches.rt/drivers-edac-prevent-potential-printk-storm:
  Prevent potential EDAC printk storm.
- patches.rt/drivers-edac-test_device.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-k8-rev-f.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-add-sysfs_notify-calls.patch:
  edac-2.6.23-to-2.6.22.patch back-port.
- patches.rt/drivers-edac-new-amd64.patch:
  drivers-edac-new-amd64.patch (revision 108).
  Obsolete:
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: Delete.
- patches.rt/add-support-for-HS21XM-SMI-remediation: Delete.
- patches.rt/prevent-potential-EDAC-printk-storm: Delete.
* Thu May 29 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-macbook-fix: ata_piix: fix
  macbook ich8m problems (bnc#395407).
* Thu May 29 2008 agruen@suse.de
- Obsolete some KMPs which have been integrated into mainline
  meanwhile (bnc#357799).
* Thu May 29 2008 jbeulich@novell.com
- supported.conf: Mark 8250_pnp as supported.
* Wed May 28 2008 teheo@suse.de
- patches.drivers/libata-acpi-fix-hotplug: libata: Handle bay
  devices in dock stations (bnc#390822 bnc#395082).
* Wed May 28 2008 jkosina@suse.de
- patches.fixes/input-add-i8042-nopnp-for-D845PESV.patch: Input:
  Add i8042.nopnp for Intel D845PESV (bnc#386952).
* Mon May 26 2008 sdietrich@suse.de
  RT: Update to 2.6.25.4-rt3 - add RWSEM / RWLOCK patches:
- patches.rt/rt-mutex-core.patch: Linux-RT 2.6.25.4-RT3.
- patches.rt/multi-reader-account.patch: map tasks to reader
  locks held.
- patches.rt/multi-reader-limit.patch: implement reader limit
  on read write locks.
- patches.rt/multi-reader-lock-account.patch: map read/write
  locks back to their readers.
- patches.rt/multi-reader-pi.patch: read lock Priority Inheritance
  implementation.
- patches.rt/native-sched-clock-booboo.patch: Re: 2.6.25.4-rt2
  (native_sched_clock() booboo).
- patches.rt/rwlocks-default-nr-readers-nr-cpus.patch:
- patches.rt/rwlocks-multiple-readers.patch: implement rwlocks
  management.
- patches.rt/rwsems-multiple-readers.patch: add framework for
  multi readers on rwsems.
* Mon May 26 2008 olh@suse.de
- add patches.arch/ppc-efika-slowdown.patch
  slow down hot code paths to avoid hangs during install (bnc#374309)
* Sun May 25 2008 tiwai@suse.de
- Update config files: forgot to update vanilla kernel configs
* Sat May 24 2008 tiwai@suse.de
- Update config files: disable group scheduler for normal kernels
  for openSUSE 11.0, too (this should be enabled again later for
  11.1 once after the bugs get fixed...)
* Fri May 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-dma-pos-fix: hda - Fix DMA position
  inaccuracy (bnc#362775, bnc#364421).
- patches.drivers/alsa-hda-vt1708-pcm-noise-fix: hda - Fix noise
  on VT1708 codec (bnc#390473).
* Fri May 23 2008 sdietrich@suse.de
  RT: Update config files: Disable Group Scheduler
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-simg3726-nosrst: libata: SRST can't
  be trusted on PMP sil3726 (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: update config files: Disable SYSFS_DEPRECATED
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).  series.conf not
  updated.  Fix it.
* Thu May 22 2008 teheo@suse.de
- patches.drivers/libata-pmp-detection-fixes: libata: fix a
  number of PMP detection problems (bnc#393456).
* Thu May 22 2008 sdietrich@suse.de
  RT: build fix
- suppress adaptive locking patches that are not upstream.
- Update config files.
* Wed May 21 2008 jblunck@suse.de
- patches.fixes/acpi-bay-cleanup-and-exit.patch: bay: Exit if
  notify handler cannot be installed (bnc#390822).
* Wed May 21 2008 jbeulich@novell.com
- patches.xen/xen3-patch-2.6.25: Fix DomU boot issue.
* Wed May 21 2008 oneukum@suse.de
- patches.drivers/ehci_fix_remote_wakeup_regression.diff: EHCI:
  fix remote-wakeup regression. (bnc#373128)
* Tue May 20 2008 jblunck@suse.de
- doc/novell-kmp/novell-example-1.1.tar.bz2,
  doc/novell-kmp/novell-example.spec: Fix example spec and Kbuild
  because EXTRA_CFLAGS isn't taken from the environment anymore.
* Tue May 20 2008 sdietrich@suse.de
- Update config files: SLERT compatibility: SYSFS_DEPRECATED
* Tue May 20 2008 sdietrich@suse.de
  RT: Update to 2.5.25.4-rt2 (refreshed patches suppressed)
  Add:
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/x86-fix-32bit-sched-clock-crap.patch: x86: disable TSC
  for sched_clock() when calibration failed
- patches.rt/x86-fix-tsc-cyc2ns-crap.patch: x86: fix setup of cyc2ns
  in tsc_64.c.
- patches.rt/x86-prepare-to-fix-32bit-sched-clock-crap.patch:
  x86: distangle user disabled TSC from unstable
- patches.rt/adaptive-spinlock-lite-v2.patch: adaptive spinlocks
  lite.
- patches.rt/rtmutex-remove-xchg.patch: rtmutex - remove double
  xchg.
  Update:
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
  Resolve Conflicts:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- Update config files.
* Mon May 19 2008 sdietrich@suse.de
  RT: Adaptive locking patches:
- patches.rt/rtmutex-lateral-steal.patch: allow rt-mutex
  lock-stealing to include lateral priority.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
- patches.rt/rtmutex-rearrange.patch: rearrange
  rt_spin_lock_slowlock sleeping code.
- patches.rt/rtmutex-adaptive-locks.patch: adaptive real-time
  lock support.
- patches.rt/rtmutex-adaptive-timeout.patch: add a timeout
  mechanism to adaptive-locking.
- patches.rt/rtmutex-optimize-wakeup.patch: optimize rt lock
  wakeup.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch:
  adjust pi_lock usage in wakeup.
- patches.rt/rtmutex-remove-extra-try.patch: remove the extra
  call to try_to_take_lock.
- Update config files:
  CONFIG_RTLOCK_LATERAL_STEAL=y
  CONFIG_ADAPTIVE_RTLOCK=y
  CONFIG_IBM_RTL (disable temporarily to address build error)
* Mon May 19 2008 tiwai@suse.de
- Update config files (missing for rt*).
* Mon May 19 2008 tiwai@suse.de
- patches.drivers/alsa-hda-backport-2.6.25-rc3: Backport ALSA
  HDA-Intel patches from 2.6.25-rc3 (bnc#390473, bnc#386422,
  bnc#385473).
- patches.drivers/alsa-intel8x0-8ch: intel8x0 - Add support of
  8 channel sound.
- patches.drivers/alsa-mixer-oss-map-fix: Add more fallbacks to
  OSS PHONEOUT mixer map.
- patches.drivers/alsa-usb-audio-disconnect-oops-fix: Fix Oops
  with usb-audio reconnection.
- patches.drivers/alsa-hda-intel-new-ati-id: Delete.
- patches.drivers/alsa-hda-intel-new-nvidia-id: Delete.
- patches.drivers/alsa-hda-intel-use-PCI_DEVICE: Delete.
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Delete.
- Update config files.
* Mon May 19 2008 jbeulich@novell.com
- Update Xen patches to c/s 524 and 2.6.25.4.
- patches.xen/xen-balloon-hvm-min: don't allow ballooning down
  a HVM domain below a reasonable limit (172482).
- patches.xen/xen-swiotlb-heuristics: adjust Xen's swiotlb
  default size setting.
* Mon May 19 2008 jbeulich@novell.com
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Add missing list terminator for acpi_rsdt_dmi_table[] and move to
  __initdata.
* Mon May 19 2008 sdietrich@suse.de
  RT: SMI latency fixes from IBM.
- patches.rt/add-support-for-HS21_LS21-SMI-remediation: [PATCH
  1/3] Add support for HS21/LS21 SMI Remediation.
- patches.rt/add-support-for-HS21XM-SMI-remediation: [PATCH 2/3]
  Add support for HS21XM SMI Remediation .
- patches.rt/prevent-potential-EDAC-printk-storm: [PATCH 3/3]
  Prevent potential EDAC printk storm.
- RT: Update config files.
* Mon May 19 2008 agruen@suse.de
- patches.suse/nfs4acl-ext3.diff: Fix compilation error when
  CONFIG_EXT3_FS_NFS4ACL is off.
* Mon May 19 2008 sdietrich@suse.de
- RT: Update config files.
* Mon May 19 2008 trenn@suse.de
- patches.suse/acpi-dsdt-initrd-v0.9a-2.6.25.patch: ACPI:
  initramfs DSDT override support.
  - > Did not make it into 2.6.25 again...
- Update config files.
* Sun May 18 2008 agruen@suse.de
- Update the nfs4acl patches (and split them out more explicitly).
  Export all new symbols als GPL only.
- patches.apparmor/parent-permission.diff: Rediff.
* Sun May 18 2008 sdietrich@suse.de
- RT: Update config files.
* Sun May 18 2008 sdietrich@suse.de
  RT: update to 2.6.25.4-rt1 patch queue.
* Sun May 18 2008 sdietrich@suse.de
  RT cleanup: Remove unused/obsolete RT patches.
* Sun May 18 2008 sdietrich@suse.de
- Update config files: update RT debug configs.
- config.conf: enable DEBUG flavors.
* Sat May 17 2008 sdietrich@suse.de
  Linux-RT 2.6.25-RT:
- Updated RT patch queue (not individually enumerated here)
- Update config files: RT
- config.conf: RT
* Fri May 16 2008 gregkh@suse.de
- Update config files.
- patches.drivers/usb-add-option-hso-driver.patch: USB: add
  option hso driver.
* Fri May 16 2008 gregkh@suse.de
- refresh patches due to fuzz
* Fri May 16 2008 gregkh@suse.de
- patches.fixes/bluetooth-wake-up-properly-after-ide-timeout-expires.patch:
  bluetooth: wake up properly after ide timeout expires
  (bnc#390839).
* Fri May 16 2008 olh@suse.de
- update patches.fixes/tg3-flowctrl.patch
  do not compare flow control settings in parallel detect mode
* Fri May 16 2008 trenn@suse.de
- patches.arch/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch:
  Introduce acpi_root_table=rsdt boot param and dmi list to
  force rsdt (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_introduce_acpica_rsdt_global_variable.patch:
  ACPICA: Add acpi_gbl_force_rsdt variable
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/acpi_thinkpad_remove_R40e_c-state_blacklist.patch:
  Remove R40e c-state blacklist
  (http://bugzilla.kernel.org/show_bug.cgi?id=8246).
- patches.arch/cpufreq_fix_acpi_driver_on_BIOS_changes.patch:
  CPUFREQ: Check against freq changes from the BIOS.
* Fri May 16 2008 jblunck@suse.de
- patches.fixes/vfs-2.6.git-9bc300eae0400efdfae3fec3352896e10468a78f.patch:
  return to old errno choice for fix mkdir -p with ro-bind mounts
* Fri May 16 2008 jblunck@suse.de
- rpm/kernel-{binary,source}.spec.in: use localversion and set
  KBUILD_BUILD_VERSION (used for Kernel:Vanilla)
* Thu May 15 2008 gregkh@suse.de
- Update to final version of 2.6.25.4
* Thu May 15 2008 jblunck@suse.de
- rpm/macros.kernel-source: Let KMPs fail when flavors_to_build is empty
- rpm/kernel-{dummy,source,syms,binary}.spec.in, scripts/tar-up.sh:
  fix release number changes introduced by bnc#271712 for OBS (bnc#378933)
* Thu May 15 2008 olh@suse.de
- add patches.fixes/tg3-flowctrl.patch
  revert 'Fix supporting flowctrl code' to fix JS21 (bnc#390314)
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 oneukum@suse.de
- patches.drivers/appletouch_persist.diff: reset_resume and
  autosuspend for appletouch touchpads (bnc#388399).
* Wed May 14 2008 teheo@suse.de
- patches.drivers/libata-force-hardreset-if-link-pm: libata:
  force hardreset if link is in powersave mode (bnc#381795).
- patches.drivers/libata-ahci-sb600-no-msi: ahci: SB600 ahci
  can't do MSI, blacklist that capability (bnc#384559).
* Tue May 13 2008 gregkh@suse.de
- Update config files for vanilla targets
* Tue May 13 2008 gregkh@suse.de
- Update to 2.6.25.4-rc1
  - lots of bug fixes
* Mon May 12 2008 sdietrich@suse.de
  Cleanup RT:
- patches.rt/*: Delete.
* Mon May 12 2008 jkosina@suse.de
- patches.fixes/input-hid-apple-numlock-emulation.patch:
  HID: split Numlock emulation quirk from
  HID_QUIRK_APPLE_HAS_FN. (bnc#381764).
* Sat May 10 2008 gregkh@suse.de
- Update to 2.6.25.3
  - fixes 2 security issues (one networking, one sparc, no CVE
    numbers issued just yet)
* Fri May  9 2008 jeffm@suse.de
- patches.apparmor/fsetattr-restore-ia_file: vfs: restore ia_file
  for compatibility with external modules. (bnc#381259)
* Fri May  9 2008 hare@suse.de
- patches.drivers/open-iscsi-git-update: Delete.
- patches.fixes/open-iscsi-nop-fixes: NOP timeout fixes.
* Thu May  8 2008 gregkh@suse.de
- patches.kernel.org/v4l-dvb-patch-for-various-dibcom-based-devices.patch:
  V4L/DVB (7473): PATCH for various Dibcom based devices
  (bnc#381632).
* Thu May  8 2008 gregkh@suse.de
- comment out vmware patch as it should no longer be needed
* Thu May  8 2008 gregkh@suse.de
- rediff patches to apply cleanly.
* Thu May  8 2008 gregkh@suse.de
- Update to 2.6.25.3-rc1
  - potential fix for increased power consumption and other bugs
* Thu May  8 2008 sassmann@suse.de
- Update config file ppc64.
- patches.arch/ppc-ps3-ps3vram-mtd.patch: ps3vram driver that
  allows you to access the extra ~240MB of DDR video.
* Wed May  7 2008 gregkh@suse.de
- patches.kernel.org/patch-2.6.25.1-2: Linux 2.6.25.2.
  - fixes CVE-2008-1669
* Tue May  6 2008 schwab@suse.de
- suse-ppc32-mol-semaphore: fix mol for 2.6.26-rc1.
* Mon May  5 2008 jack@suse.cz
  Bring UDF to state in 2.6.26-rc1 to support UDF 2.50.
- patches.suse/udf-10-simple-cleanup-of-truncate.c.patch: udf:
  simple cleanup of truncate.c (fate#303336).
- patches.suse/udf-11-truncate-create-function-for-updating-of-Alloc.patch:
  udf: truncate: create function for updating of Allocation Ext
  Descriptor (fate#303336).
- patches.suse/udf-12-replace-all-adds-to-little-endians-variables-wi.patch:
  udf: replace all adds to little endians variables with
  le*_add_cpu (fate#303336).
- patches.suse/udf-13-simplify-__udf_read_inode.patch: udf:
  simplify __udf_read_inode (fate#303336).
- patches.suse/udf-14-replace-udf_-_offset-macros-with-functions.patch:
  udf: replace udf_*_offset macros with functions (fate#303336).
- patches.suse/udf-15-convert-udf_count_free_bitmap-to-use-bitmap_wei.patch:
  udf: convert udf_count_free_bitmap to use bitmap_weight
  (fate#303336).
- patches.suse/udf-16-udf_get_block-inode_bmap-remove-unneeded-che.patch:
  udf: udf_get_block, inode_bmap - remove unneeded checks
  (fate#303336).
- patches.suse/udf-17-create-function-for-conversion-from-timestamp-t.patch:
  udf: create function for conversion from timestamp to timespec
  (fate#303336).
- patches.suse/udf-18-convert-udf_stamp_to_time-to-return-struct-time.patch:
  udf: convert udf_stamp_to_time to return struct timespec
  (fate#303336).
- patches.suse/udf-19-convert-udf_stamp_to_time-and-udf_time_to_stamp.patch:
  udf: convert udf_stamp_to_time and udf_time_to_stamp to use
  timestamps (fate#303336).
- patches.suse/udf-1-kill-udf_set_blocksize.patch: udf: kill
  udf_set_blocksize (fate#303336).
- patches.suse/udf-20-remove-unneeded-kernel_timestamp-type.patch:
  udf: remove unneeded kernel_timestamp type (fate#303336).
- patches.suse/udf-21-super.c-reorganization.patch: udf: super.c
  reorganization (fate#303336).
- patches.suse/udf-22-Mark-udf_process_sequence-as-noinline.patch:
  udf: Mark udf_process_sequence() as noinline (fate#303336).
- patches.suse/udf-23-Remove-checking-of-existence-of-filename-in-udf.patch:
  udf: Remove checking of existence of filename in udf_add_entry()
  (fate#303336).
- patches.suse/udf-24-Remove-declarations-of-arrays-of-size-UDF_NAME_.patch:
  udf: Remove declarations of arrays of size UDF_NAME_LEN (256
  bytes) (fate#303336).
- patches.suse/udf-25-fix-anchor-point-detection.patch: udf:
  fix anchor point detection (fate#303336).
- patches.suse/udf-26-Cleanup-volume-descriptor-sequence-processing.patch:
  udf: Cleanup volume descriptor sequence processing
  (fate#303336).
- patches.suse/udf-27-Improve-error-recovery-on-mount.patch:
  udf: Improve error recovery on mount (fate#303336).
- patches.suse/udf-28-Move-filling-of-partition-descriptor-info-into.patch:
  udf: Move filling of partition descriptor info into a separate
  function (fate#303336).
- patches.suse/udf-29-Move-processing-of-virtual-partitions.patch:
  udf: Move processing of virtual partitions (fate#303336).
- patches.suse/udf-2-kill-useless-file-header-comments-for-vfs-metho.patch:
  udf: kill useless file header comments for vfs method
  implementations (fate#303336).
- patches.suse/udf-30-Cleanup-anchor-block-detection.patch: udf:
  Cleanup anchor block detection. (fate#303336).
- patches.suse/udf-31-Improve-anchor-block-detection.patch: udf:
  Improve anchor block detection (fate#303336).
- patches.suse/udf-32-Silence-warning-about-accesses-beyond-end-of-de.patch:
  udf: Silence warning about accesses beyond end of device
  (fate#303336).
- patches.suse/udf-33-Fix-detection-of-VAT-version.patch: udf:
  Fix detection of VAT version (fate#303336).
- patches.suse/udf-34-Allow-loading-of-VAT-inode.patch: udf:
  Allow loading of VAT inode (fate#303336).
- patches.suse/udf-35-Handle-VAT-packed-inside-inode-properly.patch:
  udf: Handle VAT packed inside inode properly (fate#303336).
- patches.suse/udf-36-Mount-filesystem-read-only-if-it-has-pseudoover.patch:
  udf: Mount filesystem read-only if it has pseudooverwrite
  partition (fate#303336).
- patches.suse/udf-37-Fix-handling-of-multisession-media.patch:
  udf: Fix handling of multisession media (fate#303336).
- patches.suse/udf-38-Add-read-only-support-for-2.50-UDF-media.patch:
  udf: Add read-only support for 2.50 UDF media (fate#303336).
- patches.suse/udf-39-Fix-bug-in-VAT-mapping-code.patch: udf:
  Fix bug in VAT mapping code (fate#303336).
- patches.suse/udf-3-move-headers-out-include-linux.patch: udf:
  move headers out include/linux/ (fate#303336).
- patches.suse/udf-40-Fix-compilation-warnings-when-UDF-debug-is-on.patch:
  udf: Fix compilation warnings when UDF debug is on
  (fate#303336).
- patches.suse/udf-41-use-crc_itu_t-from-lib-instead-of-udf_crc.patch:
  udf: use crc_itu_t from lib instead of udf_crc (fate#303336).
- patches.suse/udf-42-fs-udf-partition.c-udf_get_pblock-mustn-t-be.patch:
  udf: fs/udf/partition.c:udf_get_pblock() mustn't be inline
  (fate#303336).
- patches.suse/udf-4-Use-DIV_ROUND_UP.patch: fs/udf: Use
  DIV_ROUND_UP (fate#303336).
- patches.suse/udf-5--udf_error-static.patch: make udf_error()
  static (fate#303336).
- patches.suse/udf-6-udf_CS0toUTF8-cleanup.patch: udf:
  udf_CS0toUTF8 cleanup (fate#303336).
- patches.suse/udf-7-fix-udf_build_ustr.patch: udf: fix
  udf_build_ustr (fate#303336).
- patches.suse/udf-8-udf_CS0toNLS-cleanup.patch: udf: udf_CS0toNLS
  cleanup (fate#303336).
- patches.suse/udf-9-constify-crc.patch: udf: constify crc
  (fate#303336).
* Fri May  2 2008 teheo@suse.de
- patches.drivers/libata-sata_inic162x-update-to-0.4:
  sata_inic162x: update to 0.4 (bnc#385599).
* Thu May  1 2008 gregkh@suse.de
- update to 2.6.25.1:
  - fixes CVE-2008-1375 and CVE-2008-1675
  - lots of other minor bugfixes
* Thu May  1 2008 agruen@suse.de
- Provide "kernel(flavor:symset) = version" instead of
  "kernel(symset) = version". This disambiguates the case where
  several kernel flavors end up with the same modver checksums
  (bnc#190163, bnc#355628).
* Thu May  1 2008 teheo@suse.de
- patches.drivers/libata-ata_piix-verify-sidpr: ata_piix: verify
  SIDPR access before enabling it (bnc#385535).
* Wed Apr 30 2008 gregkh@suse.de
- novfs: fixes needed due to apparmor vfs core changes
  (extended attributes probably do not work now...)
* Wed Apr 30 2008 gregkh@suse.de
- patches.suse/novfs-add-the-novell-filesystem-client-kernel-module.patch:
  novfs: Add the Novell filesystem client kernel module.
- Update config files.
* Wed Apr 30 2008 jeffm@suse.de
- patches.suse/reiserfs-simplify-xattr-internal-file-lookups-opens.diff:
  removed fs.h changes, they weren't used.
* Mon Apr 28 2008 gregkh@suse.de
- Update config files.
  hopefully the build system is happy now
* Mon Apr 28 2008 gregkh@suse.de
- rpm/config-subst: add #!/bin/sh at start of script to keep future
  build issues (like bnc#382214) from causing problems.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete patches: ARM-ep93xx-timer, latency-tracing,
  RCU, KVM, mcount, PPC-gtod
- patches.rt/ep93xx-timer-accuracy.patch: Delete.
- patches.rt/ep93xx-clockevents.patch: Delete.
- patches.rt/ep93xx-clockevents-fix.patch: Delete.
- patches.rt/kvm-fix-preemption-bug.patch: Delete.
- patches.rt/kvm-lapic-migrate-latency-fix.patch: Delete.
- patches.rt/kvm-make-less-noise.patch: Delete.
- patches.rt/kvm-preempt-rt-resched-delayed.patch: Delete.
- patches.rt/sched-use-a-2d-bitmap-search-prio-cpu.patch: Delete.
- patches.rt/remove-unused-var-warning.patch: Delete.
- patches.rt/latency-tracing.patch: Delete.
- patches.rt/latency-tracing-remove-trace-array.patch: Delete.
- patches.rt/latency-tracer-disable-across-trace-cmdline.patch:
  Delete.
- patches.rt/latency-tracing-i386-paravirt-fastcall.patch: Delete.
- patches.rt/latency-tracing-i386.patch: Delete.
- patches.rt/latency-tracing-x86_64.patch: Delete.
- patches.rt/latency-tracing-ppc.patch: Delete.
- patches.rt/latency-tracer-printk-fix.patch: Delete.
- patches.rt/latency-tracing-exclude-printk.patch: Delete.
- patches.rt/latency-tracing-prctl-api-hack.patch: Delete.
- patches.rt/latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/latency-tracer-one-off-fix.patch: Delete.
- patches.rt/smaller-trace.patch: Delete.
- patches.rt/trace-name-plus.patch: Delete.
- patches.rt/trace-with-caller-addr.patch: Delete.
- patches.rt/trace-sti-mwait.patch: Delete.
- patches.rt/latency-tracer-optimize-a-bit.patch: Delete.
- patches.rt/idle-stop-critical-timing.patch: Delete.
- patches.rt/latency-tracer-variable-threshold.patch: Delete.
- patches.rt/reset-latency-histogram.patch: Delete.
- patches.rt/undo-latency-tracing-raw-spinlock-hack.patch: Delete.
- patches.rt/random-driver-latency-fix.patch: Delete.
- patches.rt/latency-tracing-use-now.patch: Delete.
- patches.rt/preempt_max_latency-in-all-modes.patch: Delete.
- patches.rt/latency-hist-add-resetting-for-all-timing-options.patch:
  Delete.
- patches.rt/latency-trace-sysctl-config-fix.patch: Delete.
- patches.rt/latency-trace-convert-back-to-ms.patch: Delete.
- patches.rt/latency-trace-fix.patch: Delete.
- patches.rt/trace-cpuidle.patch: Delete.
- patches.rt/lockdep-show-held-locks.patch: Delete.
- patches.rt/lockdep-lock_set_subclass.patch: Delete.
- patches.rt/lockdep-prettify.patch: Delete.
- patches.rt/lockdep-more-entries.patch: Delete.
- patches.rt/latency-tracer-arch-low-address.patch: Delete.
- patches.rt/latency-tracer-dont-panic-on-failed-bootmem-alloc.patch:
  Delete.
- patches.rt/mcount-add-x86_64-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-x86-vdso-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-nmi-notrace-annotations.patch: Delete.
- patches.rt/mcount-add-time-notrace-annotations.patch: Delete.
- patches.rt/mcount-lockdep-notrace-annotations.patch: Delete.
- patches.rt/mcount-preemptcount-notrace-annotations.patch:
  Delete.
- patches.rt/mcount-fault-notrace-annotations.patch: Delete.
- patches.rt/mcount-irqs-notrace-annotations.patch: Delete.
- patches.rt/mcount-rcu-notrace-annotations.patch: Delete.
- patches.rt/latency-measurement-drivers-fix.patch: Delete.
- patches.rt/latency-measurement-drivers.patch: Delete.
- patches.rt/redo-regparm-option.patch: Delete.
- patches.rt/nmi-profiling-base.patch: Delete.
- patches.rt/ppc-gtod-notrace-fix.patch: Delete.
- patches.rt/ppc-gtod-support.patch: Delete.
- patches.rt/ppc-gtod-support-fix.patch: Delete.
- patches.rt/ppc-a-2.patch: Delete.
- patches.rt/ppc-fix-clocksource-timebase-shift.patch: Delete.
- patches.rt/ppc-remove-broken-vsyscall.patch: Delete.
- patches.rt/ppc-read-persistent-clock.patch: Delete.
- patches.rt/ppc-clockevents.patch: Delete.
- patches.rt/ppc-clockevents-fix.patch: Delete.
- patches.rt/ppc-highres-dyntick.patch: Delete.
- patches.rt/inet-hash-bits-ipv6-fix.patch: Delete.
- patches.rt/inet_hash_bits.patch: Delete.
- patches.rt/rcu-1.patch: Delete.
- patches.rt/rcu-2.patch: Delete.
- patches.rt/rcu-3.patch: Delete.
- patches.rt/rcu-4.patch: Delete.
- patches.rt/rcu-preempt-fix-nmi-watchdog.patch: Delete.
- patches.rt/rcu-preempt-fix-rcu-torture.patch: Delete.
- patches.rt/dynticks-rcu-rt-fixlet.patch: Delete.
- patches.rt/rcu-tasklet-softirq.patch: Delete.
- patches.rt/rcu-classic-fixup.patch: Delete.
- patches.rt/rcu-warn-underflow.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove obsolete Adaptive-locking patches
- patches.rt/rtmutex-adaptive-locks.patch: Delete.
- patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
- patches.rt/rtmutex-adaptive-timeout.patch: Delete.
- patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
- patches.rt/rtmutex-lateral-steal.patch: Delete.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
- patches.rt/rtmutex-optimize-wakeup.patch: Delete.
- patches.rt/rtmutex-rearrange.patch: Delete.
- patches.rt/rtmutex-remove-extra-try.patch: Delete.
- patches.rt/x86-ticket-lock.patch: Delete.
* Mon Apr 28 2008 sdietrich@suse.de
  Cleanup:
  Remove ARM and MIPS RT patches
- patches.rt/arm-cmpxchg-support-armv6.patch: Delete.
- patches.rt/arm-cmpxchg.patch: Delete.
- patches.rt/arm-compile-fix.patch: Delete.
- patches.rt/arm-fix-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-futex-atomic-cmpxchg.patch: Delete.
- patches.rt/arm-latency-tracer-support.patch: Delete.
- patches.rt/arm-leds-timer.patch: Delete.
- patches.rt/arm-preempt-config.patch: Delete.
- patches.rt/arm-trace-preempt-idle.patch: Delete.
- patches.rt/latency-tracing-arm.patch: Delete.
- patches.rt/preempt-irqs-arm-fix-oprofile.patch: Delete.
- patches.rt/preempt-irqs-arm.patch: Delete.
- patches.rt/preempt-realtime-arm-bagde4.patch: Delete.
- patches.rt/preempt-realtime-arm-footbridge.patch: Delete.
- patches.rt/preempt-realtime-arm-integrator.patch: Delete.
- patches.rt/preempt-realtime-arm-ixp4xx.patch: Delete.
- patches.rt/preempt-realtime-arm-pxa.patch: Delete.
- patches.rt/preempt-realtime-arm-rawlock-in-mmu_context-h.patch:
  Delete.
- patches.rt/preempt-realtime-arm-shark.patch: Delete.
- patches.rt/preempt-realtime-arm.patch: Delete.
- patches.rt/preempt-irqs-mips.patch: Delete.
- patches.rt/preempt-realtime-mips.patch: Delete.
- patches.rt/rt-mutex-arm-fix.patch: Delete.
- patches.rt/rt-mutex-arm.patch: Delete.
- patches.rt/rt-mutex-mips.patch: Delete.
- patches.rt/mips-change-raw-spinlock-type.patch: Delete.
- patches.rt/mips-remove-conlicting-rtc-lock-declaration.patch:
  Delete.
- patches.rt/mips-remove-duplicate-kconfig.patch: Delete.
- patches.rt/mips-remove-finish-arch-switch.patch: Delete.
* Fri Apr 25 2008 carnold@novell.com
- rpm/kernel-binary.spec.in: kernel-xen does not obsolete/provide
  kernel-xenpae (bnc#382309)
* Fri Apr 25 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  create /builtin/sound/cell-index, content == 1
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add newline to devspec files
* Thu Apr 24 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  add devspec file for mac-io, it was created as a side effect
  in of/platform.c (bnc#374693)
* Thu Apr 24 2008 olh@suse.de
- use bzip2 instead of lzma as rpm compression method for vanilla
* Thu Apr 24 2008 olh@suse.de
- relax Conflicts for kernel-vanilla
  no version check for lvm, udev and apparmor
* Wed Apr 23 2008 olh@suse.de
- readd patches.arch/ppc-pegasos-console-autodetection.patch
  force speed 115200, device-tree has no current-speed property
* Wed Apr 23 2008 tiwai@suse.de
- patches.drivers/alsa-hda-intel-new-ati-id,
  patches.drivers/alsa-hda-intel-use-PCI_DEVICE,
  patches.drivers/alsa-hda-intel-new-nvidia-id: Add missing PCI
  ids for new ATI/Nvidia devices (bnc#370775)
- patches.drivers/alsa-dell-xps-m1330-hp-fix: Fix Dell XPS M1330
  outputs
* Tue Apr 22 2008 jack@suse.cz
- patches.fixes/quota_reiserfs_tail_fix.diff: reiserfs: Unpack
  tails on quota files (375179).
* Tue Apr 22 2008 olh@suse.de
- update patches.arch/ppc-efika-mpc52xx-ac97.patch
  fixes for 2.6.25
* Sat Apr 19 2008 schwab@suse.de
- Add compat handler for PTRACE_GETSIGINFO.
* Sat Apr 19 2008 aj@suse.de
- Conflict with apparmor-parser < 2.3 (not <=) in kernel-binary
  spec files.
* Fri Apr 18 2008 jeffm@suse.de
- Re-synced reiserfs patch set due to broken local repo.
* Fri Apr 18 2008 jeffm@suse.de
- Updated reiserfs patch set
  - Eliminated xattr interaction with AppArmor
  - Eliminated xattr deadlock under load between journal lock and
    xattr dir i_mutex
  - Properly annotated xattr i_mutex locking for lockdep
  - Code cleanup
* Fri Apr 18 2008 jjohanse@suse.de
- Update fsetattr.diff to EXPORT_SYMBOL_GPL(fnotify_change)
* Fri Apr 18 2008 jjohanse@suse.de
- patches.apparmor/__d_path-keep-connected.diff: Fix __d_path
  to allow for old and new behavior bnc#380763.
* Thu Apr 17 2008 gregkh@suse.de
- refresh patches to apply without fuzz
* Thu Apr 17 2008 gregkh@suse.de
- Update to 2.6.25-final
* Wed Apr 16 2008 jjohanse@suse.de
- Update to AppArmor 2.3 patch series
* Wed Apr 16 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Fixed accidental
  passing of -ENODATA to userspace during chown, and messages during
  chown and delete.
* Tue Apr 15 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc9 and c/s 517.
* Fri Apr 11 2008 gregkh@suse.de
- refresh patches to clean up fuzz
* Fri Apr 11 2008 gregkh@suse.de
- Update config files.
* Fri Apr 11 2008 gregkh@suse.de
- updat to 2.6.25-rc9
* Thu Apr 10 2008 gregkh@suse.de
- update to 2.6.25-rc8-git8
* Tue Apr  8 2008 gregkh@suse.de
- update to 2.6.25-rc8-git7
* Mon Apr  7 2008 gregkh@suse.de
- patches.kernel.org/pvrusb2-fix-broken-build-due-to-patch-order-dependency.patch:
  pvrusb2: fix broken build due to patch order dependency.
* Mon Apr  7 2008 gregkh@suse.de
- update to 2.6.25-rc8-git5
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Removed struct
  file use entirely.
* Sun Apr  6 2008 jeffm@suse.de
- patches.suse/reiserfs-kill-xattr-readdir.diff: Eliminated use
  of vfsmount-less dentry_open().
* Thu Apr  3 2008 teheo@suse.de
- patches.drivers/libata-pata_ali-disable-ATAPI_DMA: pata_ali:
  disable ATAPI DMA (332588).
* Wed Apr  2 2008 gregkh@suse.de
- Update to 2.6.25-rc8
* Tue Apr  1 2008 jblunck@suse.de
- rpm/kernel-source.spec.in,kernel-binary.spec.in: Cleanup Requires
* Mon Mar 31 2008 jdelvare@suse.de
- supported.conf: Add new hwmon drivers, all unsupported.
* Thu Mar 27 2008 jeffm@suse.de
- Fixed up the rest of the reiserfs patch queue.
* Thu Mar 27 2008 jeffm@suse.de
- Updated reiserfs xattr patches.
* Thu Mar 27 2008 gregkh@suse.de
- fix merge error in patches.suse/supported-flag caused by me...
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7-git2
* Thu Mar 27 2008 gregkh@suse.de
- update to 2.6.25-rc7
  - note that reiserfs xattr patches are now disabled due to merge
    issues...
* Sun Mar 23 2008 teheo@suse.de
- patches.drivers/libata-improve-hpa-error-handling: libata:
  improve HPA error handling (365534).
* Thu Mar 20 2008 gregkh@suse.de
- fix up some EXPORT_SYMBOL() markings to be EXPORT_SYMBOL_GPL() as the
  code is not upstream and we aren't allowed to add non-GPL exports to
  our kernel tree.
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git5
- refresh patches to apply cleanly
* Thu Mar 20 2008 gregkh@suse.de
- update to 2.6.25-rc6-git4
- refresh patches to apply cleanly
* Thu Mar 20 2008 agruen@suse.de
- scripts/tar-up.sh: Rename --kbuild option to --source-timestamp.
  For generating the source timestamp, use HEAD as the branch
  name.
- rpm/get_release_number.sh.in: Don't try to synchronize release
  numbers with kernel-dummy if the release number has been
  specified explicitly (tar-up with --release-string, --timestamp,
  or --source-timestamp).
* Thu Mar 20 2008 olh@suse.de
- remove patches.kernel.org/powerpc-needs-uboot
  not needed without mpc51xx support
* Thu Mar 20 2008 olh@suse.de
- disable gianfar network driver and unused freescale drivers
* Wed Mar 19 2008 gregkh@suse.de
- patch refreshes due to version update
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6-git3
- Update config files.
* Wed Mar 19 2008 gregkh@suse.de
- Update to 2.6.25-rc6
  - which deleted the following patches:
  - patches.fixes/hibernation-snapshot-numa-workaround.patch
  - patches.fixes/acpi-fix-double-log-level.patch
  - patches.fixes/acpi_fix_mem_corruption.patch
  - patches.kernel.org/patch-2.6.25-rc5
  - patches.kernel.org/patch-2.6.25-rc5-git3
- Update config files.
- delete patches.arch/x86-nvidia-timer-quirk as it is not being used.
* Wed Mar 19 2008 olh@suse.de
- remove patches.arch/ppc-efika-ipic.patch
  disable mpc51xx support instead
* Tue Mar 18 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Changed to just match %%ix86
* Mon Mar 17 2008 olh@suse.de
- add patches.arch/ppc-efika-ipic.patch
  fix a crash in init_ipic_sysfs on efika
* Mon Mar 17 2008 agruen@suse.de
- post.sh: Fix a syntax error when creating the initrd.
* Mon Mar 17 2008 jbeulich@novell.com
- patches.xen/xen-quicklist.patch: Delete.
- Update i386 Xen config file.
- patches.xen/xen3-patch-2.6.25-rc5-rc6: 2.6.25-rc6.
- patches.xen/xen3-auto-xen-kconfig.diff,
  patches.xen/xen3-fixup-kconfig,
  patches.xen/xen3-patch-2.6.19,
  patches.xen/xen3-patch-2.6.20,
  patches.xen/xen3-patch-2.6.21,
  patches.xen/xen3-patch-2.6.22,
  patches.xen/xen3-patch-2.6.23,
  patches.xen/xen3-patch-2.6.24,
  patches.xen/xen3-patch-2.6.25-rc5,
  patches.xen/xen-x86-no-lapic,
  patches.xen/xen-x86-panic-no-reboot: Various adjustments.
* Sun Mar 16 2008 jeffm@suse.de
- rpm/kernel-binary.spec.in: Added an RPM conflict for 32-bit
  kernels and 64-bit glibc to avoid installing a 32-bit kernel
  with 64-bit userspace. (364433, et al)
* Fri Mar 14 2008 jeffm@suse.de
- scripts/tar-up.sh: Added --kbuild option to autogenerate
  release number based on branch and timestamp.
* Fri Mar 14 2008 jeffm@suse.de
- patches.apparmor/export-security_inode_permission-for-aufs:
  LSM: Export security_inode_permission for aufs (356902).
* Fri Mar 14 2008 agruen@suse.de
- Boot loader: do the same during initial installation as when
  updating a kernel package (FATE 302660).
* Thu Mar 13 2008 gregkh@suse.de
- Update to 2.6.25-rc5-git3
* Thu Mar 13 2008 olh@suse.de
- disable unuses pata platform and ibm newemac driver on powerpc
* Thu Mar 13 2008 olh@suse.de
- add patches.xen/xen-quicklist.patch
  fix kernel-xen compile, readd CONFIG_QUICKLIST for xen
* Wed Mar 12 2008 gregkh@suse.de
- remove alpha configs as they are no longer used
* Wed Mar 12 2008 gregkh@suse.de
- Enabled CONFIG_UNUSED_SYMBOLS for now.  It will be disabled
  after the next openSUSE alpha release.  It is being enabled
  for now to let some kmp packages still work while their
  maintainers are working to update them with the 2.6.25
  kernel changes.
* Wed Mar 12 2008 gregkh@suse.de
- refresh patches to apply cleanly
* Wed Mar 12 2008 gregkh@suse.de
- update to 2.6.25-rc5-git2
* Wed Mar 12 2008 sassmann@suse.de
- patches.arch/ppc-ps3-rename-wireless-interface.patch:
  rename ps3 wireless interface from eth? to wlan? for better
  handling in udev
* Wed Mar 12 2008 jbeulich@novell.com
- Update Xen patches to 2.6.25-rc5 and c/s 471.
- patches.xen/xen3-aslr-i386-and-x86_64-randomize-brk.patch:
  Delete.
- patches.xen/xen3-aslr-pie-executable-randomization.patch:
  Delete.
- patches.xen/xen3-early-firewire.diff: Delete.
- Update x86 config files.
- config.conf: Re-enable Xen configs.
* Tue Mar 11 2008 gregkh@suse.de
- add usb persist for storage devices across suspend to ram.  This is going to
  be in 2.6.26, just missed the .25 merge window.
* Tue Mar 11 2008 gregkh@suse.de
- Update to 2.6.26-rc5-git1
- Update config files.
* Tue Mar 11 2008 gregkh@suse.de
- update to 2.6.25-rc5
* Mon Mar 10 2008 agruen@suse.de
- scripts/tar-up.sh: Don't lose the EXTRAVERSION when overriding
  the release number with --release-string or --timestamp.
* Sun Mar  9 2008 jeffm@suse.de
- patches.fixes/hibernation-snapshot-numa-workaround.patch:
  swsusp: workaround for crash on NUMA (kernel.org#9966).
* Sat Mar  8 2008 agruen@suse.de
- Encode the EXTRAVERSION part of kernel release numbers in the
  RPM release instead of in the version. This resolves the problem
  that kernel releases like 2.6.25-rc4 would result in a package
  with a higher version than 2.6.25 according to RPM's versioning
  scheme (bug 271712).
* Fri Mar  7 2008 schwab@suse.de
- Update kdb patches.
* Thu Mar  6 2008 trenn@suse.de
- patches.fixes/acpi_fix_mem_corruption.patch: ACPI: Fix mem
  corruption (350017).
- patches.fixes/acpi_thermal_passive_cleanup.patch: Warn user
  about a BIOS bug in asus boards (350017).
* Thu Mar  6 2008 gregkh@suse.de
- Update s390 config files.
* Thu Mar  6 2008 gregkh@suse.de
- update to 2.6.24-rc5-git1
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_GROUP_SCHED
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_HIGH_RES_TIMERS on i386
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_USB_PERSIST for vanilla config files
* Wed Mar  5 2008 gregkh@suse.de
- refresh patches to apply cleanly with no fuzz
- enable CONFIG_USB_PERSIST so that users can enable this if they want
* Wed Mar  5 2008 gregkh@suse.de
- update the vanilla config files for CONFIG_DEBUG_RODATA
* Wed Mar  5 2008 gregkh@suse.de
- enable CONFIG_DEBUG_RODATA (Not really a debug option, something
  we need in all of our kernels.)
* Wed Mar  5 2008 gregkh@suse.de
- Update vanilla config files.
* Wed Mar  5 2008 jbeulich@novell.com
- patches.fixes/parport-mutex,
  patches.suse/stack-unwind: Fix merge mistakes.
- Update i386 config files.
* Wed Mar  5 2008 gregkh@suse.de
- Update tree to 2.6.25-rc4
* Wed Mar  5 2008 fseidel@suse.de
- add patches.fixes/fat_detect_media_wo_parttable.patch and
  patches.fixes/fat_valid_media.patch:
  detect FAT formated medias without partition table correctly
  (bnc 364365)
* Tue Mar  4 2008 olh@suse.de
- add patches.kernel.org/s390-defkeymap.patch
  Build fix for drivers/s390/char/defkeymap.c
* Tue Mar  4 2008 olh@suse.de
- enable ext2/3 acl support in ps3 kernel
* Tue Mar  4 2008 olh@suse.de
- Update to 2.6.25-rc3-git5
* Tue Mar  4 2008 olh@suse.de
- use suffix -ps3 for PS3 kernel, it is only used in otheros.bld
* Mon Mar  3 2008 lmb@suse.de
- rpm/kernel-binary.spec.in: Require udev >= 118.
* Mon Mar  3 2008 ak@suse.de
- patches.arch/x86-nvidia-timer-quirk: Delete.
  PCI device ID list still not complete and let's have the same
  crap as mainline for now. It would be better to fix the PCI
  ID lists (#302327)
* Sun Mar  2 2008 olh@suse.de
- add patches.fixes/ibmvstgt-fixes.patch
  fix oops in ibmvstgt init function
* Fri Feb 29 2008 olh@suse.de
- add patches.arch/ppc-pci-bogus-resources.patch
  fix bogus test for unassigned resources
* Thu Feb 28 2008 olh@suse.de
- disable CONFIG_CRYPTO_DEV_HIFN_795X on ppc32 due to __divdi3 usage
- update patches.kernel.org/powerpc-needs-uboot
  disable mkimage call in arch/powerpc/boot/wrapper
* Thu Feb 28 2008 olh@suse.de
- update patches.kernel.org/fixed-phy-select
  add dependency on libphy=y
* Wed Feb 27 2008 jdelvare@suse.de
- patches.fixes/acpi-fix-double-log-level.patch: ACPI: Fix a
  duplicate log level.
* Wed Feb 27 2008 trenn@suse.de
- patches.fixes/acpi_force-fan-active.patch: Delete.
* Tue Feb 26 2008 sdietrich@suse.de
- remove obsolete adaptive-locks patches
  patches.rt/rtmutex-adaptive-locks.patch: Delete.
  patches.rt/rtmutex-adjust-pi_lock-usage-in-wakeup.patch: Delete.
  patches.rt/rtmutex-optimize-wakeup.patch: Delete.
  patches.rt/rtmutex-rearrange.patch: Delete.
  patches.rt/rtmutex-remove-extra-try.patch: Delete.
  patches.rt/rtmutex-adaptive-mutexes.patch: Delete.
  patches.rt/rtmutex-adaptive-timeout.patch: Delete.
  patches.rt/rtmutex-lateral-steal.patch: Delete.
  patches.rt/rtmutex-lateral-steal-sysctl.patch: Delete.
* Tue Feb 26 2008 sassmann@suse.de
- remove patches included upstream
  patches.arch/ppc-ps3-gelic-cleanup.patch
  patches.arch/ppc-ps3-gelic-endianness.patch
  patches.arch/ppc-ps3-gelic-ethernet-linkstatus.patch
  patches.arch/ppc-ps3-gelic-fix-fallback.diff
  patches.arch/ppc-ps3-gelic-multiple-interface.patch
  patches.arch/ppc-ps3-gelic-remove-duplicate-ethtool-handlers.patch
  patches.arch/ppc-ps3-gelic-wireless-v2.patch
* Tue Feb 26 2008 jeffm@suse.de
- Update config files: Disabled CONFIG_INPUT_YEALINK per an old
  request from AJ.
* Tue Feb 26 2008 jeffm@suse.de
- Update to 2.6.25-rc3.
* Sun Feb 24 2008 sdietrich@suse.de
- patches.rt/0001-sched-count-of-queued-RT-tasks.patch: Delete.
- patches.rt/0002-sched-track-highest-prio-task-queued.patch:
  Delete.
- patches.rt/0003-sched-add-RT-task-pushing.patch: Delete.
- patches.rt/0004-sched-add-rt-overload-tracking.patch: Delete.
- patches.rt/0005-sched-pull-RT-tasks-from-overloaded-runqueues.patch:
  Delete.
- patches.rt/0006-sched-push-RT-tasks-from-overloaded-CPUs.patch:
  Delete.
- patches.rt/0007-sched-disable-standard-balancer-for-RT-tasks.patch:
  Delete.
- patches.rt/0008-sched-add-RT-balance-cpu-weight.patch: Delete.
- patches.rt/0009-sched-clean-up-this_rq-use-in-kernel-sched_rt.c.patch:
  Delete.
- patches.rt/0010-sched-de-SCHED_OTHER-ize-the-RT-path.patch:
  Delete.
- patches.rt/0011-sched-break-out-search-for-RT-tasks.patch:
  Delete.
- patches.rt/0012-sched-RT-balancing-include-current-CPU.patch:
  Delete.
- patches.rt/0013-sched-pre-route-RT-tasks-on-wakeup.patch:
  Delete.
- patches.rt/0014-sched-optimize-RT-affinity.patch: Delete.
- patches.rt/0015-sched-wake-balance-fixes.patch: Delete.
- patches.rt/0016-sched-RT-balance-avoid-overloading.patch:
  Delete.
- patches.rt/0017-sched-break-out-early-if-RT-task-cannot-be-migrated.patch:
  Delete.
- patches.rt/0018-sched-RT-balance-optimize.patch: Delete.
- patches.rt/0019-sched-RT-balance-optimize-cpu-search.patch:
  Delete.
- patches.rt/0020-sched-RT-balance-on-new-task.patch: Delete.
- patches.rt/0021-sched-clean-up-pick_next_highest_task_rt.patch:
  Delete.
- patches.rt/0022-sched-clean-up-find_lock_lowest_rq.patch:
  Delete.
- patches.rt/0023-sched-clean-up-overlong-line-in-kernel-sched_debug.patch:
  Delete.
- patches.rt/0024-sched-clean-up-kernel-sched_rt.c.patch: Delete.
- patches.rt/0025-sched-remove-rt_overload.patch: Delete.
- patches.rt/0026-sched-remove-leftover-debugging.patch: Delete.
- patches.rt/0027-sched-clean-up-pull_rt_task.patch: Delete.
- patches.rt/0028-sched-clean-up-schedule_balance_rt.patch:
  Delete.
- patches.rt/0029-sched-add-sched-domain-roots.patch: Delete.
- patches.rt/0030-sched-update-root-domain-spans-upon-departure.patch:
  Delete.
- patches.rt/0031-Subject-SCHED-Only-balance-our-RT-tasks-within-ou.patch:
  Delete.
- patches.rt/0032-sched-fix-sched_rt.c-join-leave_domain.patch:
  Delete.
- patches.rt/0033-sched-remove-unused-JIFFIES_TO_NS-macro.patch:
  Delete.
- patches.rt/0034-sched-style-cleanup-2.patch: Delete.
- patches.rt/0035-sched-add-credits-for-RT-balancing-improvements.patch:
  Delete.
- patches.rt/0036-sched-reactivate-fork-balancing.patch: Delete.
- patches.rt/0037-sched-whitespace-cleanups-in-topology.h.patch:
  Delete.
- patches.rt/0038-sched-no-need-for-affine-wakeup-balancing-in.patch:
  Delete.
- patches.rt/0039-sched-get-rid-of-new_cpu-in-try_to_wake_up.patch:
  Delete.
- patches.rt/0040-sched-remove-do_div-from-__sched_slice.patch:
  Delete.
- patches.rt/0041-sched-RT-balance-replace-hooks-with-pre-post-sched.patch:
  Delete.
- patches.rt/0042-sched-RT-balance-add-new-methods-to-sched_class.patch:
  Delete.
- patches.rt/0043-sched-RT-balance-only-adjust-overload-state-when-c.patch:
  Delete.
- patches.rt/0044-sched-remove-some-old-cpuset-logic.patch:
  Delete.
- Remove scheduler patches already upstream in 2.6.25-rc1
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/libertas-section-conflict: libertas: fix
  section conflict.
* Sat Feb 23 2008 jeffm@suse.de
- Enabled patches.kernel.org/ps3-lpm-include
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/spu_profiler-include: powerpc: spu_profiler
  build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/ps3-lpm-include: ps3: lpm build fix.
* Sat Feb 23 2008 jeffm@suse.de
- patches.kernel.org/fixed-phy-select: powerpc: FSL_SOC requires
  FIXED_PHY.
- patches.kernel.org/lguest-fixups: lguest: Fix asm-offsets_32
  with correct config option.
* Sat Feb 23 2008 jeffm@suse.de
- Build fixes for ia64 and i386.
* Sat Feb 23 2008 jeffm@suse.de
- Update to 2.6.25-rc2-git6.
  - Removed:
  - patches.arch/ppc-pegasos-pata_via-fixup.patch: Delete.
  - patches.arch/ppc-pegasos-console-autodetection.patch: Delete.
  - patches.arch/ppc-ps3-make-dev_id-and-bus_id-u64.diff: Delete.
  - patches.arch/acpi_autoload_bay.patch: Delete.
  - patches.arch/small-acpica-extension-to-be-able-to-store-the-name-of.patch:
    Delete.
  - patches.arch/export-acpi_check_resource_conflict.patch: Delete.
  - patches.drivers/early-firewire.diff: Delete.
  - patches.drivers/scsi-throttle-SG_DXFER_TO_FROM_DEV-warning-better:
    Delete.
  - patches.drivers/libata-implement-force-parameter: Delete.
  - patches.drivers/igb-1.0.8-k2: Delete.
  - patches.drivers/always-announce-new-usb-devices.patch: Delete.
  - patches.drivers/nozomi.patch: Delete.
  - patches.drivers/libata-quirk_amd_ide_mode: Delete.
  - patches.fixes/acpi_autoload_baydock.patch: Delete.
  - patches.fixes/bluetooth_hci_dev_put.patch: Delete.
  - patches.fixes/bluetooth_hci_conn_childs.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan1.patch: Delete.
  - patches.fixes/mac80211-fix-hw-scan2.patch: Delete.
  - patches.fixes/libiscsi-missing-semicolon.diff: Delete.
  - patches.fixes/pci-quirk-enable-smbus-on-hp-xw4100.patch: Delete.
  - patches.kernel.org/patch-2.6.24.1: Delete.
  - patches.suse/acpi_dsdt_ssdt_initrd_initramfs.patch: Delete.
  - patches.suse/squashfs.patch.fixup: Delete.
  - patches.suse/aslr-pie-executable-randomization.patch: Delete.
  - patches.suse/aslr-i386-and-x86_64-randomize-brk.patch: Delete.
  - Xen and RT currently disabled.
  - SquashFS may not work.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: fixed and renabled check
* Fri Feb 22 2008 sdietrich@suse.de
- embargoed-patches: eliminate embargoed patches abuse.
* Fri Feb 22 2008 jeffm@suse.de
- scripts/embargo-filter: Disable check for non-existant patches.
* Fri Feb 22 2008 schwab@suse.de
- Update kdb patches.
* Fri Feb 22 2008 jbeulich@novell.com
- config/i386/xenpae: Rename to config/i386/xen.
- config.conf: Delete i386/xenpae.
* Thu Feb 21 2008 sdietrich@suse.de
- Update config files: update RT options for adaptive RT locks
* Thu Feb 21 2008 sdietrich@suse.de
- patches.rt/rtmutex-adaptive-mutexes.patch: cleanup.
- patches.rt/rtmutex-adaptive-timeout.patch: cleanup.
- patches.rt/rtmutex-lateral-steal-sysctl.patch: sysctl for
  runtime-control of lateral mutex stealing.
* Thu Feb 21 2008 jbeulich@novell.com
- Update Xen patches to c/s 425.
- patches.xen/sfc-network-driver: Solarflare: Standard network driver
  (disabled until status clarified).
- patches.xen/sfc-resource-driver: Solarflare: Resource driver
  (disabled until status clarified).
- Update Xen config files.
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v20
* Wed Feb 20 2008 ghaskins@suse.de
- adaptive-locking v19
* Wed Feb 20 2008 jeffm@suse.de
- Update config files for dmraid45.
* Wed Feb 20 2008 bwalle@suse.de
- rpm/kernel-binary.spec.in: add PAGESIZE detection for
  makedumpfile.config from the .config file also for PPC64
* Wed Feb 20 2008 fseidel@suse.de
- patches.fixes/bluetooth_hci_dev_put.patch,
  patches.fixes/bluetooth_hci_conn_childs.patch,
  patches.fixes/bluetooth_hci_unregister_sysfs.patch:
  fix kernel crash after removing bluetooth adapter (bnc 359546)
* Tue Feb 19 2008 jeffm@suse.de
- patches.suse/dm-raid45-2.6.24-20080602a.patch: DMRAID45 module.
* Fri Feb 15 2008 sdietrich@suse.de
- Update to latest patch set:
- patches.rt/rearrange_rtspinlock_sleep:
  [PATCH 02/10] rearrange rtspinlock sleep
- patches.rt/optimize_rtspinlock_wakeup:
  [PATCH 03/10] optimize rtspinlock wakeup
- patches.rt/adaptive_RT_spinlock_support:
  [PATCH 04/10] Adaptive RT spinlock support
- patches.rt/add_timeout_mechanism: [PATCH 05/10]
  add a loop counter based timeoutmechanism
- patches.rt/adaptive_mutexes: [PATCH 06/10] adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  [PATCH 07/10] Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: [PATCH 08/10]
  optimize the !printk fastpath throughthe lock acquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  [PATCH 09/10] remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: [PATCH 10/10] allow
  rt-mutex lock-stealing toinclude lateral priority
* Fri Feb 15 2008 sdietrich@suse.de
- embargoed-patches: (embargo development RT throughput patches)
- Update config files (RT config options)
- patches.rt/optimize_rtspinlock_wakeup: optimize rtspinlock
  wakeup.
- patches.rt/adaptive_RT_spinlock_support: Adaptive RT spinlock
  support.
- patches.rt/add_timeout_mechanism: add
  a loop counter based timeout mechanism
- patches.rt/adaptive_mutexes: adaptive mutexes
- patches.rt/adjust_pi_lock_usage_in_wakeup:
  Adjust pi_lock usage in wakeup
- patches.rt/optimize_printk_fastpath: optimize
  the !printk fastpath through the lockacquisition
- patches.rt/remove_extra_call_try_to_take_lock:
  remove the extra call to try_to_take_lock
- patches.rt/lateral_lock_steal: allow rt-mutex
  lock-stealing to include lateralpriority
- patches.rt/rearrange_rtspinlock_sleep: cleanup rtspinlock sleep
* Thu Feb 14 2008 jeffm@suse.de
- Removed unused OCFS2 patches.
* Thu Feb 14 2008 jeffm@suse.de
- Removed old commented out ocfs2 patchset.
* Thu Feb 14 2008 teheo@suse.de
- patches.drivers/libata-quirk_amd_ide_mode: PCI: modify SATA
  IDE mode quirk (345124).
* Wed Feb 13 2008 jeffm@suse.de
- patches.suse/ocfs2-03-split-disk-heartbeat-out.diff: Fixed
  section conflict.
* Wed Feb 13 2008 jeffm@suse.de
- Update config files.
* Wed Feb 13 2008 jeffm@suse.de
- Merged and re-enabled OCFS2 userspace clustering
* Wed Feb 13 2008 jdelvare@suse.de
- config/*: Don't build i2c algorithm drivers that we do not use.
- supported.conf: Drop i2c-elektor and i2c-algo-pcf, we don't ship
  them.
* Tue Feb 12 2008 teheo@suse.de
  Build fix for section mismatch check.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Mon Feb 11 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: Delete.
- patches.drivers/libata-implement-force-parameter: libata:
  implement libata.force module parameter (337610).
* Fri Feb  8 2008 gregkh@suse.de
- Update to 2.6.24.1
  - fixes CVE-2008-0007, CVE-2008-0009, CVE-2008-0010
  - lots of USB device ids updated
  - lots of other bugfixes
  - removed patches.fixes/bootstrap-memoryless-node.patch as it is now
    contained within.
* Fri Feb  8 2008 gregkh@suse.de
- Move ipv6-no-autoconf to xen directory as it is a Xen bugfix
* Fri Feb  8 2008 bwalle@suse.de
- patches.arch/ppc-fix-prpmc2800: remove patch since it's not needed
  with current binutils any more
* Fri Feb  8 2008 bwalle@suse.de
- patches.drivers/igb-2007-12-11: Delete.
- patches.drivers/igb-1.0.8-k2: Update to latest version which is
  also upstream now in the 2.6.25 tree.
* Fri Feb  8 2008 gregkh@suse.de
- Remove NO_BRP_NOEXECSTACK from the .spec files as it is obsolete
  and doesn't do anything anymore.
* Fri Feb  8 2008 jbeulich@novell.com
- patches.xen/xen3-auto-common.diff,
  patches.xen/xen3-patch-2.6.23: fix merge mistake.
* Fri Feb  8 2008 jbenc@suse.cz
- Update config files: disabled CONFIG_BCM43XX.
* Wed Feb  6 2008 jeffm@suse.de
- patches.apparmor/vfs-mkdir.diff: Added missing case in
  kernel/cgroup.c
* Wed Feb  6 2008 fseidel@suse.de
- updated patches.drivers/nozomi.patch: mainline info
* Wed Feb  6 2008 sdietrich@suse.de
- Update config files: RT@1KHz, sched groups & cpusets enabled.
* Wed Feb  6 2008 olh@suse.de
- enable bnx2 on ppc64 (bnc 359114 - LTC42106)
* Wed Feb  6 2008 gregkh@suse.de
- remove unused lockd patches:
  - patches.suse/lockd-switchable-statd
  - patches.suse/lockd-kernel-statd
  - patches.suse/lockd-suse-config
  - patches.suse/lockd-max-hosts-dynamic
* Tue Feb  5 2008 oneukum@suse.de
- patches.suse/usb_printer_no_auto.diff: Delete.
  Obsoleted by mainline change
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547) for RT kernels
* Tue Feb  5 2008 gregkh@suse.de
- Enable CONFIG_TASK_IO_ACCOUNTING (bnc 356547)
* Thu Jan 31 2008 sdietrich@suse.de
- patches.rt/megasas_IRQF_NODELAY.patch: Convert megaraid sas
  IRQ to non-threaded IRQ.
- patches.rt/version.patch: Delete (unused).
* Thu Jan 31 2008 jbenc@suse.cz
- patches.fixes/mac80211-fix-hw-scan1.patch,
  patches.fixes/mac80211-fix-hw-scan2.patch: mac80211: hardware
  scan rework (bnc#307050).
* Thu Jan 31 2008 sdietrich@suse.de
- Remove a legacy tweak carried over from the 10.3 Kernel,
  enable the affinity load-balancing sysctl.
* Wed Jan 30 2008 sdietrich@suse.de
- patches.rt/x86-ticket-lock.patch: FIFO ticket lock spinlocks
  for x86 (RT).
- patches.rt/rt-mutex-i386.patch: Resolve conflicts.
* Tue Jan 29 2008 olh@suse.de
- really skip kernel-ps3 in suse_kernel_module_package rpm macro
* Tue Jan 29 2008 jbeulich@novell.com
- Update Xen patches to 2.6.24 final and c/s 399.
- patches.xen/xen3-seccomp-disable-tsc-option: [PATCH seccomp:
  make tsc disabling optional (191123).
* Sat Jan 26 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rt1 (many patches in patches.rt refreshed).
- patches.rt/series: Delete (unused).
* Sat Jan 26 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  use struct device_attribute to fix oops on boot
* Fri Jan 25 2008 jeffm@suse.de
- scripts/sequence-patch.sh: Updated to include $EXTRA_SYMBOLS in
  $PATCH_DIR (e.g.: --symbol=RT creates linux-2.6.24-RT)
* Fri Jan 25 2008 jeffm@suse.de
- patches.rt/rcu-new-1.patch: Updated context against 2.6.24.
* Fri Jan 25 2008 olh@suse.de
- add patches.fixes/bootstrap-memoryless-node.patch
  slab: fix bootstrap on memoryless node
* Fri Jan 25 2008 gregkh@suse.de
- refresh allmost all patches to apply cleanly and have a proper
  diffstat (except for the xen patches, they were left alone...)
* Fri Jan 25 2008 gregkh@suse.de
- Update to 2.6.24
* Thu Jan 24 2008 olh@suse.de
- always skip kernel-ps3 in suse_kernel_module_package rpm macro
* Thu Jan 24 2008 sdietrich@suse.de
- Update config files: set SYSFS_DEPRECATED for reverse
  compatibility with SLERT
* Tue Jan 22 2008 olh@suse.de
- update patches.arch/ppc-efika-modalias.patch
  simplify patch
* Tue Jan 22 2008 agruen@suse.de
- patches.rpmify/cloneconfig.diff: Adjust to upstream i386 + x86_64
  merge (347712).
* Tue Jan 22 2008 sassmann@suse.de
- add defconfig for ps3 kernel
- add entry for ps3 defconfig in config.conf
- add support for kernels without loadable modules to rpm/kernel-binary.spec.in
- include ps3 target in scripts/tar-up_and_run_mbuild.sh
* Mon Jan 21 2008 sdietrich@suse.de
- Update config files (RT)
* Mon Jan 21 2008 sdietrich@suse.de
- Linux-RT 2.6.24-rc8-rt1
* Mon Jan 21 2008 olh@suse.de
- add patches.arch/ppc-pegasos-pata_via-fixup.patch
  call chrp_pci_fixup_vt8231_ata() later to allow pata_via usage
* Mon Jan 21 2008 aj@suse.de
- Remove unused config/s390/rt.
* Fri Jan 18 2008 jeffm@suse.de
- patches.rt/irq-flags-unsigned-long.patch: Delete.
* Fri Jan 18 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git2.
* Fri Jan 18 2008 jeffm@suse.de
- Enabled 2.6.24-rc8-git1.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: Delete. The patch
  is not correct, there exist two cards with different chipsets but
  the same USB ID.
* Fri Jan 18 2008 jbenc@suse.cz
- patches.fixes/rt2x00-remove-duplicate-id.patch: rt2x00: remove
  duplicate USB ID (350956).
* Fri Jan 18 2008 olh@suse.de
- sync powerpc vanilla with default .config to enable libata
* Fri Jan 18 2008 olh@suse.de
- add patches.arch/ppc-pegasos-mv643xx_eth-modalias.patch
  provide module alias platform:mv643xx_eth
* Thu Jan 17 2008 jeffm@suse.de
- Update to 2.6.24-rc8-git1.
* Wed Jan 16 2008 jeffm@suse.de
- Update to 2.6.24-rc8.
* Sun Jan 13 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git5.
* Fri Jan 11 2008 jeffm@suse.de
- Update to 2.6.24-rc7-git3.
* Fri Jan 11 2008 jbeulich@novell.com
- Update Xen patches to c/s 372 and 2.6.24-rc7.
- patches.xen/xen3-aux-at_vector_size.patch: Delete.
- Update Xen config files.
* Thu Jan 10 2008 olh@suse.de
- update patches.arch/ppc-efika-ethernet-phy.patch
  move Forth code to fixup_device_tree_efika
* Wed Jan  9 2008 schwab@suse.de
- Fix debug package build.
* Wed Jan  9 2008 oneukum@suse.de
- Update config files. CONFIG_USB_SUSPEND default
* Wed Jan  9 2008 schwab@suse.de
- Update kdb patches.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Another try...
* Wed Jan  9 2008 jeffm@suse.de
- Update config files: Enabled CONFIG_SCSI_SAS_ATA. (346990)
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: Fix CONFIG_FRAME_POINTER build.
* Wed Jan  9 2008 jbeulich@novell.com
- patches.suse/stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- patches.xen/xen3-stack-unwind: DWARF2 EH-frame based stack
  unwinding.
- Update config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: Fixed so it only applies
  to i386, and updated config files.
* Tue Jan  8 2008 jeffm@suse.de
- patches.fixes/seccomp-disable-tsc-option: [PATCH] seccomp:
  make tsc disabling optional (191123).
* Tue Jan  8 2008 olh@suse.de
- add patches.arch/ppc-efika-ethernet-phy.patch
  drop patches.arch/ppc-efika-bestcomm-ethernet.patch
  provide phy-handle property for fec_mpc52xx (347234)
* Tue Jan  8 2008 teheo@suse.de
- patches.drivers/libata-force-cable-type: libata: implement
  libata.force_cbl parameter (337610).
* Mon Jan  7 2008 jeffm@suse.de
- Update to 2.6.24-rc7.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-sata_nv-disable-ADMA: sata_nv: disable
  ADMA by default (346508).
* Mon Jan  7 2008 teheo@suse.de
  Bug 347708.  port_info for vmw was being assigned to the wrong index.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Mon Jan  7 2008 teheo@suse.de
  As the rest of kernel has caught up now, this one is no longer
  necessary.
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
* Mon Jan  7 2008 teheo@suse.de
- patches.drivers/libata-fix-up-build-after-upstream-update.patch:
  Delete.
- patches.drivers/libata-ata_piix-vmw-ign-DMA-err: ata_piix:
  ignore ATA_DMA_ERR on vmware ich4 (258256).
* Fri Jan  4 2008 jeffm@suse.de
- Update config files for -vanilla.
* Fri Jan  4 2008 jeffm@suse.de
- patches.rt/timer-freq-tweaks.patch: Adjusted context.
* Fri Jan  4 2008 jeffm@suse.de
- Update config files.
* Fri Jan  4 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git11.
* Wed Jan  2 2008 jblunck@suse.de
- rpm/kernel-binary.spec.in: Copy debug sources to a proper location.
* Tue Jan  1 2008 jeffm@suse.de
- Update to 2.6.24-rc6-git7.
* Tue Jan  1 2008 jeffm@suse.de
- scripts/run_oldconfig.sh: Removed RT symbol from EXTRA_SYMBOLS.
  We add it manually when building the patch list. This allows
  the script to work with the RT kernel without having to remove
  all the other configs from config.conf first.
